-- -*- mode: sql; sql-product: postgres; -*-

DROP TABLE IF EXISTS henry_notes   CASCADE;
DROP TABLE IF EXISTS henry         CASCADE;
DROP TABLE IF EXISTS species       CASCADE;
DROP TABLE IF EXISTS subcategories CASCADE;
DROP TABLE IF EXISTS categories    CASCADE;
DROP TABLE IF EXISTS notes         CASCADE;
DROP TABLE IF EXISTS literature    CASCADE;
CREATE TABLE notes (id SERIAL PRIMARY KEY,
    notelabel TEXT,
    noterefs  TEXT,
    notetext  TEXT);
CREATE TABLE literature (id SERIAL PRIMARY KEY,
    bibtexkey    TEXT,
    quotation    TEXT,
    bibliography TEXT,
    doi          TEXT);
CREATE TABLE categories (id SERIAL PRIMARY KEY,
    catname TEXT);
CREATE TABLE subcategories (id SERIAL PRIMARY KEY,
    subcatname TEXT,
    cat_id INT REFERENCES categories(id));
CREATE TABLE species (id SERIAL PRIMARY KEY,
    iupac    TEXT,
    formula  TEXT,
    trivial  TEXT,
    casrn    TEXT,
    inchikey TEXT,
    subcat_id INT REFERENCES subcategories(id));
CREATE TABLE henry (id SERIAL PRIMARY KEY,
    Hominus TEXT,
    mindHR  TEXT,
    htype   TEXT,
    species_id    INT REFERENCES species(id),
    literature_id INT REFERENCES literature(id));
CREATE TABLE henry_notes (id SERIAL,
    henry_id INT REFERENCES henry(id) ON UPDATE CASCADE,
    notes_id INT REFERENCES notes(id) ON UPDATE CASCADE,
    CONSTRAINT henry_notes_pkey PRIMARY KEY (henry_id, notes_id));

INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2291',
    'Abd-El-Bary et&nbsp;al. (1986)',
    'Abd-El-Bary, M. F., Hamoda, M. F., Tanisho, S., &#x0026; Wakao, N.: <span class="cmti-10">Henry&#x2019;s</span> <span class="cmti-10">constants for phenol over its diluted aqueous solution</span>, J. Chem. Eng. Data, 31, 229–230, <a href="https://doi.org/10.1021/JE00044A027" >doi:10.1021/JE00044A027</a> (1986). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3521',
    'Abney (2021)',
    'Abney, C. A.: Predicting Henry&#x2019;s Law constants of volatile organic compounds present in bourbon using molecular simulations, Master&#x2019;s thesis, University of Louisville, Kentucky, USA, <a href="https://doi.org/10.18297/etd/3440" >doi:10.18297/etd/3440</a> (2021). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3006',
    'Abou-Naccoul et&nbsp;al. (2014)',
    'Abou-Naccoul, R., Mokbel, I., Bassil, G., Saab, J., Stephan, K., &#x0026; Jose, J.: <span class="cmti-10">Aqueous solubility (in the range between 298.15 and 338.15 </span>K<span class="cmti-10">),</span> <span class="cmti-10">vapor pressures (in the range between </span>10<sup><span class="cmsy-7">−</span><span class="cmr-7">5</span></sup> <span class="cmti-10">and 80 Pa) and Henry&#x2019;s</span> <span class="cmti-10">law constant of 1,2,3,4-dibenzanthracene and 1,2,5,6-dibenzanthracene</span>, Chemosphere, 95, 41–49, <a href="https://doi.org/10.1016/J.CHEMOSPHERE.2013.08.010" >doi:10.1016/J.CHEMOSPHERE.2013.08.010</a> (2014). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2526',
    'Abraham et&nbsp;al. (2007)',
    'Abraham, M. A., Enomoto, K., Clarke, E. D., Rosés, M., Ràfols, C., &#x0026; Fuguet, E.: <span class="cmti-10">Henry&#x2019;s law constants or air to water partition coefficients</span> <span class="cmti-10">for 1,3,5-triazines by an LFER method</span>, J. Environ. Monit., 9, 234–239, <a href="https://doi.org/10.1039/B617181H" >doi:10.1039/B617181H</a> (2007). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2226',
    'Abraham (1979)',
    'Abraham, M. H.: <span class="cmti-10">Free energies of solution of rare</span> <span class="cmti-10">gases and alkanes in water and nonaqueous solvents. A quantitative</span> <span class="cmti-10">assessment of the hydrophobic effect</span>, J. Am. Chem. Soc., 101, 5477–5484, <a href="https://doi.org/10.1021/JA00513A004" >doi:10.1021/JA00513A004</a> (1979). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1497',
    'Abraham (1984)',
    'Abraham, M. H.: <span class="cmti-10">Thermodynamics of solution of</span> <span class="cmti-10">homologous series of solutes in water</span>, J. Chem. Soc. Faraday Trans. 1, 80, 153–181, <a href="https://doi.org/10.1039/F19848000153" >doi:10.1039/F19848000153</a> (1984). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3613',
    'Abraham (2003)',
    'Abraham, M. H.: <span class="cmti-10">The determination of air/water</span> <span class="cmti-10">partition coefficients for alkyl carboxylic acids by a new indirect method</span>, J. Environ. Monit., 5, 747–752, <a href="https://doi.org/10.1039/B308175C" >doi:10.1039/B308175C</a> (2003). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2580',
    'Abraham and Acree (2007)',
    'Abraham, M. H. &#x0026; Acree, Jr., W. E.: <span class="cmti-10">Prediction</span> <span class="cmti-10">of gas to water partition coefficients from 273 to 373 </span>K <span class="cmti-10">using predicted</span> <span class="cmti-10">enthalpies and heat capacities of hydration</span>, Fluid Phase Equilib., 262, 97–110, <a href="https://doi.org/10.1016/J.FLUID.2007.08.011" >doi:10.1016/J.FLUID.2007.08.011</a> (2007). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1498',
    'Abraham and Matteoli (1988)',
    'Abraham, M. H. &#x0026; Matteoli, E.: <span class="cmti-10">The</span> <span class="cmti-10">temperature variation of the hydrophobic effect</span>, J. Chem. Soc. Faraday Trans. 1, 84, 1985–2000, <a href="https://doi.org/10.1039/F19888401985" >doi:10.1039/F19888401985</a> (1988). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2225',
    'Abraham and Nasehzadeh (1981)',
    'Abraham, M. H. &#x0026; Nasehzadeh, A.: <span class="cmti-10">Thermodynamics of solution of gaseous tetramethyltin in 36 solvents.</span> <span class="cmti-10">Comparison of experimental results with cavity-theory calculations</span>, J. Chem. Soc. Faraday Trans. 1, 77, 321–339, <a href="https://doi.org/10.1039/F19817700321" >doi:10.1039/F19817700321</a> (1981). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3614',
    'Abraham and Weathersby (1994)',
    'Abraham, M. H. &#x0026; Weathersby, P. K.: <span class="cmti-10">Hydrogen bonding. 30. Solubility of gases and vapors in biological liquids</span> <span class="cmti-10">and tissues</span>, J. Pharm. Sci., 83, 1450–1456, <a href="https://doi.org/10.1002/JPS.2600831017" >doi:10.1002/JPS.2600831017</a> (1994). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1500',
    'Abraham et&nbsp;al. (1990)',
    'Abraham, M. H., Whiting, G. S., Fuchs, R., &#x0026; Chambers, E. J.: <span class="cmti-10">Thermodynamics</span> <span class="cmti-10">of solute transfer from water to hexadecane</span>, J. Chem. Soc. Perkin Trans. 2, pp. 291–300, <a href="https://doi.org/10.1039/P29900000291" >doi:10.1039/P29900000291</a> (1990). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1501',
    'Abraham et&nbsp;al. (1994a)',
    'Abraham, M. H., Andonian-Haftvan, J., Whiting, G. S., Leo, A., &#x0026; Taft, R. S.: <span class="cmti-10">Hydrogen bonding. Part 34. The factors that influence the</span> <span class="cmti-10">solubility of gases and vapours in water at 298 </span>K<span class="cmti-10">, and a new method</span> <span class="cmti-10">for its determination</span>, J. Chem. Soc. Perkin Trans. 2, pp. 1777–1791, <a href="https://doi.org/10.1039/P29940001777" >doi:10.1039/P29940001777</a> (1994a). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3072',
    'Abraham et&nbsp;al. (1994b)',
    'Abraham, M. H., Chadha, H. S., Whiting, G. S., &#x0026; Mitchell, R.: <span class="cmti-10">Hydrogen bonding. 32. An analysis of water-octanol and water-alkane</span> <span class="cmti-10">partitioning and the </span>Δlog <span class="cmmi-10">P </span><span class="cmti-10">parameter of Seiler</span>, J. Pharm. Sci., 83, 1085–1100, <a href="https://doi.org/10.1002/JPS.2600830806" >doi:10.1002/JPS.2600830806</a> (1994b). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2577',
    'Abraham et&nbsp;al. (2008)',
    'Abraham, M. H., Gil-Lostes, J., Acree, Jr., W. E., Cometto-Muñiz, J. E., &#x0026; Cain, W. S.: <span class="cmti-10">Solvation parameters for mercury and mercury(II)</span> <span class="cmti-10">compounds: calculation of properties of environmental interest</span>, J. Environ. Monit., 10, 435–442, <a href="https://doi.org/10.1039/B719685G" >doi:10.1039/B719685G</a> (2008). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3627',
    'Abraham et&nbsp;al. (2019)',
    'Abraham, M. H., Acree Jr., W. E., Hoekman, D., Leo, A. J., &#x0026; Medlin, M. L.: <span class="cmti-10">A new method for the determination of Henry&#x2019;s law constants</span> <span class="cmti-10">(air–water-partition coefficients)</span>, Fluid Phase Equilib., 502, 112 300, <a href="https://doi.org/10.1016/J.FLUID.2019.112300" >doi:10.1016/J.FLUID.2019.112300</a> (2019). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3939',
    'Abusallout et&nbsp;al. (2022)',
    'Abusallout, I., Holton, C., Wang, J., &#x0026; Hanigan, D.: <span class="cmti-10">Henry&#x2019;s</span> <span class="cmti-10">Law constants of 15 per- and polyfluoroalkyl substances determined</span> <span class="cmti-10">by static headspace analysis</span>, J. Hazard. Mater. Lett., 3, 100 070, <a href="https://doi.org/10.1016/J.HAZL.2022.100070" >doi:10.1016/J.HAZL.2022.100070</a> (2022). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3925',
    'Adams and Edmonds (1937)',
    'Adams, F. W. &#x0026; Edmonds, R. G.: <span class="cmti-10">Absorption</span> <span class="cmti-10">of chlorine by water in a packed tower</span>, Ind. Eng. Chem., 29, 447–451, <a href="https://doi.org/10.1021/IE50328A021" >doi:10.1021/IE50328A021</a> (1937). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3587',
    'Addison et&nbsp;al. (1983)',
    'Addison, R. F., Paterson, S., &#x0026; Mackay, D.: <span class="cmti-10">The predicted environmental</span> <span class="cmti-10">distribution of some PCB replacements</span>, Chemosphere, 12, 827–834, <a href="https://doi.org/10.1016/0045-6535(83)90148-0" >doi:10.1016/0045-6535(83)90148-0</a> (1983). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3535',
    'Aieta and Roberts (1986)',
    'Aieta, E. M. &#x0026; Roberts, P. V.: <span class="cmti-10">Henry constant of</span> <span class="cmti-10">molecular chlorine in aqueous solution</span>, J. Chem. Eng. Data, 31, 51–53, <a href="https://doi.org/10.1021/JE00043A017" >doi:10.1021/JE00043A017</a> (1986). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1597',
    'Alaee et&nbsp;al. (1996)',
    'Alaee, M., Whittal, R. M., &#x0026; Strachan, W. M. J.: <span class="cmti-10">The effect of water temperature and composition</span> <span class="cmti-10">on Henry&#x2019;s law constant for various PAH&#x2019;s</span>, Chemosphere, 32, 1153–1164, <a href="https://doi.org/10.1016/0045-6535(96)00031-8" >doi:10.1016/0045-6535(96)00031-8</a> (1996). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3946',
    'Albanese et&nbsp;al. (1987)',
    'Albanese, V., Milano, J. C., &#x0026; Vernet, J. L.: <span class="cmti-10">Etude de l&#x2019;evaporation de</span> <span class="cmti-10">quelques hydrocarbures halogenenes de faible masse moleculaire dissous</span> <span class="cmti-10">a l&#x2019;etat de traces dans l&#x2019;eau</span>, Environ. Technol. Lett., 8, 657–668, <a href="https://doi.org/10.1080/09593338709384529" >doi:10.1080/09593338709384529</a> (1987). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '985',
    'Allen et&nbsp;al. (1998)',
    'Allen, J. M., Balcavage, W. X., Ramachandran, B. R., &#x0026; Shrout, A. L.: <span class="cmti-10">Determination of Henry&#x2019;s Law constants by equilibrium partitioning in</span> <span class="cmti-10">a closed system using a new in situ optical absorbance method</span>, Environ. Toxicol. Chem., 17, 1216–1221, <a href="https://doi.org/10.1002/ETC.5620170704" >doi:10.1002/ETC.5620170704</a> (1998). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3696',
    'Allott et&nbsp;al. (1973)',
    'Allott, P. R., Steward, A., Flook, V., &#x0026; Mapleson, W. W.: <span class="cmti-10">Variation with temperature</span> <span class="cmti-10">of the solubilities of inhaled anaesthestics in water, oil and biological</span> <span class="cmti-10">media</span>, Br. J. Anaesth., 45, 294–300, <a href="https://doi.org/10.1093/BJA/45.3.294" >doi:10.1093/BJA/45.3.294</a> (1973). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2817',
    'Allou et&nbsp;al. (2011)',
    'Allou, L., El Maimouni, L., &#x0026; Le Calvé, S.: <span class="cmti-10">Henry&#x2019;s law constant</span> <span class="cmti-10">measurements for formaldehyde and benzaldehyde as a function of</span> <span class="cmti-10">temperature and water composition</span>, Atmos. Environ., 45, 2991–2998, <a href="https://doi.org/10.1016/J.ATMOSENV.2010.05.044" >doi:10.1016/J.ATMOSENV.2010.05.044</a> (2011). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3676',
    'Alton and Browne (2022)',
    'Alton, M. W. &#x0026; Browne, E. C.: <span class="cmti-10">Atmospheric degradation of cyclic volatile methyl</span> <span class="cmti-10">siloxanes: Radical chemistry and oxidation products</span>, ACS Environ. Au, 2, 263–274, <a href="https://doi.org/10.1021/ACSENVIRONAU.1C00043" >doi:10.1021/ACSENVIRONAU.1C00043</a> (2022). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1195',
    'Altschuh et&nbsp;al. (1999)',
    'Altschuh, J., Brüggemann, R., Santl, H., Eichinger, G., &#x0026; Piringer, O. G.: <span class="cmti-10">Henry&#x2019;s law constants for a diverse set of organic chemicals:</span> <span class="cmti-10">Experimental determination and comparison of estimation methods</span>, Chemosphere, 39, 1871–1887, <a href="https://doi.org/10.1016/S0045-6535(99)00082-X" >doi:10.1016/S0045-6535(99)00082-X</a> (1999). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '670',
    'Amels et&nbsp;al. (1996)',
    'Amels, P., Elias, H., Götz, U., Steingens, U., &#x0026; Wannowius, K. J.: <span class="cmti-10">Chapter 3.1: Kinetic investigation of the stability of peroxonitric acid</span> <span class="cmti-10">and of its reaction with sulfur(IV) in aqueous solution</span>, in: Heterogeneous and Liquid-Phase Processes, edited by Warneck, P., pp. 77–88, Springer Verlag, Berlin, <a href="https://doi.org/10.1007/978-3-642-61445-3_3" >doi:10.1007/978-3-642-61445-3_3</a> (1996). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3788',
    'Ammari and Schroen (2019)',
    'Ammari, A. &#x0026; Schroen, K.: <span class="cmti-10">Effect of ethanol</span> <span class="cmti-10">and temperature on partition coefficients of ethyl acetate, isoamyl acetate,</span> <span class="cmti-10">and isoamyl alcohol: Instrumental and predictive investigation</span>, J. Chem. Eng. Data, 64, 3224–3230, <a href="https://doi.org/10.1021/ACS.JCED.8B01125" >doi:10.1021/ACS.JCED.8B01125</a> (2019). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2388',
    'Amoore and Buttery (1978)',
    'Amoore, J. E. &#x0026; Buttery, R. G.: <span class="cmti-10">Partition</span> <span class="cmti-10">coefficient and comparative olfactometry</span>, Chem. Senses Flavour, 3, 57–71, <a href="https://doi.org/10.1093/CHEMSE/3.1.57" >doi:10.1093/CHEMSE/3.1.57</a> (1978). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3262',
    'Anderson (2011)',
    'Anderson, G. K.: <span class="cmti-10">A thermodynamic study of the</span> <span class="cmti-10">(difluoromethane + water) system</span>, J. Chem. Thermodyn., 43, 1331–1335, <a href="https://doi.org/10.1016/J.JCT.2011.03.020" >doi:10.1016/J.JCT.2011.03.020</a> (2011). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2983',
    'Anderson (1992)',
    'Anderson, M. A.: <span class="cmti-10">Influence of surfactants on vapor-liquid partitioning</span>, Environ. Sci. Technol., 26, 2186–2191, <a href="https://doi.org/10.1021/ES00035A017" >doi:10.1021/ES00035A017</a> (1992). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2820',
    'Andersson et&nbsp;al. (2008)',
    'Andersson, M. E., Gårdfeldt, K., Wängberg, I., &#x0026; Strömberg, D.: <span class="cmti-10">Determination of Henry&#x2019;s law constant for elemental mercury</span>, Chemosphere, 73, 587–592, <a href="https://doi.org/10.1016/J.CHEMOSPHERE.2008.05.067" >doi:10.1016/J.CHEMOSPHERE.2008.05.067</a> (2008). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '719',
    'Andon et&nbsp;al. (1954)',
    'Andon, R. J. L., Cox, J. D., &#x0026; Herington, E. F. G.: <span class="cmti-10">Phase relationships</span> <span class="cmti-10">in the pyridine series. Part V. The thermodynamic properties of dilute</span> <span class="cmti-10">solutions of pyridine bases in water at 25</span><span class="cmsy-7">∘</span> <span class="cmti-10">and 40</span><span class="cmsy-7">∘</span>, J. Chem. Soc., pp. 3188–3196, <a href="https://doi.org/10.1039/JR9540003188" >doi:10.1039/JR9540003188</a> (1954). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3590',
    'Andreozzi et&nbsp;al. (1996)',
    'Andreozzi, R., Caprio, V., Ermellino, I., Insola, A., &#x0026; Tufano, V.: <span class="cmti-10">Ozone</span> <span class="cmti-10">solubility in phosphate-buffered aqueous solutions: effect of temperature,</span> <span class="cmti-10">tert-butyl alcohol, and pH</span>, Ind. Eng. Chem. Res., 35, 1467–1471, <a href="https://doi.org/10.1021/IE940778R" >doi:10.1021/IE940778R</a> (1996). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1151',
    'Andrew and Hanson (1961)',
    'Andrew, S. P. S. &#x0026; Hanson, D.: <span class="cmti-10">The dynamics of nitrous gas absorption</span>, Chem. Eng. Sci., 14, 105–113, <a href="https://doi.org/10.1016/0009-2509(61)85060-4" >doi:10.1016/0009-2509(61)85060-4</a> (1961). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2371',
    'Aprea et&nbsp;al. (2007)',
    'Aprea, E., Biasioli, F., Märk, T. D., &#x0026; Gasperi, F.: <span class="cmti-10">PTR-MS study of esters in water and</span> <span class="cmti-10">water/ethanol</span> <span class="cmti-10">solutions: Fragmentation patterns and partition coefficients</span>, Int. J. Mass Spectrom., 262, 114–121, <a href="https://doi.org/10.1016/J.IJMS.2006.10.016" >doi:10.1016/J.IJMS.2006.10.016</a> (2007). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2481',
    'Arbuckle (1983)',
    'Arbuckle, W. B.: <span class="cmti-10">Estimating activity coefficients for use</span> <span class="cmti-10">in calculating environmental parameters</span>, Environ. Sci. Technol., 17, 537–542, <a href="https://doi.org/10.1021/ES00115A008" >doi:10.1021/ES00115A008</a> (1983). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '629',
    'Arijs and Brasseur (1986)',
    'Arijs, E. &#x0026; Brasseur, G.: <span class="cmti-10">Acetonitrile in the</span> <span class="cmti-10">stratosphere and implications for positive ion composition</span>, J. Geophys. Res., 91, 4003–4016, <a href="https://doi.org/10.1029/JD091ID03P04003" >doi:10.1029/JD091ID03P04003</a> (1986). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3942',
    'Arkadiev (1918)',
    'Arkadiev, V.: <span class="cmti-10">Solubility of chlorine in water</span>, J. Russ. Phys. Chem. Soc., 50, 205–209, (in Russian) (1918). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3073',
    'Armbrust (2000)',
    'Armbrust, K. L.: <span class="cmti-10">Pesticide hydroxyl radical rate constants: Measurements and estimates of</span> <span class="cmti-10">their importance in aquatic environments</span>, Environ. Toxicol. Chem., 19, 2175–2180, <a href="https://doi.org/10.1002/ETC.5620190905" >doi:10.1002/ETC.5620190905</a> (2000). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3562',
    'Armstrong et&nbsp;al. (2015)',
    'Armstrong, D. A., Huie, R. E., Koppenol, W. H., Lymar, S. V., Merényi, G., Neta, P., Ruscic, B., Stanbury, D. M., Steenken, S., &#x0026; Wardman, P.: <span class="cmti-10">Standard electrode potentials involving radicals in aqueous</span> <span class="cmti-10">solution: inorganic radicals (IUPAC Technical Report)</span>, Pure Appl. Chem., 87, 1139–1150, <a href="https://doi.org/10.1515/PAC-2014-0502" >doi:10.1515/PAC-2014-0502</a> (2015). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2378',
    'Arnett and Chawla (1979)',
    'Arnett, E. M. &#x0026; Chawla, B.: <span class="cmti-10">Complete thermodynamic analysis of the hydration of thirteen pyridines</span> <span class="cmti-10">and pyridinium ions. The special case of 2,6-di-tert-butylpyridine</span>, J. Am. Chem. Soc., 101, 7141–7146, <a href="https://doi.org/10.1021/JA00518A001" >doi:10.1021/JA00518A001</a> (1979). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2386',
    'Arnett et&nbsp;al. (1977)',
    'Arnett, E. M., Chawla, B., Bell, L., Taagepera, M., Hehre, W. J., &#x0026; Taft, R. W.: <span class="cmti-10">Solvation and hydrogen bonding of pyridinium ions</span>, J. Am. Chem. Soc., 99, 5729–5738, <a href="https://doi.org/10.1021/JA00459A034" >doi:10.1021/JA00459A034</a> (1977). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2646',
    'Arp and Schmidt (2004)',
    'Arp, H. P. H. &#x0026; Schmidt, T. C.: <span class="cmti-10">Air–water transfer</span> <span class="cmti-10">of MTBE, its degradation products, and alternative fuel oxygenates:</span> <span class="cmti-10">the role of temperature</span>, Environ. Sci. Technol., 38, 5405–5412, <a href="https://doi.org/10.1021/ES049286O" >doi:10.1021/ES049286O</a> (2004). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2992',
    'Arp et&nbsp;al. (2006)',
    'Arp, H. P. H., Niederer, C., &#x0026; Goss, K. U.: <span class="cmti-10">Predicting the partitioning behavior of various</span> <span class="cmti-10">highly fluorinated compounds</span>, Environ. Sci. Technol., 40, 7298–7304, <a href="https://doi.org/10.1021/ES060744Y" >doi:10.1021/ES060744Y</a> (2006). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2831',
    'Ashton et&nbsp;al. (1968)',
    'Ashton, J. T., Dawe, R. A., Miller, K. W., Smith, E. B., &#x0026; Stickings, B. J.: <span class="cmti-10">The solubility of certain gaseous fluorine compounds in water</span>, J. Chem. Soc. A, pp. 1793–1796, <a href="https://doi.org/10.1039/J19680001793" >doi:10.1039/J19680001793</a> (1968). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1156',
    'Ashworth et&nbsp;al. (1988)',
    'Ashworth, R. A., Howe, G. B., Mullins, M. E., &#x0026; Rogers, T. N.: <span class="cmti-10">Air–water</span> <span class="cmti-10">partitioning coefficients of organics in dilute aqueous solutions</span>, J. Hazard. Mater., 18, 25–36, <a href="https://doi.org/10.1016/0304-3894(88)85057-X" >doi:10.1016/0304-3894(88)85057-X</a> (1988). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1926',
    'Atlas et&nbsp;al. (1982)',
    'Atlas, E., Foster, R., &#x0026; Giam, C. S.: <span class="cmti-10">Air-sea exchange of high-molecular</span> <span class="cmti-10">weight organic pollutants: laboratory studies</span>, Environ. Sci. Technol., 16, 283–286, <a href="https://doi.org/10.1021/ES00099A010" >doi:10.1021/ES00099A010</a> (1982). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2533',
    'Atlas et&nbsp;al. (1983)',
    'Atlas, E., Velasco, A., Sullivan, K., &#x0026; Giam, C. S.: <span class="cmti-10">A radiotracer study of air–water</span> <span class="cmti-10">exchange of synthetic organic compounds</span>, Chemosphere, 12, 1251–1258, <a href="https://doi.org/10.1016/0045-6535(83)90130-3" >doi:10.1016/0045-6535(83)90130-3</a> (1983). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1076',
    'Ayers (1983)',
    'Ayers, G. P.: <span class="cmti-10">Equilibrium</span> <span class="cmti-10">partial pressures over</span> (NH<sub><span class="cmr-7">4</span></sub>)<sub><span class="cmr-7">2</span></sub>SO<sub><span class="cmr-7">4</span></sub><span class="cmti-10">/</span>H<sub><span class="cmr-7">2</span></sub>SO<sub><span class="cmr-7">4</span></sub> <span class="cmti-10">mixtures</span>, Aust. J. Chem., 36, 179–182, <a href="https://doi.org/10.1071/CH9830179" >doi:10.1071/CH9830179</a> (1983). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '201',
    'Ayers et&nbsp;al. (1980)',
    'Ayers, G. P., Gillett, R. W., &#x0026; Gras, J. L.: <span class="cmti-10">On the vapor pressure of sulfuric acid</span>, Geophys. Res. Lett., 7, 433–436, <a href="https://doi.org/10.1029/GL007I006P00433" >doi:10.1029/GL007I006P00433</a> (1980). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2969',
    'Ayuttaya et&nbsp;al. (2001)',
    'Ayuttaya, P. C. N., Rogers, T. N., Mullins, M. E., &#x0026; Kline, A. A.: <span class="cmti-10">Henry&#x2019;s law constants derived from equilibrium static cell measurements</span> <span class="cmti-10">for dilute organic-water mixtures</span>, Fluid Phase Equilib., 185, 359–377, <a href="https://doi.org/10.1016/S0378-3812(01)00484-8" >doi:10.1016/S0378-3812(01)00484-8</a> (2001). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3697',
    'Bachofen and Farhi (1971)',
    'Bachofen, H. &#x0026; Farhi, L. E.: <span class="cmti-10">Simple manometric</span> <span class="cmti-10">apparatus for measuring partition coefficients of highly soluble gases</span>, J. Appl. Physiol., 30, 136–139, <a href="https://doi.org/10.1152/JAPPL.1971.30.1.136" >doi:10.1152/JAPPL.1971.30.1.136</a> (1971). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3771',
    'Badia et&nbsp;al. (2019)',
    'Badia, A., Reeves, C. E., Baker, A. R., Saiz-Lopez, A., Volkamer, R., Koenig, T. K., Apel, E. C., Hornbrook, R. S., Carpenter, L. J., Andrews, S. J., Sherwen, T., &#x0026; von Glasow, R.: <span class="cmti-10">Importance</span> <span class="cmti-10">of reactive halogens in the tropical marine atmosphere: a regional</span> <span class="cmti-10">modelling study using WRF-Chem</span>, Atmos. Chem. Phys., 19, 3161–3189, <a href="https://doi.org/10.5194/ACP-19-3161-2019" >doi:10.5194/ACP-19-3161-2019</a> (2019). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2016',
    'Bagno et&nbsp;al. (1991)',
    'Bagno, A., Lucchini, V., &#x0026; Scorrano, G.: <span class="cmti-10">Thermodynamics of protonation of ketones and esters</span> <span class="cmti-10">and energies of hydration of their conjugate acids</span>, J. Phys. Chem., 95, 345–352, <a href="https://doi.org/10.1021/J100154A063" >doi:10.1021/J100154A063</a> (1991). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3938',
    'Bakhuis Roozeboom (1884)',
    'Bakhuis Roozeboom, H. W.: <span class="cmti-10">Sur l&#x2019;hydrate de chlore</span>, Recl. Trav. Chim. Pays-Bas, 3, 59–72, <a href="https://doi.org/10.1002/RECL.18840030203" >doi:10.1002/RECL.18840030203</a> (1884). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2923',
    'Bakierowska and Trzeszczyński (2003)',
    'Bakierowska, A.-M. &#x0026; Trzeszczyński, J.: <span class="cmti-10">Graphical method for the determination of water/gas partition</span> <span class="cmti-10">coefficients of volatile organic compounds by a headspace gas</span> <span class="cmti-10">chromatography technique</span>, Fluid Phase Equilib., 213, 139–146, <a href="https://doi.org/10.1016/S0378-3812(03)00286-3" >doi:10.1016/S0378-3812(03)00286-3</a> (2003). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2952',
    'Balls (1980)',
    'Balls, P. W.: Gas transfer across air–water interfaces, Ph.D. thesis, University of East Anglia, Great Britain (1980). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2974',
    'Ballschmiter and Wittlinger (1991)',
    'Ballschmiter, K. &#x0026; Wittlinger, R.: <span class="cmti-10">Interhemisphere exchange of hexachlorocyclohexanes, hexachlorobenzene,</span> <span class="cmti-10">polychlorobiphenyls, and 1,1,1-trichloro-2,2-bis(p-chlorophenyl)ethane</span> <span class="cmti-10">in the lower troposphere</span>, Environ. Sci. Technol., 25, 1103–1111, <a href="https://doi.org/10.1021/ES00018A014" >doi:10.1021/ES00018A014</a> (1991). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2477',
    'Bamford et&nbsp;al. (1999a)',
    'Bamford, H. A., Poster, D. L., &#x0026; Baker, J. E.: <span class="cmti-10">Temperature dependence of Henry&#x2019;s law constants</span> <span class="cmti-10">of thirteen polycyclic aromatic hydrocarbons between 4</span><span class="cmsy-7">∘</span>C <span class="cmti-10">and 31</span><span class="cmsy-7">∘</span>C, Environ. Toxicol. Chem., 18, 1905–1912, <a href="https://doi.org/10.1002/ETC.5620180906" >doi:10.1002/ETC.5620180906</a> (1999a). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2914',
    'Bamford et&nbsp;al. (1999b)',
    'Bamford, H. A., Poster, D. L., &#x0026; Baker, J. E.: <span class="cmti-10">Method for measuring the temperature dependence</span> <span class="cmti-10">of the Henry&#x2019;s law constant of selected polycyclic aromatic hydrocarbons</span>, Polycyclic Aromat. Compd., 14, 11–22, <a href="https://doi.org/10.1080/10406639908019107" >doi:10.1080/10406639908019107</a> (1999b). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2340',
    'Bamford et&nbsp;al. (2000)',
    'Bamford, H. A., Poster, D. L., &#x0026; Baker, J. E.: <span class="cmti-10">Henry&#x2019;s law constants of polychlorinated biphenyl</span> <span class="cmti-10">congeners and their variation with temperature</span>, J. Chem. Eng. Data, 45, 1069–1074, <a href="https://doi.org/10.1021/JE0000266" >doi:10.1021/JE0000266</a> (2000). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2472',
    'Bamford et&nbsp;al. (2002)',
    'Bamford, H. A., Poster, D. L., Huie, R. E., &#x0026; Baker, J. E.: <span class="cmti-10">Using</span> <span class="cmti-10">extrathermodynamic relationships to model the temperature dependence</span> <span class="cmti-10">of Henry&#x2019;s law constants of 209 PCB congeners</span>, Environ. Sci. Technol., 36, 4395–4402, <a href="https://doi.org/10.1021/ES020599Y" >doi:10.1021/ES020599Y</a> (2002). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1773',
    'Barcellos da Rosa et&nbsp;al. (2003)',
    'Barcellos da Rosa, M., Behnke, W., &#x0026; Zetzsch, C.: <span class="cmti-10">Study</span> <span class="cmti-10">of the heterogeneous reaction of</span> O<sub><span class="cmr-7">3</span></sub> <span class="cmti-10">with</span> CH<sub><span class="cmr-7">3</span></sub>SCH<sub><span class="cmr-7">3</span></sub> <span class="cmti-10">using the</span> <span class="cmti-10">wetted-wall flowtube technique</span>, Atmos. Chem. Phys., 3, 1665–1673, <a href="https://doi.org/10.5194/ACP-3-1665-2003" >doi:10.5194/ACP-3-1665-2003</a> (2003). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    'barcelo97',
    'Barcelo and Hennion (1997)',
    'Barcelo, D. &#x0026; Hennion, M. C.: Trace Determination of Pesticides and Their Degradation Products in Water, Elsevier Science, Amsterdam, ISBN 9780444818423 (1997). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1147',
    'Barr and Newsham (1987)',
    'Barr, R. S. &#x0026; Newsham, D. M. T.: <span class="cmti-10">Phase</span> <span class="cmti-10">equilibria in very dilute mixtures of water and chlorinated hydrocarbons.</span> <span class="cmti-10">Part I. Experimental results</span>, Fluid Phase Equilib., 35, 189–205, <a href="https://doi.org/10.1016/0378-3812(87)80012-2" >doi:10.1016/0378-3812(87)80012-2</a> (1987). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2928',
    'Barrett et&nbsp;al. (1988)',
    'Barrett, T. J., Anderson, G. M., &#x0026; Lugowski, J.: <span class="cmti-10">The solubility of hydrogen sulphide</span> <span class="cmti-10">in 0–5m NaCl solutions at 25</span><span class="cmsy-7">∘</span><span class="cmti-10">-95</span><span class="cmsy-7">∘</span>C <span class="cmti-10">and one atmosphere</span>, Geochim. Cosmochim. Acta, 52, 807–811, <a href="https://doi.org/10.1016/0016-7037(88)90352-3" >doi:10.1016/0016-7037(88)90352-3</a> (1988). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3393',
    'Bartelt-Hunt et&nbsp;al. (2008)',
    'Bartelt-Hunt, S. L., Knappe, D. R. U., &#x0026; Barlaz, M. A.: <span class="cmti-10">A review of chemical warfare</span> <span class="cmti-10">agent simulants for the study of environmental behavior</span>, Crit. Rev. Environ. Sci. Technol., 38, 112–136, <a href="https://doi.org/10.1080/10643380701643650" >doi:10.1080/10643380701643650</a> (2008). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1038',
    'Bartlett and Margerum (1999)',
    'Bartlett, W. P. &#x0026; Margerum, D. W.: <span class="cmti-10">Temperature dependencies of the Henry&#x2019;s law constant and the aqueous</span> <span class="cmti-10">phase dissociation constant of bromine chloride</span>, Environ. Sci. Technol., 33, 3410–3414, <a href="https://doi.org/10.1021/ES990300K" >doi:10.1021/ES990300K</a> (1999). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3853',
    'Battino (1981)',
    'Battino, R.: IUPAC Solubility Data Series, Volume 7, Oxygen and Ozone, Pergamon Press, Oxford, <a href="https://doi.org/10.1016/C2013-0-03145-3" >doi:10.1016/C2013-0-03145-3</a> (1981). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3856',
    'Battino (1982)',
    'Battino, R.: IUPAC Solubility Data Series, Volume 10, Nitrogen and Air, Pergamon Press, Oxford, ISBN 0080239226 (1982). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2413',
    'Battino and Clever (1966)',
    'Battino, R. &#x0026; Clever, H. L.: <span class="cmti-10">The solubility of</span> <span class="cmti-10">gases in liquids</span>, Chem. Rev., 66, 395–463, <a href="https://doi.org/10.1021/CR60242A003" >doi:10.1021/CR60242A003</a> (1966). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2301',
    'Battino et&nbsp;al. (1983)',
    'Battino, R., Rettich, T. R., &#x0026; Tominaga, T.: <span class="cmti-10">The solubility of oxygen and ozone in liquids</span>, J. Phys. Chem. Ref. Data, 12, 163–178, <a href="https://doi.org/10.1063/1.555680" >doi:10.1063/1.555680</a> (1983). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2433',
    'Battino et&nbsp;al. (1984)',
    'Battino, R., Rettich, T. R., &#x0026; Tominaga, T.: <span class="cmti-10">The solubility of nitrogen and air in liquids</span>, J. Phys. Chem. Ref. Data, 13, 563–600, <a href="https://doi.org/10.1063/1.555713" >doi:10.1063/1.555713</a> (1984). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3407',
    'Battino et&nbsp;al. (2018)',
    'Battino, R., Rettich, T. R., &#x0026; Wilhelm, E.: <span class="cmti-10">Gas solubilities in liquid water near the</span> <span class="cmti-10">temperature of the density maximum, </span><span class="cmmi-10">T</span><sub><span class="cmr-7">max</span></sub><span class="cmti-10">(</span>H<sub><span class="cmr-7">2</span></sub>O<span class="cmti-10">) = 277.13K</span>, Monatsh. Chem. – Chem. Mon., 149, 219–230, <a href="https://doi.org/10.1007/S00706-017-2097-3" >doi:10.1007/S00706-017-2097-3</a> (2018). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2963',
    'Bebahani et&nbsp;al. (2002)',
    'Bebahani, G. R. R., Hogan, P., &#x0026; Waghorne, W. E.: <span class="cmti-10">Ostwald concentration</span> <span class="cmti-10">coefficients of acetonitrile in aqueous mixed solvents: a new, rapid method</span> <span class="cmti-10">for measuring the solubilities of volatile solutes</span>, J. Chem. Eng. Data, 47, 1290–1292, <a href="https://doi.org/10.1021/JE0200665" >doi:10.1021/JE0200665</a> (2002). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '625',
    'Becker et&nbsp;al. (1996)',
    'Becker, K. H., Kleffmann, J., Kurtenbach, R., &#x0026; Wiesen, P.: <span class="cmti-10">Solubility</span> <span class="cmti-10">of nitrous acid (</span>HONO<span class="cmti-10">) in sulfuric acid solutions</span>, J. Phys. Chem., 100, 14 984–14 990, <a href="https://doi.org/10.1021/JP961140R" >doi:10.1021/JP961140R</a> (1996). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1056',
    'Becker et&nbsp;al. (1998)',
    'Becker, K. H., Kleffmann, J., Negri, R. M., &#x0026; Wiesen, P.: <span class="cmti-10">Solubility of nitrous</span> <span class="cmti-10">acid (</span>HONO<span class="cmti-10">) in ammonium sulfate solutions</span>, J. Chem. Soc. Faraday Trans., 94, 1583–1586, <a href="https://doi.org/10.1039/A800458G" >doi:10.1039/A800458G</a> (1998). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '536',
    'Behnke et&nbsp;al. (1997)',
    'Behnke, W., George, C., Scheer, V., &#x0026; Zetzsch, C.: <span class="cmti-10">Production and decay of</span> ClNO<sub><span class="cmr-7">2</span></sub> <span class="cmti-10">from the reaction of gaseous</span> N<sub><span class="cmr-7">2</span></sub>O<sub><span class="cmr-7">5</span></sub> <span class="cmti-10">with</span> NaCl <span class="cmti-10">solution: Bulk and aerosol</span> <span class="cmti-10">experiments</span>, J. Geophys. Res., 102, 3795–3804, <a href="https://doi.org/10.1029/96JD03057" >doi:10.1029/96JD03057</a> (1997). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '821',
    'Beilke and Gravenhorst (1978)',
    'Beilke, S. &#x0026; Gravenhorst, G.: <span class="cmti-10">Heterogeneous</span> SO<sub><span class="cmr-7">2</span></sub><span class="cmti-10">-oxidation in the droplet phase</span>, Atmos. Environ., 12, 231–239, <a href="https://doi.org/10.1016/0004-6981(78)90203-2" >doi:10.1016/0004-6981(78)90203-2</a> (1978). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    'bell66',
    'Bell (1966)',
    'Bell, R. P.: <span class="cmti-10">The reversible hydration of carbonyl compounds</span>, Adv. Phys. Org. Chem., 4, 1–29, <a href="https://doi.org/10.1016/S0065-3160(08)60351-2" >doi:10.1016/S0065-3160(08)60351-2</a> (1966). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3734',
    'Ben-Naim and Battino (1985)',
    'Ben-Naim, A. &#x0026; Battino, R.: <span class="cmti-10">Solubilization of</span> <span class="cmti-10">methane, ethane, propane and </span><span class="cmmi-10">n</span><span class="cmti-10">-butane in aqueous solutions of sodium</span> <span class="cmti-10">dodecylsulfate</span>, J. Solution Chem., 14, 245–253, <a href="https://doi.org/10.1007/BF00644456" >doi:10.1007/BF00644456</a> (1985). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2219',
    'Ben-Naim and Wilf (1980)',
    'Ben-Naim, A. &#x0026; Wilf, J.: <span class="cmti-10">Solubilities and</span> <span class="cmti-10">hydrophobic interactions in aqueous solutions of monoalkylbenzene</span> <span class="cmti-10">molecules</span>, J. Phys. Chem., 84, 583–586, <a href="https://doi.org/10.1021/J100443A004" >doi:10.1021/J100443A004</a> (1980). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1996',
    'Beneš and Dohnal (1999)',
    'Beneš, M. &#x0026; Dohnal, V.: <span class="cmti-10">Limiting activity</span> <span class="cmti-10">coefficients of some aromatic and aliphatic nitro compounds in water</span>, J. Chem. Eng. Data, 44, 1097–1102, <a href="https://doi.org/10.1021/JE9900326" >doi:10.1021/JE9900326</a> (1999). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '617',
    'Benkelberg et&nbsp;al. (1995)',
    'Benkelberg, H.-J., Hamm, S., &#x0026; Warneck, P.: <span class="cmti-10">Henry&#x2019;s law coefficients for aqueous</span> <span class="cmti-10">solutions of acetone, acetaldehyde and acetonitrile, and equilibrium</span> <span class="cmti-10">constants for the addition compounds of acetone and acetaldehyde with</span> <span class="cmti-10">bisulfite</span>, J. Atmos. Chem., 20, 17–34, <a href="https://doi.org/10.1007/BF01099916" >doi:10.1007/BF01099916</a> (1995). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2437',
    'Benson et&nbsp;al. (1979)',
    'Benson, B. B., Krause, Jr., D., &#x0026; Peterson, M. A.: <span class="cmti-10">The solubility and isotopic fractionation of</span> <span class="cmti-10">gases in dilute aqueous solution. I. oxygen</span>, J. Solution Chem., 8, 655–690, <a href="https://doi.org/10.1007/BF01033696" >doi:10.1007/BF01033696</a> (1979). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '763',
    'Berdnikov and Bazhin (1970)',
    'Berdnikov, V. M. &#x0026; Bazhin, N. M.: <span class="cmti-10">Oxidation-reduction potentials of certain inorganic radicals in aqueous</span> <span class="cmti-10">solutions</span>, Russ. J. Phys. Chem., 44, 395–398 (1970). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2601',
    'Bernauer and Dohnal (2008)',
    'Bernauer, M. &#x0026; Dohnal, V.: <span class="cmti-10">Temperature</span> <span class="cmti-10">dependence of air–water partitioning of </span>N<span class="cmti-10">-methylated (</span>C1 <span class="cmti-10">and</span> C2<span class="cmti-10">) fatty</span> <span class="cmti-10">acid amides</span>, J. Chem. Eng. Data, 53, 2622–2631, <a href="https://doi.org/10.1021/JE800517R" >doi:10.1021/JE800517R</a> (2008). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2826',
    'Bernauer and Dohnal (2009)',
    'Bernauer, M. &#x0026; Dohnal, V.: <span class="cmti-10">Temperature</span> <span class="cmti-10">dependences of limiting activity coefficients and Henry&#x2019;s law constants</span> <span class="cmti-10">for N-methylpyrrolidone, pyridine, and piperidine in water</span>, Fluid Phase Equilib., 282, 100–107, <a href="https://doi.org/10.1016/J.FLUID.2009.05.005" >doi:10.1016/J.FLUID.2009.05.005</a> (2009). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2123',
    'Bernauer et&nbsp;al. (2006)',
    'Bernauer, M., Dohnal, V., Roux, A. H., Roux-Desgranges, G., &#x0026; Majer, V.: <span class="cmti-10">Temperature dependences of limiting activity coefficients and Henry&#x2019;s</span> <span class="cmti-10">law constants for nitrobenzene, aniline, and cyclohexylamine in water</span>, J. Chem. Eng. Data, 51, 1678–1685, <a href="https://doi.org/10.1021/JE060136Y" >doi:10.1021/JE060136Y</a> (2006). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '495',
    'Betterton (1991)',
    'Betterton, E. A.: <span class="cmti-10">The partitioning of ketones between</span> <span class="cmti-10">the gas and aqueous phases</span>, Atmos. Environ., 25A, 1473–1477, <a href="https://doi.org/10.1016/0960-1686(91)90006-S" >doi:10.1016/0960-1686(91)90006-S</a> (1991). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '510',
    'Betterton (1992)',
    'Betterton, E. A.: <span class="cmti-10">Henry&#x2019;s law constants of soluble and</span> <span class="cmti-10">moderately soluble organic gases: Effects on aqueous phase chemistry</span>, Adv. Environ. Sci. Technol., 24, 1–50 (1992). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '484',
    'Betterton and Hoffmann (1988)',
    'Betterton, E. A. &#x0026; Hoffmann, M. R.: <span class="cmti-10">Henry&#x2019;s law constants of some environmentally important aldehydes</span>, Environ. Sci. Technol., 22, 1415–1418, <a href="https://doi.org/10.1021/ES00177A004" >doi:10.1021/ES00177A004</a> (1988). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2806',
    'Betterton and Robinson (1997)',
    'Betterton, E. A. &#x0026; Robinson, J. L.: <span class="cmti-10">Henry&#x2019;s</span> <span class="cmti-10">law coefficient of hydrazoic acid</span>, J. Air Waste Manage. Assoc., 47, 1216–1219, <a href="https://doi.org/10.1080/10473289.1997.10464060" >doi:10.1080/10473289.1997.10464060</a> (1997). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3802',
    'Bettin and Spieweck (1990)',
    'Bettin, H. &#x0026; Spieweck, F.: <span class="cmti-10">Die</span> <span class="cmti-10">Dichte des Wassers als Funktion der Temperatur</span> <span class="cmti-10">nach Einf</span><span class="cmti-10">ührung der Internationalen Temperaturskala</span> <span class="cmti-10">von 1990</span>, PTB-Mitteilungen, 100, 195–196, URL https://www.ptb.de/cms/fileadmin/internet/publikationen/ptb_mitteilungen/mitt_pdf_vor_2007/1990/PTB-Mitteilungen_3_1990.pdf (1990). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3424',
    'Bhangare et&nbsp;al. (2019)',
    'Bhangare, R. C., Ajmal, P. Y., Rathod, T. D., Tiwari, M., &#x0026; Sahu, S. K.: <span class="cmti-10">Experimental and theoretical determination of Henry&#x2019;s law</span> <span class="cmti-10">constant for polychlorinated biphenyls: its dependence on solubility and</span> <span class="cmti-10">degree of chlorination</span>, Arch. Environ. Contam. Toxicol., 76, 142–152, <a href="https://doi.org/10.1007/S00244-018-0577-Z" >doi:10.1007/S00244-018-0577-Z</a> (2019). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2522',
    'Bierwagen and Keller (2001)',
    'Bierwagen, B. G. &#x0026; Keller, A. A.: <span class="cmti-10">Measurement of Henry&#x2019;s law constant</span> <span class="cmti-10">for methyl tert-butyl ether using solid-phase microextraction</span>, Environ. Toxicol. Chem., 20, 1625–1629, <a href="https://doi.org/10.1002/ETC.5620200802" >doi:10.1002/ETC.5620200802</a> (2001). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3967',
    'Bigorgne (1947)',
    'Bigorgne, M.: <span class="cmti-10">Formation de chlorites </span><span class="cmti-10">à partir de peroxyde</span> <span class="cmti-10">de chlore et de m</span><span class="cmti-10">étaux</span>, C. R. Hebd. Séances Acad. Sci., 225, 527–529 (1947). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3747',
    'Billitzer (1902)',
    'Billitzer, J.: <span class="cmti-10">Über die saure Natur des Acetylens</span>, Z. Phys. Chem., 40, 535–544, <a href="https://doi.org/10.1515/ZPCH-1902-4026" >doi:10.1515/ZPCH-1902-4026</a> (1902). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3589',
    'Biń (2005)',
    'Biń, A. K.: <span class="cmti-10">Ozone solubility in liquids</span>, Ozone: Sci. Eng., 28, 67–75, <a href="https://doi.org/10.1080/01919510600558635" >doi:10.1080/01919510600558635</a> (2005). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2270',
    'Bissonette et&nbsp;al. (1990)',
    'Bissonette, E. M., Westrick, J. J., &#x0026; Morand, J. M.: <span class="cmti-10">Determination of Henry&#x2019;s</span> <span class="cmti-10">coefficient for volatile organic compounds in dilute aqueous systems</span>, in: Proceedings of the Annual Conference of the American Water Works Association, Cincinnati, OH, June 17–21, pp. 1913–1922 (1990). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '486',
    'Blair and Ledbury (1925)',
    'Blair, E. W. &#x0026; Ledbury, W.: <span class="cmti-10">The partial</span> <span class="cmti-10">formaldehyde vapour pressures of aqueous solutions of formaldehyde.</span> <span class="cmti-10">Part I</span>, J. Chem. Soc., 127, 26–40, <a href="https://doi.org/10.1039/CT9252700026" >doi:10.1039/CT9252700026</a> (1925). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '288',
    'Blatchley et&nbsp;al. (1992)',
    'Blatchley, III, E. R., Johnson, R. W., Alleman, J. E., &#x0026; McCoy, W. F.: <span class="cmti-10">Effective</span> <span class="cmti-10">Henry&#x2019;s law constants for free chlorine and free bromine</span>, Wat. Res., 26, 99–106, <a href="https://doi.org/10.1016/0043-1354(92)90117-M" >doi:10.1016/0043-1354(92)90117-M</a> (1992). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2899',
    'Bobadilla et&nbsp;al. (2003)',
    'Bobadilla, R., Huybrechts, T., Dewulf, J., &#x0026; van Langenhove, H.: <span class="cmti-10">Determination of the Henry&#x2019;s constant of volatile and semi-volatile</span> <span class="cmti-10">organic componuds of environmental concern by the bas (batch air</span> <span class="cmti-10">stripping) technique: a new mathematical approach</span>, J. Chilean Chem. Soc., 48, <a href="https://doi.org/10.4067/S0717-97072003000300001" >doi:10.4067/S0717-97072003000300001</a> (2003). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3110',
    'Bobra et&nbsp;al. (1985)',
    'Bobra, A., Shiu, W. Y., &#x0026; Mackay, D.: <span class="cmti-10">Quantitative structure-activity relationships for the acute</span> <span class="cmti-10">toxicity of chlorobenzenes to daphnia magna</span>, Environ. Toxicol. Chem., 4, 297–305, <a href="https://doi.org/10.1002/ETC.5620040305" >doi:10.1002/ETC.5620040305</a> (1985). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2552',
    'Boggs and Buck (1958)',
    'Boggs, J. E. &#x0026; Buck, Jr., A. E.: <span class="cmti-10">The solubility</span> <span class="cmti-10">of some chloromethanes in water</span>, J. Phys. Chem., 62, 1459–1461, <a href="https://doi.org/10.1021/J150569A031" >doi:10.1021/J150569A031</a> (1958). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3302',
    'Böhme et&nbsp;al. (2008)',
    'Böhme, A., Paschke, A., Vrbka, P., Dohnal, V., &#x0026; Schüürmann, G.: <span class="cmti-10">Determination of temperature-dependent Henry&#x2019;s law constant of four</span> <span class="cmti-10">oxygenated solutes in water using headspace solid-phase microextraction</span> <span class="cmti-10">technique</span>, J. Chem. Eng. Data, 53, 2873–2877, <a href="https://doi.org/10.1021/JE800623X" >doi:10.1021/JE800623X</a> (2008). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '790',
    'Bohon and Claussen (1951)',
    'Bohon, R. J. &#x0026; Claussen, W. F.: <span class="cmti-10">The solubility</span> <span class="cmti-10">of aromatic hydrocarbons in water</span>, J. Am. Chem. Soc., 73, 1571–1578, <a href="https://doi.org/10.1021/JA01148A047" >doi:10.1021/JA01148A047</a> (1951). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2841',
    'Bohr (1899)',
    'Bohr, C.: <span class="cmti-10">Definition und Methode zur Bestimmung der Invasions- und</span> <span class="cmti-10">Evasionscoefficienten bei der Aufl</span><span class="cmti-10">ösung von Gasen in Fl</span><span class="cmti-10">üssigkeiten.</span> <span class="cmti-10">Werthe der genannten Constanten sowie der Absorptionscoefficienten</span> <span class="cmti-10">der Kohlens</span><span class="cmti-10">äure bei Aufl</span><span class="cmti-10">ösung in Wasser und in Chlornatriuml</span><span class="cmti-10">ösungen</span>, Wied. Ann., 68, 500–525, <a href="https://doi.org/10.1002/ANDP.18993040707" >doi:10.1002/ANDP.18993040707</a> (1899). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3713',
    'Bohr and Bock (1891)',
    'Bohr, C. &#x0026; Bock, J.: <span class="cmti-10">Bestimmung der Absorption</span> <span class="cmti-10">einiger Gase in Wasser bei den Temperaturen zwischen 0 und 100</span><span class="cmsy-7">∘</span>, Ann. Phys., 280, 318–343, <a href="https://doi.org/10.1002/ANDP.18912801010" >doi:10.1002/ANDP.18912801010</a> (1891). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '641',
    'Bone et&nbsp;al. (1983)',
    'Bone, R., Cullis, P., &#x0026; Wolfenden, R.: <span class="cmti-10">Solvent effects on equilibria of addition of nucleophiles to</span> <span class="cmti-10">acetaldehyde and the hydrophilic character of diols</span>, J. Am. Chem. Soc., 105, 1339–1343, <a href="https://doi.org/10.1021/JA00343A044" >doi:10.1021/JA00343A044</a> (1983). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2610',
    'Bonifácio et&nbsp;al. (2001)',
    'Bonifácio, R. P., Pádua, A. A. H., &#x0026; Costa Gomes, M. F.: <span class="cmti-10">Perfluoroalkanes in</span> <span class="cmti-10">water: experimental Henry&#x2019;s law coefficients for hexafluoroethane and</span> <span class="cmti-10">computer simulations for tetrafluoromethane and hexafluoroethane</span>, J. Phys. Chem. B, 105, 8403–8409, <a href="https://doi.org/10.1021/JP010597K" >doi:10.1021/JP010597K</a> (2001). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2835',
    'Booth and Jolley (1943)',
    'Booth, N. &#x0026; Jolley, L. J.: <span class="cmti-10">The removal of organic</span> <span class="cmti-10">sulphur compounds from gases</span>, J. Soc. Chem. Ind., 62, 87–88, <a href="https://doi.org/10.1002/JCTB.5000620603" >doi:10.1002/JCTB.5000620603</a> (1943). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3794',
    'Bopp (1983)',
    'Bopp, R. F.: <span class="cmti-10">Revised parameters for modeling the transport</span> <span class="cmti-10">of PCB components across an air water interface</span>, J. Geophys. Res., 88, 2521–2529, <a href="https://doi.org/10.1029/JC088IC04P02521" >doi:10.1029/JC088IC04P02521</a> (1983). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3411',
    'Borduas et&nbsp;al. (2016)',
    'Borduas, N., Place, B., Wentworth, G. R., Abbatt, J. P. D., &#x0026; Murphy, J. G.: <span class="cmti-10">Solubility and reactivity of HNCO in water: insights</span> <span class="cmti-10">into HNCO&#x2019;s fate in the atmosphere</span>, Atmos. Chem. Phys., 16, 703–714, <a href="https://doi.org/10.5194/ACP-16-703-2016" >doi:10.5194/ACP-16-703-2016</a> (2016). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '619',
    'Bowden et&nbsp;al. (1996)',
    'Bowden, D. J., Clegg, S. L., &#x0026; Brimblecombe, P.: <span class="cmti-10">The Henry&#x2019;s law constant of</span> <span class="cmti-10">trifluoroacetic acid</span> <span class="cmti-10">and its partitioning into liquid water in the atmosphere</span>, Chemosphere, 32, 405–420, <a href="https://doi.org/10.1016/0045-6535(95)00330-4" >doi:10.1016/0045-6535(95)00330-4</a> (1996). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '896',
    'Bowden et&nbsp;al. (1998a)',
    'Bowden, D. J., Clegg, S. L., &#x0026; Brimblecombe, P.: <span class="cmti-10">The Henry&#x2019;s law</span> <span class="cmti-10">constants of the haloacetic acids</span>, J. Atmos. Chem., 29, 85–107, <a href="https://doi.org/10.1023/A:1005899813756" >doi:10.1023/A:1005899813756</a> (1998a). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '992',
    'Bowden et&nbsp;al. (1998b)',
    'Bowden, D. J., Clegg, S. L., &#x0026; Brimblecombe, P.: <span class="cmti-10">The Henry&#x2019;s law</span> <span class="cmti-10">constant of trichloroacetic acid</span>, Water Air Soil Pollut., 101, 197–215, <a href="https://doi.org/10.1023/A:1004966126770" >doi:10.1023/A:1004966126770</a> (1998b). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3790',
    'Brandsch et&nbsp;al. (1993)',
    'Brandsch, R., Gruber, L., &#x0026; Santl, H.: <span class="cmti-10">Experimental determination of Henry&#x2019;s law constant for</span> <span class="cmti-10">some dioxins</span>, Organohalogen Compd., 12, 369–372 (1993). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2570',
    'Braun and Dransfeld (1989)',
    'Braun, H. &#x0026; Dransfeld, P.: <span class="cmti-10">Abscheidung von</span> <span class="cmti-10">Quecksilber</span>, GVC/VDI-Tagung “Entsorgung von Sonderabfällen durch Verbrennung”, Baden-Baden, 4–6 Dec 1989 (1989). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3795',
    'Braun (1900)',
    'Braun, L.: <span class="cmti-10">Über die Absorption von Stickstoff und von</span> <span class="cmti-10">Wasserstoff in w</span><span class="cmti-10">ässerigen L</span><span class="cmti-10">ösungen verschieden dissociierter Stoffe</span>, Z. Phys. Chem., 33U, 721–739, <a href="https://doi.org/10.1515/ZPCH-1900-3349" >doi:10.1515/ZPCH-1900-3349</a> (1900). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2241',
    'Breiter et&nbsp;al. (1998)',
    'Breiter, W. A., Baker, J. M., &#x0026; Koskinen, W. C.: <span class="cmti-10">Direct measurement of Henry&#x2019;s constant</span> <span class="cmti-10">for S-ethyl N,N-di-n-propylthiocarbamate</span>, J. Agric. Food Chem., 46, 1624–1629, <a href="https://doi.org/10.1021/JF980042V" >doi:10.1021/JF980042V</a> (1998). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1064',
    'Brennan et&nbsp;al. (1998)',
    'Brennan, R. A., Nirmalakhandan, N., &#x0026; Speece, R. E.: <span class="cmti-10">Comparison of predictive</span> <span class="cmti-10">methods for Henrys law coefficients of organic chemicals</span>, Wat. Res., 32, 1901–1911, <a href="https://doi.org/10.1016/S0043-1354(97)00402-8" >doi:10.1016/S0043-1354(97)00402-8</a> (1998). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '750',
    'Brian et&nbsp;al. (1962)',
    'Brian, P. L. T., Vivian, J. E., &#x0026; Habib, A. G.: <span class="cmti-10">The effect of the hydrolysis reaction upon the</span> <span class="cmti-10">rate of absorption of chlorine into water</span>, AIChE J., 8, 205–209, <a href="https://doi.org/10.1002/AIC.690080215" >doi:10.1002/AIC.690080215</a> (1962). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '695',
    'Brimblecombe (1986)',
    'Brimblecombe, P.: Air Composition &#x0026; Chemistry, Cambridge University Press, Cambridge, ISBN 0521459729 (1986). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '260',
    'Brimblecombe and Clegg (1988)',
    'Brimblecombe, P. &#x0026; Clegg, S. L.: <span class="cmti-10">The</span> <span class="cmti-10">solubility and behaviour of acid gases in the marine aerosol</span>, J. Atmos. Chem., 7, 1–18, <a href="https://doi.org/10.1007/BF00048251" >doi:10.1007/BF00048251</a> (1988). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '530',
    'Brimblecombe and Clegg (1989)',
    'Brimblecombe, P. &#x0026; Clegg, S. L.: <span class="cmti-10">Erratum</span>, J. Atmos. Chem., 8, 95, <a href="https://doi.org/10.1007/BF00053818" >doi:10.1007/BF00053818</a> (1989). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2231',
    'Brimblecombe et&nbsp;al. (1992)',
    'Brimblecombe, P., Clegg, S. L., &#x0026; Khan, I.: <span class="cmti-10">Thermodynamic properties</span> <span class="cmti-10">of carboxylic acids relevant to their solubility in aqueous solutions</span>, J. Aerosol Sci., 23, S901–S904, <a href="https://doi.org/10.1016/0021-8502(92)90557-C" >doi:10.1016/0021-8502(92)90557-C</a> (1992). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '528',
    'Briner and Perrottet (1939)',
    'Briner, E. &#x0026; Perrottet, E.: <span class="cmti-10">D</span><span class="cmti-10">étermination des</span> <span class="cmti-10">solubilit</span><span class="cmti-10">és de l&#x2019;ozone dans l&#x2019;eau et dans une solution aqueuse de chlorure</span> <span class="cmti-10">de sodium; calcul des solubilit</span><span class="cmti-10">és de l&#x2019;ozone atmosph</span><span class="cmti-10">érique dans les eaux</span>, Helv. Chim. Acta, 22, 397–404, <a href="https://doi.org/10.1002/HLCA.19390220151" >doi:10.1002/HLCA.19390220151</a> (1939). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3518',
    'Brockbank (2013)',
    'Brockbank, S. A.: Aqueous Henry&#x2019;s law constants, infinite dilution activity coefficients, and water solubility: critically evaluated database, experimental analysis, and prediction methods, Ph.D. thesis, Brigham Young University, USA, URL https://scholarsarchive.byu.edu/etd/3691/ (2013). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2926',
    'Brockbank et&nbsp;al. (2013)',
    'Brockbank, S. A., Russon, J. L., Giles, N. F., Rowley, R. L., &#x0026; Wilding, W. V.: <span class="cmti-10">Infinite dilution activity coefficients and Henry&#x2019;s law constants</span> <span class="cmti-10">of compounds in water using the inert gas stripping method</span>, Fluid Phase Equilib., 348, 45–51, <a href="https://doi.org/10.1016/J.FLUID.2013.03.023" >doi:10.1016/J.FLUID.2013.03.023</a> (2013). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3698',
    'Brody et&nbsp;al. (1971)',
    'Brody, A. W., Lyons, K. P., Kurowski, J. L., McGill, J. J., &#x0026; Weaver, M. J.: <span class="cmti-10">Analysis and solubility of dimethyl and diethyl ether</span> <span class="cmti-10">in water, saline, oils, and blood</span>, J. Appl. Physiol., 31, 125–131, <a href="https://doi.org/10.1152/JAPPL.1971.31.1.125" >doi:10.1152/JAPPL.1971.31.1.125</a> (1971). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2981',
    'Brown and Wasik (1974)',
    'Brown, R. L. &#x0026; Wasik, S. P.: <span class="cmti-10">A method of</span> <span class="cmti-10">measuring the solubilities of hydrocarbons in aqueous solutions</span>, J. Res. Natl. Bureau Standards A: Phys. Chem., 78A, 453–460, <a href="https://doi.org/10.6028/JRES.078A.028" >doi:10.6028/JRES.078A.028</a> (1974). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3793',
    'Brownawell (1986)',
    'Brownawell, B. J.: The role of colloidal organic matter in the marine geochemistry of PCBs, Ph.D. thesis, Massachusetts Institute of Technology and the Woods Hole Oceanographic Institution, <a href="https://doi.org/10.1575/1912/3932" >doi:10.1575/1912/3932</a> (1986). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3508',
    'Bruneel et&nbsp;al. (2016)',
    'Bruneel, J., Walgraeve, C., Van Huffel, K., &#x0026; Van Langenhove, H.: <span class="cmti-10">Determination of the gas-to-liquid partitioning coefficients using a new</span> <span class="cmti-10">dynamic absorption method (DynAb method)</span>, Chem. Eng. J., 283, 544–552, <a href="https://doi.org/10.1016/J.CEJ.2015.07.053" >doi:10.1016/J.CEJ.2015.07.053</a> (2016). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1194',
    'Brunner et&nbsp;al. (1990)',
    'Brunner, S., Hornung, E., Santl, H., Wolff, E., Piringer, O. G., Altschuh, J., &#x0026; Brüggemann, R.: <span class="cmti-10">Henry&#x2019;s law constants</span> <span class="cmti-10">for polychlorinated biphenyls: Experimental determination and</span> <span class="cmti-10">structure-property relationships</span>, Environ. Sci. Technol., 24, 1751–1754, <a href="https://doi.org/10.1021/ES00081A021" >doi:10.1021/ES00081A021</a> (1990). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1775',
    'Bu and Warner (1995)',
    'Bu, X. &#x0026; Warner, M. J.: <span class="cmti-10">Solubility</span> <span class="cmti-10">of chlorofluorocarbon 113 in water and seawater</span>, Deep-Sea Res. I, 42, 1151–1161, <a href="https://doi.org/10.1016/0967-0637(95)00052-8" >doi:10.1016/0967-0637(95)00052-8</a> (1995). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3803',
    'Buck (1981)',
    'Buck, A. L.: <span class="cmti-10">New equations for computing vapor pressure</span> <span class="cmti-10">and enhancement factor</span>, J. Appl. Meteorol. Clim., 20, 1527–1532, <a href="https://doi.org/10.1175/1520-0450(1981)020<1527:NEFCVP>2.0.CO;2" >doi:10.1175/1520-0450(1981)020<1527:NEFCVP>2.0.CO;2</a> (1981). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3571',
    'Bullister and Wisegarver (1998)',
    'Bullister, J. L. &#x0026; Wisegarver, D. P.: <span class="cmti-10">The</span> <span class="cmti-10">solubility of carbon tetrachloride in water and seawater</span>, Deep-Sea Res. I, 45, 1285–1302, <a href="https://doi.org/10.1016/S0967-0637(98)00017-X" >doi:10.1016/S0967-0637(98)00017-X</a> (1998). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1776',
    'Bullister et&nbsp;al. (2002)',
    'Bullister, J. L., Wisegarver, D. P., &#x0026; Menzia, F. A.: <span class="cmti-10">The solubility of</span> <span class="cmti-10">sulfur hexafluoride in water and seawater</span>, Deep-Sea Res. I, 49, 175–187, <a href="https://doi.org/10.1016/S0967-0637(01)00051-6" >doi:10.1016/S0967-0637(01)00051-6</a> (2002). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3717',
    'Bunsen (1855a)',
    'Bunsen, R.: <span class="cmti-10">Ueber das Gesetz der Gasabsorption</span>, Liebigs Ann. Chem., 93, 1–50, <a href="https://doi.org/10.1002/JLAC.18550930102" >doi:10.1002/JLAC.18550930102</a> (1855a). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3927',
    'Bunsen (1855b)',
    'Bunsen, R.: <span class="cmti-10">XV. On the law of absorption of gases</span>, Philos. Mag., 9, 116–130, <a href="https://doi.org/10.1080/14786445508641836" >doi:10.1080/14786445508641836</a> (1855b). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3930',
    'Bunsen (1855c)',
    'Bunsen, R.: <span class="cmti-10">XXVII. On the law of absorption of gases</span>, Philos. Mag., 9, 181–201, <a href="https://doi.org/10.1080/14786445508641851" >doi:10.1080/14786445508641851</a> (1855c). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '850',
    'Burkhard et&nbsp;al. (1985)',
    'Burkhard, L. P., Armstrong, D. E., &#x0026; Andren, A. W.: <span class="cmti-10">Henry&#x2019;s law constants for</span> <span class="cmti-10">the polychlorinated biphenyls</span>, Environ. Sci. Technol., 19, 590–596, <a href="https://doi.org/10.1021/ES00137A002" >doi:10.1021/ES00137A002</a> (1985). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2968',
    'Burkhard and Guth (1981)',
    'Burkhard, N. &#x0026; Guth, J. A.: <span class="cmti-10">Rate of volatilisation of pesticides from soil surfaces; comparison</span> <span class="cmti-10">of calculated results with those determined in a laboratory model system</span>, Pestic. Sci., 12, 37–44, <a href="https://doi.org/10.1002/PS.2780120106" >doi:10.1002/PS.2780120106</a> (1981). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3245',
    'Burkholder et&nbsp;al. (2015)',
    'Burkholder, J. B., Sander, S. P., Abbatt, J., Barker, J. R., Huie, R. E., Kolb, C. E., Kurylo, M. J., Orkin, V. L., Wilmouth, D. M., &#x0026; Wine, P. H.: <span class="cmti-10">Chemical Kinetics and Photochemical Data for Use in</span> <span class="cmti-10">Atmospheric Studies, Evaluation No. 18</span>, JPL Publication 15-10, Jet Propulsion Laboratory, Pasadena, URL https://jpldataeval.jpl.nasa.gov (2015). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3500',
    'Burkholder et&nbsp;al. (2019)',
    'Burkholder, J. B., Sander, S. P., Abbatt, J., Barker, J. R., Cappa, C., Crounse, J. D., Dibble, T. S., Huie, R. E., Kolb, C. E., Kurylo, M. J., Orkin, V. L., Percival, C. J., Wilmouth, D. M., &#x0026; Wine, P. H.: <span class="cmti-10">Chemical Kinetics and Photochemical Data for Use in Atmospheric</span> <span class="cmti-10">Studies, Evaluation No. 19</span>, JPL Publication 19-5, Jet Propulsion Laboratory, Pasadena, URL https://jpldataeval.jpl.nasa.gov (2019). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '496',
    'Burnett (1963)',
    'Burnett, M. G.: <span class="cmti-10">Determination of partition coefficients at</span> <span class="cmti-10">infinite dilution by the gas chromatographic analysis of the vapor above</span> <span class="cmti-10">dilute solutions</span>, Anal. Chem., 35, 1567–1570, <a href="https://doi.org/10.1021/AC60204A007" >doi:10.1021/AC60204A007</a> (1963). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '713',
    'Butler and Ramchandani (1935)',
    'Butler, J. A. V. &#x0026; Ramchandani, C. N.: <span class="cmti-10">The solubility of non-electrolytes. Part II. The influence of the polar</span> <span class="cmti-10">group on the free energy of hydration of aliphatic compounds</span>, J. Chem. Soc., pp. 952–955, <a href="https://doi.org/10.1039/JR9350000952" >doi:10.1039/JR9350000952</a> (1935). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '711',
    'Butler et&nbsp;al. (1933)',
    'Butler, J. A. V., Thomson, D. W., &#x0026; Maclennan, W. H.: <span class="cmti-10">The free</span> <span class="cmti-10">energy of the normal aliphatic alcohols in aqueous solution. Part I.</span> <span class="cmti-10">The partial vapour pressures of aqueous solutions of methyl, </span><span class="cmmi-10">n</span><span class="cmti-10">-propyl,</span> <span class="cmti-10">and </span><span class="cmmi-10">n</span><span class="cmti-10">-butyl alcohols. Part II. The solubilities of some normal aliphatic</span> <span class="cmti-10">alcohols in water. Part III. The theory of binary solutions, and its</span> <span class="cmti-10">application to aqueous-alcoholic solutions</span>, J. Chem. Soc., pp. 674–686, <a href="https://doi.org/10.1039/JR9330000674" >doi:10.1039/JR9330000674</a> (1933). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '712',
    'Butler et&nbsp;al. (1935)',
    'Butler, J. A. V., Ramchandani, C. N., &#x0026; Thomson, D. W.: <span class="cmti-10">The solubility of</span> <span class="cmti-10">non-electrolytes. Part I. The free energy of hydration of some aliphatic</span> <span class="cmti-10">alcohols</span>, J. Chem. Soc., pp. 280–285, <a href="https://doi.org/10.1039/JR9350000280" >doi:10.1039/JR9350000280</a> (1935). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3075',
    'Buttery et&nbsp;al. (1965)',
    'Buttery, R. G., Guadagni, D. G., &#x0026; Okano, S.: <span class="cmti-10">Air–water partition</span> <span class="cmti-10">coefficients of some aldehydes</span>, J. Sci. Food Agric., 16, 691–692, <a href="https://doi.org/10.1002/JSFA.2740161110" >doi:10.1002/JSFA.2740161110</a> (1965). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '754',
    'Buttery et&nbsp;al. (1969)',
    'Buttery, R. G., Ling, L. C., &#x0026; Guadagni, D. G.: <span class="cmti-10">Volatilities of aldehydes, ketones, and</span> <span class="cmti-10">esters in dilute water solutions</span>, J. Agric. Food Chem., 17, 385–389, <a href="https://doi.org/10.1021/JF60162A025" >doi:10.1021/JF60162A025</a> (1969). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '755',
    'Buttery et&nbsp;al. (1971)',
    'Buttery, R. G., Bomben, J. L., Guadagni, D. G., &#x0026; Ling, L. C.: <span class="cmti-10">Some considerations of</span> <span class="cmti-10">volatilities of organic flavor compounds in foods</span>, J. Agric. Food Chem., 19, 1045–1048, <a href="https://doi.org/10.1021/JF60178A004" >doi:10.1021/JF60178A004</a> (1971). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '722',
    'Cabani et&nbsp;al. (1971a)',
    'Cabani, S., Conti, G., &#x0026; Lepori, L.: <span class="cmti-10">Thermodynamic study on aqueous dilute solutions of organic</span> <span class="cmti-10">compounds. Part 1. – Cyclic amines</span>, Trans. Faraday Soc., 67, 1933–1942, <a href="https://doi.org/10.1039/TF9716701933" >doi:10.1039/TF9716701933</a> (1971a). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '723',
    'Cabani et&nbsp;al. (1971b)',
    'Cabani, S., Conti, G., &#x0026; Lepori, L.: <span class="cmti-10">Thermodynamic study on aqueous dilute solutions of organic</span> <span class="cmti-10">compounds. Part 2. – Cyclic ethers</span>, Trans. Faraday Soc., 67, 1943–1950, <a href="https://doi.org/10.1039/TF9716701943" >doi:10.1039/TF9716701943</a> (1971b). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2376',
    'Cabani et&nbsp;al. (1975a)',
    'Cabani, S., Conti, G., Giannessi, D., &#x0026; Lepori, L.: <span class="cmti-10">Thermodynamic</span> <span class="cmti-10">study of aqueous dilute solutions of organic compounds. Part 3. –</span> <span class="cmti-10">Morpholines and piperazines</span>, J. Chem. Soc. Faraday Trans. 1, 71, 1154–1160, <a href="https://doi.org/10.1039/F19757101154" >doi:10.1039/F19757101154</a> (1975a). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2377',
    'Cabani et&nbsp;al. (1975b)',
    'Cabani, S., Conti, G., Mollica, V., &#x0026; Lepori, L.: <span class="cmti-10">Thermodynamic study of dilute aqueous</span> <span class="cmti-10">solutions of organic compounds. Part 4. – Cyclic and straight chain</span> <span class="cmti-10">secondary alcohols</span>, J. Chem. Soc. Faraday Trans. 1, 71, 1943–1952, <a href="https://doi.org/10.1039/F19757101943" >doi:10.1039/F19757101943</a> (1975b). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2381',
    'Cabani et&nbsp;al. (1978)',
    'Cabani, S., Mollica, V., &#x0026; Lepori, L.: <span class="cmti-10">Thermodynamic study of dilute aqueous solutions of organic</span> <span class="cmti-10">compounds. Part 5. – Open-chain saturated bifunctional compounds</span>, J. Chem. Soc. Faraday Trans. 1, 74, 2667–2671, <a href="https://doi.org/10.1039/F19787402667" >doi:10.1039/F19787402667</a> (1978). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1910',
    'Cabani et&nbsp;al. (1981)',
    'Cabani, S., Gianni, P., Mollica, V., &#x0026; Lepori, L.: <span class="cmti-10">Group contributions to the thermodynamic</span> <span class="cmti-10">properties of non-ionic organic solutes in dilute aqueous solution</span>, J. Solution Chem., 10, 563–595, <a href="https://doi.org/10.1007/BF00646936" >doi:10.1007/BF00646936</a> (1981). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2203',
    'Cady and Misra (1974)',
    'Cady, G. H. &#x0026; Misra, S.: <span class="cmti-10">Hydrolysis of sulfuryl</span> <span class="cmti-10">fluoride</span>, Inorg. Chem., 13, 837–841, <a href="https://doi.org/10.1021/IC50134A016" >doi:10.1021/IC50134A016</a> (1974). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3548',
    'Cady et&nbsp;al. (1922)',
    'Cady, H. P., Elsey, H. M., &#x0026; Berger, E. V.: <span class="cmti-10">The solubility of helium in water</span>, J. Am. Chem. Soc., 44, 1456–1461, <a href="https://doi.org/10.1021/JA01428A009" >doi:10.1021/JA01428A009</a> (1922). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2977',
    'Calamari et&nbsp;al. (1991)',
    'Calamari, D., Bacci, E., Focardi, S., Gaggi, C., Morosini, M., &#x0026; Vighi, M.: <span class="cmti-10">Role of plant biomass in the global environmental partitioning</span> <span class="cmti-10">of chlorinated hydrocarbons</span>, Environ. Sci. Technol., 25, 1489–1495, <a href="https://doi.org/10.1021/ES00020A020" >doi:10.1021/ES00020A020</a> (1991). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3866',
    'Cargill (1990)',
    'Cargill, R. W.: IUPAC Solubility Data Series, Volume 43, Carbon Monoxide, Pergamon Press, Oxford, <a href="https://doi.org/10.1016/C2009-0-01228-8" >doi:10.1016/C2009-0-01228-8</a> (1990). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3708',
    'Carius (1855)',
    'Carius, L.: <span class="cmti-10">Absorptiometrische Untersuchungen</span>, Liebigs Ann. Chem., 94, 129–166, <a href="https://doi.org/10.1002/JLAC.18550940202" >doi:10.1002/JLAC.18550940202</a> (1855). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2976',
    'Caron et&nbsp;al. (1985)',
    'Caron, G., Suffet, I. H., &#x0026; Belton, T.: <span class="cmti-10">Effect of dissolved organic carbon on the environmental</span> <span class="cmti-10">distribution of nonpolar organic compounds</span>, Chemosphere, 14, 993–1000, <a href="https://doi.org/10.1016/0045-6535(85)90020-7" >doi:10.1016/0045-6535(85)90020-7</a> (1985). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '525',
    'Carpenter (1966)',
    'Carpenter, J. H.: <span class="cmti-10">New measurements of oxygen solubility</span> <span class="cmti-10">in pure and natural water</span>, Limnol. Oceanogr., 11, 264–277, <a href="https://doi.org/10.4319/LO.1966.11.2.0264" >doi:10.4319/LO.1966.11.2.0264</a> (1966). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '615',
    'Carroll and Mather (1989)',
    'Carroll, J. J. &#x0026; Mather, A. E.: <span class="cmti-10">The solubility of</span> <span class="cmti-10">hydrogen sulphide</span> <span class="cmti-10">in water from 0 to 90</span><span class="cmsy-7">∘</span>C <span class="cmti-10">and pressures to 1</span> MPa, Geochim. Cosmochim. Acta, 53, 1163–1170, <a href="https://doi.org/10.1016/0016-7037(89)90053-7" >doi:10.1016/0016-7037(89)90053-7</a> (1989). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '631',
    'Carroll et&nbsp;al. (1991)',
    'Carroll, J. J., Slupsky, J. D., &#x0026; Mather, A. E.: <span class="cmti-10">The solubility of carbon dioxide in water at low</span> <span class="cmti-10">pressure</span>, J. Phys. Chem. Ref. Data, 20, 1201–1209, <a href="https://doi.org/10.1063/1.555900" >doi:10.1063/1.555900</a> (1991). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3124',
    'Carroll et&nbsp;al. (1997)',
    'Carroll, J. J., Jou, F.-Y., &#x0026; Mather, A. E.: <span class="cmti-10">Fluid phase equilibria in the system </span><span class="cmmi-10">n</span><span class="cmti-10">-butane + water</span>, Fluid Phase Equilib., 140, 157–169, <a href="https://doi.org/10.1016/S0378-3812(97)00199-4" >doi:10.1016/S0378-3812(97)00199-4</a> (1997). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2840',
    'Carslaw et&nbsp;al. (1995)',
    'Carslaw, K. S., Clegg, S. L., &#x0026; Brimblecombe, P.: <span class="cmti-10">A thermodynamic model of the</span> <span class="cmti-10">system</span> HCl<span class="cmti-10">-</span>HNO<sub><span class="cmr-7">3</span></sub><span class="cmti-10">-</span>H<sub><span class="cmr-7">2</span></sub>SO<sub><span class="cmr-7">4</span></sub><span class="cmti-10">-</span>H<sub><span class="cmr-7">2</span></sub>O<span class="cmti-10">, including solubilities of</span> HBr<span class="cmti-10">, from </span><span class="cmmi-10">&#x003C;</span><span class="cmti-10">200</span> <span class="cmti-10">to 328 </span>K, J. Phys. Chem., 99, 11 557–11 574, <a href="https://doi.org/10.1021/J100029A039" >doi:10.1021/J100029A039</a> (1995). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '793',
    'Carter et&nbsp;al. (1968)',
    'Carter, G. B., McIver, M. C., &#x0026; Miller, G. J.: <span class="cmti-10">Evidence for the formation of a</span> <span class="cmti-10">hexahydrotriazine in the condensation of acetaldehyde with methylamine</span>, J. Chem. Soc. C, pp. 2591–2592, <a href="https://doi.org/10.1039/J39680002591" >doi:10.1039/J39680002591</a> (1968). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2468',
    'Cetin and Odabasi (2005)',
    'Cetin, B. &#x0026; Odabasi, M.: <span class="cmti-10">Measurement of Henry&#x2019;s</span> <span class="cmti-10">law constants of seven polybrominated diphenyl ether (PBDE) congeners</span> <span class="cmti-10">as a function of temperature</span>, Atmos. Environ., 39, 5273–5280, <a href="https://doi.org/10.1016/J.ATMOSENV.2005.05.029" >doi:10.1016/J.ATMOSENV.2005.05.029</a> (2005). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2814',
    'Cetin et&nbsp;al. (2006)',
    'Cetin, B., Ozer, S., Sofuoglu, A., &#x0026; Odabasi, M.: <span class="cmti-10">Determination of Henry&#x2019;s law</span> <span class="cmti-10">constants of organochlorine pesticides in deionized and saline water</span> <span class="cmti-10">as a function of temperature</span>, Atmos. Environ., 40, 4538–4546, <a href="https://doi.org/10.1016/J.ATMOSENV.2006.04.009" >doi:10.1016/J.ATMOSENV.2006.04.009</a> (2006). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2825',
    'Chai et&nbsp;al. (2005)',
    'Chai, X.-S., Falabella, J. B., &#x0026; Teja, A. S.: <span class="cmti-10">A relative headspace method for Henry&#x2019;s constants</span> <span class="cmti-10">of volatile organic compounds</span>, Fluid Phase Equilib., 231, 239–245, <a href="https://doi.org/10.1016/J.FLUID.2005.02.006" >doi:10.1016/J.FLUID.2005.02.006</a> (2005). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1073',
    'Chaintreau et&nbsp;al. (1995)',
    'Chaintreau, A., Grade, A., &#x0026; Muñoz-Box, R.: <span class="cmti-10">Determination of partition coefficients</span> <span class="cmti-10">and quantitation of headspace volatile compounds</span>, Anal. Chem., 67, 3300–3304, <a href="https://doi.org/10.1021/AC00114A029" >doi:10.1021/AC00114A029</a> (1995). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '87',
    'Chameides (1984)',
    'Chameides, W. L.: <span class="cmti-10">The</span> <span class="cmti-10">photochemistry of a remote marine stratiform cloud</span>, J. Geophys. Res., 89, 4739–4755, <a href="https://doi.org/10.1029/JD089ID03P04739" >doi:10.1029/JD089ID03P04739</a> (1984). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '88',
    'Chameides (1986)',
    'Chameides, W. L.: <span class="cmti-10">Reply</span>, J. Geophys. Res., 91, 14 571–14 572, <a href="https://doi.org/10.1029/JD091ID13P14571" >doi:10.1029/JD091ID13P14571</a> (1986). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '171',
    'Chameides and Stelson (1992)',
    'Chameides, W. L. &#x0026; Stelson, A. W.: <span class="cmti-10">Aqueous</span> <span class="cmti-10">phase chemical processes in deliquescent sea-salt aerosols: A mechanism</span> <span class="cmti-10">that couples the atmospheric cycles of </span>S <span class="cmti-10">and sea salt</span>, J. Geophys. Res., 97, 20 565–20 580, <a href="https://doi.org/10.1029/92JD01923" >doi:10.1029/92JD01923</a> (1992). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3097',
    'Chan et&nbsp;al. (2010)',
    'Chan, M. N., Surratt, J. D., Claeys, M., Edgerton, E. S., Tanner, R. L., Shaw, S. L., Zheng, M., Knipping, E. M., Eddingsaas, N. C., Wennberg, P. O., &#x0026; Seinfeld, J. H.: <span class="cmti-10">Characterization and quantification of</span> <span class="cmti-10">isoprene-derived epoxydiols in ambient aerosol in the southeastern United</span> <span class="cmti-10">States</span>, Environ. Sci. Technol., 44, 4590–4596, <a href="https://doi.org/10.1021/ES100596B" >doi:10.1021/ES100596B</a> (2010). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2628',
    'Chancel and Parmentier (1885)',
    'Chancel, G. &#x0026; Parmentier, F.: <span class="cmti-10">Sur la</span> <span class="cmti-10">solubilit</span><span class="cmti-10">é du sulfure de carbone et sur celle du chloroforme</span>, C. R. Hebd. Séances Acad. Sci., 100, 773–776 (1885). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2121',
    'Chang and Criddle (1995)',
    'Chang, W.-K. &#x0026; Criddle, C. S.: <span class="cmti-10">Biotransformation of HCFC-22, HCFC-142b, HCFC-123,</span> <span class="cmti-10">and HFC-134a by methanotrophic mixed culture MM1</span>, Biodegrad., 6, 1–9, <a href="https://doi.org/10.1007/BF00702293" >doi:10.1007/BF00702293</a> (1995). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3404',
    'Chao et&nbsp;al. (2017)',
    'Chao, H.-P., Lee, J.-F., &#x0026; Chiou, C. T.: <span class="cmti-10">Determination of the Henry&#x2019;s law constants of low-volatility</span> <span class="cmti-10">compounds via the measured air-phase transfer coefficients</span>, Wat. Res., 120, 238–244, <a href="https://doi.org/10.1016/J.WATRES.2017.04.074" >doi:10.1016/J.WATRES.2017.04.074</a> (2017). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3129',
    'Chapoy et&nbsp;al. (2004)',
    'Chapoy, A., Mokraoui, S., Valtz, A., Richon, D., Mohammadi, A. H., &#x0026; Tohidi, B.: <span class="cmti-10">Solubility measurement and modeling for the system</span> <span class="cmti-10">propane-water from 277.62 to 368.16K</span>, Fluid Phase Equilib., 226, 213–220, <a href="https://doi.org/10.1016/J.FLUID.2004.08.040" >doi:10.1016/J.FLUID.2004.08.040</a> (2004). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2629',
    'Chapoy et&nbsp;al. (2005)',
    'Chapoy, A., Mohammadi, A. H., Tohidi, B., Valtz, A., &#x0026; Richon, D.: <span class="cmti-10">Experimental measurement and phase behavior modeling of hydrogen</span> <span class="cmti-10">sulfide-water binary system</span>, Ind. Eng. Chem. Res., 44, 7567–7574, <a href="https://doi.org/10.1021/IE050201H" >doi:10.1021/IE050201H</a> (2005). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2496',
    'Charles and Destaillats (2005)',
    'Charles, M. J. &#x0026; Destaillats, H.: <span class="cmti-10">Experimental determinations of Henry&#x2019;s law constants of polybrominated</span> <span class="cmti-10">diphenyl ethers (PBDEs) to evaluate exposure to aquatic biota</span>, technical completion report, University of California Water Resources Center, UC Berkeley, URL https://escholarship.org/uc/item/9zv0s4np (2005). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1137',
    'Chen et&nbsp;al. (1979)',
    'Chen, C.-C., Britt, H. I., Boston, J. F., &#x0026; Evans, L. B.: <span class="cmti-10">Extension and application of the Pitzer</span> <span class="cmti-10">equation for vapor-liquid equlibrium of aqueous electrolyte systems with</span> <span class="cmti-10">molecular solutes</span>, AIChE J., 25, 820–831, <a href="https://doi.org/10.1002/AIC.690250510" >doi:10.1002/AIC.690250510</a> (1979). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2824',
    'Chen et&nbsp;al. (2012)',
    'Chen, F., Freedman, D. L., Falta, R. W., &#x0026; Murdoch, L. C.: <span class="cmti-10">Henry&#x2019;s law</span> <span class="cmti-10">constants of chlorinated solvents at elevated temperatures</span>, Chemosphere, 86, 156–165, <a href="https://doi.org/10.1016/J.CHEMOSPHERE.2011.10.004" >doi:10.1016/J.CHEMOSPHERE.2011.10.004</a> (2012). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2808',
    'Chen et&nbsp;al. (2003)',
    'Chen, L., Takenaka, N., Bandow, H., &#x0026; Maeda, Y.: <span class="cmti-10">Henry&#x2019;s law constants for</span> C<sub><span class="cmr-7">2</span></sub><span class="cmti-10">-</span>C<sub><span class="cmr-7">3</span></sub> <span class="cmti-10">fluorinated alcohols and their wet deposition in the atmosphere</span>, Atmos. Environ., 37, 4817–4822, <a href="https://doi.org/10.1016/J.ATMOSENV.2003.08.002" >doi:10.1016/J.ATMOSENV.2003.08.002</a> (2003). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1856',
    'Cheng et&nbsp;al. (2003)',
    'Cheng, W.-H., Chu, F.-S., &#x0026; Liou, J.-J.: <span class="cmti-10">Air–water interface equilibrium</span> <span class="cmti-10">partitioning coefficients of aromatic hydrocarbons</span>, Atmos. Environ., 37, 4807–4815, <a href="https://doi.org/10.1016/J.ATMOSENV.2003.08.012" >doi:10.1016/J.ATMOSENV.2003.08.012</a> (2003). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2483',
    'Cheng et&nbsp;al. (2004)',
    'Cheng, W.-H., Chou, M.-S., Perng, C.-H., &#x0026; Chu, F.-S.: <span class="cmti-10">Determining the</span> <span class="cmti-10">equilibrium partitioning coefficients of</span> <span class="cmti-10">volatile organic compounds at an air–water interface</span>, Chemosphere, 54, 935–942, <a href="https://doi.org/10.1016/J.CHEMOSPHERE.2003.08.038" >doi:10.1016/J.CHEMOSPHERE.2003.08.038</a> (2004). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3076',
    'Chesters et&nbsp;al. (1989)',
    'Chesters, G., Simsiman, G. V., Levy, J., Alhajjar, B. J., Fathulla, R. N., &#x0026; Harkin, J. M.: <span class="cmti-10">Environmental fate of alachlor and metolachlor</span>, Rev. Environ. Contam. Toxicol., 110, 1–74, <a href="https://doi.org/10.1007/978-1-4684-7092-5_1" >doi:10.1007/978-1-4684-7092-5_1</a> (1989). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1502',
    'Cheung et&nbsp;al. (2000)',
    'Cheung, J. L., Li, Y. Q., Boniface, J., Shi, Q., Davidovits, P., Worsnop, D. R., Jayne, J. T., &#x0026; Kolb, C. E.: <span class="cmti-10">Heterogeneous interactions of</span> NO<sub><span class="cmr-7">2</span></sub> <span class="cmti-10">with aqueous surfaces</span>, J. Phys. Chem. A, 104, 2655–2662, <a href="https://doi.org/10.1021/JP992929F" >doi:10.1021/JP992929F</a> (2000). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1113',
    'Chiang et&nbsp;al. (1998)',
    'Chiang, P.-C., Hung, C.-H., Mar, J. C., &#x0026; Chang, E. E.: <span class="cmti-10">Henry&#x2019;s constants and mass transfer</span> <span class="cmti-10">coefficients of halogenated organic pollutants in an air stripping packed</span> <span class="cmti-10">column</span>, Wat. Sci. Tech., 38, 287–294 (1998). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2979',
    'Chiou et&nbsp;al. (1980)',
    'Chiou, C. T., Freed, V. H., Peters, L. J., &#x0026; Kohnert, R. L.: <span class="cmti-10">Evaporation of solutes from</span> <span class="cmti-10">water</span>, Environ. Int., 3, 231–236, <a href="https://doi.org/10.1016/0160-4120(80)90123-3" >doi:10.1016/0160-4120(80)90123-3</a> (1980). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '721',
    'Christie and Crisp (1967)',
    'Christie, A. O. &#x0026; Crisp, D. J.: <span class="cmti-10">Activity coefficients on the </span><span class="cmmi-10">n</span><span class="cmti-10">-primary, secondary</span> <span class="cmti-10">and tertiary aliphatic amines in aqueous solution</span>, J. Appl. Chem., 17, 11–14, <a href="https://doi.org/10.1002/JCTB.5010170103" >doi:10.1002/JCTB.5010170103</a> (1967). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2821',
    'Cimetiere and de Laat (2009)',
    'Cimetiere, N. &#x0026; de Laat, J.: <span class="cmti-10">Henry&#x2019;s law</span> <span class="cmti-10">constant of N,N-dichloromethylamine: Application to the contamination</span> <span class="cmti-10">of the atmosphere of indoor swimming pools</span>, Chemosphere, 77, 465–470, <a href="https://doi.org/10.1016/J.CHEMOSPHERE.2009.07.056" >doi:10.1016/J.CHEMOSPHERE.2009.07.056</a> (2009). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3917',
    'Clarke and Glew (1971)',
    'Clarke, E. C. W. &#x0026; Glew, D. N.: <span class="cmti-10">Aqueous</span> <span class="cmti-10">nonelectrolyte solutions. Part VIII. Deuterium and hydrogen sulfides</span> <span class="cmti-10">solubilities in deuterium oxide and water</span>, Can. J. Chem., 49, 691–698, <a href="https://doi.org/10.1139/V71-116" >doi:10.1139/V71-116</a> (1971). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3658',
    'Clarke et&nbsp;al. (1962)',
    'Clarke, G. A., Williams, T. R., &#x0026; Taft, R. W.: <span class="cmti-10">A manometric determination of</span> <span class="cmti-10">the solvolysis rate of gaseous </span><span class="cmmi-10">t</span><span class="cmti-10">-butyl chloride in aqueous solution</span>, J. Am. Chem. Soc., 84, 2292–2295, <a href="https://doi.org/10.1021/JA00871A004" >doi:10.1021/JA00871A004</a> (1962). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1071',
    'Clegg and Brimblecombe (1986)',
    'Clegg, S. L. &#x0026; Brimblecombe, P.: <span class="cmti-10">The dissociation constant and Henry&#x2019;s law</span> <span class="cmti-10">constant of</span> HCl <span class="cmti-10">in aqueous solution</span>, Atmos. Environ., 20, 2483–2485, <a href="https://doi.org/10.1016/0004-6981(86)90079-X" >doi:10.1016/0004-6981(86)90079-X</a> (1986). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '620',
    'Clegg and Brimblecombe (1989)',
    'Clegg, S. L. &#x0026; Brimblecombe, P.: <span class="cmti-10">Solubility</span> <span class="cmti-10">of ammonia in pure aqueous and multicomponent solutions</span>, J. Phys. Chem., 93, 7237–7248, <a href="https://doi.org/10.1021/J100357A041" >doi:10.1021/J100357A041</a> (1989). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2839',
    'Clegg and Brimblecombe (1990)',
    'Clegg, S. L. &#x0026; Brimblecombe, P.: <span class="cmti-10">Equilibrium partial pressures and mean activity and osmotic coefficients</span> <span class="cmti-10">of 0–100% nitric acid as a function of temperature</span>, J. Phys. Chem., 94, 5369–5380, <a href="https://doi.org/10.1021/J100376A038" >doi:10.1021/J100376A038</a> (1990). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1925',
    'Clegg et&nbsp;al. (1996)',
    'Clegg, S. L., Brimblecombe, P., &#x0026; Khan, I.: <span class="cmti-10">The Henry&#x2019;s law constant of oxalic</span> <span class="cmti-10">acid and its partitioning into in the atmospheric aerosol</span>, Idöjárás, 100, 51–68 (1996). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2838',
    'Clegg et&nbsp;al. (1998)',
    'Clegg, S. L., Brimblecombe, P., &#x0026; Wexler, A. S.: <span class="cmti-10">Thermodynamic model of</span> <span class="cmti-10">the system</span> H<sup><span class="cmr-7">+</span></sup><span class="cmti-10">-</span>NH<sub><span class="cmr-7">4</span></sub><sup><span class="cmr-7">+</span></sup><span class="cmti-10">-</span>SO<sub><span class="cmr-7">4</span></sub><sup><span class="cmr-7">2</span><span class="cmsy-7">−</span></sup><span class="cmti-10">-</span>NO<sub><span class="cmr-7">3</span></sub><sup><span class="cmsy-7">−</span></sup><span class="cmti-10">-</span>H<sub><span class="cmr-7">2</span></sub>O <span class="cmti-10">at tropospheric temperatures</span>, J. Phys. Chem. A, 102, 2137–2154, <a href="https://doi.org/10.1021/JP973042R" >doi:10.1021/JP973042R</a> (1998). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3849',
    'Clever (1979a)',
    'Clever, H. L.: IUPAC Solubility Data Series, Volume 1, Helium and Neon, Pergamon Press, Oxford, ISBN 0080223516 (1979a). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3850',
    'Clever (1979b)',
    'Clever, H. L.: IUPAC Solubility Data Series, Volume 2, Krypton, Xenon and Radon, Pergamon Press, Oxford, ISBN 0080223524 (1979b). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3851',
    'Clever (1980)',
    'Clever, H. L.: IUPAC Solubility Data Series, Volume 4, Argon, Pergamon Press, Oxford, ISBN 0080223532 (1980). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3862',
    'Clever (1987)',
    'Clever, H. L.: IUPAC Solubility Data Series, Volume 29, Mercury in Liquids, Compressed Gases, Molten Salts and Other Elements, Pergamon Press, Oxford, <a href="https://doi.org/10.1016/C2009-0-01263-X" >doi:10.1016/C2009-0-01263-X</a> (1987). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3861',
    'Clever and Young (1987)',
    'Clever, H. L. &#x0026; Young, C. L.: IUPAC Solubility Data Series, Volume 27/28, Methane, Pergamon Press, Oxford, <a href="https://doi.org/10.1016/C2009-0-00752-1" >doi:10.1016/C2009-0-00752-1</a> (1987). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2279',
    'Clever et&nbsp;al. (1985)',
    'Clever, H. L., Johnson, S. A., &#x0026; Derrick, M. E.: <span class="cmti-10">The solubility of mercury and some sparingly</span> <span class="cmti-10">soluble mercury salts in water and aqueous-electrolyte solutions</span>, J. Phys. Chem. Ref. Data, 14, 631–681, <a href="https://doi.org/10.1063/1.555732" >doi:10.1063/1.555732</a> (1985). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2447',
    'Clever et&nbsp;al. (2005)',
    'Clever, H. L., Battino, R., Jaselskis, B., Yampol&#x2019;skii, Y. P., Jaselskis, B., Scharlin, P., &#x0026; Young, C. L.: <span class="cmti-10">IUPAC-NIST solubility data series.</span> <span class="cmti-10">80. Gaseous fluorides of boron, nitrogen, sulfur, carbon, and silicon and</span> <span class="cmti-10">solid xenon fluorides in all solvents</span>, J. Phys. Chem. Ref. Data, 34, 201–438, <a href="https://doi.org/10.1063/1.1794762" >doi:10.1063/1.1794762</a> (2005). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3410',
    'Clever et&nbsp;al. (2014)',
    'Clever, H. L., Battino, R., Miyamoto, H., Yampolski, Y., &#x0026; Young, C. L.: <span class="cmti-10">IUPAC-NIST solubility data series. 103. Oxygen and ozone in</span> <span class="cmti-10">water, aqueous solutions, and organic liquids (supplement to solubility</span> <span class="cmti-10">data series volume 7)</span>, J. Phys. Chem. Ref. Data, 43, 033 102, <a href="https://doi.org/10.1063/1.4883876" >doi:10.1063/1.4883876</a> (2014). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '730',
    'Cline and Bates (1983)',
    'Cline, J. D. &#x0026; Bates, T. S.: <span class="cmti-10">Dimethyl sulfide in the</span> <span class="cmti-10">equatorial Pacific Ocean: A natural source of sulfur to the atmosphere</span>, Geophys. Res. Lett., 10, 949–952, <a href="https://doi.org/10.1029/GL010I010P00949" >doi:10.1029/GL010I010P00949</a> (1983). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3022',
    'Compernolle and Müller (2014a)',
    'Compernolle, S. &#x0026; Müller, J.-F.: <span class="cmti-10">Henry&#x2019;s</span> <span class="cmti-10">law constants of diacids and hydroxy polyacids: recommended values</span>, Atmos. Chem. Phys., 14, 2699–2712, <a href="https://doi.org/10.5194/ACP-14-2699-2014" >doi:10.5194/ACP-14-2699-2014</a> (2014a). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3067',
    'Compernolle and Müller (2014b)',
    'Compernolle, S. &#x0026; Müller, J.-F.: <span class="cmti-10">Henry&#x2019;s</span> <span class="cmti-10">law constants of polyols</span>, Atmos. Chem. Phys., 14, 12 815–12 837, <a href="https://doi.org/10.5194/ACP-14-12815-2014" >doi:10.5194/ACP-14-12815-2014</a> (2014b). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2534',
    'Conway et&nbsp;al. (1983)',
    'Conway, R. A., Waggy, G. T., Spiegel, M. H., &#x0026; Berglund, R. L.: <span class="cmti-10">Environmental</span> <span class="cmti-10">fate and effects of ethylene oxide</span>, Environ. Sci. Technol., 17, 107–112, <a href="https://doi.org/10.1021/ES00108A009" >doi:10.1021/ES00108A009</a> (1983). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1148',
    'Cooling et&nbsp;al. (1992)',
    'Cooling, M. R., Khalfaoui, B., &#x0026; Newsham, D. M. T.: <span class="cmti-10">Phase equilibria</span> <span class="cmti-10">in very dilute mixtures of water and unsaturated chlorinated hydrocarbons</span> <span class="cmti-10">and of water and benzene</span>, Fluid Phase Equilib., 81, 217–229, <a href="https://doi.org/10.1016/0378-3812(92)85153-Y" >doi:10.1016/0378-3812(92)85153-Y</a> (1992). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3554',
    'Copolovici and Niinemets (2007)',
    'Copolovici, L. &#x0026; Niinemets, U.: <span class="cmti-10">Salting-in</span> <span class="cmti-10">and salting-out effects of ionic and neutral osmotica on limonene and</span> <span class="cmti-10">linalool Henry&#x2019;s law constants and octanol/water partition coefficients</span>, Chemosphere, 69, 621–629, <a href="https://doi.org/10.1016/J.CHEMOSPHERE.2007.02.066" >doi:10.1016/J.CHEMOSPHERE.2007.02.066</a> (2007). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3216',
    'Copolovici and Niinemets (2015)',
    'Copolovici, L. &#x0026; Niinemets, U.: <span class="cmti-10">Temperature dependencies of Henry&#x2019;s law</span> <span class="cmti-10">constants for different plant sesquiterpenes</span>, Chemosphere, 138, 751–757, <a href="https://doi.org/10.1016/J.CHEMOSPHERE.2015.07.075" >doi:10.1016/J.CHEMOSPHERE.2015.07.075</a> (2015). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2124',
    'Copolovici and Niinemets (2005)',
    'Copolovici, L. O. &#x0026; Niinemets, U.: <span class="cmti-10">Temperature dependencies of</span> <span class="cmti-10">Henry&#x2019;s law constants and octanol/water partition coefficients for</span> <span class="cmti-10">key plant volatile monoterpenoids</span>, Chemosphere, 61, 1390–1400, <a href="https://doi.org/10.1016/J.CHEMOSPHERE.2005.05.003" >doi:10.1016/J.CHEMOSPHERE.2005.05.003</a> (2005). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1929',
    'Coquelet and Richon (2005)',
    'Coquelet, C. &#x0026; Richon, D.: <span class="cmti-10">Measurement</span> <span class="cmti-10">of Henry&#x2019;s law constants and infinite dilution activity coefficients</span> <span class="cmti-10">of propyl mercaptan, butyl mercaptan, and dimethyl sulfide in</span> <span class="cmti-10">methyldiethanolamine (1) + water (2) with </span><span class="cmmi-10">w</span><sub><span class="cmr-7">1</span></sub> <span class="cmti-10">= 0.50 using</span> <span class="cmti-10">a gas stripping technique</span>, J. Chem. Eng. Data, 50, 2053–2057, <a href="https://doi.org/10.1021/JE050268B" >doi:10.1021/JE050268B</a> (2005). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3601',
    'Cosgrove and Walkley (1981)',
    'Cosgrove, B. A. &#x0026; Walkley, J.: <span class="cmti-10">Solubilities</span> <span class="cmti-10">of gases in</span> H<sub><span class="cmr-7">2</span></sub>O <span class="cmti-10">and</span> <sup><span class="cmr-7">2</span></sup>H<sub><span class="cmr-7">2</span></sub>O, J. Chromatogr., 216, 161–167, <a href="https://doi.org/10.1016/S0021-9673(00)82344-4" >doi:10.1016/S0021-9673(00)82344-4</a> (1981). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1995',
    'Cotham and Bidleman (1989)',
    'Cotham, W. E. &#x0026; Bidleman, T. F.: <span class="cmti-10">Degradation of malathion, endosulfan, and fenvalerate</span> <span class="cmti-10">in seawater and seawater/sediment microcosms</span>, J. Agric. Food Chem., 37, 824–828, <a href="https://doi.org/10.1021/JF00087A055" >doi:10.1021/JF00087A055</a> (1989). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2957',
    'Cousins and Mackay (2000)',
    'Cousins, I. &#x0026; Mackay, D.: <span class="cmti-10">Correlating the physical-chemical properties of</span> <span class="cmti-10">phthalate esters using the ‘three solubility&#x2019; approach</span>, Chemosphere, 41, 1389–1399, <a href="https://doi.org/10.1016/S0045-6535(00)00005-9" >doi:10.1016/S0045-6535(00)00005-9</a> (2000). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3628',
    'Cramer (1980)',
    'Cramer, S. D.: <span class="cmti-10">The solubility of oxygen in brines from</span> <span class="cmti-10">0 to 300</span><span class="cmsy-7">∘</span>C, Ind. Eng. Chem. Process Des. Dev., 19, 300–305, <a href="https://doi.org/10.1021/I260074A018" >doi:10.1021/I260074A018</a> (1980). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1153',
    'Crovetto (1991)',
    'Crovetto, R.: <span class="cmti-10">Evaluation of solubility data for the system</span> CO<sub><span class="cmr-7">2</span></sub><span class="cmti-10">-</span>H<sub><span class="cmr-7">2</span></sub>O <span class="cmti-10">from 273 </span>K <span class="cmti-10">to the critical point of water</span>, J. Phys. Chem. Ref. Data, 20, 575–589, <a href="https://doi.org/10.1063/1.555905" >doi:10.1063/1.555905</a> (1991). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2557',
    'Crovetto et&nbsp;al. (1982)',
    'Crovetto, R., Fernández-Prini, R., &#x0026; Japas, M. L.: <span class="cmti-10">Solubilities of inert gases and</span> <span class="cmti-10">methane in</span> H<sub><span class="cmr-7">2</span></sub>O <span class="cmti-10">and in</span> D<sub><span class="cmr-7">2</span></sub>O <span class="cmti-10">in the temperature range of 300 to 600 </span>K, J. Chem. Phys., 76, 1077–1086, <a href="https://doi.org/10.1063/1.443074" >doi:10.1063/1.443074</a> (1982). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3781',
    'Crozier and Yamamoto (1974)',
    'Crozier, T. E. &#x0026; Yamamoto, S.: <span class="cmti-10">Solubility of</span> <span class="cmti-10">hydrogen in water, seawater and NaCl-solutions</span>, J. Chem. Eng. Data, 19, 242–244, <a href="https://doi.org/10.1021/JE60062A007" >doi:10.1021/JE60062A007</a> (1974). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3962',
    'Cruzeiro et&nbsp;al. (2022)',
    'Cruzeiro, V. W. D., Galib, M., Limmer, D. T., &#x0026; Götz, A. W.: <span class="cmti-10">Uptake of</span> N<sub><span class="cmr-7">2</span></sub>O<sub><span class="cmr-7">5</span></sub> <span class="cmti-10">by</span> <span class="cmti-10">aqueous aerosol unveiled using chemically accurate many-body potentials</span>, Nature Commun., 13, 1266, <a href="https://doi.org/10.1038/S41467-022-28697-8" >doi:10.1038/S41467-022-28697-8</a> (2022). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3600',
    'da&nbsp;Silva et&nbsp;al. (1980)',
    'da Silva, A. M., Formosinho, S. J., &#x0026; Martins, C. T.: <span class="cmti-10">Gas chromatographic</span> <span class="cmti-10">determination of the solubility of gases in liquids at low pressures</span>, J. Chromatogr. Sci., 18, 180–182, <a href="https://doi.org/10.1093/CHROMSCI/18.4.180" >doi:10.1093/CHROMSCI/18.4.180</a> (1980). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '512',
    'Dacey et&nbsp;al. (1984)',
    'Dacey, J. W. H., Wakeham, S. G., &#x0026; Howes, B. L.: <span class="cmti-10">Henry&#x2019;s law constants</span> <span class="cmti-10">for dimethylsulfide in freshwater and seawater</span>, Geophys. Res. Lett., 11, 991–994, <a href="https://doi.org/10.1029/GL011I010P00991" >doi:10.1029/GL011I010P00991</a> (1984). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2944',
    'Dallos et&nbsp;al. (1983)',
    'Dallos, A., Ország, I., &#x0026; Ratkovics, F.: <span class="cmti-10">Liquid-liquid and vapour-liquid equilibrium data and</span> <span class="cmti-10">calculations for the system aniline + water in the presence of</span> NaCl<span class="cmti-10">,</span> NaI<span class="cmti-10">,</span> NH<sub><span class="cmr-7">4</span></sub>Cl <span class="cmti-10">and</span> NH<sub><span class="cmr-7">4</span></sub>I, Fluid Phase Equilib., 11, 91–102, <a href="https://doi.org/10.1016/0378-3812(83)85008-0" >doi:10.1016/0378-3812(83)85008-0</a> (1983). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '487',
    'Dasgupta and Dong (1986)',
    'Dasgupta, P. G. &#x0026; Dong, S.: <span class="cmti-10">Solubility of ammonia in liquid water and</span> <span class="cmti-10">generation of trace levels of standard gaseous ammonia</span>, Atmos. Environ., 20, 565–570, <a href="https://doi.org/10.1016/0004-6981(86)90099-5" >doi:10.1016/0004-6981(86)90099-5</a> (1986). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1573',
    'David et&nbsp;al. (2000)',
    'David, M. D., Fendinger, N. J., &#x0026; Hand, V. C.: <span class="cmti-10">Determination of Henry&#x2019;s law constants for</span> <span class="cmti-10">organosilicones in actual and simulated wastewater</span>, Environ. Sci. Technol., 34, 4554–4559, <a href="https://doi.org/10.1021/ES991204M" >doi:10.1021/ES991204M</a> (2000). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3573',
    'De Bruyn and Saltzman (1997)',
    'De Bruyn, W. J. &#x0026; Saltzman, E. S.: <span class="cmti-10">The</span> <span class="cmti-10">solubility of methyl bromide in pure water, 35permil sodium chloride and</span> <span class="cmti-10">seawater</span>, Mar. Chem., 56, 51–57, <a href="https://doi.org/10.1016/S0304-4203(96)00089-8" >doi:10.1016/S0304-4203(96)00089-8</a> (1997). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '389',
    'De Bruyn et&nbsp;al. (1994)',
    'De Bruyn, W. J., Shorter, J. A., Davidovits, P., Worsnop, D. R., Zahniser, M. S., &#x0026; Kolb, C. E.: <span class="cmti-10">Uptake of gas-phase sulfur species</span> <span class="cmti-10">methanesulfonic acid, dimethylsulfoxide, and dimethyl sulfone by aqueous</span> <span class="cmti-10">surfaces</span>, J. Geophys. Res., 99, 16 927–16 932, <a href="https://doi.org/10.1029/94JD00684" >doi:10.1029/94JD00684</a> (1994). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1125',
    'De Bruyn et&nbsp;al. (1995a)',
    'De Bruyn, W. J., Shorter, J. A., Davidovits, P., Worsnop, D. R., Zahniser, M. S., &#x0026; Kolb, C. E.: <span class="cmti-10">Uptake of haloacetyl and carbonyl</span> <span class="cmti-10">halides by water surfaces</span>, Environ. Sci. Technol., 29, 1179–1185, <a href="https://doi.org/10.1021/ES00005A007" >doi:10.1021/ES00005A007</a> (1995a). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '586',
    'De Bruyn et&nbsp;al. (1995b)',
    'De Bruyn, W. J., Swartz, E., Hu, J. H., Shorter, J. A., Davidovits, P., Worsnop, D. R., Zahniser, M. S., &#x0026; Kolb, C. E.: <span class="cmti-10">Henry&#x2019;s law</span> <span class="cmti-10">solubilities and </span><span class="cmti-10">Śetchenow coefficients for biogenic reduced sulfur species</span> <span class="cmti-10">obtained from gas-liquid uptake measurements</span>, J. Geophys. Res., 100, 7245–7251, <a href="https://doi.org/10.1029/95JD00217" >doi:10.1029/95JD00217</a> (1995b). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '981',
    'De Maagd et&nbsp;al. (1998)',
    'De Maagd, P. G.-J., Ten Hulscher, D. T. E. M., van den Heuvel, H., Opperhuizen, A., &#x0026; Sijm, D. T. H. M.: <span class="cmti-10">Physicochemical properties of</span> <span class="cmti-10">polycyclic aromatic hydrocarbons: Aqueous solubilities, </span><span class="cmmi-10">n</span><span class="cmti-10">-octanol/water</span> <span class="cmti-10">partition coefficients, and Henry&#x2019;s law constants</span>, Environ. Toxicol. Chem., 17, 251–257, <a href="https://doi.org/10.1002/ETC.5620170216" >doi:10.1002/ETC.5620170216</a> (1998). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2950',
    'de Wolf and Lieder (1998)',
    'de Wolf, W. &#x0026; Lieder, P. H.: <span class="cmti-10">A novel method</span> <span class="cmti-10">to determine uptake and elimination kinetics of volatile chemicals in</span> <span class="cmti-10">fish</span>, Chemosphere, 36, 1713–1724, <a href="https://doi.org/10.1016/S0045-6535(97)10062-5" >doi:10.1016/S0045-6535(97)10062-5</a> (1998). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3806',
    'Dean et&nbsp;al. (1973)',
    'Dean, C. R. S., Finch, A., &#x0026; Gardner, P. J.: <span class="cmti-10">The aqueous solubilities of nitrogen trifluoride and</span> <span class="cmti-10">dinitrogen tetrafluoride</span>, J. Chem. Soc. Dalton Trans., pp. 2722–2725, <a href="https://doi.org/10.1039/DT9730002722" >doi:10.1039/DT9730002722</a> (1973). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '379',
    'Dean and Lange (1999)',
    'Dean, J. A. &#x0026; Lange, N. A.: Lange&#x2019;s Handbook of Chemistry, Fifteenth Edition, McGraw-Hill, Inc., ISBN 9780070163843 (1999). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1935',
    'Delgado and Alderete (2002)',
    'Delgado, E. J. &#x0026; Alderete, J.: <span class="cmti-10">On the</span> <span class="cmti-10">calculation of Henry&#x2019;s law constants of chlorinated benzenes in water</span> <span class="cmti-10">from semiempirical quantum chemical methods</span>, J. Chem. Inf. Comput. Sci., 42, 559–563, <a href="https://doi.org/10.1021/CI0101206" >doi:10.1021/CI0101206</a> (2002). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1931',
    'Delgado and Alderete (2003)',
    'Delgado, E. J. &#x0026; Alderete, J. B.: <span class="cmti-10">Prediction</span> <span class="cmti-10">of Henry&#x2019;s law constants of triazine derived herbicides from quantum</span> <span class="cmti-10">chemical continuum solvation models</span>, J. Chem. Inf. Comput. Sci., 43, 1226–1230, <a href="https://doi.org/10.1021/CI0256485" >doi:10.1021/CI0256485</a> (2003). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2220',
    'Della Gatta et&nbsp;al. (1981)',
    'Della Gatta, G., Stradella, L., &#x0026; Venturello, P.: <span class="cmti-10">Enthalpies of solvation</span> <span class="cmti-10">in cyclohexane and in water for homologous aliphatic ketones and esters</span>, J. Solution Chem., 10, 209–220, <a href="https://doi.org/10.1007/BF00653098" >doi:10.1007/BF00653098</a> (1981). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '529',
    'Deno and Berkheimer (1960)',
    'Deno, N. C. &#x0026; Berkheimer, H. E.: <span class="cmti-10">Activity</span> <span class="cmti-10">coefficients as a functon of structure and media</span>, J. Chem. Eng. Data, 5, 1–5, <a href="https://doi.org/10.1021/JE60005A001" >doi:10.1021/JE60005A001</a> (1960). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2497',
    'Destaillats and Charles (2002)',
    'Destaillats, H. &#x0026; Charles, M. J.: <span class="cmti-10">Henry&#x2019;s</span> <span class="cmti-10">law constants of carbonyl-pentafluorobenzyl hydroxylamine (PFBHA)</span> <span class="cmti-10">derivatives in aqueous solution</span>, J. Chem. Eng. Data, 47, 1481–1487, <a href="https://doi.org/10.1021/JE025545I" >doi:10.1021/JE025545I</a> (2002). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '584',
    'Dewulf et&nbsp;al. (1995)',
    'Dewulf, J., Drijvers, D., &#x0026; van Langenhove, H.: <span class="cmti-10">Measurement of Henry&#x2019;s law</span> <span class="cmti-10">constant as function of temperature and salinity for the low temperature</span> <span class="cmti-10">range</span>, Atmos. Environ., 29, 323–331, <a href="https://doi.org/10.1016/1352-2310(94)00256-K" >doi:10.1016/1352-2310(94)00256-K</a> (1995). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1107',
    'Dewulf et&nbsp;al. (1999)',
    'Dewulf, J., van Langenhove, H., &#x0026; Everaert, P.: <span class="cmti-10">Determination of Henry&#x2019;s law</span> <span class="cmti-10">coefficients by combination of the equilibrium partitioning in closed</span> <span class="cmti-10">systems and solid-phase microextraction techniques</span>, J. Chromatogr. A, 830, 353–363, <a href="https://doi.org/10.1016/S0021-9673(98)00877-2" >doi:10.1016/S0021-9673(98)00877-2</a> (1999). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3118',
    'Diaz et&nbsp;al. (2005)',
    'Diaz, A., Ventura, F., &#x0026; Galceran, M. T.: <span class="cmti-10">Determination of odorous</span> <span class="cmti-10">mixed chloro-bromoanisoles in water by solid-phase micro-extraction and</span> <span class="cmti-10">gas chromatography-mass detection</span>, J. Chromatogr. A, 1064, 97–106, <a href="https://doi.org/10.1016/J.CHROMA.2004.12.027" >doi:10.1016/J.CHROMA.2004.12.027</a> (2005). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '545',
    'Dilling (1977)',
    'Dilling, W. L.: <span class="cmti-10">Interphase transfer processes. II. Evaporation</span> <span class="cmti-10">rates of chloro methanes, ethanes, ethylenes, propanes, and propylenes</span> <span class="cmti-10">from dilute aqueous solutions. Comparisons with theoretical predictions</span>, Environ. Sci. Technol., 11, 405–409, <a href="https://doi.org/10.1021/ES60127A009" >doi:10.1021/ES60127A009</a> (1977). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1916',
    'Dilling et&nbsp;al. (1975)',
    'Dilling, W. L., Tefertiller, N. B., &#x0026; Kallos, G. J.: <span class="cmti-10">Evaporation rates and reactivities of</span> <span class="cmti-10">methylene chloride, chloroform, 1,1,1-trichloroethane, trichloroethylene,</span> <span class="cmti-10">tetrachloroethylene, and other chlorinated compounds in dilute aqueous</span> <span class="cmti-10">solutions</span>, Environ. Sci. Technol., 9, 833–838, <a href="https://doi.org/10.1021/ES60107A008" >doi:10.1021/ES60107A008</a> (1975). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1018',
    'Disselkamp et&nbsp;al. (1999)',
    'Disselkamp, R. S., Chapman, E. G., Barchet, W. R., Colson, S. D., &#x0026; Howd, C. D.: BrCl <span class="cmti-10">production in</span> NaBr<span class="cmti-10">/</span>NaCl<span class="cmti-10">/</span>HNO<sub><span class="cmr-7">3</span></sub><span class="cmti-10">/</span>O<sub><span class="cmr-7">3</span></sub> <span class="cmti-10">solutions</span> <span class="cmti-10">representative of sea-salt aerosols in the marine boundary layer</span>, Geophys. Res. Lett., 26, 2183–2186, <a href="https://doi.org/10.1029/1999GL900251" >doi:10.1029/1999GL900251</a> (1999). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3638',
    'Djerki and Laub (1988)',
    'Djerki, R. A. &#x0026; Laub, R. J.: <span class="cmti-10">Solute retention in column liquid chromatography. X. Determination of</span> <span class="cmti-10">solute infinite-dilution activity coefficients in methanol, water, and their</span> <span class="cmti-10">mixtures, by combined gas-liquid and liquid-liquid chromatography</span>, J. Liq. Chromatogr., 11, 585–612, <a href="https://doi.org/10.1080/01483918808068333" >doi:10.1080/01483918808068333</a> (1988). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2936',
    'Dohányosová et&nbsp;al. (2004)',
    'Dohányosová, P., Sarraute, S., Dohnal, V., Majer, V., &#x0026; Costa Gomes, M.: <span class="cmti-10">Aqueous solubility and related thermodynamic functions of</span> <span class="cmti-10">nonaromatic hydrocarbons as a function of molecular structure</span>, Ind. Eng. Chem. Res., 43, 2805–2815, <a href="https://doi.org/10.1021/IE030800T" >doi:10.1021/IE030800T</a> (2004). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1907',
    'Dohnal and Fenclová (1995)',
    'Dohnal, V. &#x0026; Fenclová, D.: <span class="cmti-10">Air–water partitioning and aqueous solubility of phenols</span>, J. Chem. Eng. Data, 40, 478–483, <a href="https://doi.org/10.1021/JE00018A027" >doi:10.1021/JE00018A027</a> (1995). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2938',
    'Dohnal and Hovorka (1999)',
    'Dohnal, V. &#x0026; Hovorka, Š.: <span class="cmti-10">Exponential saturator:</span> <span class="cmti-10">a novel gas-liquid partitioning technique for measurement of large</span> <span class="cmti-10">limiting activity coefficients</span>, Ind. Eng. Chem. Res., 38, 2036–2043, <a href="https://doi.org/10.1021/IE980743H" >doi:10.1021/IE980743H</a> (1999). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3065',
    'Dohnal et&nbsp;al. (2006)',
    'Dohnal, V., Fenclová, D., &#x0026; Vrbka, P.: <span class="cmti-10">Temperature dependences of limiting activity coefficients,</span> <span class="cmti-10">Henry&#x2019;s law constants, and derivative infinite dilution properties of</span> <span class="cmti-10">lower (</span>C<sub><span class="cmr-7">1</span></sub><span class="cmti-10">-</span>C<sub><span class="cmr-7">5</span></sub><span class="cmti-10">) 1-alkanols in water. critical compilation, correlation,</span> <span class="cmti-10">and recommended data</span>, J. Phys. Chem. Ref. Data, 35, 1621–1651, <a href="https://doi.org/10.1063/1.2203355" >doi:10.1063/1.2203355</a> (2006). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3523',
    'Dohnal et&nbsp;al. (2010)',
    'Dohnal, V., Vrbka, P., Řehák, K., Böhme, A., &#x0026; Paschke, A.: <span class="cmti-10">Activity coefficients and partial molar excess enthalpies at infinite</span> <span class="cmti-10">dilution for four esters in water</span>, Fluid Phase Equilib., 295, 194–200, <a href="https://doi.org/10.1016/J.FLUID.2010.05.010" >doi:10.1016/J.FLUID.2010.05.010</a> (2010). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1337',
    'Donahue and Prinn (1993)',
    'Donahue, N. M. &#x0026; Prinn, R. G.: <span class="cmti-10">In situ</span> <span class="cmti-10">nonmethane hydrocarbon measurements on SAGA 3</span>, J. Geophys. Res., 98, 16 915–16 932, <a href="https://doi.org/10.1029/93JD01780" >doi:10.1029/93JD01780</a> (1993). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '485',
    'Dong and Dasgupta (1986)',
    'Dong, S. &#x0026; Dasgupta, P. G.: <span class="cmti-10">Solubility of</span> <span class="cmti-10">gaseous formaldehyde in liquid water and generation of trace</span> <span class="cmti-10">standard gaseous formaldehyde</span>, Environ. Sci. Technol., 20, 637–640, <a href="https://doi.org/10.1021/ES00148A016" >doi:10.1021/ES00148A016</a> (1986). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '4017',
    'D&#x2019;Orazio and Wood (1963)',
    'D&#x2019;Orazio, L. A. &#x0026; Wood, R. H.: <span class="cmti-10">The thermodynamics of the solution of polar gases in</span> <span class="cmti-10">water; the heat, free energy, and entropy of solution of hydrazoic acid</span>, J. Phys. Chem., 67, 1435–1438, <a href="https://doi.org/10.1021/J100801A007" >doi:10.1021/J100801A007</a> (1963). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1911',
    'Douglas (1967)',
    'Douglas, E.: <span class="cmti-10">Carbon monoxide solubilities in sea water</span>, J. Phys. Chem., 71, 1931–1933, <a href="https://doi.org/10.1021/J100865A064" >doi:10.1021/J100865A064</a> (1967). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '982',
    'Drouillard et&nbsp;al. (1998)',
    'Drouillard, K. G., Tomy, G. T., Muir, D. C. G., &#x0026; Friesen, K. J.: <span class="cmti-10">Volatility of chlorinated </span><span class="cmmi-10">n</span><span class="cmti-10">-alkanes (</span>C<sub><span class="cmr-7">10</span></sub><span class="cmti-10">-</span>C<sub><span class="cmr-7">12</span></sub><span class="cmti-10">): Vapor pressures and</span> <span class="cmti-10">Henry&#x2019;s law constants</span>, Environ. Toxicol. Chem., 17, 1252–1260, <a href="https://doi.org/10.1002/ETC.5620170709" >doi:10.1002/ETC.5620170709</a> (1998). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3645',
    'Druaux et&nbsp;al. (1998)',
    'Druaux, C., Le Thanh, M., Seuvre, A.-M., &#x0026; Voilley, A.: <span class="cmti-10">Application of headspace</span> <span class="cmti-10">analysis to the study of aroma compounds-lipids interactions</span>, J. Am. Oil Chem. Soc., 75, 127–130, <a href="https://doi.org/10.1007/S11746-998-0022-Y" >doi:10.1007/S11746-998-0022-Y</a> (1998). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3426',
    'Du et&nbsp;al. (2017)',
    'Du, Y., Yuan, Y., &#x0026; Rochelle, G. T.: <span class="cmti-10">Volatility of amines for</span> CO<sub><span class="cmr-7">2</span></sub> <span class="cmti-10">capture</span>, Int. J. Greenhouse Gas Control, 58, 1–9, <a href="https://doi.org/10.1016/J.IJGGC.2017.01.001" >doi:10.1016/J.IJGGC.2017.01.001</a> (2017). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '759',
    'Dubik et&nbsp;al. (1987)',
    'Dubik, N. A., Titova, G. M., &#x0026; Loshakova, E. I.: <span class="cmti-10">Partition coefficients of bromine and</span> <span class="cmti-10">bromine chloride between air and natural brines</span>, Issled. v Obl. Poluch. Magniya, Ioda, Broma i ikh Soed., M., pp. 53–57, (in Russian, see also Chem. Abstr., 109, 213154j) (1987). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3659',
    'Dubowski (1979)',
    'Dubowski, K. M.: <span class="cmti-10">Breath-alcohol simulators: Scientific</span> <span class="cmti-10">basis and actual performance</span>, J. Anal. Technol., 3, 177–182, <a href="https://doi.org/10.1093/JAT/3.5.177" >doi:10.1093/JAT/3.5.177</a> (1979). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3586',
    'Duchowicz et&nbsp;al. (2020)',
    'Duchowicz, P. R., Aranda, J. F., Bacelo, D. E., &#x0026; Fioressi, S. E.: <span class="cmti-10">QSPR</span> <span class="cmti-10">study of the Henry&#x2019;s law constant for heterogeneous compounds</span>, Chem. Eng. Res. Des., 154, 115–121, <a href="https://doi.org/10.1016/J.CHERD.2019.12.009" >doi:10.1016/J.CHERD.2019.12.009</a> (2020). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1140',
    'Dunnivant and Elzerman (1988)',
    'Dunnivant, F. M. &#x0026; Elzerman, A. W.: <span class="cmti-10">Aqueous solubility and Henry&#x2019;s law constant data for PCB congeners</span> <span class="cmti-10">for evaluation of quantitative structure-property relationships (QSPRs)</span>, Chemosphere, 17, 525–541, <a href="https://doi.org/10.1016/0045-6535(88)90028-8" >doi:10.1016/0045-6535(88)90028-8</a> (1988). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '643',
    'Dunnivant et&nbsp;al. (1988)',
    'Dunnivant, F. M., Coates, J. T., &#x0026; Elzerman, A. W.: <span class="cmti-10">Experimentally</span> <span class="cmti-10">determined Henry&#x2019;s law constants for 17 polychlorobiphenyl congeners</span>, Environ. Sci. Technol., 22, 448–453, <a href="https://doi.org/10.1021/ES00169A013" >doi:10.1021/ES00169A013</a> (1988). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2475',
    'Dunnivant et&nbsp;al. (1992)',
    'Dunnivant, F. M., Elzerman, A. W., Jurs, P. C., &#x0026; Hasan, M. N.: <span class="cmti-10">Quantitative</span> <span class="cmti-10">structure-property relationships for aqueous solubilities and Henry&#x2019;s</span> <span class="cmti-10">law constants of polychlorinated biphenyls</span>, Environ. Sci. Technol., 26, 1567–1573, <a href="https://doi.org/10.1021/ES00032A012" >doi:10.1021/ES00032A012</a> (1992). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3682',
    'Dupeux et&nbsp;al. (2022)',
    'Dupeux, T., Gaudin, T., Marteau-Roussy, C., Aubry, J.-M., &#x0026; Nardello-Rataj, V.: <span class="cmti-10">COSMO-RS as an effective tool for predicting the</span> <span class="cmti-10">physicochemical properties of fragrance raw materials</span>, Flavour Fragrance J., 37, 106–120, <a href="https://doi.org/10.1002/FFJ.3690" >doi:10.1002/FFJ.3690</a> (2022). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '492',
    'Durham et&nbsp;al. (1981)',
    'Durham, J. L., Overton, Jr., J. H., &#x0026; Aneja, V. P.: <span class="cmti-10">Influence of gaseous nitric acid on</span> <span class="cmti-10">sulfate production and acidity in rain</span>, Atmos. Environ., 15, 1059–1068, <a href="https://doi.org/10.1016/0004-6981(81)90106-2" >doi:10.1016/0004-6981(81)90106-2</a> (1981). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2478',
    'Eastcott et&nbsp;al. (1988)',
    'Eastcott, L., Shiu, W. Y., &#x0026; Mackay, D.: <span class="cmti-10">Environmentally relevant physical-chemical properties of</span> <span class="cmti-10">hydrocarbons: A review of data and development of simple correlations</span>, Oil Chem. Pollut., 4, 191–216, <a href="https://doi.org/10.1016/S0269-8579(88)80020-0" >doi:10.1016/S0269-8579(88)80020-0</a> (1988). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3769',
    'Easterbrook et&nbsp;al. (2023)',
    'Easterbrook, K. D., Vona, M. A., Nayebi-Astaneh, K., Miller, A. M., &#x0026; Osthoff, H. D.: <span class="cmti-10">Measurement of Henry&#x2019;s law and liquid-phase</span> <span class="cmti-10">loss rate constants of peroxypropionic nitric anhydride (PPN) in</span> <span class="cmti-10">deionized water and in n-octanol</span>, Atmos. Chem. Phys., 23, 311–322, <a href="https://doi.org/10.5194/ACP-23-311-2023" >doi:10.5194/ACP-23-311-2023</a> (2023). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3766',
    'Ebert et&nbsp;al. (2023)',
    'Ebert, R.-U., Kühne, R., &#x0026; Schüürmann, G.: <span class="cmti-10">Henry&#x2019;s law constant – a general-purpose fragment</span> <span class="cmti-10">model to predict log </span><span class="cmmi-10">K</span><sub><span class="cmr-7">aw</span></sub> <span class="cmti-10">from molecular structure</span>, Environ. Sci. Technol., 57, 160–167, <a href="https://doi.org/10.1021/ACS.EST.2C05623" >doi:10.1021/ACS.EST.2C05623</a> (2023). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3580',
    'Eddingsaas et&nbsp;al. (2010)',
    'Eddingsaas, N. C., VanderVelde, D. G., &#x0026; Wennberg, P. O.: <span class="cmti-10">Kinetics</span> <span class="cmti-10">and products of the acid-catalyzed ring-opening of atmospherically</span> <span class="cmti-10">relevant butyl epoxy alcohols</span>, J. Phys. Chem. A, 114, 8106–8113, <a href="https://doi.org/10.1021/JP103907C" >doi:10.1021/JP103907C</a> (2010). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2442',
    'Edelist et&nbsp;al. (1964)',
    'Edelist, G., Singer, M. M., &#x0026; Eger, E. I., I.: <span class="cmti-10">Solubility</span> <span class="cmti-10">coefficients of teflurane in various biological media</span>, Anesthesiology, 25, 223–225, <a href="https://doi.org/10.1097/00000542-196403000-00015" >doi:10.1097/00000542-196403000-00015</a> (1964). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3540',
    'Edwards et&nbsp;al. (1975)',
    'Edwards, T. J., Newman, J., &#x0026; Prausnitz, J. M.: <span class="cmti-10">Thermodynamics of</span> <span class="cmti-10">aqueous solutions containing volatile weak electrolytes</span>, AIChE J., 21, 248–259, <a href="https://doi.org/10.1002/AIC.690210205" >doi:10.1002/AIC.690210205</a> (1975). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '540',
    'Edwards et&nbsp;al. (1978)',
    'Edwards, T. J., Maurer, G., Newman, J., &#x0026; Prausnitz, J. M.: <span class="cmti-10">Vapor-liquid equilibria in multicomponent aqueous solutions of volatile</span> <span class="cmti-10">weak electrolytes</span>, AIChE J., 24, 966–976, <a href="https://doi.org/10.1002/AIC.690240605" >doi:10.1002/AIC.690240605</a> (1978). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3699',
    'Eger et&nbsp;al. (1963)',
    'Eger, E. I., Shargel, R., &#x0026; Merkel, G.: <span class="cmti-10">Solubility of diethyl ether in water, blood and oil</span>, Anesthesiology, 24, 676–678, <a href="https://doi.org/10.1097/00000542-196309000-00017" >doi:10.1097/00000542-196309000-00017</a> (1963). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3402',
    'Eger et&nbsp;al. (1999)',
    'Eger, II, E. I., Ionescu, P., Laster, M. J., Gong, D., Hudlicky, T., Kendig, J. J., Harris, R. A., Trudell, J. R., &#x0026; Pohorille, A.: <span class="cmti-10">Minimum alveolar anesthetic concentration of fluorinated alkanols in</span> <span class="cmti-10">rats: relevance to theories of narcosis</span>, Anesth. Analg., 88, 867–876, <a href="https://doi.org/10.1213/00000539-199904000-00035" >doi:10.1213/00000539-199904000-00035</a> (1999). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1149',
    'Eguchi et&nbsp;al. (1973)',
    'Eguchi, W., Adachi, M., &#x0026; Yoneda, M.: <span class="cmti-10">Dependency of partition equilibrium of iodine between air</span> <span class="cmti-10">and aqueous solution containing sodium hydroxide upon temperature and</span> <span class="cmti-10">concentration</span>, J. Chem. Eng. Jpn., 6, 389–396, <a href="https://doi.org/10.1252/JCEJ.6.389" >doi:10.1252/JCEJ.6.389</a> (1973). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2631',
    'Elliott (1989)',
    'Elliott, S.: <span class="cmti-10">The solubility of carbon disulfide vapor in natural</span> <span class="cmti-10">aqueous systems</span>, Atmos. Environ., 23, 1977–1980, <a href="https://doi.org/10.1016/0004-6981(89)90523-4" >doi:10.1016/0004-6981(89)90523-4</a> (1989). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1342',
    'Elliott and Rowland (1993)',
    'Elliott, S. &#x0026; Rowland, F. S.: <span class="cmti-10">Nucleophilic</span> <span class="cmti-10">substitution rates and solubilities for methyl halides in seawater</span>, Geophys. Res. Lett., 20, 1043–1046, <a href="https://doi.org/10.1029/93GL01081" >doi:10.1029/93GL01081</a> (1993). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2597',
    'Emel&#x2019;yanenko et&nbsp;al. (2007)',
    'Emel&#x2019;yanenko, V. N., Dabrowska, A., Verevkin, S. P., Hertel, M. O., Scheuren, H., &#x0026; Sommer, K.: <span class="cmti-10">Vapor pressures, enthalpies of vaporization,</span> <span class="cmti-10">and limiting activity coefficients in water at 100</span><span class="cmsy-7">∘</span>C <span class="cmti-10">of 2-furanaldehyde,</span> <span class="cmti-10">benzaldehyde, phenylethanal, and 2-phenylethanol</span>, J. Chem. Eng. Data, 52, 468–471, <a href="https://doi.org/10.1021/JE060406C" >doi:10.1021/JE060406C</a> (2007). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2543',
    'English and Carroll (2001)',
    'English, N. J. &#x0026; Carroll, D. G.: <span class="cmti-10">Prediction of</span> <span class="cmti-10">Henry&#x2019;s law constants by a quantitative structure property relationship</span> <span class="cmti-10">and neural networks</span>, J. Chem. Inf. Comput. Sci., 41, 1150–1161, <a href="https://doi.org/10.1021/CI010361D" >doi:10.1021/CI010361D</a> (2001). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3700',
    'Ercan (1979)',
    'Ercan, M. T.: <span class="cmti-10">Solubility coefficients of</span> <sup><span class="cmr-7">133</span></sup>Xe <span class="cmti-10">in water,</span> <span class="cmti-10">saline, dog blood and organs</span>, Int. J. Appl. Radiat. Isot., 30, 757–759, <a href="https://doi.org/10.1016/0020-708X(79)90156-X" >doi:10.1016/0020-708X(79)90156-X</a> (1979). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2271',
    'Ervin et&nbsp;al. (1980)',
    'Ervin, A. L., Mangone, M. A., &#x0026; Singley, J. E.: <span class="cmti-10">Trace organics removal by air</span> <span class="cmti-10">stripping</span>, in: Proceedings of the Annual Conference of the American Water Works Association, pp. 507–530 (1980). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '858',
    'Ettre et&nbsp;al. (1993)',
    'Ettre, L. S., Welter, C., &#x0026; Kolb, B.: <span class="cmti-10">Determination of gas-liquid partition coefficients by automatic</span> <span class="cmti-10">equilibrium headspace – gas chromatography utilizing the phase ratio</span> <span class="cmti-10">variation method</span>, Chromatographia, 35, 73–84, <a href="https://doi.org/10.1007/BF02278560" >doi:10.1007/BF02278560</a> (1993). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3115',
    'Falabella (2007)',
    'Falabella, J. B.: Air–water partitioning of volatile organic compounds and greenhouse gases in the presence of salts, Ph.D. thesis, Georgia Institute of Technology, USA, URL http://hdl.handle.net/1853/16221 (2007). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3116',
    'Falabella and Teja (2008)',
    'Falabella, J. B. &#x0026; Teja, A. S.: <span class="cmti-10">Air–water partitioning of gasoline components in the presence of sodium</span> <span class="cmti-10">chloride</span>, Energy Fuels, 22, 398–401, <a href="https://doi.org/10.1021/EF700513K" >doi:10.1021/EF700513K</a> (2008). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3112',
    'Falabella et&nbsp;al. (2006)',
    'Falabella, J. B., Nair, A., &#x0026; Teja, A. S.: <span class="cmti-10">Henry&#x2019;s constants of 1-alkanols and 2-ketones in salt</span> <span class="cmti-10">solutions</span>, J. Chem. Eng. Data, 51, 1940–1945, <a href="https://doi.org/10.1021/JE0600956" >doi:10.1021/JE0600956</a> (2006). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2460',
    'Falk et&nbsp;al. (1990)',
    'Falk, A., Gullstrand, E., Löf, A., &#x0026; Wigaeus-Hjelm, E.: <span class="cmti-10">Liquid/air</span> <span class="cmti-10">partition coefficients of four terpenes</span>, Br. J. Ind. Med., 47, 62–64, <a href="https://doi.org/10.1136/OEM.47.1.62" >doi:10.1136/OEM.47.1.62</a> (1990). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2565',
    'Fang et&nbsp;al. (2006)',
    'Fang, F., Chu, S., &#x0026; Hong, C.-S.: <span class="cmti-10">Air–water Henry&#x2019;s law constants for PCB congeners: experimental</span> <span class="cmti-10">determination and modeling of structure-property relationship</span>, Anal. Chem., 78, 5412–5418, <a href="https://doi.org/10.1021/AC0604742" >doi:10.1021/AC0604742</a> (2006). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3506',
    'Feigenbrugel and Le Calvé (2021)',
    'Feigenbrugel, V. &#x0026; Le Calvé, S.: <span class="cmti-10">Temperature dependence of Henry&#x2019;s law</span> <span class="cmti-10">constants of fenpropidin and pyrimethanil: impact on their atmospheric</span> <span class="cmti-10">partitionnings and lifetimes</span>, J. Environ. Sci. Public Health, 5, 180–199, <a href="https://doi.org/10.26502/JESPH.96120124" >doi:10.26502/JESPH.96120124</a> (2021). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2818',
    'Feigenbrugel et&nbsp;al. (2004a)',
    'Feigenbrugel, V., Le Calvé, S., &#x0026; Mirabel, P.: <span class="cmti-10">Temperature dependence</span> <span class="cmti-10">of Henry&#x2019;s law constants of metolachlor and diazinon</span>, Chemosphere, 57, 319–327, <a href="https://doi.org/10.1016/J.CHEMOSPHERE.2004.05.013" >doi:10.1016/J.CHEMOSPHERE.2004.05.013</a> (2004a). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2488',
    'Feigenbrugel et&nbsp;al. (2004b)',
    'Feigenbrugel, V., Le Calvé, S., Mirabel, P., &#x0026; Louis, F.: <span class="cmti-10">Henry&#x2019;s law constant measurements for phenol,</span> <span class="cmmi-10">o</span><span class="cmti-10">-, </span><span class="cmmi-10">m</span><span class="cmti-10">-, and </span><span class="cmmi-10">p</span><span class="cmti-10">-cresol as a function of temperature</span>, Atmos. Environ., 38, 5577–5588, <a href="https://doi.org/10.1016/J.ATMOSENV.2004.06.025" >doi:10.1016/J.ATMOSENV.2004.06.025</a> (2004b). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3943',
    'Felder et&nbsp;al. (1986)',
    'Felder, J. D., Adams, W. J., &#x0026; Saeger, V. W.: <span class="cmti-10">Assessment of the safety of dioctyl adipate</span> <span class="cmti-10">in freshwater environments</span>, Environ. Toxicol. Chem., 5, 777–784, <a href="https://doi.org/10.1002/ETC.5620050809" >doi:10.1002/ETC.5620050809</a> (1986). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3077',
    'Feldhake and Stevens (1963)',
    'Feldhake, C. J. &#x0026; Stevens, C. D.: <span class="cmti-10">The</span> <span class="cmti-10">solubility of tetraethyllead in water</span>, J. Chem. Eng. Data, 8, 196–197, <a href="https://doi.org/10.1021/JE60017A016" >doi:10.1021/JE60017A016</a> (1963). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3527',
    'Fenclová et&nbsp;al. (2007)',
    'Fenclová, D., Dohnal, V., Vrbka, P., &#x0026; Laštovka, V.: <span class="cmti-10">Temperature dependence of</span> <span class="cmti-10">limiting activity coefficients, Henry&#x2019;s law constants, and related infinite</span> <span class="cmti-10">dilution properties of branched (C3 and C4) alkanols in water</span>, J. Chem. Eng. Data, 52, 989–1002, <a href="https://doi.org/10.1021/JE600567Z" >doi:10.1021/JE600567Z</a> (2007). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3633',
    'Fenclová et&nbsp;al. (2010)',
    'Fenclová, D., Dohnal, V., Vrbka, P., &#x0026; ehk, K.: <span class="cmti-10">Temperature dependence</span> <span class="cmti-10">of limiting activity coefficients, Henry&#x2019;s law constants, and related infinite</span> <span class="cmti-10">dilution properties of branched pentanols in water. Measurement, critical</span> <span class="cmti-10">compilation, correlation, and recommended data</span>, J. Chem. Eng. Data, 55, 3032–3043, <a href="https://doi.org/10.1021/JE901063S" >doi:10.1021/JE901063S</a> (2010). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3093',
    'Fenclová et&nbsp;al. (2014)',
    'Fenclová, D., Blahut, A., Vrbka, P., Dohnal, V., &#x0026; Böhme, A.: <span class="cmti-10">Temperature dependence of limiting activity coefficients, Henry&#x2019;s law</span> <span class="cmti-10">constants, and related infinite dilution properties of C4-C6 isomeric</span> <span class="cmmi-10">n</span><span class="cmti-10">-alkyl ethanoates/ethyl </span><span class="cmmi-10">n</span><span class="cmti-10">-alkanoates in water. Measurement, critical</span> <span class="cmti-10">compilation, correlation, and recommended data</span>, Fluid Phase Equilib., 375, 347–359, <a href="https://doi.org/10.1016/J.FLUID.2014.05.023" >doi:10.1016/J.FLUID.2014.05.023</a> (2014). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '900',
    'Fendinger and Glotfelty (1988)',
    'Fendinger, N. J. &#x0026; Glotfelty, D. E.: <span class="cmti-10">A</span> <span class="cmti-10">laboratory method for the experimental determination of air–water</span> <span class="cmti-10">Henry&#x2019;s law constants for several pesticides</span>, Environ. Sci. Technol., 22, 1289–1293, <a href="https://doi.org/10.1021/ES00176A007" >doi:10.1021/ES00176A007</a> (1988). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1144',
    'Fendinger and Glotfelty (1990)',
    'Fendinger, N. J. &#x0026; Glotfelty, D. E.: <span class="cmti-10">Henry&#x2019;s</span> <span class="cmti-10">law constants for selected pesticides, PAHs and PCBs</span>, Environ. Toxicol. Chem., 9, 731–735, <a href="https://doi.org/10.1002/ETC.5620090606" >doi:10.1002/ETC.5620090606</a> (1990). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '901',
    'Fendinger et&nbsp;al. (1989)',
    'Fendinger, N. J., Glotfelty, D. E., &#x0026; Freeman, H. P.: <span class="cmti-10">Comparison of two experimental</span> <span class="cmti-10">techniques for determining air/water Henry&#x2019;s law constants</span>, Environ. Sci. Technol., 23, 1528–1531, <a href="https://doi.org/10.1021/ES00070A013" >doi:10.1021/ES00070A013</a> (1989). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2105',
    'Fernández-Prini et&nbsp;al. (2003)',
    'Fernández-Prini, R., Alvarez, J. L., &#x0026; Harvey, A. H.: <span class="cmti-10">Henry&#x2019;s constants</span> <span class="cmti-10">and vapor-liquid distribution constants for gaseous solutes in</span> H<sub><span class="cmr-7">2</span></sub>O <span class="cmti-10">and</span> D<sub><span class="cmr-7">2</span></sub>O <span class="cmti-10">at high temperatures</span>, J. Phys. Chem. Ref. Data, 32, 903–916, <a href="https://doi.org/10.1063/1.1564818" >doi:10.1063/1.1564818</a> (2003). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2532',
    'Ferreira (2001)',
    'Ferreira, M. M. C.: <span class="cmti-10">Polycyclic aromatic hydrocarbons: a QSPR study</span>, Chemosphere, 44, 125–146, <a href="https://doi.org/10.1016/S0045-6535(00)00275-7" >doi:10.1016/S0045-6535(00)00275-7</a> (2001). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2462',
    'Fichan et&nbsp;al. (1999)',
    'Fichan, I., Larroche, C., &#x0026; Gros, J. B.: <span class="cmti-10">Water solubility, vapor pressure, and activity coefficients</span> <span class="cmti-10">of terpenes and terpenoids</span>, J. Chem. Eng. Data, 44, 56–62, <a href="https://doi.org/10.1021/JE980070+" >doi:10.1021/JE980070+</a> (1999). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '910',
    'Fickert (1998)',
    'Fickert, S.: Laboruntersuchungen zur Freisetzung photoreaktiver Halogenverbindungen aus Seesalzaerosol, Ph.D. thesis, Johannes Gutenberg-Universität, Mainz, Germany (1998). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2647',
    'Fischer et&nbsp;al. (2004)',
    'Fischer, A., Müller, M., &#x0026; Klasmeier, J.: <span class="cmti-10">Determination of Henry&#x2019;s law constant for methyl</span> <span class="cmti-10">tert-butyl ether (MTBE) at groundwater temperatures</span>, Chemosphere, 54, 689–694, <a href="https://doi.org/10.1016/J.CHEMOSPHERE.2003.08.025" >doi:10.1016/J.CHEMOSPHERE.2003.08.025</a> (2004). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3594',
    'Fischer and Tropsch (1917)',
    'Fischer, F. &#x0026; Tropsch, H.: <span class="cmti-10">Notiz </span><span class="cmti-10">über Farbe</span> <span class="cmti-10">und Oxydationswert einiger Ozonl</span><span class="cmti-10">ösungen</span>, Ber. Dtsch. Chem. Ges., 50, 765–767, <a href="https://doi.org/10.1002/CBER.191705001124" >doi:10.1002/CBER.191705001124</a> (1917). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '978',
    'Fischer and Ballschmiter (1998a)',
    'Fischer, R. G. &#x0026; Ballschmiter, K.: <span class="cmti-10">Determination of vapor pressure, water solubility, gas-water partition</span> <span class="cmti-10">coefficient </span><span class="cmmi-10">P</span><sub><span class="cmr-7">GW</span></sub><span class="cmti-10">, Henry&#x2019;s law constant, and octanol-water partition</span> <span class="cmti-10">coefficient </span><span class="cmmi-10">P</span><sub><span class="cmr-7">OW</span></sub> <span class="cmti-10">of 26 alkyl dinitrates</span>, Chemosphere, 36, 2891–2901, <a href="https://doi.org/10.1016/S0045-6535(97)10246-6" >doi:10.1016/S0045-6535(97)10246-6</a> (1998a). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '998',
    'Fischer and Ballschmiter (1998b)',
    'Fischer, R. G. &#x0026; Ballschmiter, K.: <span class="cmti-10">Prediction of the environmental distribution</span> <span class="cmti-10">of alkyl dinitrates – Chromatographic determination of vapor pressure</span> <span class="cmmi-10">p</span><sup><span class="cmr-7">0</span></sup><span class="cmti-10">, water solubility </span><span class="cmmi-10">S</span><sub><span class="cmr-7">H</span><sub><span class="cmr-5">2</span></sub><span class="cmr-7">O</span></sub><span class="cmti-10">, gas-water partition coefficient </span><span class="cmmi-10">K</span><sub><span class="cmr-7">GW</span></sub> <span class="cmti-10">(Henry&#x2019;s</span> <span class="cmti-10">law constant) and octanol-water partition coefficient </span><span class="cmmi-10">K</span><sub><span class="cmr-7">OW</span></sub>, Fresenius J. Anal. Chem., 360, 769–776, <a href="https://doi.org/10.1007/S002160050803" >doi:10.1007/S002160050803</a> (1998b). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2959',
    'Fishbein and Albro (1972)',
    'Fishbein, L. &#x0026; Albro, P. W.: <span class="cmti-10">Chromatographic</span> <span class="cmti-10">and biological aspects of the phthalate esters</span>, J. Chromatogr. A, 70, 365–412, <a href="https://doi.org/10.1016/S0021-9673(00)92702-X" >doi:10.1016/S0021-9673(00)92702-X</a> (1972). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1943',
    'Fogg and Sangster (2003)',
    'Fogg, P. &#x0026; Sangster, J.: Chemicals in the Atmosphere: Solubility, Sources and Reactivity, John Wiley &#x0026; Sons, Inc., ISBN 978-0-471-98651-5 (2003). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3863',
    'Fogg and Young (1988)',
    'Fogg, P. G. T. &#x0026; Young, C. L.: IUPAC Solubility Data Series, Volume 32, Hydrogen Sulfide, Deuterium Sulfide and Hydrogen Selenide, Pergamon Press, Oxford, <a href="https://doi.org/10.1016/C2009-0-00348-1" >doi:10.1016/C2009-0-00348-1</a> (1988). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3528',
    'Fogg et&nbsp;al. (2002)',
    'Fogg, P. G. T., Bligh, S.-W. A., Derrick, M. E., Yampol&#x2019;skii, Y. P., Clever, H. L., Skrzecz, A., Young, C. L., &#x0026; Fogg, P. G. T.: <span class="cmti-10">IUPAC-NIST</span> <span class="cmti-10">solubility data series. 76. Solubility of ethyne in liquids</span>, J. Phys. Chem. Ref. Data, 30, 1693–1876, <a href="https://doi.org/10.1063/1.1397768" >doi:10.1063/1.1397768</a> (2002). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    'foster94',
    'Foster et&nbsp;al. (1994)',
    'Foster, P., Ferronato, C., &#x0026; Jacob, V.: <span class="cmti-10">Organic-compound transfer between gas-phase and raindrops</span> <span class="cmti-10">– 1st experiments in a simulation chamber</span>, Fresenius Environ. Bull., 3, 318–323 (1994). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3716',
    'Fox (1909)',
    'Fox, C. J. J.: <span class="cmti-10">On the coefficients of absorption of nitrogen and</span> <span class="cmti-10">oxygen in distilled water and sea-water, and of atmospheric carbonic acid</span> <span class="cmti-10">in sea-water</span>, Trans. Faraday Soc., 5, 68–86, <a href="https://doi.org/10.1039/TF9090500068" >doi:10.1039/TF9090500068</a> (1909). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3300',
    'Franco et&nbsp;al. (2021)',
    'Franco, B., Blumenstock, T., Cho, C., Clarisse, L., Clerbaux, C., Coheur, P.-F., De Mazière, M., De Smedt, I., Dorn, H.-P., Emmerichs, T., Fuchs, H., Gkatzelis, G., Griffith, D. W. T., Gromov, S., Hannigan, J. W., Hase, F., Hohaus, T., Jones, N., Kerkweg, A., Kiendler-Scharr, A., Lutsch, E., Mahieu, E., Novelli, A., Ortega, I., Paton-Walsh, C., Pommier, M., Pozzer, A., Reimer, D., Rosanka, S., Sander, R., Schneider, M., Strong, K., Tillmann, R., Van Roozendael, M., Vereecken, L., Vigouroux, C., Wahner, A., &#x0026; Taraborrelli, D.: <span class="cmti-10">Ubiquitous atmospheric</span> <span class="cmti-10">production of organic acids mediated by cloud droplets</span>, Nature, 593, 233–237, <a href="https://doi.org/10.1038/S41586-021-03462-X" >doi:10.1038/S41586-021-03462-X</a> (2021). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1913',
    'Fredenhagen and Liebster (1932)',
    'Fredenhagen, K. &#x0026; Liebster, H.: <span class="cmti-10">Die Teildrucke und Verteilungszahlen der Essigs</span><span class="cmti-10">äure </span><span class="cmti-10">über</span> <span class="cmti-10">ihren w</span><span class="cmti-10">ässerigen L</span><span class="cmti-10">ösungen bei 25</span><span class="cmsy-7">∘</span>C, Z. Phys. Chem., 162A, 449–453, <a href="https://doi.org/10.1515/ZPCH-1932-16234" >doi:10.1515/ZPCH-1932-16234</a> (1932). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1914',
    'Fredenhagen and Wellmann (1932a)',
    'Fredenhagen, K. &#x0026; Wellmann, M.: <span class="cmti-10">Verteilungszahlen des Fluorwasserstoffs </span><span class="cmti-10">über</span> <span class="cmti-10">dem Zweistoffsystem [</span>H<sub><span class="cmr-7">2</span></sub>O<span class="cmti-10">-</span>HF<span class="cmti-10">] bei 25</span><span class="cmsy-7">∘</span>C <span class="cmti-10">und die Siedepunktskurve</span> <span class="cmti-10">dieses Systems bei Atmosph</span><span class="cmti-10">ärendruck</span>, Z. Phys. Chem., 162A, 454–466, <a href="https://doi.org/10.1515/ZPCH-1932-16235" >doi:10.1515/ZPCH-1932-16235</a> (1932a). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1915',
    'Fredenhagen and Wellmann (1932b)',
    'Fredenhagen, K. &#x0026; Wellmann, M.: <span class="cmti-10">Verteilungszahlen des Cyanwasserstoffs und des Wassers </span><span class="cmti-10">über dem</span> <span class="cmti-10">Zweistoffsystem [</span>H<sub><span class="cmr-7">2</span></sub>O<span class="cmti-10">-</span>HCN<span class="cmti-10">] bei 18</span><span class="cmsy-7">∘</span>C, Z. Phys. Chem., 162A, 467–470, <a href="https://doi.org/10.1515/ZPCH-1932-16236" >doi:10.1515/ZPCH-1932-16236</a> (1932b). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '937',
    'Frenzel et&nbsp;al. (1998)',
    'Frenzel, A., Scheer, V., Sikorski, R., George, C., Behnke, W., &#x0026; Zetzsch, C.: <span class="cmti-10">Heterogeneous interconversion reactions of</span> BrNO<sub><span class="cmr-7">2</span></sub><span class="cmti-10">,</span> ClNO<sub><span class="cmr-7">2</span></sub><span class="cmti-10">,</span> Br<sub><span class="cmr-7">2</span></sub><span class="cmti-10">, and</span> Cl<sub><span class="cmr-7">2</span></sub>, J. Phys. Chem. A, 102, 1329–1337, <a href="https://doi.org/10.1021/JP973044B" >doi:10.1021/JP973044B</a> (1998). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3531',
    'Frenzel et&nbsp;al. (2000)',
    'Frenzel, A., Kutsuna, S., Takeuchi, K., &#x0026; Ibusuki, T.: <span class="cmti-10">Solubility</span> <span class="cmti-10">and reactivity of peroxyacetyl nitrate (PAN) in dilute aqueous salt</span> <span class="cmti-10">solutions and in sulphuric acid</span>, Atmos. Environ., 34, 3641–3644, <a href="https://doi.org/10.1016/S1352-2310(00)00132-1" >doi:10.1016/S1352-2310(00)00132-1</a> (2000). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '729',
    'Friant and Suffet (1979)',
    'Friant, S. L. &#x0026; Suffet, I. H.: <span class="cmti-10">Interactive effects of</span> <span class="cmti-10">temperature, salt concentration, and pH on head space analysis for</span> <span class="cmti-10">isolating volatile trace organics in aqueous environmental samples</span>, Anal. Chem., 51, 2167–2172, <a href="https://doi.org/10.1021/AC50049A027" >doi:10.1021/AC50049A027</a> (1979). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '514',
    'Fried et&nbsp;al. (1994)',
    'Fried, A., Henry, B. E., Calvert, J. G., &#x0026; Mozurkewich, M.: <span class="cmti-10">The reaction probability</span> <span class="cmti-10">of</span> N<sub><span class="cmr-7">2</span></sub>O<sub><span class="cmr-7">5</span></sub> <span class="cmti-10">with sulfuric acid aerosols at stratospheric temperatures and</span> <span class="cmti-10">compositions</span>, J. Geophys. Res., 99, 3517–3532, <a href="https://doi.org/10.1029/93JD01907" >doi:10.1029/93JD01907</a> (1994). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3801',
    'Friedman (1954)',
    'Friedman, H. L.: <span class="cmti-10">The solubilities of sulfur hexafluoride</span> <span class="cmti-10">in water and of the rare gases, sulfur hexafluoride and osmium</span> <span class="cmti-10">tetroxide in nitromethane</span>, J. Am. Chem. Soc., 76, 3294–3297, <a href="https://doi.org/10.1021/JA01641A065" >doi:10.1021/JA01641A065</a> (1954). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2945',
    'Friesen et&nbsp;al. (1993)',
    'Friesen, K. J., Loewen, M. D., Fairchild, W. L., Lawrence, S. G., Holoka, M. H., &#x0026; Muir, D. C. G.: <span class="cmti-10">Evidence for particle-mediated</span> <span class="cmti-10">transport of 2,3,7,8-tetrachlorodibenzofuran during gas sparging</span> <span class="cmti-10">of natural water</span>, Environ. Toxicol. Chem., 12, 2037–2044, <a href="https://doi.org/10.1002/ETC.5620121110" >doi:10.1002/ETC.5620121110</a> (1993). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3033',
    'Fu et&nbsp;al. (2013)',
    'Fu, M., Yu, Z., Lu, G., &#x0026; Song, X.: <span class="cmti-10">Henry&#x2019;s law constant for phosphine in seawater: determination and</span> <span class="cmti-10">assessment of influencing factors</span>, Chin. J. Oceanol. Limnol., 31, 860–866, <a href="https://doi.org/10.1007/S00343-013-2212-1" >doi:10.1007/S00343-013-2212-1</a> (2013). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3693',
    'Fukuchi et&nbsp;al. (2002)',
    'Fukuchi, K., Miyoshi, K., Watanabe, T., Yonezawa, S., &#x0026; Arai, Y.: <span class="cmti-10">Measurement and correlation of infinite dilution activity coefficients of</span> <span class="cmti-10">alkanol or ether in aqueous solution</span>, Fluid Phase Equilib., 194-197, 937–945, <a href="https://doi.org/10.1016/S0378-3812(01)00675-6" >doi:10.1016/S0378-3812(01)00675-6</a> (2002). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3701',
    'Gabel and Schultz (1973)',
    'Gabel, R. A. &#x0026; Schultz, B.: <span class="cmti-10">Solubility of nitrous oxide in water, 20–80 C</span>, Anesthesiology, 38, 75–81, <a href="https://doi.org/10.1097/00000542-197301000-00019" >doi:10.1097/00000542-197301000-00019</a> (1973). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    'gaffney84',
    'Gaffney and Senum (1984)',
    'Gaffney, J. S. &#x0026; Senum, G. I.: <span class="cmti-10">Peroxides,</span> <span class="cmti-10">peracids, aldehydes, and PANs and their links to natural and</span> <span class="cmti-10">anthropogenic organic sources</span>, in: Gas-Liquid Chemistry of Natural Waters, edited by Newman, L., pp. 5–1–5–7, NTIS TIC-4500, UC-11, BNL 51757 Brookhaven National Laboratory (1984). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '715',
    'Gaffney et&nbsp;al. (1987)',
    'Gaffney, J. S., Streit, G. E., Spall, W. D., &#x0026; Hall, J. H.: <span class="cmti-10">Beyond acid rain. Do soluble oxidants</span> <span class="cmti-10">and organic toxins interact with</span> SO<sub><span class="cmr-7">2</span></sub> <span class="cmti-10">and</span> NO<sub><span class="cmr-7">x</span></sub> <span class="cmti-10">to increase ecosystem</span> <span class="cmti-10">effects?</span>, Environ. Sci. Technol., 21, 519–524, <a href="https://doi.org/10.1021/ES00160A001" >doi:10.1021/ES00160A001</a> (1987). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3963',
    'Galib and Limmer (2021)',
    'Galib, M. &#x0026; Limmer, D. T.: <span class="cmti-10">Reactive uptake of</span> N<sub><span class="cmr-7">2</span></sub>O<sub><span class="cmr-7">5</span></sub> <span class="cmti-10">by atmospheric aerosol is dominated by interfacial processes</span>, Science, 371, 921–925, <a href="https://doi.org/10.1126/SCIENCE.ABD7716" >doi:10.1126/SCIENCE.ABD7716</a> (2021). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '892',
    'Gan and Yates (1996)',
    'Gan, J. &#x0026; Yates, S. R.: <span class="cmti-10">Degradation and phase</span> <span class="cmti-10">partition of methyl iodide in soil</span>, J. Agric. Food Chem., 44, 4001–4008, <a href="https://doi.org/10.1021/JF960413C" >doi:10.1021/JF960413C</a> (1996). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2902',
    'Garbarini and Lion (1985)',
    'Garbarini, D. R. &#x0026; Lion, L. W.: <span class="cmti-10">Evaluation</span> <span class="cmti-10">of sorptive partitioning of nonionic pollutants in closed systems</span> <span class="cmti-10">by headspace analysis</span>, Environ. Sci. Technol., 19, 1122–1128, <a href="https://doi.org/10.1021/ES00141A018" >doi:10.1021/ES00141A018</a> (1985). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3748',
    'Gatterer (1926)',
    'Gatterer, A.: <span class="cmti-10">XXXIX.—The absorption of gases by colloidal solutions</span>, J. Chem. Soc., 129, 299–316, <a href="https://doi.org/10.1039/JR9262900299" >doi:10.1039/JR9262900299</a> (1926). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2438',
    'Gautier et&nbsp;al. (2003)',
    'Gautier, C., Le Calvé, S., &#x0026; Mirabel, P.: <span class="cmti-10">Henry&#x2019;s law constants measurements of alachlor and</span> <span class="cmti-10">dichlorvos between 283 and 298 </span>K, Atmos. Environ., 37, 2347–2353, <a href="https://doi.org/10.1016/S1352-2310(03)00155-9" >doi:10.1016/S1352-2310(03)00155-9</a> (2003). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3711',
    'Geffcken (1904)',
    'Geffcken, G.: <span class="cmti-10">Beitr</span><span class="cmti-10">äge zur Kenntnis der L</span><span class="cmti-10">öslichkeitsbeeinflussung</span>, Z. Phys. Chem., 49, 257–302, <a href="https://doi.org/10.1515/ZPCH-1904-4925" >doi:10.1515/ZPCH-1904-4925</a> (1904). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    'george93',
    'George et&nbsp;al. (1993)',
    'George, C., Ponche, J. L., &#x0026; Mirabel, P.: <span class="cmti-10">Experimental determination of uptake coefficients for acid</span> <span class="cmti-10">halides</span>, in: Proceedings of Workshop on STEP-HALOCSIDE, AFEAS, Dublin, 23–25 March (1993). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1126',
    'George et&nbsp;al. (1994a)',
    'George, C., Lagrange, J., Lagrange, P., Mirabel, P., Pallares, C., &#x0026; Ponche, J. L.: <span class="cmti-10">Heterogeneous chemistry of trichloroacetyl chloride in the</span> <span class="cmti-10">atmosphere</span>, J. Geophys. Res., 99, 1255–1262, <a href="https://doi.org/10.1029/93JD02915" >doi:10.1029/93JD02915</a> (1994a). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1127',
    'George et&nbsp;al. (1994b)',
    'George, C., Saison, J. Y., Ponche, J. L., &#x0026; Mirabel, P.: <span class="cmti-10">Kinetics of mass</span> <span class="cmti-10">transfer of carbonyl fluoride, trifluoroacetyl fluoride, and trifluoroacetyl</span> <span class="cmti-10">chloride at the air/water interface</span>, J. Phys. Chem., 98, 10 857–10 862, <a href="https://doi.org/10.1021/J100093A029" >doi:10.1021/J100093A029</a> (1994b). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2512',
    'Gershenzon et&nbsp;al. (2001)',
    'Gershenzon, M., Davidovits, P., Jayne, J. T., Kolb, C. E., &#x0026; Worsnop, D. R.: <span class="cmti-10">Simultaneous uptake of DMS and ozone on water</span>, J. Phys. Chem. A, 105, 7031–7036, <a href="https://doi.org/10.1021/JP010696Y" >doi:10.1021/JP010696Y</a> (2001). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3579',
    'Gharagheizi et&nbsp;al. (2010)',
    'Gharagheizi, F., Abbasi, R., &#x0026; Tirandazi, B.: <span class="cmti-10">Prediction of Henry&#x2019;s law constant of</span> <span class="cmti-10">organic compounds in water from a new group-contribution-based model</span>, Ind. Eng. Chem. Res., 49, 10 149–10 152, <a href="https://doi.org/10.1021/IE101532E" >doi:10.1021/IE101532E</a> (2010). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3406',
    'Gharagheizi et&nbsp;al. (2012)',
    'Gharagheizi, F., Eslamimanesh, A., Mohammadi, A. H., &#x0026; Richon, D.: <span class="cmti-10">Empirical method for estimation of Henry&#x2019;s law constant of</span> <span class="cmti-10">non-electrolyte organic compounds in water</span>, J. Chem. Thermodyn., 47, 295–299, <a href="https://doi.org/10.1016/J.JCT.2011.11.015" >doi:10.1016/J.JCT.2011.11.015</a> (2012). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3078',
    'Giardino et&nbsp;al. (1988)',
    'Giardino, N. J., Andelman, J. B., Borrazzo, J. E., &#x0026; Davidson, C. I.: <span class="cmti-10">Sulfur hexafluoride as a surrogate for volatilization of organics</span> <span class="cmti-10">from indoor water uses</span>, J. Air Pollut. Control Assoc., 38, 278–279, <a href="https://doi.org/10.1080/08940630.1988.10466379" >doi:10.1080/08940630.1988.10466379</a> (1988). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2014',
    'Gibbs et&nbsp;al. (1991)',
    'Gibbs, P., Radzicka, A., &#x0026; Wolfenden, R.: <span class="cmti-10">The anomalous hydrophilic character of proline</span>, J. Am. Chem. Soc., 113, 4714–4715, <a href="https://doi.org/10.1021/JA00012A068" >doi:10.1021/JA00012A068</a> (1991). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2224',
    'Gill et&nbsp;al. (1976)',
    'Gill, S. J., Nichols, N. F., &#x0026; Wadsö, I.: <span class="cmti-10">Calorimetric determination of enthalpies of solution of slightly</span> <span class="cmti-10">soluble liquids II. Enthalpy of solution of some hydrocarbons in water and</span> <span class="cmti-10">their use in establishing the temperature dependence of their solubilities</span>, J. Chem. Thermodyn., 8, 445–452, <a href="https://doi.org/10.1016/0021-9614(76)90065-3" >doi:10.1016/0021-9614(76)90065-3</a> (1976). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    'giona69',
    'Giona et&nbsp;al. (1969)',
    'Giona, A. R., Passino, A., &#x0026; Turriziani, R.: <span class="cmti-10">Assorbimento del bromo in acqua</span>, La Ricerca Scientifica, 30, 2047–2056 (1969). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2578',
    'Glew and Hames (1971)',
    'Glew, D. N. &#x0026; Hames, D. A.: <span class="cmti-10">Aqueous nonelectrolyte solutions. Part X. Mercury solubility in</span> <span class="cmti-10">water</span>, Can. J. Chem., 49, 3114–3118, <a href="https://doi.org/10.1139/V71-520" >doi:10.1139/V71-520</a> (1971). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2222',
    'Glew and Moelwyn-Hughes (1953)',
    'Glew, D. N. &#x0026; Moelwyn-Hughes, E. A.: <span class="cmti-10">Chemical statics of the methyl halides in water</span>, Discuss. Faraday Soc., 15, 150–161, <a href="https://doi.org/10.1039/DF9531500150" >doi:10.1039/DF9531500150</a> (1953). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2452',
    'Glotfelty et&nbsp;al. (1987)',
    'Glotfelty, D. E., Seiber, J. N., &#x0026; Liljedahl, A.: <span class="cmti-10">Pesticides in fog</span>, Nature, 325, 602–605, <a href="https://doi.org/10.1038/325602A0" >doi:10.1038/325602A0</a> (1987). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '752',
    'Gmitro and Vermeulen (1964)',
    'Gmitro, J. I. &#x0026; Vermeulen, T.: <span class="cmti-10">Vapor-liquid</span> <span class="cmti-10">equilibria for aqueous sulfuric acid</span>, AIChE J., 10, 740–746, <a href="https://doi.org/10.1002/AIC.690100531" >doi:10.1002/AIC.690100531</a> (1964). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    'usepa82',
    'Goldstein (1982)',
    'Goldstein, D. J.: <span class="cmti-10">Air and steam</span> <span class="cmti-10">stripping of toxic pollutants, Appendix 3: Henry&#x2019;s law constants</span>, Tech. Rep. EPA-68-03-002, Industrial Environmental Research Laboratory, Cincinnati, OH, USA (1982). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3729',
    'Goodarzi et&nbsp;al. (2010)',
    'Goodarzi, M., Ortiz, E. V., Coelho, L. D. S., &#x0026; Duchowicz, P. R.: <span class="cmti-10">Linear and non-linear relationships mapping the Henry&#x2019;s law</span> <span class="cmti-10">parameters of organic pesticides</span>, Atmos. Environ., 44, 3179–3186, <a href="https://doi.org/10.1016/J.ATMOSENV.2010.05.025" >doi:10.1016/J.ATMOSENV.2010.05.025</a> (2010). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3935',
    'Goodwin (1883)',
    'Goodwin, W. L.: <span class="cmti-10">XXVI.—On the nature of solution. Part</span> <span class="cmti-10">I.—On the solubility of chlorine in water, and in aqueous solutions of</span> <span class="cmti-10">soluble chlorides</span>, Earth Environ. Sci. Trans. R. Soc. Edinburgh, 30, 597–618, <a href="https://doi.org/10.1017/S0080456800025096" >doi:10.1017/S0080456800025096</a> (1883). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3782',
    'Gordon et&nbsp;al. (1977)',
    'Gordon, L. I., Cohen, Y., &#x0026; Standley, D. R.: <span class="cmti-10">The solubility of molecular hydrogen in seawater</span>, Deep-Sea Res., 24, 937–941, <a href="https://doi.org/10.1016/0146-6291(77)90563-X" >doi:10.1016/0146-6291(77)90563-X</a> (1977). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    'gordon1895',
    'Gordon (1895)',
    'Gordon, V.: <span class="cmti-10">Ueber die Absorption des Stickoxyduls</span> <span class="cmti-10">in Wasser und in Salzl</span><span class="cmti-10">ösungen</span>, Z. Phys. Chem., 18, 1–16, <a href="https://doi.org/10.1515/ZPCH-1895-1802" >doi:10.1515/ZPCH-1895-1802</a> (1895). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2953',
    'Görgényi et&nbsp;al. (2002)',
    'Görgényi, M., Dewulf, J., &#x0026; Van Langenhove, H.: <span class="cmti-10">Temperature dependence of</span> <span class="cmti-10">Henry&#x2019;s law constant in an extended temperature range</span>, Chemosphere, 48, 757–762, <a href="https://doi.org/10.1016/S0045-6535(02)00131-5" >doi:10.1016/S0045-6535(02)00131-5</a> (2002). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3780',
    'Goss (2005)',
    'Goss, K.-U.: <span class="cmti-10">Predicting the equilibrium partitioning of organic</span> <span class="cmti-10">compounds using just one linear solvation energy relationship (LSER)</span>, Fluid Phase Equilib., 233, 19–22, <a href="https://doi.org/10.1016/J.FLUID.2005.04.006" >doi:10.1016/J.FLUID.2005.04.006</a> (2005). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2993',
    'Goss et&nbsp;al. (2006)',
    'Goss, K. U., Bronner, G., Harner, T., Hertel, M., &#x0026; Schmidt, T.: <span class="cmti-10">The partition</span> <span class="cmti-10">behavior of fluorotelomer alcohols and olefins</span>, Environ. Sci. Technol., 40, 3572–3577, <a href="https://doi.org/10.1021/ES060004P" >doi:10.1021/ES060004P</a> (2006). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2951',
    'Gossett (1980)',
    'Gossett, J. M.: <span class="cmti-10">Packed tower air</span> <span class="cmti-10">stripping of trichloroethylene from dilute aqueous solution</span>, Final Report ESL-TR-81-38, Engineering and Services Laboratory, Tyndall Air Force Base, FL (1980). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '532',
    'Gossett (1987)',
    'Gossett, J. M.: <span class="cmti-10">Measurement of Henry&#x2019;s law constants for</span> C<sub><span class="cmr-7">1</span></sub> <span class="cmti-10">and</span> C<sub><span class="cmr-7">2</span></sub> <span class="cmti-10">chlorinated hydrocarbons</span>, Environ. Sci. Technol., 21, 202–208, <a href="https://doi.org/10.1021/ES00156A012" >doi:10.1021/ES00156A012</a> (1987). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2269',
    'Gossett et&nbsp;al. (1985)',
    'Gossett, J. M., Cameron, C. E., Eckstrom, B. P., Goodman, C., &#x0026; Lincoff, A. H.: <span class="cmti-10">Mass transfer coefficients and Henry&#x2019;s constants</span> <span class="cmti-10">for packed-tower air stripping of volatile organics: Measurements and</span> <span class="cmti-10">Correlations</span>, Final Report ESL-TR-85-18, Engineering and Services Laboratory, Tyndall Air Force Base, FL (1985). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1112',
    'Govers and Krop (1998)',
    'Govers, H. A. J. &#x0026; Krop, H. B.: <span class="cmti-10">Partition constants</span> <span class="cmti-10">of chlorinated dibenzofurans and dibenzo-p-dioxins</span>, Chemosphere, 37, 2139–2152, <a href="https://doi.org/10.1016/S0045-6535(98)00276-8" >doi:10.1016/S0045-6535(98)00276-8</a> (1998). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '82',
    'Graedel and Goldberg (1983)',
    'Graedel, T. E. &#x0026; Goldberg, K. I.: <span class="cmti-10">Kinetic</span> <span class="cmti-10">studies of raindrop chemistry 1.</span><span class="cmti-10"> Inorganic and organic processes</span>, J. Geophys. Res., 88, 10 865–10 882, <a href="https://doi.org/10.1029/JC088IC15P10865" >doi:10.1029/JC088IC15P10865</a> (1983). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2942',
    'Green and Frank (1979)',
    'Green, W. J. &#x0026; Frank, H. S.: <span class="cmti-10">The state of</span> <span class="cmti-10">dissolved benzene in aqueous solution</span>, J. Solution Chem., 8, 187–196, <a href="https://doi.org/10.1007/BF00648878" >doi:10.1007/BF00648878</a> (1979). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3715',
    'Grollman (1929)',
    'Grollman, A.: <span class="cmti-10">The solubility of gases in blood and blood</span> <span class="cmti-10">fluids</span>, J. Biol. Chem., 82, 317–325, <a href="https://doi.org/10.1016/S0021-9258(20)78278-5" >doi:10.1016/S0021-9258(20)78278-5</a> (1929). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2924',
    'Guitart et&nbsp;al. (1989)',
    'Guitart, R., Puigdemont, F., &#x0026; Arboix, M.: <span class="cmti-10">Rapid headspace gas chromatographic</span> <span class="cmti-10">method for the determination of liquid/gas partition coefficients</span>, J. Chromatogr., 491, 271–280, <a href="https://doi.org/10.1016/S0378-4347(00)82845-5" >doi:10.1016/S0378-4347(00)82845-5</a> (1989). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2183',
    'Guo and Brimblecombe (2007)',
    'Guo, X. X. &#x0026; Brimblecombe, P.: <span class="cmti-10">Henry&#x2019;s law constants of phenol and</span> <span class="cmti-10">mononitrophenols in water and aqueous sulfuric acid</span>, Chemosphere, 68, 436–444, <a href="https://doi.org/10.1016/J.CHEMOSPHERE.2007.01.011" >doi:10.1016/J.CHEMOSPHERE.2007.01.011</a> (2007). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2961',
    'Gupta et&nbsp;al. (2000)',
    'Gupta, A. K., Teja, A. S., Chai, X. S., &#x0026; Zhu, J. Y.: <span class="cmti-10">Henry&#x2019;s constants of </span><span class="cmmi-10">n</span><span class="cmti-10">-alkanols (methanol</span> <span class="cmti-10">through </span><span class="cmmi-10">n</span><span class="cmti-10">-hexanol) in water at temperatures between 40</span><span class="cmsy-7">∘</span>C <span class="cmti-10">and 90</span><span class="cmsy-7">∘</span>C, Fluid Phase Equilib., 170, 183–192, <a href="https://doi.org/10.1016/S0378-3812(00)00350-2" >doi:10.1016/S0378-3812(00)00350-2</a> (2000). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3591',
    'Gurol and Singer (1982)',
    'Gurol, M. D. &#x0026; Singer, P. C.: <span class="cmti-10">Kinetics of ozone</span> <span class="cmti-10">decomposition: a dynamic approach</span>, Environ. Sci. Technol., 16, 377–383, <a href="https://doi.org/10.1021/ES00101A003" >doi:10.1021/ES00101A003</a> (1982). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '794',
    'Guthrie (1973)',
    'Guthrie, J. P.: <span class="cmti-10">Hydration of carboxylic acids and esters.</span> <span class="cmti-10">Evaluation of the free energy change for addition of water to acetic and</span> <span class="cmti-10">formic acids and their methyl esters</span>, J. Am. Chem. Soc., 95, 6999–7003, <a href="https://doi.org/10.1021/JA00802A021" >doi:10.1021/JA00802A021</a> (1973). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3304',
    'Haimi et&nbsp;al. (2006)',
    'Haimi, P., Uusi-Kyyny, P., Pokki, J.-P., Aittamaa, J., &#x0026; Keskinen, K. I.: <span class="cmti-10">Infinite dilution activity coefficient</span> <span class="cmti-10">measurements by inert gas stripping method</span>, Fluid Phase Equilib., 243, 126–132, <a href="https://doi.org/10.1016/J.FLUID.2006.02.022" >doi:10.1016/J.FLUID.2006.02.022</a> (2006). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '482',
    'Hales and Drewes (1979)',
    'Hales, J. M. &#x0026; Drewes, D. R.: <span class="cmti-10">Solubility of</span> <span class="cmti-10">ammonia in water at low concentrations</span>, Atmos. Environ., 13, 1133–1147, <a href="https://doi.org/10.1016/0004-6981(79)90037-4" >doi:10.1016/0004-6981(79)90037-4</a> (1979). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3955',
    'Haller and Northgraves (1955)',
    'Haller, J. F. &#x0026; Northgraves, W. W.: <span class="cmti-10">Chlorine dioxide and safety</span>, TAPPI, 38, 199–202 (1955). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2456',
    'Hamelink et&nbsp;al. (1996)',
    'Hamelink, J. L., Simon, P. B., &#x0026; Silberhorn, E. M.: <span class="cmti-10">Henry&#x2019;s law constant, volatilization</span> <span class="cmti-10">rate, and aquatic half-life of octamethylcyclotetrasiloxane</span>, Environ. Sci. Technol., 30, 1946–1952, <a href="https://doi.org/10.1021/ES950634J" >doi:10.1021/ES950634J</a> (1996). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '632',
    'Hamm et&nbsp;al. (1984)',
    'Hamm, S., Hahn, J., Helas, G., &#x0026; Warneck, P.: <span class="cmti-10">Acetonitrile in the troposphere: residence</span> <span class="cmti-10">time due to rainout and uptake by the ocean</span>, Geophys. Res. Lett., 11, 1207–1210, <a href="https://doi.org/10.1029/GL011I012P01207" >doi:10.1029/GL011I012P01207</a> (1984). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '903',
    'Hansen et&nbsp;al. (1993)',
    'Hansen, K. C., Zhou, Z., Yaws, C. L., &#x0026; Aminabhavi, T. M.: <span class="cmti-10">Determination of Henry&#x2019;s</span> <span class="cmti-10">law constants of organics in dilute aqueous solutions</span>, J. Chem. Eng. Data, 38, 546–550, <a href="https://doi.org/10.1021/JE00012A017" >doi:10.1021/JE00012A017</a> (1993). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '618',
    'Hansen et&nbsp;al. (1995)',
    'Hansen, K. C., Zhou, Z., Yaws, C. L., &#x0026; Aminabhavi, T. M.: <span class="cmti-10">A laboratory method for</span> <span class="cmti-10">the determination of Henry&#x2019;s law constants of volatile organic chemicals</span>, J. Chem. Educ., 72, 93–96, <a href="https://doi.org/10.1021/ED072P93" >doi:10.1021/ED072P93</a> (1995). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '183',
    'Hanson and Ravishankara (1991)',
    'Hanson, D. R. &#x0026; Ravishankara, A. R.: <span class="cmti-10">The reaction probabilities of</span> ClONO<sub><span class="cmr-7">2</span></sub> <span class="cmti-10">and</span> N<sub><span class="cmr-7">2</span></sub>O<sub><span class="cmr-7">5</span></sub> <span class="cmti-10">on 40 to 75% sulfuric acid solutions</span>, J. Geophys. Res., 96, 17 307–17 314, <a href="https://doi.org/10.1029/91JD01750" >doi:10.1029/91JD01750</a> (1991). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '515',
    'Hanson et&nbsp;al. (1992)',
    'Hanson, D. R., Burkholder, J. B., Howard, C. J., &#x0026; Ravishankara, A. R.: <span class="cmti-10">Measurement of</span> OH <span class="cmti-10">and</span> HO<sub><span class="cmr-7">2</span></sub> <span class="cmti-10">radical uptake coefficients on</span> <span class="cmti-10">water and sulfuric acid surfaces</span>, J. Phys. Chem., 96, 4979–4985, <a href="https://doi.org/10.1021/J100191A046" >doi:10.1021/J100191A046</a> (1992). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3660',
    'Harger et&nbsp;al. (1950)',
    'Harger, R. N., Raney, B. B., Bridwell, E. G., &#x0026; Kitchel, M. F.: <span class="cmti-10">The partition ratio of alcohol between air and water, urine and</span> <span class="cmti-10">blood; estimation and identification of alcohol in these liquids from</span> <span class="cmti-10">analysis of air equilibrated with them</span>, J. Biol. Chem., 183, 197–213, <a href="https://doi.org/10.1016/S0021-9258(18)56458-9" >doi:10.1016/S0021-9258(18)56458-9</a> (1950). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    'harris51',
    'Harris (1951)',
    'Harris, T. A. B.: The Mode of Action of Anaesthetics, E. &#x0026; S. Livingstone (1951). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1912',
    'Harrison et&nbsp;al. (1993)',
    'Harrison, D. P., Valsaraj, K. T., &#x0026; Wetzel, D. M.: <span class="cmti-10">Air stripping of organics from ground</span> <span class="cmti-10">water</span>, Waste Manage., 13, 417–429, <a href="https://doi.org/10.1016/0956-053X(93)90074-7" >doi:10.1016/0956-053X(93)90074-7</a> (1993). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1513',
    'Harrison et&nbsp;al. (2002)',
    'Harrison, M. A. J., Cape, J. N., &#x0026; Heal, M. R.: <span class="cmti-10">Experimentally determined</span> <span class="cmti-10">Henry&#x2019;s Law coefficients of phenol, 2-methylphenol and 2-nitrophenol</span> <span class="cmti-10">in the temperature range 281-302 </span>K, Atmos. Environ., 36, 1843–1851, <a href="https://doi.org/10.1016/S1352-2310(02)00137-1" >doi:10.1016/S1352-2310(02)00137-1</a> (2002). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '640',
    'Hartkopf and Karger (1973)',
    'Hartkopf, A. &#x0026; Karger, B. L.: <span class="cmti-10">Study of the</span> <span class="cmti-10">interfacial properties of water by gas chromatography</span>, Acc. Chem. Res., 6, 209–216, <a href="https://doi.org/10.1021/AR50066A006" >doi:10.1021/AR50066A006</a> (1973). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3524',
    'Haruta et&nbsp;al. (2011)',
    'Haruta, S., Jiao, W., Chen, W., Chang, A. C., &#x0026; Gan, J.: <span class="cmti-10">Evaluating Henry&#x2019;s law constant</span> <span class="cmti-10">of N-Nitrosodimethylamine (NDMA)</span>, Wat. Sci. Tech., 64, 1636–1641, <a href="https://doi.org/10.2166/WST.2011.742" >doi:10.2166/WST.2011.742</a> (2011). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1024',
    'Hauff et&nbsp;al. (1998)',
    'Hauff, K., Fischer, R. G., &#x0026; Ballschmiter, K.: <span class="cmti-10">Determination of</span> C<sub><span class="cmr-7">1</span></sub><span class="cmti-10">-</span>C<sub><span class="cmr-7">5</span></sub> <span class="cmti-10">alkyl nitrates in rain, snow, white frost, and tap water by a combined</span> <span class="cmti-10">codistillation head-space gas chromatography technique. Determination of</span> <span class="cmti-10">Henry&#x2019;s law constants by head-space GC</span>, Chemosphere, 37, 2599–2615, <a href="https://doi.org/10.1016/S0045-6535(98)00159-3" >doi:10.1016/S0045-6535(98)00159-3</a> (1998). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2232',
    'Hawthorne et&nbsp;al. (1985)',
    'Hawthorne, S. B., Sievers, R. E., &#x0026; Barkley, R. M.: <span class="cmti-10">Organic emissions from shale oil</span> <span class="cmti-10">wastewaters and their implications for air quality</span>, Environ. Sci. Technol., 19, 992–997, <a href="https://doi.org/10.1021/ES00140A018" >doi:10.1021/ES00140A018</a> (1985). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3855',
    'Hayduk (1982)',
    'Hayduk, W.: IUPAC Solubility Data Series, Volume 9, Ethane, Pergamon Press, Oxford, ISBN 0080262309 (1982). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3860',
    'Hayduk (1986)',
    'Hayduk, W.: IUPAC Solubility Data Series, Volume 24, Propane, Butane and 2-Methylpropane, Pergamon Press, Oxford, ISBN 008029202X (1986). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3869',
    'Hayduk (1994)',
    'Hayduk, W.: IUPAC Solubility Data Series, Volume 57, Ethene, Pergamon Press, Oxford (1994). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3728',
    'Hayer et&nbsp;al. (2022)',
    'Hayer, N., Jirasek, F., &#x0026; Hasse, H.: <span class="cmti-10">Prediction of Henry&#x2019;s law constants by matrix completion</span>, AIChE J., 68, e17 753, <a href="https://doi.org/10.1002/AIC.17753" >doi:10.1002/AIC.17753</a> (2022). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3034',
    'Haynes (2014)',
    'Haynes, W. M.: CRC Handbook of Chemistry and Physics, 95th Edition (Internet Version 2015), Taylor and Francis Group, <a href="https://doi.org/10.1201/b17118" >doi:10.1201/b17118</a> (2014). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1484',
    'Heal et&nbsp;al. (1995)',
    'Heal, M. R., Pilling, M. J., Titcombe, P. E., &#x0026; Whitaker, B. J.: <span class="cmti-10">Mass accommodation</span> <span class="cmti-10">of aniline, phenol and toluene on aqueous droplets</span>, Geophys. Res. Lett., 22, 3043–3046, <a href="https://doi.org/10.1029/95GL02944" >doi:10.1029/95GL02944</a> (1995). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2255',
    'Hedgecock and Pirrone (2004)',
    'Hedgecock, I. M. &#x0026; Pirrone, N.: <span class="cmti-10">Chasing</span> <span class="cmti-10">quicksilver: Modeling the atmospheric lifetime of</span> Hg<sub><span class="cmr-7">(g)</span></sub><sup><span class="cmr-7">0</span></sup> <span class="cmti-10">in the marine</span> <span class="cmti-10">boundary layer at various latitudes</span>, Environ. Sci. Technol., 38, 69–76, <a href="https://doi.org/10.1021/ES034623Z" >doi:10.1021/ES034623Z</a> (2004). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2169',
    'Hedgecock et&nbsp;al. (2005)',
    'Hedgecock, I. M., Trunfio, G. A., Pirrone, N., &#x0026; Sprovieri, F.: <span class="cmti-10">Mercury</span> <span class="cmti-10">chemistry in the MBL: Mediterranean case and sensitivity studies using</span> <span class="cmti-10">the AMCOTS (Atmospheric Mercury Chemistry over the Sea) model</span>, Atmos. Environ., 39, 7217–7230, <a href="https://doi.org/10.1016/J.ATMOSENV.2005.09.002" >doi:10.1016/J.ATMOSENV.2005.09.002</a> (2005). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2912',
    'Heidman et&nbsp;al. (1985)',
    'Heidman, J. L., Tsonopoulos, C., Brady, C. J., &#x0026; Wilson, G. M.: <span class="cmti-10">High-temperature mutual solubilities of hydrocarbons and water. Part II:</span> <span class="cmti-10">Ethylbenzene, ethylcyclohexane, and </span><span class="cmmi-10">n</span><span class="cmti-10">-octane</span>, AIChE J., 31, 376–384, <a href="https://doi.org/10.1002/AIC.690310304" >doi:10.1002/AIC.690310304</a> (1985). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2955',
    'Helburn et&nbsp;al. (2008)',
    'Helburn, R., Albritton, J., Howe, G., Michael, L., &#x0026; Franke, D.: <span class="cmti-10">Henry&#x2019;s law constants for fragrance and organic solvent compounds in</span> <span class="cmti-10">aqueous industrial surfactants</span>, J. Chem. Eng. Data, 53, 1071–1079, <a href="https://doi.org/10.1021/JE700418A" >doi:10.1021/JE700418A</a> (2008). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3775',
    'Heller et&nbsp;al. (2015)',
    'Heller, S. R., McNaught, A., Pletnev, I., Stein, S., &#x0026; Tchekhovskoi, D.: <span class="cmti-10">InChI, the IUPAC international chemical identifier</span>, J. Cheminformatics, 7, 23, <a href="https://doi.org/10.1186/S13321-015-0068-4" >doi:10.1186/S13321-015-0068-4</a> (2015). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2448',
    'Hellmann (1987)',
    'Hellmann, H.: <span class="cmti-10">Model tests on volatilization of organic</span> <span class="cmti-10">trace substances in surfaces waters</span>, Fresenius J. Anal. Chem., 328, 475–479, <a href="https://doi.org/10.1007/BF00475967" >doi:10.1007/BF00475967</a> (1987). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '869',
    'Hempel (1901)',
    'Hempel, W.: <span class="cmti-10">Ueber Kohlenoxysulfid</span>, Z. Angew. Chem., 14, 865–868, <a href="https://doi.org/10.1002/ANGE.19010143502" >doi:10.1002/ANGE.19010143502</a> (1901). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2606',
    'Henry (1803)',
    'Henry, W.: <span class="cmti-10">Experiments on the quantity of gases absorbed</span> <span class="cmti-10">by water, at different temperatures, and under different pressures</span>, Phil. Trans. R. Soc. Lond., 93, 29–43, <a href="https://doi.org/10.1098/RSTL.1803.0004" >doi:10.1098/RSTL.1803.0004</a> (1803). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1046',
    'Heron et&nbsp;al. (1998)',
    'Heron, G., Christensen, T. H., &#x0026; Enfield, C. G.: <span class="cmti-10">Henry&#x2019;s law constant for trichloroethylene</span> <span class="cmti-10">between 10 and 95</span><span class="cmsy-7">∘</span>C, Environ. Sci. Technol., 32, 1433–1437, <a href="https://doi.org/10.1021/ES9707015" >doi:10.1021/ES9707015</a> (1998). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2598',
    'Hertel and Sommer (2005)',
    'Hertel, M. O. &#x0026; Sommer, K.: <span class="cmti-10">Limiting separation</span> <span class="cmti-10">factors and limiting activity coefficients for 2-phenylethanol and</span> <span class="cmti-10">2-phenylethanal in water at 100</span><span class="cmsy-7">∘</span>C, J. Chem. Eng. Data, 50, 1905–1906, <a href="https://doi.org/10.1021/JE050171P" >doi:10.1021/JE050171P</a> (2005). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2599',
    'Hertel and Sommer (2006)',
    'Hertel, M. O. &#x0026; Sommer, K.: <span class="cmti-10">Limiting separation</span> <span class="cmti-10">factors and limiting activity coefficients for 2-furfural, </span><span class="cmmi-10">γ</span><span class="cmti-10">-nonalactone,</span> <span class="cmti-10">benzaldehyde, and linalool in water at 100</span><span class="cmsy-7">∘</span>C, J. Chem. Eng. Data, 51, 1283–1285, <a href="https://doi.org/10.1021/JE0600404" >doi:10.1021/JE0600404</a> (2006). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2600',
    'Hertel et&nbsp;al. (2007)',
    'Hertel, M. O., Scheuren, H., Sommer, K., &#x0026; Glas, K.: <span class="cmti-10">Limiting separation</span> <span class="cmti-10">factors and limiting activity coefficients for hexanal, 2-methylbutanal,</span> <span class="cmti-10">3-methylbutanal, and dimethylsulfide in water at (98.1 to 99.0)</span><span class="cmsy-7">∘</span>C, J. Chem. Eng. Data, 52, 148–150, <a href="https://doi.org/10.1021/JE060324O" >doi:10.1021/JE060324O</a> (2007). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2891',
    'Hiatt (2013)',
    'Hiatt, M. H.: <span class="cmti-10">Determination of Henry&#x2019;s law constants using</span> <span class="cmti-10">internal standards with benchmark values</span>, J. Chem. Eng. Data, 58, 902–908, <a href="https://doi.org/10.1021/JE3010535" >doi:10.1021/JE3010535</a> (2013). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2521',
    'Hilal et&nbsp;al. (2008)',
    'Hilal, S. H., Ayyampalayam, S. N., &#x0026; Carreira, L. A.: <span class="cmti-10">Air-liquid</span> <span class="cmti-10">partition coefficient for a diverse set of organic compounds: Henry&#x2019;s law</span> <span class="cmti-10">constant in water and hexadecane</span>, Environ. Sci. Technol., 42, 9231–9236, <a href="https://doi.org/10.1021/ES8005783" >doi:10.1021/ES8005783</a> (2008). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '627',
    'Hill et&nbsp;al. (1968)',
    'Hill, J. O., Worsley, I. G., &#x0026; Hepler, L. G.: <span class="cmti-10">Calorimetric determination of the distribution coefficient</span> <span class="cmti-10">and thermodynamic properties of bromine in water and carbon</span> <span class="cmti-10">tetrachloride</span>, J. Phys. Chem., 72, 3695–3697, <a href="https://doi.org/10.1021/J100856A066" >doi:10.1021/J100856A066</a> (1968). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3431',
    'Himmelblau (1960)',
    'Himmelblau, D. M.: <span class="cmti-10">Solubilities of inert gases in water.</span> <span class="cmti-10">0</span><span class="cmsy-7">∘</span>C<span class="cmti-10">. to near the critical point of water</span>, J. Chem. Eng. Data, 5, 10–15, <a href="https://doi.org/10.1021/JE60005A003" >doi:10.1021/JE60005A003</a> (1960). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '642',
    'Hine and Mookerjee (1975)',
    'Hine, J. &#x0026; Mookerjee, P. K.: <span class="cmti-10">The intrinsic hydrophilic character of organic</span> <span class="cmti-10">compounds. Correlations in terms of structural contributions</span>, J. Org. Chem., 40, 292–298, <a href="https://doi.org/10.1021/JO00891A006" >doi:10.1021/JO00891A006</a> (1975). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '714',
    'Hine and Weimar (1965)',
    'Hine, J. &#x0026; Weimar, Jr., R. D.: <span class="cmti-10">Carbon basicity</span>, J. Am. Chem. Soc., 87, 3387–3396, <a href="https://doi.org/10.1021/JA01093A018" >doi:10.1021/JA01093A018</a> (1965). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3964',
    'Hirshberg et&nbsp;al. (2018)',
    'Hirshberg, B., Rossich Molina, E., Götz, A. W., Hammerich, A. D., Nathanson, G. M., Bertram, T. H., Johnson, M. A., &#x0026; Gerber, R. B.: N<sub><span class="cmr-7">2</span></sub>O<sub><span class="cmr-7">5</span></sub> <span class="cmti-10">at water surfaces: binding forces, charge separation, energy</span> <span class="cmti-10">accommodation and atmospheric implications</span>, Phys. Chem. Chem. Phys., 20, 17 961–17 976, <a href="https://doi.org/10.1039/C8CP03022G" >doi:10.1039/C8CP03022G</a> (2018). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '637',
    'Hoff et&nbsp;al. (1993)',
    'Hoff, J. T., Mackay, D., Gillham, R., &#x0026; Shiu, W. Y.: <span class="cmti-10">Partitioning of organic chemicals at the</span> <span class="cmti-10">air–water interface in environmental systems</span>, Environ. Sci. Technol., 27, 2174–2180, <a href="https://doi.org/10.1021/ES00047A026" >doi:10.1021/ES00047A026</a> (1993). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '140',
    'Hoffmann and Calvert (1985)',
    'Hoffmann, M. R. &#x0026; Calvert, J. G.: <span class="cmti-10">Chemical</span> <span class="cmti-10">transformation modules for Eulerian acid deposition models. Volume II.</span> <span class="cmti-10">The aqueous-phase chemistry</span>, Tech. rep., NCAR, Box 3000, Boulder, CO 80307 (1985). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '103',
    'Hoffmann and Jacob (1984)',
    'Hoffmann, M. R. &#x0026; Jacob, D. J.: <span class="cmti-10">Kinetics and</span> <span class="cmti-10">mechanisms of the catalytic oxidation of dissolved sulfur dioxide in</span> <span class="cmti-10">aqueous solution: An application to nighttime fog water chemistry</span>, in: SO<sub><span class="cmr-7">2</span></sub>, NO and NO<sub><span class="cmr-7">2</span></sub> Oxidation Mechanisms: Atmospheric Considerations, edited by Calvert, J. G., pp. 101–172, Butterworth Publishers, Boston, MA, ISBN 0250405687 (1984). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '513',
    'Holdren et&nbsp;al. (1984)',
    'Holdren, M. W., Spicer, C. W., &#x0026; Hales, J. M.: <span class="cmti-10">Peroxyacetyl nitrate solubility</span> <span class="cmti-10">and decomposition rate in acidic water</span>, Atmos. Environ., 18, 1171–1173, <a href="https://doi.org/10.1016/0004-6981(84)90148-3" >doi:10.1016/0004-6981(84)90148-3</a> (1984). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3969',
    'Holst (1944)',
    'Holst, G.: <span class="cmti-10">Die Grundlagen einer technischen Methode zur</span> <span class="cmti-10">Darstellung von Chlordioxyd</span>, Svensk Papperstidn., 47, 537–546 (1944). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '287',
    'Holzwarth et&nbsp;al. (1984)',
    'Holzwarth, G., Balmer, R. G., &#x0026; Soni, L.: <span class="cmti-10">The fate of chlorine</span> <span class="cmti-10">and chloramines in cooling towers</span>, Wat. Res., 18, 1421–1427, <a href="https://doi.org/10.1016/0043-1354(84)90012-5" >doi:10.1016/0043-1354(84)90012-5</a> (1984). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3653',
    'Horvath and Getzen (1999)',
    'Horvath, A. L. &#x0026; Getzen, F. W.: <span class="cmti-10">IUPAC-NIST</span> <span class="cmti-10">Solubility Data Series 68. Halogenated Aliphatic Hydrocarbon Compounds</span> C<sub><span class="cmr-7">3</span></sub><span class="cmti-10">-</span>C<sub><span class="cmr-7">14</span></sub>, J. Phys. Chem. Ref. Data, 28, 649–777, <a href="https://doi.org/10.1063/1.556051" >doi:10.1063/1.556051</a> (1999). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '443',
    'Hough (1991)',
    'Hough, A. M.: <span class="cmti-10">Development of a two-dimensional global</span> <span class="cmti-10">tropospheric model: Model chemistry</span>, J. Geophys. Res., 96, 7325–7362, <a href="https://doi.org/10.1029/90JD01327" >doi:10.1029/90JD01327</a> (1991). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2450',
    'Hovorka and Dohnal (1997)',
    'Hovorka, Š. &#x0026; Dohnal, V.: <span class="cmti-10">Determination of</span> <span class="cmti-10">air–water partitioning of volatile halogenated hydrocarbons by the</span> <span class="cmti-10">inert gas stripping method</span>, J. Chem. Eng. Data, 42, 924–933, <a href="https://doi.org/10.1021/JE970046G" >doi:10.1021/JE970046G</a> (1997). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3609',
    'Hovorka et&nbsp;al. (2002)',
    'Hovorka, Š., Dohnal, V., Roux, A. H., &#x0026; Roux-Desgranges, G.: <span class="cmti-10">Determination of temperature dependence of limiting activity coefficients</span> <span class="cmti-10">for a group of moderately hydrophobic organic solutes in water</span>, Fluid Phase Equilib., 201, 135–164, <a href="https://doi.org/10.1016/S0378-3812(02)00087-0" >doi:10.1016/S0378-3812(02)00087-0</a> (2002). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3632',
    'Hovorka et&nbsp;al. (2019)',
    'Hovorka, Š., Vrbka, P., Bermúdez-Salguero, C., Böhme, A., &#x0026; Dohnal, V.: <span class="cmti-10">Air–water partitioning of C5 and C6 alkanones: measurement,</span> <span class="cmti-10">critical compilation, correlation, and recommended data</span>, J. Chem. Eng. Data, 64, 5765–5774, <a href="https://doi.org/10.1021/ACS.JCED.9B00726" >doi:10.1021/ACS.JCED.9B00726</a> (2019). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    'howard89',
    'Howard (1989)',
    'Howard, P. H.: Handbook of Environmental fate and exposure data for organic chemicals. Vol. I: Large production and priority pollutants, Lewis Publishers Inc. Chelsea, Michigan, ISBN 0873711513 (1989). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    'howard90',
    'Howard (1990)',
    'Howard, P. H.: Handbook of Environmental fate and exposure data for organic chemicals. Vol. II: Solvents, Lewis Publishers Inc. Chelsea, Michigan, <a href="https://doi.org/10.1201/9781003418863" >doi:10.1201/9781003418863</a> (1990). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    'howard91b',
    'Howard (1991)',
    'Howard, P. H.: Handbook of Environmental fate and exposure data for organic chemicals. Vol. III: Pesticides, Lewis Publishers Inc. Chelsea, Michigan, <a href="https://doi.org/10.1201/9780203719305" >doi:10.1201/9780203719305</a> (1991). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    'howard93',
    'Howard (1993)',
    'Howard, P. H.: Handbook of Environmental fate and exposure data for organic chemicals. Vol. IV: Solvents 2, Lewis Publishers Inc. Chelsea, Michigan, <a href="https://doi.org/10.1201/9781003418887" >doi:10.1201/9781003418887</a> (1993). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    'howard97',
    'Howard and Meylan (1997)',
    'Howard, P. H. &#x0026; Meylan, W. M.: Handbook of physical properties of organic chemicals, CRC Press, Lewis Publisher, Boca Raton, FL, ISBN 1566702275 (1997). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    'howard91',
    'Howard et&nbsp;al. (1991)',
    'Howard, P. H., Boethling, R. S., Jarvis, W. F., Meylan, W. M., &#x0026; Michalenko, E. M.: Handbook of Environmental Degradation Rates, Lewis Publishers Inc. Chelsea, Michigan, <a href="https://doi.org/10.1201/9780203719329" >doi:10.1201/9780203719329</a> (1991). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2894',
    'Howe et&nbsp;al. (1987)',
    'Howe, G. B., Mullins, M. E., &#x0026; Rogers, T. N.: <span class="cmti-10">Evaluation and prediction of Henry&#x2019;s law constants</span> <span class="cmti-10">and aqueous solubilities for solvents and hydrocarbon fuel components.</span> <span class="cmti-10">Vol II: Experimental Henry&#x2019;s law data</span>, Tech. Rep. NTIS AD-A202 262, Research Triangle Institute, Research Triangle Park, NC, 27709, USA (1987). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3119',
    'Hoyt (1982)',
    'Hoyt, S. D.: The ocean-air exchange of carbonyl sulfide (OCS) and halocarbons, Ph.D. thesis, Oregon Graduate Center, USA, URL https://digitalcollections.ohsu.edu/record/67/files/67_etd.pdf (1982). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3088',
    'HSDB (2015)',
    'HSDB: <span class="cmti-10">Hazardous Substances Data Bank, TOXicology</span> <span class="cmti-10">data NETwork (TOXNET), National Library of Medicine (US)</span>, URL https://www.nlm.nih.gov/toxnet/Accessing_HSDB_Content_from_PubChem.html (2015). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2827',
    'Huang and Chen (2010)',
    'Huang, D. &#x0026; Chen, Z.: <span class="cmti-10">Reinvestigation of the Henry&#x2019;s law constant for</span> <span class="cmti-10">hydrogen peroxide with temperature and acidity variation</span>, J. Environ. Sci., 22, 570–574, <a href="https://doi.org/10.1016/S1001-0742(09)60147-9" >doi:10.1016/S1001-0742(09)60147-9</a> (2010). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '608',
    'Hunter-Smith et&nbsp;al. (1983)',
    'Hunter-Smith, R. J., Balls, P. W., &#x0026; Liss, P. S.: <span class="cmti-10">Henry&#x2019;s law constants and the air-sea</span> <span class="cmti-10">exchange of various low molecular weight halocarbon gases</span>, Tellus, 35B, 170–176, <a href="https://doi.org/10.1111/J.1600-0889.1983.TB00021.X" >doi:10.1111/J.1600-0889.1983.TB00021.X</a> (1983). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '315',
    'Huthwelker et&nbsp;al. (1995)',
    'Huthwelker, T., Clegg, S. L., Peter, T., Carslaw, K., Luo, B. P., &#x0026; Brimblecombe, P.: <span class="cmti-10">Solubility of</span> HOCl <span class="cmti-10">in water and aqueous</span> H<sub><span class="cmr-7">2</span></sub>SO<sub><span class="cmr-7">4</span></sub> <span class="cmti-10">to stratospheric temperatures</span>, J. Atmos. Chem., 21, 81–95, <a href="https://doi.org/10.1007/BF00712439" >doi:10.1007/BF00712439</a> (1995). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '488',
    'Hwang and Dasgupta (1985)',
    'Hwang, H. &#x0026; Dasgupta, P. G.: <span class="cmti-10">Thermodynamics of the hydrogen peroxide-water</span> <span class="cmti-10">system</span>, Environ. Sci. Technol., 19, 255–258, <a href="https://doi.org/10.1021/ES00133A006" >doi:10.1021/ES00133A006</a> (1985). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3691',
    'Hwang et&nbsp;al. (2010)',
    'Hwang, I.-C., Kwak, H.-Y., &#x0026; Park, S.-J.: <span class="cmti-10">Determination and prediction of </span><span class="cmmi-10">K</span><sub><span class="cmmi-7">ow</span></sub> <span class="cmti-10">and dimensionless</span> <span class="cmti-10">Henry&#x2019;s constant (</span><span class="cmmi-10">H</span><span class="cmti-10">) for 6 ether compounds at several temperatures</span>, J. Ind. Eng. Chem., 16, 629–633, <a href="https://doi.org/10.1016/J.JIEC.2010.03.003" >doi:10.1016/J.JIEC.2010.03.003</a> (2010). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2439',
    'Hwang et&nbsp;al. (1992)',
    'Hwang, Y.-L., Olson, J. D., &#x0026; Keller, II, G. E.: <span class="cmti-10">Steam stripping for removal of organic pollutants</span> <span class="cmti-10">from water. 2. Vapor-liquid equilibrium data</span>, Ind. Eng. Chem. Res., 31, 1759–1768, <a href="https://doi.org/10.1021/IE00007A022" >doi:10.1021/IE00007A022</a> (1992). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1936',
    'Iliuta and Larachi (2005a)',
    'Iliuta, M. C. &#x0026; Larachi, F.: <span class="cmti-10">Gas-liquid partition</span> <span class="cmti-10">coefficients and Henry&#x2019;s law constants of DMS in aqueous solutions of</span> Fe(II) <span class="cmti-10">chelate complexes using the static headspace method</span>, J. Chem. Eng. Data, 50, 1700–1705, <a href="https://doi.org/10.1021/JE0501686" >doi:10.1021/JE0501686</a> (2005a). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3610',
    'Iliuta and Larachi (2005b)',
    'Iliuta, M. C. &#x0026; Larachi, F.: <span class="cmti-10">Solubility of dimethyldisulfide (DMDS) in aqueous</span> <span class="cmti-10">solutions of Fe(III) complexes of trans-1,2-cyclohexanediaminetetraacetic</span> <span class="cmti-10">acid (CDTA) using the static headspace method</span>, Fluid Phase Equilib., 233, 184–189, <a href="https://doi.org/10.1016/J.FLUID.2005.05.004" >doi:10.1016/J.FLUID.2005.05.004</a> (2005b). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2630',
    'Iliuta and Larachi (2007)',
    'Iliuta, M. C. &#x0026; Larachi, F.: <span class="cmti-10">Solubility of total</span> <span class="cmti-10">reduced sulfurs (hydrogen sulfide, methyl mercaptan, dimethyl sulfide,</span> <span class="cmti-10">and dimethyl disulfide) in liquids</span>, J. Chem. Eng. Data, 52, 2–19, <a href="https://doi.org/10.1021/JE060263U" >doi:10.1021/JE060263U</a> (2007). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3957',
    'Imagawa (1950)',
    'Imagawa, H.: <span class="cmti-10">Chemical reactions in the</span> <span class="cmti-10">chlorate manufacturing electrolytic cell (part 1) The vapour pressure of</span> <span class="cmti-10">hypochlorous acid on its aquous solution</span>, J. Electrochem. Soc. Jpn., 18, 382–385, <a href="https://doi.org/10.5796/DENKA.18.382" >doi:10.5796/DENKA.18.382</a> (1950). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3100',
    'Inga and McKetta (1961)',
    'Inga, R. F. &#x0026; McKetta, J. J.: <span class="cmti-10">Solubility of propyne</span> <span class="cmti-10">in water</span>, J. Chem. Eng. Data, 6, 337–338, <a href="https://doi.org/10.1021/JE00103A008" >doi:10.1021/JE00103A008</a> (1961). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3640',
    'Ioffe et&nbsp;al. (1984)',
    'Ioffe, B. V., Kostkina, M. I., &#x0026; Vitenberg, A. G.: <span class="cmti-10">Preparation of standard vapor-gas mixtures</span> <span class="cmti-10">for gas chromatography: discontinuous gas extraction</span>, Anal. Chem., 56, 2500–2503, <a href="https://doi.org/10.1021/AC00277A053" >doi:10.1021/AC00277A053</a> (1984). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2401',
    'Ip et&nbsp;al. (2009)',
    'Ip, H. S. S., Huang, X. H. H., &#x0026; Yu, J. Z.: <span class="cmti-10">Effective Henry&#x2019;s law constants of</span> <span class="cmti-10">glyoxal, glyoxylic acid, and glycolic acid</span>, Geophys. Res. Lett., 36, L01802, <a href="https://doi.org/10.1029/2008GL036212" >doi:10.1029/2008GL036212</a> (2009). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1004',
    'Iraci et&nbsp;al. (1999)',
    'Iraci, L. T., Baker, B. M., Tyndall, G. S., &#x0026; Orlando, J. J.: <span class="cmti-10">Measurements of the Henry&#x2019;s</span> <span class="cmti-10">law coefficients of 2-methyl-3-buten-2-ol, methacrolein, and methylvinyl</span> <span class="cmti-10">ketone</span>, J. Atmos. Chem., 33, 321–330, <a href="https://doi.org/10.1023/A:1006169029230" >doi:10.1023/A:1006169029230</a> (1999). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2550',
    'Irmann (1965)',
    'Irmann, F.: <span class="cmti-10">Eine einfache Korrelation zwischen Wasserl</span><span class="cmti-10">öslichkeit und Struktur von</span> <span class="cmti-10">Kohlenwasserstoffen und Halogenkohlenwasserstoffen</span>, Chem.-Ing.-Tech., 37, 789–798, <a href="https://doi.org/10.1002/CITE.330370802" >doi:10.1002/CITE.330370802</a> (1965). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3413',
    'Isaacman-VanWertz et&nbsp;al. (2016)',
    'Isaacman-VanWertz, G., Yee, L. D., Kreisberg, N. M., Wernis, R., Moss, J. A., Hering, S. V., de Sá, S. S., Martin, S. T., Alexander, M. L., Palm, B. B., Hu, W., Campuzano-Jost, P., Day, D. A., Jimenez, J. L., Riva, M., Surratt, J. D., Viegas, J., Manzi, A., Edgerton, E., Baumann, K., Souza, R., Artaxo, P., &#x0026; Goldstein, A. H.: <span class="cmti-10">Ambient</span> <span class="cmti-10">gas-particle partitioning of tracers for biogenic oxidation</span>, Environ. Sci. Technol., 50, 9952–9962, <a href="https://doi.org/10.1021/ACS.EST.6B01674" >doi:10.1021/ACS.EST.6B01674</a> (2016). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3965',
    'Ishi (1958)',
    'Ishi, G.: <span class="cmti-10">Solubility of chlorine dioxide</span>, Chem. Eng. (Japan), 22, 153–154, <a href="https://doi.org/10.1252/KAKORONBUNSHU1953.22.153" >doi:10.1252/KAKORONBUNSHU1953.22.153</a> (1958). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2288',
    'Iverfeldt and Lindqvist (1982)',
    'Iverfeldt, Å. &#x0026; Lindqvist, O.: <span class="cmti-10">Distribution</span> <span class="cmti-10">equilibrium of methyl mercury chloride between water and air</span>, Atmos. Environ., 16, 2917–2925, <a href="https://doi.org/10.1016/0004-6981(82)90042-7" >doi:10.1016/0004-6981(82)90042-7</a> (1982). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2576',
    'Iverfeldt and Persson (1985)',
    'Iverfeldt, Å. &#x0026; Persson, I.: <span class="cmti-10">The solvation thermodynamics of methylmercury(II) species derived from</span> <span class="cmti-10">measurements of the heat of solution and the Henry&#x2019;s law constant</span>, Inorg. Chim. Acta, 103, 113–119, <a href="https://doi.org/10.1016/S0020-1693(00)87476-9" >doi:10.1016/S0020-1693(00)87476-9</a> (1985). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '46',
    'Jacob (1986)',
    'Jacob, D. J.: <span class="cmti-10">Chemistry of</span> OH <span class="cmti-10">in remote clouds and its role</span> <span class="cmti-10">in the production of formic acid and peroxymonosulfate</span>, J. Geophys. Res., 91, 9807–9826, <a href="https://doi.org/10.1029/JD091ID09P09807" >doi:10.1029/JD091ID09P09807</a> (1986). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '76',
    'Jacob et&nbsp;al. (1989)',
    'Jacob, D. J., Gottlieb, E. W., &#x0026; Prather, M. J.: <span class="cmti-10">Chemistry of a</span> <span class="cmti-10">polluted cloudy boundary layer</span>, J. Geophys. Res., 94, 12 975–13 002, <a href="https://doi.org/10.1029/JD094ID10P12975" >doi:10.1029/JD094ID10P12975</a> (1989). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3751',
    'Jadkar and Chaudhari (1980)',
    'Jadkar, P. B. &#x0026; Chaudhari, R. V.: <span class="cmti-10">Solubility</span> <span class="cmti-10">of acetylene in aqueous solutions of formaldehyde and 2-butyne-1,4-diol</span>, J. Chem. Eng. Data, 25, 115–117, <a href="https://doi.org/10.1021/JE60085A021" >doi:10.1021/JE60085A021</a> (1980). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1536',
    'Jaeglé et&nbsp;al. (1996)',
    'Jaeglé, L., Yung, Y. L., Toon, G. C., Sen, B., &#x0026; Blavier, J.-F.: <span class="cmti-10">Balloon observations or</span> <span class="cmti-10">organic and inorganic chlorine in the stratosphere: The role of</span> HClO<sub><span class="cmr-7">4</span></sub> <span class="cmti-10">production on sulfate aerosols</span>, Geophys. Res. Lett., 23, 1749–1752, <a href="https://doi.org/10.1029/96GL01543" >doi:10.1029/96GL01543</a> (1996). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1154',
    'Janini and Quaddora (1986)',
    'Janini, G. M. &#x0026; Quaddora, L. A.: <span class="cmti-10">Determination of activity coefficients of oxygenated</span> <span class="cmti-10">hydrocarbons by liquid-liquid chromatography</span>, J. Liq. Chromatogr., 9, 39–53, <a href="https://doi.org/10.1080/01483918608076621" >doi:10.1080/01483918608076621</a> (1986). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2492',
    'Jantunen and Bidleman (2006)',
    'Jantunen, L. M. &#x0026; Bidleman, T. F.: <span class="cmti-10">Henry&#x2019;s</span> <span class="cmti-10">law</span> <span class="cmti-10">constants for hexachlorobenzene, p,p&#x2019;-DDE and components of technical</span> <span class="cmti-10">chlordane and estimates of gas exchange for Lake Ontario</span>, Chemosphere, 62, 1689–1696, <a href="https://doi.org/10.1016/J.CHEMOSPHERE.2005.06.035" >doi:10.1016/J.CHEMOSPHERE.2005.06.035</a> (2006). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3664',
    'Järnberg and Johanson (1995)',
    'Järnberg, J. &#x0026; Johanson, G.: <span class="cmti-10">Liquid/air</span> <span class="cmti-10">partition coefficients of the trimethylbenzenes</span>, Toxicol. Ind. Health, 11, 81–88, <a href="https://doi.org/10.1177/074823379501100107" >doi:10.1177/074823379501100107</a> (1995). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2525',
    'Jayasinghe et&nbsp;al. (1992)',
    'Jayasinghe, D. S., Brownawell, B. J., Chen, H., &#x0026; Westall, J. C.: <span class="cmti-10">Determination of Henry&#x2019;s constants of organic compounds of low</span> <span class="cmti-10">volatility: methylanilines in methanol-water</span>, Environ. Sci. Technol., 26, 2275–2281, <a href="https://doi.org/10.1021/ES00035A028" >doi:10.1021/ES00035A028</a> (1992). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '753',
    'Jenkins and King (1965)',
    'Jenkins, J. &#x0026; King, M. B.: <span class="cmti-10">Vapor-liquid equilibria</span> <span class="cmti-10">for the system bromine/water at low bromine concentrations</span>, Chem. Eng. Sci., 20, 921–922, <a href="https://doi.org/10.1016/0009-2509(65)80089-6" >doi:10.1016/0009-2509(65)80089-6</a> (1965). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2524',
    'Ji and Evans (2007)',
    'Ji, C. &#x0026; Evans, E. M.: <span class="cmti-10">Using an internal standard</span> <span class="cmti-10">method to determine Henry&#x2019;s law constants</span>, Environ. Toxicol. Chem., 26, 231–236, <a href="https://doi.org/10.1897/06-339R.1" >doi:10.1897/06-339R.1</a> (2007). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3724',
    'Ji et&nbsp;al. (2008)',
    'Ji, C., Day, S. E., Ortega, S. A., &#x0026; Beall, G. W.: <span class="cmti-10">Henry&#x2019;s law constants of some aromatic aldehydes and</span> <span class="cmti-10">ketones measured by an internal standard method</span>, J. Chem. Eng. Data, 53, 1093–1097, <a href="https://doi.org/10.1021/JE700612B" >doi:10.1021/JE700612B</a> (2008). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3079',
    'Johanson and Dynésius (1988)',
    'Johanson, G. &#x0026; Dynésius, B.: <span class="cmti-10">Liquid/air</span> <span class="cmti-10">partition coefficients of six commonly used glycol ethers</span>, Br. J. Ind. Med., 45, 561–564, <a href="https://doi.org/10.1136/OEM.45.8.561" >doi:10.1136/OEM.45.8.561</a> (1988). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '4023',
    'Johnson (1990)',
    'Johnson, B. J.: The carbon isotope content and concentration of ambient formic acid and acetic acid, Ph.D. thesis, University of Arizona, Tucson, AZ, USA, URL https://hdl.handle.net/10150/185355 (1990). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '511',
    'Johnson et&nbsp;al. (1996)',
    'Johnson, B. J., Betterton, E. A., &#x0026; Craig, D.: <span class="cmti-10">Henry&#x2019;s law coefficients of formic</span> <span class="cmti-10">and acetic acids</span>, J. Atmos. Chem., 24, 113–119, <a href="https://doi.org/10.1007/BF00162406" >doi:10.1007/BF00162406</a> (1996). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '524',
    'Johnson and Harrison (1986)',
    'Johnson, J. E. &#x0026; Harrison, H.: <span class="cmti-10">Carbonyl sulfide</span> <span class="cmti-10">concentrations in the surface waters and above the Pacific Ocean</span>, J. Geophys. Res., 91, 7883–7888, <a href="https://doi.org/10.1029/JD091ID07P07883" >doi:10.1029/JD091ID07P07883</a> (1986). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1072',
    'Johnstone and Leppla (1934)',
    'Johnstone, H. F. &#x0026; Leppla, P. W.: <span class="cmti-10">The</span> <span class="cmti-10">solubility of sulfur-dioxide at low partial pressures</span>, J. Am. Chem. Soc., 56, 2233–2238, <a href="https://doi.org/10.1021/JA01326A009" >doi:10.1021/JA01326A009</a> (1934). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3661',
    'Jones (1983)',
    'Jones, A. W.: <span class="cmti-10">Determination of liquid/air partition coefficients for dilute solutions of</span> <span class="cmti-10">ethanol in water, whole blood, and plasma</span>, J. Anal. Technol., 7, 193–197, <a href="https://doi.org/10.1093/JAT/7.4.193" >doi:10.1093/JAT/7.4.193</a> (1983). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3934',
    'Jones (1911)',
    'Jones, W. J.: <span class="cmti-10">XLIX.—The determination of solubility</span> <span class="cmti-10">coefficients by aspiration</span>, J. Chem. Soc. Trans., 99, 392–404, <a href="https://doi.org/10.1039/CT9119900392" >doi:10.1039/CT9119900392</a> (1911). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3649',
    'Jones et&nbsp;al. (1988)',
    'Jones, W. J., Egoville, M. J., Strolle, E. O., &#x0026; Dellamonica, E. S.: <span class="cmti-10">Determination of</span> <span class="cmti-10">partition coefficients by headspace gas chromatography</span>, J. Chromatogr. A, 455, 45–51, <a href="https://doi.org/10.1016/S0021-9673(01)82105-1" >doi:10.1016/S0021-9673(01)82105-1</a> (1988). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2909',
    'Jönsson et&nbsp;al. (1982)',
    'Jönsson, J. Å., Vejrosta, J., &#x0026; Novák, J.: <span class="cmti-10">Air/water partition coefficients for normal</span> <span class="cmti-10">alkanes (</span><span class="cmmi-10">n</span><span class="cmti-10">-pentane to </span><span class="cmmi-10">n</span><span class="cmti-10">-nonane)</span>, Fluid Phase Equilib., 9, 279–286, <a href="https://doi.org/10.1016/0378-3812(82)80023-X" >doi:10.1016/0378-3812(82)80023-X</a> (1982). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2833',
    'Joosten and Danckwerts (1972)',
    'Joosten, G. E. H. &#x0026; Danckwerts, P. V.: <span class="cmti-10">Solubility and diffusivity of nitrous oxide in equimolar potassium</span> <span class="cmti-10">carbonate-potassium bicarbonate solutions at 25</span><span class="cmsy-7">∘</span>C <span class="cmti-10">and 1atm</span>, J. Chem. Eng. Data, 17, 452–454, <a href="https://doi.org/10.1021/JE60055A016" >doi:10.1021/JE60055A016</a> (1972). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2910',
    'Jou and Mather (2000)',
    'Jou, F.-Y. &#x0026; Mather, A. E.: <span class="cmti-10">Vapor-liquid-liquid locus</span> <span class="cmti-10">of the system pentane + water</span>, J. Chem. Eng. Data, 45, 728–729, <a href="https://doi.org/10.1021/JE000065H" >doi:10.1021/JE000065H</a> (2000). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3556',
    'Jou et&nbsp;al. (2021)',
    'Jou, F.-Y., Mather, A. E., &#x0026; Schmidt, K. A. G.: <span class="cmti-10">Solubility of ethanethiol in water</span>, J. Chem. Eng. Data, 66, 4174–4179, <a href="https://doi.org/10.1021/ACS.JCED.1C00358" >doi:10.1021/ACS.JCED.1C00358</a> (2021). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '541',
    'Kames and Schurath (1992)',
    'Kames, J. &#x0026; Schurath, U.: <span class="cmti-10">Alkyl nitrates and</span> <span class="cmti-10">bifunctional nitrates of atmospheric interest: Henry&#x2019;s law constants</span> <span class="cmti-10">and their temperature dependencies</span>, J. Atmos. Chem., 15, 79–95, <a href="https://doi.org/10.1007/BF00053611" >doi:10.1007/BF00053611</a> (1992). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '624',
    'Kames and Schurath (1995)',
    'Kames, J. &#x0026; Schurath, U.: <span class="cmti-10">Henry&#x2019;s law</span> <span class="cmti-10">and hydrolysis-rate constants for peroxyacyl nitrates (</span>PAN<span class="cmti-10">s) using</span> <span class="cmti-10">a homogeneous gas-phase source</span>, J. Atmos. Chem., 21, 151–164, <a href="https://doi.org/10.1007/BF00696578" >doi:10.1007/BF00696578</a> (1995). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '502',
    'Kames et&nbsp;al. (1991)',
    'Kames, J., Schweighoefer, S., &#x0026; Schurath, U.: <span class="cmti-10">Henry&#x2019;s law constant and</span> <span class="cmti-10">hydrolysis of peroxyacetyl nitrate (</span>PAN<span class="cmti-10">)</span>, J. Atmos. Chem., 12, 169–180, <a href="https://doi.org/10.1007/BF00115778" >doi:10.1007/BF00115778</a> (1991). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3010',
    'Kampf et&nbsp;al. (2013)',
    'Kampf, C. J., Waxman, E. M., Slowik, J. G., Dommen, J., Pfaffenberger, L., Praplan, A. P., Prévôt, A. S. H., Baltensperger, U., Hoffmann, T., &#x0026; Volkamer, R.: <span class="cmti-10">Effective Henry&#x2019;s law partitioning and</span> <span class="cmti-10">the salting constant of glyoxal in aerosols containing sulfate</span>, Environ. Sci. Technol., 47, 4236–4244, <a href="https://doi.org/10.1021/ES400083D" >doi:10.1021/ES400083D</a> (2013). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '498',
    'Kanakidou et&nbsp;al. (1995)',
    'Kanakidou, M., Dentener, F. J., &#x0026; Crutzen, P. J.: <span class="cmti-10">A global three-dimensional study of</span> <span class="cmti-10">the fate of</span> HCFC<span class="cmti-10">s and</span> HFC<span class="cmsy-10">−</span>134a <span class="cmti-10">in the troposphere</span>, J. Geophys. Res., 100, 18 781–18 801, <a href="https://doi.org/10.1029/95JD01919" >doi:10.1029/95JD01919</a> (1995). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2571',
    'Kanefke (2008)',
    'Kanefke, R.: Durch Quecksilberbromierung verbesserte Quecksilberabscheidung aus den Abgasen von Kohlekraftwerken und Abfallverbrennungsanlagen, Ph.D. thesis, Martin-Luther-Universität Halle-Wittenberg, Germany, ISBN 978-3-8322-7241-8 (2008). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3631',
    'Kaneko et&nbsp;al. (1994)',
    'Kaneko, T., Wang, P. Y., &#x0026; Sato, A.: <span class="cmti-10">Partition coefficients of some acetate esters and alcohols in</span> <span class="cmti-10">water, blood, olive oil, and rat tissues</span>, Occup. Environ. Med., 51, 68–72, <a href="https://doi.org/10.1136/OEM.51.1.68" >doi:10.1136/OEM.51.1.68</a> (1994). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3753',
    'Karagodin-Doyennel et&nbsp;al. (2021)',
    'Karagodin-Doyennel, A., Rozanov, E., Sukhodolov, T., Egorova, T., Saiz-Lopez, A., Cuevas, C. A., Fernandez, R. P., Sherwen, T., Volkamer, R., Koenig, T. K., Giroud, T., &#x0026; Peter, T.: <span class="cmti-10">Iodine chemistry in the</span> <span class="cmti-10">chemistry–climate model SOCOL-AERv2-I</span>, Geosci. Model Dev., 14, 6623–6645, <a href="https://doi.org/10.5194/GMD-14-6623-2021" >doi:10.5194/GMD-14-6623-2021</a> (2021). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1922',
    'Karl et&nbsp;al. (2003)',
    'Karl, T., Yeretzian, C., Jordan, A., &#x0026; Lindinger, W.: <span class="cmti-10">Dynamic</span> <span class="cmti-10">measurements of partition coefficients using proton-transfer-reaction</span> <span class="cmti-10">mass spectrometry (PTR-MS)</span>, Int. J. Mass Spectrom., 223-224, 383–395, <a href="https://doi.org/10.1016/S1387-3806(02)00927-2" >doi:10.1016/S1387-3806(02)00927-2</a> (2003). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3555',
    'Karl et&nbsp;al. (2008)',
    'Karl, T., Guenther, A., Turnipseed, A., Patton, E. G., &#x0026; Jardine, K.: <span class="cmti-10">Chemical</span> <span class="cmti-10">sensing of plant stress at the ecosystem scale</span>, Biogeosci., 5, 1287–1294, <a href="https://doi.org/10.5194/BG-5-1287-2008" >doi:10.5194/BG-5-1287-2008</a> (2008). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1323',
    'Katrib et&nbsp;al. (2001)',
    'Katrib, Y., Deiber, G., Schweitzer, F., Mirabel, P., &#x0026; George, C.: <span class="cmti-10">Chemical transformation of bromine chloride at the air/water interface</span>, J. Aerosol Sci., 32, 893–911, <a href="https://doi.org/10.1016/S0021-8502(00)00114-2" >doi:10.1016/S0021-8502(00)00114-2</a> (2001). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1940',
    'Katrib et&nbsp;al. (2003)',
    'Katrib, Y., Calve, S. L., &#x0026; Mirabel, P.: <span class="cmti-10">Uptake measurements of dibasic esters by water droplets and</span> <span class="cmti-10">determination of their Henry&#x2019;s law constants</span>, J. Phys. Chem. A, 107, 11 433–11 439, <a href="https://doi.org/10.1021/JP0368132" >doi:10.1021/JP0368132</a> (2003). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3764',
    'Katritzky et&nbsp;al. (1998)',
    'Katritzky, A. R., Wang, Y., Sild, S., Tamm, T., &#x0026; Karelson, M.: <span class="cmti-10">QSPR</span> <span class="cmti-10">studies on vapor pressure, aqueous solubility, and the prediction of</span> <span class="cmti-10">water-air partition coefficients</span>, J. Chem. Inf. Comput. Sci., 38, 720–725, <a href="https://doi.org/10.1021/CI980022T" >doi:10.1021/CI980022T</a> (1998). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2229',
    'Kawamoto and Urano (1989)',
    'Kawamoto, K. &#x0026; Urano, K.: <span class="cmti-10">Parameters for</span> <span class="cmti-10">predicting fate of organochlorine pesticides in the environment (I)</span> <span class="cmti-10">Octanol-water and air–water partition coefficients</span>, Chemosphere, 18, 1987–1996, <a href="https://doi.org/10.1016/0045-6535(89)90482-7" >doi:10.1016/0045-6535(89)90482-7</a> (1989). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2906',
    'Keeley et&nbsp;al. (1988)',
    'Keeley, D. F., Hoffpauir, M. A., &#x0026; Meriwether, J. R.: <span class="cmti-10">Solubility of</span> <span class="cmti-10">aromatic hydrocarbons in water and sodium chloride solutions of different</span> <span class="cmti-10">ionic strengths: benzene and toluene</span>, Environ. Sci. Technol., 33, 87–89, <a href="https://doi.org/10.1021/JE00052A006" >doi:10.1021/JE00052A006</a> (1988). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '508',
    'Keene and Galloway (1986)',
    'Keene, W. C. &#x0026; Galloway, J. N.: <span class="cmti-10">Considerations regarding sources for formic</span> <span class="cmti-10">and acetic acids in the troposphere</span>, J. Geophys. Res., 91, 14 466–14 474, <a href="https://doi.org/10.1029/JD091ID13P14466" >doi:10.1029/JD091ID13P14466</a> (1986). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '538',
    'Keene et&nbsp;al. (1995)',
    'Keene, W. C., Mosher, B. W., Jacob, D. J., Munger, J. W., Talbot, R. W., Artz, R. S., Maben, J. R., Daube, B. C., &#x0026; Galloway, J. N.: <span class="cmti-10">Carboxylic acids in a high-elevation forested site in central Virginia</span>, J. Geophys. Res., 100, 9345–9357, <a href="https://doi.org/10.1029/94JD01247" >doi:10.1029/94JD01247</a> (1995). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '626',
    'Kelley and Tartar (1956)',
    'Kelley, C. M. &#x0026; Tartar, H. V.: <span class="cmti-10">On the system: bromine-water</span>, J. Am. Chem. Soc., 78, 5752–5756, <a href="https://doi.org/10.1021/JA01603A010" >doi:10.1021/JA01603A010</a> (1956). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3956',
    'Kepinski and Trzeszczynski (1964)',
    'Kepinski, J. &#x0026; Trzeszczynski, J.: <span class="cmti-10">Absorption equilibria of chlorine dioxide. Solubility</span> <span class="cmti-10">in water, carbon tetrachloride, sulphuric and acetic acid solutions</span>, Rocz. Chem., 38, 201–211 (1964). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3730',
    'Keshavarz et&nbsp;al. (2022)',
    'Keshavarz, M. H., Rezaei, M., &#x0026; Hosseini, S. H.: <span class="cmti-10">A simple approach</span> <span class="cmti-10">for prediction of Henry&#x2019;s law constant of pesticides, solvents, aromatic</span> <span class="cmti-10">hydrocarbons, and persistent pollutants without using complex computer</span> <span class="cmti-10">codes and descriptors</span>, Process Saf. Environ. Prot., 162, 867–877, <a href="https://doi.org/10.1016/J.PSEP.2022.04.045" >doi:10.1016/J.PSEP.2022.04.045</a> (2022). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3248',
    'Keßel et&nbsp;al. (2017)',
    'Keßel, S., Cabrera-Perez, D., Horowitz, A., Veres, P. R., Sander, R., Taraborrelli, D., Tucceri, M., Crowley, J. N., Pozzer, A., Stönner, C., Vereecken, L., Lelieveld, J., &#x0026; Williams, J.: <span class="cmti-10">Atmospheric chemistry,</span> <span class="cmti-10">sources and sinks of carbon suboxide,</span> C<sub><span class="cmr-7">3</span></sub>O<sub><span class="cmr-7">2</span></sub>, Atmos. Chem. Phys., 17, 8789–8804, <a href="https://doi.org/10.5194/ACP-17-8789-2017" >doi:10.5194/ACP-17-8789-2017</a> (2017). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2895',
    'Khalfaoui and Newsham (1994a)',
    'Khalfaoui, B. &#x0026; Newsham, D. M. T.: <span class="cmti-10">Phase equilibria in very dilute mixtures of</span> <span class="cmti-10">water and brominated hydrocarbons</span>, Fluid Phase Equilib., 98, 213–223, <a href="https://doi.org/10.1016/0378-3812(94)80120-7" >doi:10.1016/0378-3812(94)80120-7</a> (1994a). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2931',
    'Khalfaoui and Newsham (1994b)',
    'Khalfaoui, B. &#x0026; Newsham, D. M. T.: <span class="cmti-10">Determination of infinite dilution activity coefficients and second virial</span> <span class="cmti-10">coefficients using gas-liquid chromatography I. The dilute mixtures of</span> <span class="cmti-10">water and unsaturated chlorinated</span> <span class="cmti-10">hydrocarbons and of water and benzene</span>, J. Chromatogr. A, 673, 85–92, <a href="https://doi.org/10.1016/0021-9673(94)87060-8" >doi:10.1016/0021-9673(94)87060-8</a> (1994b). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2230',
    'Khan and Brimblecombe (1992)',
    'Khan, I. &#x0026; Brimblecombe, P.: <span class="cmti-10">Henry&#x2019;s law</span> <span class="cmti-10">constants of low molecular weight (</span><span class="cmmi-10">&#x003C;</span><span class="cmti-10">130) organic acids</span>, J. Aerosol Sci., 23, S897–S900, <a href="https://doi.org/10.1016/0021-8502(92)90556-B" >doi:10.1016/0021-8502(92)90556-B</a> (1992). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1063',
    'Khan et&nbsp;al. (1992)',
    'Khan, I., Brimblecombe, P., &#x0026; Clegg, S. L.: <span class="cmti-10">The Henry&#x2019;s law constants</span> <span class="cmti-10">of pyruvic and methacrylic acids</span>, Environ. Technol., 13, 587–593, <a href="https://doi.org/10.1080/09593339209385187" >doi:10.1080/09593339209385187</a> (1992). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '493',
    'Khan et&nbsp;al. (1995)',
    'Khan, I., Brimblecombe, P., &#x0026; Clegg, S. L.: <span class="cmti-10">Solubilities of pyruvic acid</span> <span class="cmti-10">and the lower (</span>C<sub><span class="cmr-7">1</span></sub><span class="cmti-10">-</span>C<sub><span class="cmr-7">6</span></sub><span class="cmti-10">) carboxylic acids. Experimental determination of</span> <span class="cmti-10">equilibrium vapour pressures above pure aqueous and salt solutions</span>, J. Atmos. Chem., 22, 285–302, <a href="https://doi.org/10.1007/BF00696639" >doi:10.1007/BF00696639</a> (1995). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3588',
    'Kieckbusch and King (1979a)',
    'Kieckbusch, T. G. &#x0026; King, C. J.: <span class="cmti-10">Partition-coefficients for acetates in food systems</span>, J. Agric. Food Chem., 27, 504–507, <a href="https://doi.org/10.1021/JF60223A033" >doi:10.1021/JF60223A033</a> (1979a). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '628',
    'Kieckbusch and King (1979b)',
    'Kieckbusch, T. G. &#x0026; King, C. J.: <span class="cmti-10">An</span> <span class="cmti-10">improved method of determining vapor liquid equilibria for dilute</span> <span class="cmti-10">organics in aqueous solution</span>, J. Chromatogr. Sci., 17, 273–276, <a href="https://doi.org/10.1093/CHROMSCI/17.5.273" >doi:10.1093/CHROMSCI/17.5.273</a> (1979b). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3593',
    'Kilpatrick et&nbsp;al. (1956)',
    'Kilpatrick, M. L., Herrick, C. C., &#x0026; Kilpatrick, M.: <span class="cmti-10">The decomposition</span> <span class="cmti-10">of ozone in aqueous solution</span>, J. Am. Chem. Soc., 78, 1784–1789, <a href="https://doi.org/10.1021/JA01590A003" >doi:10.1021/JA01590A003</a> (1956). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2837',
    'Kim et&nbsp;al. (2000)',
    'Kim, B. R., Kalis, E. M., DeWulf, T., &#x0026; Andrews, K. M.: <span class="cmti-10">Henry&#x2019;s Law</span> <span class="cmti-10">constants for paint solvents and their implications on volatile organic</span> <span class="cmti-10">compound emissions from automotive painting</span>, Water Environ. Res., 72, 65–74, <a href="https://doi.org/10.2175/106143000X137121" >doi:10.2175/106143000X137121</a> (2000). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3654',
    'Kim et&nbsp;al. (2008)',
    'Kim, I., Svendsen, H. F., &#x0026; Børresen, E.: <span class="cmti-10">Ebulliometric determination of vapor-liquid equilibria for</span> <span class="cmti-10">pure water, monoethanolamine, N-methyldiethanolamine,</span> <span class="cmti-10">3-(methylamino)-propylamine, and their binary and ternary solutions</span>, J. Chem. Eng. Data, 53, 2521–2531, <a href="https://doi.org/10.1021/JE800290K" >doi:10.1021/JE800290K</a> (2008). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3032',
    'Kim and Kim (2014)',
    'Kim, Y.-H. &#x0026; Kim, K.-H.: <span class="cmti-10">Recent advances in thermal</span> <span class="cmti-10">desorption-gas chromatography-mass spectrometery method to eliminate</span> <span class="cmti-10">the matrix effect between air and water samples: Application to the</span> <span class="cmti-10">accurate determination of Henry&#x2019;s law constant</span>, J. Chromatogr. A, 1342, 78–85, <a href="https://doi.org/10.1016/J.CHROMA.2014.03.040" >doi:10.1016/J.CHROMA.2014.03.040</a> (2014). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3684',
    'Kim and Kim (2016)',
    'Kim, Y.-H. &#x0026; Kim, K.-H.: <span class="cmti-10">A simple method for the</span> <span class="cmti-10">accurate determination of the Henry&#x2019;s law constant for highly sorptive,</span> <span class="cmti-10">semivolatile organic compounds</span>, Anal. Bioanal. Chem., 408, 775–784, <a href="https://doi.org/10.1007/S00216-015-9159-3" >doi:10.1007/S00216-015-9159-3</a> (2016). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3007',
    'Kish et&nbsp;al. (2013)',
    'Kish, J. D., Leng, C. B., Kelley, J., Hiltner, J., Zhang, Y. H., &#x0026; Liu, Y.: <span class="cmti-10">An improved</span> <span class="cmti-10">approach for measuring Henry&#x2019;s law coefficients of atmospheric organics</span>, Atmos. Environ., 79, 561–565, <a href="https://doi.org/10.1016/J.ATMOSENV.2013.07.023" >doi:10.1016/J.ATMOSENV.2013.07.023</a> (2013). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3080',
    'Klein (1982)',
    'Klein, R. G.: <span class="cmti-10">Calculations and measurements on the volatility</span> <span class="cmti-10">of N-nitrosamines and their aqueous solutions</span>, Toxicology, 23, 135–147, <a href="https://doi.org/10.1016/0300-483X(82)90093-2" >doi:10.1016/0300-483X(82)90093-2</a> (1982). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3692',
    'Knauss et&nbsp;al. (2000)',
    'Knauss, K. G., Dibley, M. J., Leif, R. N., Mew, D. A., &#x0026; Aines, R. D.: <span class="cmti-10">The aqueous solubility of trichloroethene (TCE) and tetrachloroethene</span> <span class="cmti-10">(PCE) as a function of temperature</span>, Appl. Geochem., 15, 501–512, <a href="https://doi.org/10.1016/S0883-2927(99)00058-X" >doi:10.1016/S0883-2927(99)00058-X</a> (2000). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3081',
    'Kochetkov et&nbsp;al. (2001)',
    'Kochetkov, A., Smith, J. S., Ravikrishna, R., Valsaraj, K. T., &#x0026; Thibodeaux, L. J.: <span class="cmti-10">Air–water partition constants for volatile</span> <span class="cmti-10">methyl siloxanes</span>, Environ. Toxicol. Chem., 20, 2184–2188, <a href="https://doi.org/10.1002/ETC.5620201008" >doi:10.1002/ETC.5620201008</a> (2001). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '542',
    'Koga (1995)',
    'Koga, Y.: <span class="cmti-10">Vapor pressures of dilute aqueous </span><span class="cmmi-10">t</span><span class="cmti-10">-butyl alcohol:</span> <span class="cmti-10">How dilute is the Henry&#x2019;s law region?</span>, J. Phys. Chem., 99, 6231–6233, <a href="https://doi.org/10.1021/J100016A069" >doi:10.1021/J100016A069</a> (1995). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '857',
    'Kolb et&nbsp;al. (1992)',
    'Kolb, B., Welter, C., &#x0026; Bichler, C.: <span class="cmti-10">Determination of partition coefficients by automatic</span> <span class="cmti-10">equilibrium headspace gas chromatography by vapor phase calibration</span>, Chromatographia, 34, 235–240, <a href="https://doi.org/10.1007/BF02268351" >doi:10.1007/BF02268351</a> (1992). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1138',
    'Komiyama and Inoue (1978)',
    'Komiyama, H. &#x0026; Inoue, H.: <span class="cmti-10">Reaction and</span> <span class="cmti-10">transport of nitrogen oxides in nitrous acid solutions</span>, J. Chem. Eng. Jpn., 11, 25–32, <a href="https://doi.org/10.1252/JCEJ.11.25" >doi:10.1252/JCEJ.11.25</a> (1978). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3120',
    'Komiyama and Inoue (1980)',
    'Komiyama, H. &#x0026; Inoue, H.: <span class="cmti-10">Absorption</span> <span class="cmti-10">of nitrogen oxides into water</span>, Chem. Eng. Sci., 35, 154–161, <a href="https://doi.org/10.1016/0009-2509(80)80082-0" >doi:10.1016/0009-2509(80)80082-0</a> (1980). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2904',
    'Kondoh and Nakajima (1997)',
    'Kondoh, H. &#x0026; Nakajima, T.: <span class="cmti-10">Optimization</span> <span class="cmti-10">of headspace cryofocus gas chromatography/mass spectrometry for the</span> <span class="cmti-10">analysis of 54 volatile organic compounds, and the measurement of their</span> <span class="cmti-10">Henry&#x2019;s constants</span>, J. Environ. Chem., 7, 81–89, <a href="https://doi.org/10.5985/JEC.7.81" >doi:10.5985/JEC.7.81</a> (1997). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '480',
    'Kosak-Channing and Helz (1983)',
    'Kosak-Channing, L. F. &#x0026; Helz, G. R.: <span class="cmti-10">Solubility of ozone in aqueous solutions of 0–0.6 </span>M <span class="cmti-10">ionic strength at</span> <span class="cmti-10">5–30</span><span class="cmsy-7">∘</span>C, Environ. Sci. Technol., 17, 145–149, <a href="https://doi.org/10.1021/ES00109A005" >doi:10.1021/ES00109A005</a> (1983). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    'kotlik74',
    'Kotlik and Lebedeva (1974)',
    'Kotlik, S. B. &#x0026; Lebedeva, G. N.: <span class="cmti-10">Equilibrium</span> <span class="cmti-10">pressures of</span> HCN <span class="cmti-10">and</span> NH<sub><span class="cmr-7">3</span></sub> <span class="cmti-10">over aqueous solutions</span>, Zh. Prikl. Khim., 47, 444–446 (1974). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3123',
    'Kramers et&nbsp;al. (1961)',
    'Kramers, H., Blind, M. P. P., &#x0026; Snoeck, E.: <span class="cmti-10">Absorption of nitrogen tetroxide by water jets</span>, Chem. Eng. Sci., 14, 115–123, <a href="https://doi.org/10.1016/0009-2509(61)85062-8" >doi:10.1016/0009-2509(61)85062-8</a> (1961). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2436',
    'Krause and Benson (1989)',
    'Krause, Jr., D. &#x0026; Benson, B. B.: <span class="cmti-10">The solubility</span> <span class="cmti-10">and isotopic fractionation of gases in dilute aqueous solution. IIa.</span> <span class="cmti-10">solubilities of the noble gases</span>, J. Solution Chem., 18, 823–873, <a href="https://doi.org/10.1007/BF00685062" >doi:10.1007/BF00685062</a> (1989). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3749',
    'Kremann and Hönel (1913)',
    'Kremann, R. &#x0026; Hönel, H.: <span class="cmti-10">Über die L</span><span class="cmti-10">öslichkeit</span> <span class="cmti-10">von Acetylen in Aceton und Aceton-Wassergemischen</span>, Monatsh. Chem. – Chem. Mon., 34, 1089–1094, <a href="https://doi.org/10.1007/BF01517552" >doi:10.1007/BF01517552</a> (1913). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2321',
    'Kroll et&nbsp;al. (2005)',
    'Kroll, J. H., Ng, N. L., Murphy, S. M., Varutbangkul, V., Flagan, R. C., &#x0026; Seinfeld, J. H.: <span class="cmti-10">Chamber studies of secondary organic aerosol</span> <span class="cmti-10">growth by reactive uptake of simple carbonyl compounds</span>, J. Geophys. Res., 110, D23207, <a href="https://doi.org/10.1029/2005JD006004" >doi:10.1029/2005JD006004</a> (2005). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '977',
    'Krop et&nbsp;al. (1997)',
    'Krop, H. B., van Velzen, M. J. M., Parsons, J. R., &#x0026; Govers, H. A. J.: <span class="cmti-10">n-Octanol-water</span> <span class="cmti-10">partition coefficients, aqueous</span> <span class="cmti-10">solubilities and Henry&#x2019;s law constants of fatty acid esters</span>, Chemosphere, 34, 107–119, <a href="https://doi.org/10.1016/S0045-6535(96)00371-2" >doi:10.1016/S0045-6535(96)00371-2</a> (1997). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2927',
    'Krysztofiak et&nbsp;al. (2012)',
    'Krysztofiak, G., Catoire, V., Poulet, G., Marécal, V., Pirre, M., Louis, F., Canneaux, S., &#x0026; Josse, B.: <span class="cmti-10">Detailed modeling of the atmospheric</span> <span class="cmti-10">degradation mechanism of very-short lived brominated species</span>, Atmos. Environ., 59, 514–532, <a href="https://doi.org/10.1016/J.ATMOSENV.2012.05.026" >doi:10.1016/J.ATMOSENV.2012.05.026</a> (2012). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1152',
    'Kucklick et&nbsp;al. (1991)',
    'Kucklick, J. R., Hinckley, D. A., &#x0026; Bidleman, T. F.: <span class="cmti-10">Determination of</span> <span class="cmti-10">Henry&#x2019;s law constants for hexachlorocyclohexanes in distilled water and</span> <span class="cmti-10">artificial seawater as a function of temperature</span>, Mar. Chem., 34, 197–209, <a href="https://doi.org/10.1016/0304-4203(91)90003-F" >doi:10.1016/0304-4203(91)90003-F</a> (1991). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1917',
    'Kühne et&nbsp;al. (2005)',
    'Kühne, R., Ebert, R.-U., &#x0026; Schüürmann, G.: <span class="cmti-10">Prediction of the temperature dependency of</span> <span class="cmti-10">Henry&#x2019;s law constant from chemical structure</span>, Environ. Sci. Technol., 39, 6705–6711, <a href="https://doi.org/10.1021/ES050527H" >doi:10.1021/ES050527H</a> (2005). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3709',
    'Kunerth (1922)',
    'Kunerth, W.: <span class="cmti-10">Solubility of</span> CO<sub><span class="cmr-7">2</span></sub> <span class="cmti-10">and</span> N<sub><span class="cmr-7">2</span></sub>O <span class="cmti-10">in certain</span> <span class="cmti-10">solvents</span>, Phys. Rev., 19, 512–524, <a href="https://doi.org/10.1103/PHYSREV.19.512" >doi:10.1103/PHYSREV.19.512</a> (1922). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1932',
    'Kuramochi et&nbsp;al. (2004)',
    'Kuramochi, H., Maeda, K., &#x0026; Kawamoto, K.: <span class="cmti-10">Measurements of water solubilities and</span> <span class="cmti-10">1-octanol/water partition coefficients and estimations of Henry&#x2019;s law</span> <span class="cmti-10">constants for brominated benzenes</span>, J. Chem. Eng. Data, 49, 720–724, <a href="https://doi.org/10.1021/JE0342724" >doi:10.1021/JE0342724</a> (2004). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3024',
    'Kuramochi et&nbsp;al. (2014)',
    'Kuramochi, H., Takigami, H., Scheringer, M., &#x0026; Sakai, S.: <span class="cmti-10">Measurement</span> <span class="cmti-10">of vapor pressures of selected PBDEs, hexabromobenzene, and</span> <span class="cmti-10">1,2-bis(2,4,6-tribromophenoxy)ethane at elevated temperatures</span>, J. Chem. Eng. Data, 59, 8–15, <a href="https://doi.org/10.1021/JE400520E" >doi:10.1021/JE400520E</a> (2014). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3099',
    'Kurtén et&nbsp;al. (2015)',
    'Kurtén, T., Elm, J., Prisle, N. L., Mikkelsen, K. V., Kampf, C. J., Waxman, E. M., &#x0026; Volkamer, R.: <span class="cmti-10">Computational study of the effect of</span> <span class="cmti-10">glyoxal-sulfate clustering on the Henry&#x2019;s law coefficient of glyoxal</span>, J. Phys. Chem. A, 119, 4509–4514, <a href="https://doi.org/10.1021/JP510304C" >doi:10.1021/JP510304C</a> (2015). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1096',
    'Kurz and Ballschmiter (1999)',
    'Kurz, J. &#x0026; Ballschmiter, K.: <span class="cmti-10">Vapour pressures,</span> <span class="cmti-10">aqueous solubilities, Henry&#x2019;s law constants, partition coefficients between</span> <span class="cmti-10">gas/water (</span><span class="cmmi-10">K</span><sub><span class="cmr-7">gw</span></sub><span class="cmti-10">), </span><span class="cmmi-10">n</span><span class="cmti-10">-octanol/water (</span><span class="cmmi-10">K</span><sub><span class="cmr-7">ow</span></sub><span class="cmti-10">) and gas/n-octanol (</span><span class="cmmi-10">K</span><sub><span class="cmr-7">go</span></sub><span class="cmti-10">) of</span> <span class="cmti-10">106 polychlorinated diphenyl ethers (PCDE)</span>, Chemosphere, 38, 573–586, <a href="https://doi.org/10.1016/S0045-6535(98)00212-4" >doi:10.1016/S0045-6535(98)00212-4</a> (1999). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2939',
    'Kutsuna (2013)',
    'Kutsuna, S.: <span class="cmti-10">Determination of rate constants for aqueous</span> <span class="cmti-10">reactions of HCFC-123 and HCFC-225ca with</span> OH<sup><span class="cmsy-7">−</span></sup> <span class="cmti-10">along with Henry&#x2019;s</span> <span class="cmti-10">law constants of several HCFCs</span>, Int. J. Chem. Kinet., 45, 440–451, <a href="https://doi.org/10.1002/KIN.20780" >doi:10.1002/KIN.20780</a> (2013). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3272',
    'Kutsuna (2017)',
    'Kutsuna, S.: <span class="cmti-10">Experimental determination of Henry&#x2019;s law</span> <span class="cmti-10">constants of difluoromethane (HFC-32) and the salting-out effects in</span> <span class="cmti-10">aqueous salt solutions relevant to seawater</span>, Atmos. Chem. Phys., 17, 7495–7507, <a href="https://doi.org/10.5194/ACP-17-7495-2017" >doi:10.5194/ACP-17-7495-2017</a> (2017). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2406',
    'Kutsuna and Hori (2008a)',
    'Kutsuna, S. &#x0026; Hori, H.: <span class="cmti-10">Experimental determination of Henry&#x2019;s law constants</span> <span class="cmti-10">of trifluoroacetic acid at 278-298 </span>K, Atmos. Environ., 42, 1399–1412, <a href="https://doi.org/10.1016/J.ATMOSENV.2007.11.009" >doi:10.1016/J.ATMOSENV.2007.11.009</a> (2008a). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2816',
    'Kutsuna and Hori (2008b)',
    'Kutsuna, S. &#x0026; Hori, H.: <span class="cmti-10">Experimental</span> <span class="cmti-10">determination of Henry&#x2019;s law constant of perfluorooctanoic acid (PFOA)</span> <span class="cmti-10">at 298 </span>K <span class="cmti-10">by means of an inert-gas stripping method with a helical plate</span>, Atmos. Environ., 42, 8883–8892, <a href="https://doi.org/10.1016/J.ATMOSENV.2008.09.008" >doi:10.1016/J.ATMOSENV.2008.09.008</a> (2008b). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3507',
    'Kutsuna and Kaneyasu (2021)',
    'Kutsuna, S. &#x0026; Kaneyasu, N.: <span class="cmti-10">Henry&#x2019;s law</span> <span class="cmti-10">constants and hydration equilibrium constants of </span><span class="cmmi-10">n</span><span class="cmti-10">-hexanal and their</span> <span class="cmti-10">temperature dependence as determined by the rectangular pulse method</span>, Chem. Eng. Sci., 239, 116 639, <a href="https://doi.org/10.1016/J.CES.2021.116639" >doi:10.1016/J.CES.2021.116639</a> (2021). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2803',
    'Kutsuna et&nbsp;al. (2004)',
    'Kutsuna, S., Chen, L., Ohno, K., Tokuhashi, K., &#x0026; Sekiya, A.: <span class="cmti-10">Henry&#x2019;s law constants and hydrolysis rate constants of 2,2,2-trifluoroethyl</span> <span class="cmti-10">acetate and methyl trifluoroacetate</span>, Atmos. Environ., 38, 725–732, <a href="https://doi.org/10.1016/J.ATMOSENV.2003.10.019" >doi:10.1016/J.ATMOSENV.2003.10.019</a> (2004). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2802',
    'Kutsuna et&nbsp;al. (2005)',
    'Kutsuna, S., Chen, L., Abe, T., Mizukado, J., Uchimaru, T., Tokuhashi, K., &#x0026; Sekiya, A.: <span class="cmti-10">Henry&#x2019;s law constants of 2,2,2-trifluoroethyl formate,</span> <span class="cmti-10">ethyl trifluoroacetate, and non-fluorinated analogous esters</span>, Atmos. Environ., 39, 5884–5892, <a href="https://doi.org/10.1016/J.ATMOSENV.2005.06.021" >doi:10.1016/J.ATMOSENV.2005.06.021</a> (2005). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3940',
    'Kwan (2001)',
    'Kwan, W. C.: Physical property determination of perfluorinated surfactants, Master&#x2019;s thesis, University of Toronto, URL https://hdl.handle.net/1807/16278 (2001). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2901',
    'Lamarche and Droste (1989)',
    'Lamarche, P. &#x0026; Droste, R. L.: <span class="cmti-10">Air stripping</span> <span class="cmti-10">mass transfer correlations for volatile organics</span>, J. Am. Water Works Assoc., 81, 78–89, <a href="https://doi.org/10.1002/J.1551-8833.1989.TB03326.X" >doi:10.1002/J.1551-8833.1989.TB03326.X</a> (1989). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3647',
    'Landy et&nbsp;al. (1995)',
    'Landy, P., Druaux, C., &#x0026; A.Voilley: <span class="cmti-10">Retention of aroma compounds by proteins in aqueous</span> <span class="cmti-10">solution</span>, Food Chem., 54, 387–392, <a href="https://doi.org/10.1016/0308-8146(95)00069-U" >doi:10.1016/0308-8146(95)00069-U</a> (1995). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3651',
    'Landy et&nbsp;al. (1996)',
    'Landy, P., Courthaudon, J.-L., Dubois, C., &#x0026; Voilley, A.: <span class="cmti-10">Effect of interface in</span> <span class="cmti-10">model food emulsions on the volatility of aroma compounds</span>, J. Agric. Food Chem., 44, 526–530, <a href="https://doi.org/10.1021/JF950279G" >doi:10.1021/JF950279G</a> (1996). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3789',
    'Lannung (1930)',
    'Lannung, A.: <span class="cmti-10">The solubilities of helium, neon and argon</span> <span class="cmti-10">in water and some organic solvents</span>, J. Am. Chem. Soc., 52, 68–80, <a href="https://doi.org/10.1021/JA01364A011" >doi:10.1021/JA01364A011</a> (1930). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '499',
    'Latimer (1952)',
    'Latimer, W. M.: The Oxidation States of the Elements and their Potentials in Aqueous Solutions, Prentice-Hall, Englewood Cliffs, NJ (1952). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2564',
    'Lau et&nbsp;al. (2006)',
    'Lau, F. K., Charles, M. J., &#x0026; Cahill, T. M.: <span class="cmti-10">Evaluation of gas-stripping methods for</span> <span class="cmti-10">the determination of Henry&#x2019;s law constants for polybrominated diphenyl</span> <span class="cmti-10">ethers and polychlorinated biphenyls</span>, J. Chem. Eng. Data, 51, 871–878, <a href="https://doi.org/10.1021/JE050308B" >doi:10.1021/JE050308B</a> (2006). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2982',
    'Lau et&nbsp;al. (2010)',
    'Lau, K., Rogers, T. N., &#x0026; Chesney, D. J.: <span class="cmti-10">Measuring the aqueous Henry&#x2019;s law constant at elevated</span> <span class="cmti-10">temperatures using an extended EPICS technique</span>, J. Chem. Eng. Data, 55, 5144–5148, <a href="https://doi.org/10.1021/JE100701W" >doi:10.1021/JE100701W</a> (2010). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3947',
    'Lau et&nbsp;al. (1995)',
    'Lau, Y. L., Liu, D. L. S., Pacepavicius, G. J., &#x0026; Maguire, R. J.: <span class="cmti-10">Volatilization of</span> <span class="cmti-10">metolachlor from water</span>, J. Environ. Sci. Health B, 30, 605–620, <a href="https://doi.org/10.1080/03601239509372956" >doi:10.1080/03601239509372956</a> (1995). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3929',
    'Leaist (1986)',
    'Leaist, D. G.: <span class="cmti-10">Absorption of chlorine into water</span>, J. Solution Chem., 15, 827–838, <a href="https://doi.org/10.1007/BF00646090" >doi:10.1007/BF00646090</a> (1986). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '481',
    'Ledbury and Blair (1925)',
    'Ledbury, W. &#x0026; Blair, E. W.: <span class="cmti-10">The partial</span> <span class="cmti-10">formaldehyde vapour pressures of aqueous solutions of formaldehyde.</span> <span class="cmti-10">Part II</span>, J. Chem. Soc., 127, 2832–2839, <a href="https://doi.org/10.1039/CT9252702832" >doi:10.1039/CT9252702832</a> (1925). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2932',
    'Lee (2007)',
    'Lee, F. F.: Comprehensive analysis, Henry&#x2019;s law constant determination, and photocatalytic degradation of polychlorinated biphenyls (PCBs) and/or other persistent organic pollutants (POPs), Ph.D. thesis, University at Albany, State University of New York, USA, ISBN 978-0-549-42141-2 (2007). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3014',
    'Lee et&nbsp;al. (2012)',
    'Lee, H., Kim, H.-J., &#x0026; Kwon, J.-H.: <span class="cmti-10">Determination of Henry&#x2019;s law constant using diffusion in air</span> <span class="cmti-10">and water boundary layers</span>, J. Chem. Eng. Data, 57, 3296–3302, <a href="https://doi.org/10.1021/JE300954S" >doi:10.1021/JE300954S</a> (2012). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2987',
    'Lee et&nbsp;al. (2013)',
    'Lee, S.-H., Mukherjee, S., Brewer, B., Ryan, R., Yu, H., &#x0026; Gangoda, M.: <span class="cmti-10">A laboratory experiment to measure Henry&#x2019;s law constants of volatile</span> <span class="cmti-10">organic compounds with a bubble column and a gas chromatography</span> <span class="cmti-10">flame ionization detector (GC-FID)</span>, J. Chem. Educ., 90, 495–499, <a href="https://doi.org/10.1021/ED200303X" >doi:10.1021/ED200303X</a> (2013). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '59',
    'Lee and Schwartz (1981)',
    'Lee, Y.-N. &#x0026; Schwartz, S. E.: <span class="cmti-10">Reaction kinetics of</span> <span class="cmti-10">nitrogen dioxide with liquid water at low partial pressure</span>, J. Phys. Chem., 85, 840–848, <a href="https://doi.org/10.1021/J150607A022" >doi:10.1021/J150607A022</a> (1981). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2527',
    'Lee and Zhou (1993)',
    'Lee, Y.-N. &#x0026; Zhou, X.: <span class="cmti-10">Method for the determination</span> <span class="cmti-10">of some soluble atmospheric carbonyl compounds</span>, Environ. Sci. Technol., 27, 749–756, <a href="https://doi.org/10.1021/ES00041A020" >doi:10.1021/ES00041A020</a> (1993). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1124',
    'Lee and Zhou (1994)',
    'Lee, Y.-N. &#x0026; Zhou, X.: <span class="cmti-10">Aqueous reaction kinetics of</span> <span class="cmti-10">ozone and dimethylsulfide and its atmospheric implications</span>, J. Geophys. Res., 99, 3597–3605, <a href="https://doi.org/10.1029/93JD02919" >doi:10.1029/93JD02919</a> (1994). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2960',
    'Lei et&nbsp;al. (1999)',
    'Lei, Y. D., Wania, F., Shiu, W. Y., &#x0026; Boocock, D. G. B.: <span class="cmti-10">Temperature dependent vapor pressures</span> <span class="cmti-10">of chlorinated catechols, syringols, and syringaldehydes</span>, J. Chem. Eng. Data, 44, 200–202, <a href="https://doi.org/10.1021/JE9801819" >doi:10.1021/JE9801819</a> (1999). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2996',
    'Lei et&nbsp;al. (2004)',
    'Lei, Y. D., Wania, F., Mathers, D., &#x0026; Mabury, S. A.: <span class="cmti-10">Determination of vapor pressures,</span> <span class="cmti-10">octanol-air, and water-air partition coefficients for polyfluorinated</span> <span class="cmti-10">sulfonamide, sulfonamidoethanols, and telomer alcohols</span>, J. Chem. Eng. Data, 49, 1013–1022, <a href="https://doi.org/10.1021/JE049949H" >doi:10.1021/JE049949H</a> (2004). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2997',
    'Lei et&nbsp;al. (2007)',
    'Lei, Y. D., Shunthirasingham, C., &#x0026; Wania, F.: <span class="cmti-10">Comparison of headspace</span> <span class="cmti-10">and gas-stripping techniques for measuring the air–water partititioning</span> <span class="cmti-10">of normal alkanols (C4 to C10) – effect of temperature, chain length</span> <span class="cmti-10">and adsorption to the water surface</span>, J. Chem. Eng. Data, 52, 168–179, <a href="https://doi.org/10.1021/JE060344Q" >doi:10.1021/JE060344Q</a> (2007). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1150',
    'Leighton and Calo (1981)',
    'Leighton, D. T. &#x0026; Calo, J. M.: <span class="cmti-10">Distribution</span> <span class="cmti-10">coefficients of chlorinated hydrocarbons in dilute air–water systems</span> <span class="cmti-10">for groundwater contamination applications</span>, J. Chem. Eng. Data, 26, 382–385, <a href="https://doi.org/10.1021/JE00026A010" >doi:10.1021/JE00026A010</a> (1981). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3086',
    'Leistra (1970)',
    'Leistra, M.: <span class="cmti-10">Distribution of 1,3-dichloropropene over the phases in soil</span>, J. Agric. Food Chem., 18, 1124–1126, <a href="https://doi.org/10.1021/JF60172A004" >doi:10.1021/JF60172A004</a> (1970). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3126',
    'Lekvam and Bishnoi (1997)',
    'Lekvam, K. &#x0026; Bishnoi, P. R.: <span class="cmti-10">Dissolution of</span> <span class="cmti-10">methane in water at low temperatures and intermediate pressures</span>, Fluid Phase Equilib., 131, 297–309, <a href="https://doi.org/10.1016/S0378-3812(96)03229-3" >doi:10.1016/S0378-3812(96)03229-3</a> (1997). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '31',
    'Lelieveld and Crutzen (1991)',
    'Lelieveld, J. &#x0026; Crutzen, P. J.: <span class="cmti-10">The role of</span> <span class="cmti-10">clouds in tropospheric photochemistry</span>, J. Atmos. Chem., 12, 229–267, <a href="https://doi.org/10.1007/BF00048075" >doi:10.1007/BF00048075</a> (1991). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3008',
    'Leng et&nbsp;al. (2013)',
    'Leng, C., Kish, J. D., Kelley, J., Mach, M., Hiltner, J., Zhang, Y., &#x0026; Liu, Y.: <span class="cmti-10">Temperature-dependent Henry&#x2019;s law constants of atmospheric</span> <span class="cmti-10">organics of biogenic origin</span>, J. Phys. Chem. A, 117, 10 359–10 367, <a href="https://doi.org/10.1021/JP403603Z" >doi:10.1021/JP403603Z</a> (2013). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3685',
    'Leng et&nbsp;al. (2015a)',
    'Leng, C., Kish, J. D., Roberts, J. E., Dwebi, I., Chon, N., &#x0026; Liu, Y.: <span class="cmti-10">Temperature-dependent Henry&#x2019;s law constants of atmospheric amines</span>, J. Phys. Chem. A, 119, 8884–8891, <a href="https://doi.org/10.1021/ACS.JPCA.5B05174" >doi:10.1021/ACS.JPCA.5B05174</a> (2015a). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3686',
    'Leng et&nbsp;al. (2015b)',
    'Leng, C.-B., Roberts, J. E., Zeng, G., Zhang, Y.-H., &#x0026; Liu, Y.: <span class="cmti-10">Effects of temperature,</span> <span class="cmti-10">pH, and ionic strength on the Henry&#x2019;s law constant of triethylamine</span>, Geophys. Res. Lett., 42, 3569–3575, <a href="https://doi.org/10.1002/2015GL063840" >doi:10.1002/2015GL063840</a> (2015b). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1442',
    'Leriche et&nbsp;al. (2000)',
    'Leriche, M., Voisin, D., Chaumerliac, N., Monod, A., &#x0026; Aumont, B.: <span class="cmti-10">A</span> <span class="cmti-10">model for tropospheric multiphase chemistry: application to one cloudy</span> <span class="cmti-10">event during the CIME experiment</span>, Atmos. Environ., 34, 5015–5036, <a href="https://doi.org/10.1016/S1352-2310(00)00329-0" >doi:10.1016/S1352-2310(00)00329-0</a> (2000). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2444',
    'Lerman et&nbsp;al. (1983)',
    'Lerman, J., Willis, M. M., Gregory, G. A., &#x0026; Eger, E. I.: <span class="cmti-10">Osmolarity determines the</span> <span class="cmti-10">solubility of anesthetics in aqueous solutions at 37</span><span class="cmsy-7">∘</span>C, Anesthesiology, 59, 554–558, <a href="https://doi.org/10.1097/00000542-198312000-00013" >doi:10.1097/00000542-198312000-00013</a> (1983). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1182',
    'Leu and Zhang (1999)',
    'Leu, M.-T. &#x0026; Zhang, R.: <span class="cmti-10">Solubilities</span> <span class="cmti-10">of</span> CH<sub><span class="cmr-7">3</span></sub>C(O)O<sub><span class="cmr-7">2</span></sub>NO<sub><span class="cmr-7">2</span></sub> <span class="cmti-10">and</span> HO<sub><span class="cmr-7">2</span></sub>NO<sub><span class="cmr-7">2</span></sub> <span class="cmti-10">in water and liquid</span> H<sub><span class="cmr-7">2</span></sub>SO<sub><span class="cmr-7">4</span></sub>, Geophys. Res. Lett., 26, 1129–1132, <a href="https://doi.org/10.1029/1999GL900158" >doi:10.1029/1999GL900158</a> (1999). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1068',
    'Leuenberger et&nbsp;al. (1985)',
    'Leuenberger, C., Ligocki, M. P., &#x0026; Pankow, J. F.: <span class="cmti-10">Trace organic compounds in</span> <span class="cmti-10">rain: 4. Identities, concentrations, and scavenging mechanisms for</span> <span class="cmti-10">phenols in urban air and rain</span>, Environ. Sci. Technol., 19, 1053–1058, <a href="https://doi.org/10.1021/ES00141A005" >doi:10.1021/ES00141A005</a> (1985). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3392',
    'Levanov et&nbsp;al. (2008)',
    'Levanov, A. V., Kuskov, I. V., Antipenko, E. E., &#x0026; Lunin, V. V.: <span class="cmti-10">The solubility</span> <span class="cmti-10">of ozone in aqueous solutions of sulfuric, phosphoric, and perchloric</span> <span class="cmti-10">acids</span>, Russ. J. Phys. Chem. A, 82, 1126–1131 (2008). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3545',
    'Lewis et&nbsp;al. (1987)',
    'Lewis, C., Hopke, P. K., &#x0026; Stukel, J. J.: <span class="cmti-10">Solubility of radon in selected perfluorocarbon compounds</span> <span class="cmti-10">and water</span>, Ind. Eng. Chem. Res., 26, 356–359, <a href="https://doi.org/10.1021/IE00062A030" >doi:10.1021/IE00062A030</a> (1987). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2566',
    'Li et&nbsp;al. (2007)',
    'Li, H., Ellis, D., &#x0026; Mackay, D.: <span class="cmti-10">Measurement of low air–water partition coefficients of organic acids by</span> <span class="cmti-10">evaporation from a water surface</span>, J. Chem. Eng. Data, 52, 1580–1584, <a href="https://doi.org/10.1021/JE600556D" >doi:10.1021/JE600556D</a> (2007). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3689',
    'Li et&nbsp;al. (2014)',
    'Li, H., Wang, X., Yi, T., Xu, Z., &#x0026; Liu, X.: <span class="cmti-10">Prediction of Henry&#x2019;s law constants for organic compounds</span> <span class="cmti-10">using multilayer feedforward neural networks based on linear salvation</span> <span class="cmti-10">energy relationship</span>, J. Chem. Pharm. Res., 6, 1557–1564 (2014). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2457',
    'Li and Carr (1993)',
    'Li, J. &#x0026; Carr, P. W.: <span class="cmti-10">Measurement of water-hexadecane</span> <span class="cmti-10">partition coefficients by headspace gas chromatography and calculation</span> <span class="cmti-10">of limiting activity coefficients in water</span>, Anal. Chem., 65, 1443–1450, <a href="https://doi.org/10.1021/AC00058A023" >doi:10.1021/AC00058A023</a> (1993). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2493',
    'Li et&nbsp;al. (1993)',
    'Li, J., Dallas, A. J., Eikens, D. I., Carr, P. W., Bergmann, D. L., Hait, M. J., &#x0026; Eckert, C. A.: <span class="cmti-10">Measurement of large infinite dilution activity</span> <span class="cmti-10">coefficients of nonelectrolytes in water by inert gas stripping and gas</span> <span class="cmti-10">chromatography</span>, Anal. Chem., 65, 3212–3218, <a href="https://doi.org/10.1021/AC00070A008" >doi:10.1021/AC00070A008</a> (1993). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2464',
    'Li et&nbsp;al. (1998)',
    'Li, J., Perdue, E. M., Pavlostathis, S. G., &#x0026; Araujo, R.: <span class="cmti-10">Physicochemical properties of selected</span> <span class="cmti-10">monoterpenes</span>, Environ. Int., 24, 353–358, <a href="https://doi.org/10.1016/S0160-4120(98)00013-0" >doi:10.1016/S0160-4120(98)00013-0</a> (1998). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2970',
    'Li et&nbsp;al. (2008)',
    'Li, J.-Q., Shen, C.-Y., Xu, G.-H., Wang, H.-M., Jiang, H.-H., Han, H.-Y., Chu, Y.-N., &#x0026; Zheng, P.-C.: <span class="cmti-10">Dynamic measurements of Henry&#x2019;s law constant</span> <span class="cmti-10">of aromatic compounds using proton transfer reaction mass spectrometry</span>, Acta Phys. Chim. Sin., 24, 705–708 (2008). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2540',
    'Li et&nbsp;al. (2003)',
    'Li, N., Wania, F., Lei, Y. D., &#x0026; Daly, G. L.: <span class="cmti-10">A comprehensive and critical</span> <span class="cmti-10">compilation, evaluation, and selection of physical-chemical property data</span> <span class="cmti-10">for selected polychlorinated biphenyls</span>, J. Phys. Chem. Ref. Data, 32, 1545–1590, <a href="https://doi.org/10.1063/1.1562632" >doi:10.1063/1.1562632</a> (2003). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3570',
    'Li et&nbsp;al. (2019)',
    'Li, P., Mühle, J., Montzka, S. A., Oram, D. E., Miller, B. R., Weiss, R. F., Fraser, P. J., &#x0026; Tanhua, T.: <span class="cmti-10">Atmospheric histories, growth rates</span> <span class="cmti-10">and solubilities in seawater and other natural waters of the potential</span> <span class="cmti-10">transient tracers HCFC-22, HCFC-141b, HCFC-142b, HFC-134a,</span> <span class="cmti-10">HFC-125, HFC-23, PFC-14 and PFC-116</span>, Ocean Sci., 15, 33–60, <a href="https://doi.org/10.5194/OS-15-33-2019" >doi:10.5194/OS-15-33-2019</a> (2019). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2913',
    'Li et&nbsp;al. (2004)',
    'Li, S., Chen, Z., &#x0026; Shi, F.: <span class="cmti-10">Determination</span> <span class="cmti-10">of Henry&#x2019;s Law constant for methyl hydroperoxide by long path FTIR</span>, Prog. Nat. Sci., 14, 765–769, <a href="https://doi.org/10.1080/10020070412331344291" >doi:10.1080/10020070412331344291</a> (2004). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3667',
    'Lichtenbelt and Schram (1985)',
    'Lichtenbelt, J. H. &#x0026; Schram, B. J.: <span class="cmti-10">Vapor-liquid equilibrium of water-acetone-air at ambient temperatures</span> <span class="cmti-10">and pressures. An analysis of different VLE-fitting methods</span>, Ind. Eng. Chem. Process Des. Dev., 24, 391–397, <a href="https://doi.org/10.1021/I200029A029" >doi:10.1021/I200029A029</a> (1985). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '477',
    'Lide and Frederikse (1995)',
    'Lide, D. R. &#x0026; Frederikse, H. P. R.: CRC Handbook of Chemistry and Physics, 76th Edition, CRC Press, Inc., Boca Raton, FL, ISBN 0849304768 (1995). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1230',
    'Lin and Pehkonen (1998)',
    'Lin, C.-J. &#x0026; Pehkonen, S. O.: <span class="cmti-10">Oxidation of</span> <span class="cmti-10">elemental mercury by aqueous chlorine (</span>HOCl<span class="cmti-10">/</span>OCl<sup><span class="cmsy-7">−</span></sup><span class="cmti-10">): Implications for</span> <span class="cmti-10">tropospheric mercury chemistry</span>, J. Geophys. Res., 103, 28 093–28 102, <a href="https://doi.org/10.1029/98JD02304" >doi:10.1029/98JD02304</a> (1998). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3694',
    'Lin and Chou (2006)',
    'Lin, J.-H. &#x0026; Chou, M.-S.: <span class="cmti-10">Temperature effects on</span> <span class="cmti-10">Henry&#x2019;s law constants for four VOCs in air-activated sludge systems</span>, Atmos. Environ., 40, 2469–2477, <a href="https://doi.org/10.1016/J.ATMOSENV.2005.12.037" >doi:10.1016/J.ATMOSENV.2005.12.037</a> (2006). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '601',
    'Lincoff and Gossett (1984)',
    'Lincoff, A. H. &#x0026; Gossett, J. M.: <span class="cmti-10">The</span> <span class="cmti-10">determination of Henry&#x2019;s law constant for volatile organics by equilibrium</span> <span class="cmti-10">partitioning in closed systems</span>, in: Gas transfer at water surfaces, edited by Brutsaert, W. &#x0026; Jirka, G. H., pp. 17–25, D. Reidel Publishing Company, Dordrecht-Holland, <a href="https://doi.org/10.1007/978-94-017-1660-4_2" >doi:10.1007/978-94-017-1660-4_2</a> (1984). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '258',
    'Lind and Kok (1986)',
    'Lind, J. A. &#x0026; Kok, G. L.: <span class="cmti-10">Henry&#x2019;s law determinations</span> <span class="cmti-10">for aqueous solutions of hydrogen</span> <span class="cmti-10">peroxide, methylhydroperoxide, and peroxyacetic acid</span>, J. Geophys. Res., 91, 7889–7895, <a href="https://doi.org/10.1029/JD091ID07P07889" >doi:10.1029/JD091ID07P07889</a> (1986). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '311',
    'Lind and Kok (1994)',
    'Lind, J. A. &#x0026; Kok, G. L.: <span class="cmti-10">Correction to “Henry&#x2019;s</span> <span class="cmti-10">law determinations for aqueous solutions of hydrogen peroxide,</span> <span class="cmti-10">methylhydroperoxide, and peroxyacetic acid” by John A.</span><span class="cmti-10"> Lind and</span> <span class="cmti-10">Gregory L.</span><span class="cmti-10"> Kok</span>, J. Geophys. Res., 99, 21 119, <a href="https://doi.org/10.1029/94JD01155" >doi:10.1029/94JD01155</a> (1994). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '796',
    'Lindinger et&nbsp;al. (1998)',
    'Lindinger, W., Hansel, A., &#x0026; Jordan, A.: <span class="cmti-10">On-line monitoring of volatile organic compounds</span> <span class="cmti-10">at pptv levels by means of proton-transfer-reaction mass spectrometry</span> <span class="cmti-10">(PTR-MS) medical applications, food control and</span> <span class="cmti-10">environmental research</span>, Int. J. Mass Spectrom. Ion Proc., 173, 191–241, <a href="https://doi.org/10.1016/S0168-1176(97)00281-4" >doi:10.1016/S0168-1176(97)00281-4</a> (1998). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2290',
    'Lindqvist and Rodhe (1985)',
    'Lindqvist, O. &#x0026; Rodhe, H.: <span class="cmti-10">Atmospheric mercury – a review</span>, Tellus, 37B, 136–159, <a href="https://doi.org/10.1111/J.1600-0889.1985.TB00062.X" >doi:10.1111/J.1600-0889.1985.TB00062.X</a> (1985). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3517',
    'Linnemann et&nbsp;al. (2020)',
    'Linnemann, M., Nikolaychuk, P. A., noz Muñoz, Y. M. M., Baumhögger, E., &#x0026; Vrabec, J.: <span class="cmti-10">Henry&#x2019;s law constant of noble</span> <span class="cmti-10">gases in water, methanol, ethanol, and isopropanol by experiment</span> <span class="cmti-10">and molecular simulation</span>, J. Chem. Eng. Data, 65, 1180–1188, <a href="https://doi.org/10.1021/ACS.JCED.9B00565" >doi:10.1021/ACS.JCED.9B00565</a> (2020). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '563',
    'Liss and Slater (1974)',
    'Liss, P. S. &#x0026; Slater, P. G.: <span class="cmti-10">Flux of gases across the</span> <span class="cmti-10">air-sea interface</span>, Nature, 247, 181–184, <a href="https://doi.org/10.1038/247181A0" >doi:10.1038/247181A0</a> (1974). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3695',
    'Liu et&nbsp;al. (2021)',
    'Liu, G.-H., Wen, M.-M., Deng, L.-T., Cui, H.-N., Jia, Y.-Y., Cheng, S.-H., Cao, J., &#x0026; Li, C.: <span class="cmti-10">The determination of Henry&#x2019;s law constant</span> <span class="cmti-10">of methane in test water by A.R.M/headspace</span>, Acta Geosci. Sinica, 4, 565–571, <a href="https://doi.org/10.3975/CAGSB.2020.111202" >doi:10.3975/CAGSB.2020.111202</a> (2021). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3111',
    'Liu et&nbsp;al. (2015)',
    'Liu, X., Guo, Z., Roache, N. F., Mocka, C. A., Allen, M. R., &#x0026; Mason, M. A.: <span class="cmti-10">Henry&#x2019;s law constant and overall mass transfer coefficient for</span> <span class="cmti-10">formaldehyde emission from small water pools under simulated indoor</span> <span class="cmti-10">environmental conditions</span>, Environ. Sci. Technol., 49, 1603–1610, <a href="https://doi.org/10.1021/ES504540C" >doi:10.1021/ES504540C</a> (2015). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2954',
    'Lodge and Danso (2007)',
    'Lodge, K. B. &#x0026; Danso, D.: <span class="cmti-10">The measurement</span> <span class="cmti-10">of fugacity and the Henry&#x2019;s law constant for volatile organic</span> <span class="cmti-10">compounds containing chromophores</span>, Fluid Phase Equilib., 253, 74–79, <a href="https://doi.org/10.1016/J.FLUID.2007.01.010" >doi:10.1016/J.FLUID.2007.01.010</a> (2007). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3683',
    'Long et&nbsp;al. (2017)',
    'Long, J., Youli, Q., &#x0026; Yu, L.: <span class="cmti-10">Effect analysis of quantum chemical descriptors and substituent</span> <span class="cmti-10">characteristics on Henry&#x2019;s law constants of polybrominated diphenyl</span> <span class="cmti-10">ethers at different temperatures</span>, Ecotoxicol. Environ. Saf., 145, 176–183, <a href="https://doi.org/10.1016/J.ECOENV.2017.07.024" >doi:10.1016/J.ECOENV.2017.07.024</a> (2017). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3786',
    'Longo et&nbsp;al. (1970)',
    'Longo, L. D., Delivoria-Papadopoulos, M., Power, G. G., Hill, E. P., &#x0026; Forster, R. E.: <span class="cmti-10">Diffusion equilibration of inert gases between</span> <span class="cmti-10">maternal and fetal placental capillaires</span>, Am. J. Physiol., 219, 561–569, <a href="https://doi.org/10.1152/AJPLEGACY.1970.219.3.561" >doi:10.1152/AJPLEGACY.1970.219.3.561</a> (1970). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '732',
    'Loomis (1928)',
    'Loomis, A. G.: <span class="cmti-10">Solubilities of gases in water</span>, in: International Critical Tables of Numerical Data, Physics, Chemistry and Technology, Vol. III, edited by Washburn, E. W., West, C. J., Dorsey, N. E., Bichowsky, F. R., &#x0026; Klemenc, A., pp. 255–261, McGraw-Hill, Inc. (1928). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '726',
    'Lovelock et&nbsp;al. (1972)',
    'Lovelock, J. E., Maggs, R. J., &#x0026; Rasmussen, R. A.: <span class="cmti-10">Atmospheric dimethyl sulphide and</span> <span class="cmti-10">the natural sulphur cycle</span>, Nature, 237, 452–453, <a href="https://doi.org/10.1038/237452A0" >doi:10.1038/237452A0</a> (1972). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '533',
    'Luke et&nbsp;al. (1989)',
    'Luke, W. T., Dickerson, R. R., &#x0026; Nunnermacker, L. J.: <span class="cmti-10">Direct</span> <span class="cmti-10">measurements of the photolysis rate coefficients and Henry&#x2019;s law</span> <span class="cmti-10">constants of several alkyl nitrates</span>, J. Geophys. Res., 94, 14 905–14 921, <a href="https://doi.org/10.1029/JD094ID12P14905" >doi:10.1029/JD094ID12P14905</a> (1989). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3595',
    'Luther (1905)',
    'Luther, R.: <span class="cmti-10">Zur Kenntnis des Ozons</span>, Z. Elektrochem., 11, 832–835, <a href="https://doi.org/10.1002/BBPC.19050114704" >doi:10.1002/BBPC.19050114704</a> (1905). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3690',
    'Lutsyk et&nbsp;al. (2005)',
    'Lutsyk, A., Portnanskij, V., Sujkov, S., &#x0026; Tchuprina, V.: <span class="cmti-10">A new set of gas/water</span> <span class="cmti-10">partition coefficients for the chloromethanes</span>, Monatsh. Chem. – Chem. Mon., 136, 1183–1189, <a href="https://doi.org/10.1007/S00706-005-0319-6" >doi:10.1007/S00706-005-0319-6</a> (2005). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3533',
    'Ma et&nbsp;al. (2010a)',
    'Ma, J., Dasgupta, P. K., Blackledge, W., &#x0026; Boss, G. R.: <span class="cmti-10">Temperature dependence of</span> <span class="cmti-10">Henry&#x2019;s law constant for hydrogen cyanide. Generation of trace standard</span> <span class="cmti-10">gaseous hydrogen cyanide</span>, Environ. Sci. Technol., 44, 3028–3034, <a href="https://doi.org/10.1021/ES1001192" >doi:10.1021/ES1001192</a> (2010a). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2989',
    'Ma et&nbsp;al. (2010b)',
    'Ma, Y.-G., Lei, Y. D., Xiao, H., Wania, F., &#x0026; Wang, W.-H.: <span class="cmti-10">Critical review and recommended</span> <span class="cmti-10">values for the physical-chemical property data of 15 polycyclic</span> <span class="cmti-10">aromatic hydrocarbons at 25</span><span class="cmsy-7">∘</span>C, J. Chem. Eng. Data, 55, 819–825, <a href="https://doi.org/10.1021/JE900477X" >doi:10.1021/JE900477X</a> (2010b). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '834',
    'Maahs (1982)',
    'Maahs, H. G.: <span class="cmti-10">Sulfur-dioxide/water equilibria between 0</span><span class="cmsy-7">∘</span> <span class="cmti-10">and 50</span><span class="cmsy-7">∘</span>C<span class="cmti-10">. An examination of data at low concentrations</span>, in: Heterogeneous Atmospheric Chemistry, Geophysical Monograph 26, edited by Schryer, D. R., pp. 187–195, Am. Geophys. Union, Washington, D.C., <a href="https://doi.org/10.1029/GM026P0187" >doi:10.1029/GM026P0187</a> (1982). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '923',
    'Maaßen (1995)',
    'Maaßen, S.: Experimentelle Bestimmung und Korrelierung von Verteilungskoeffizienten in verdünnten Lösungen, Ph.D. thesis, Technische Universität Berlin, Germany, ISBN 3826511042 (1995). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2972',
    'Mabury and Crosby (1996)',
    'Mabury, S. A. &#x0026; Crosby, D. G.: <span class="cmti-10">Pesticide</span> <span class="cmti-10">reactivity toward hydroxyl and its relationship to field persistence</span>, J. Agric. Food Chem., 44, 1920–1924, <a href="https://doi.org/10.1021/JF950423Y" >doi:10.1021/JF950423Y</a> (1996). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3087',
    'MacBean (2012a)',
    'MacBean, C.: <span class="cmti-10">The Pesticide Manual, 16th Edition,</span> <span class="cmti-10">Supplementary Entries – Extended</span>, Tech. rep., British Crop Production Council, ISBN 190139686X (2012a). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    'macbean2012',
    'MacBean (2012b)',
    'MacBean, C.: The Pesticide Manual, British Crop Production Council, ISBN 9781901396867 (2012b). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    'macintosh58',
    'Macintosh et&nbsp;al. (1958)',
    'Macintosh, R. R., Mushin, W. W., &#x0026; Epstein, H. G.: Physics for the Anaesthetist: Including a Section on Explosions, Charles C. Thomas Publisher, Ltd. (1958). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2471',
    'Mackay and Leinonen (1975)',
    'Mackay, D. &#x0026; Leinonen, P. J.: <span class="cmti-10">Rate of evaporation of low-solubility contaminants</span> <span class="cmti-10">from water bodies to atmosphere</span>, Environ. Sci. Technol., 9, 1178–1180, <a href="https://doi.org/10.1021/ES60111A012" >doi:10.1021/ES60111A012</a> (1975). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '479',
    'Mackay and Shiu (1981)',
    'Mackay, D. &#x0026; Shiu, W. Y.: <span class="cmti-10">A critical review of</span> <span class="cmti-10">Henry&#x2019;s law constants for chemicals of environmental interest</span>, J. Phys. Chem. Ref. Data, 10, 1175–1199, <a href="https://doi.org/10.1063/1.555654" >doi:10.1063/1.555654</a> (1981). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2233',
    'Mackay and Yeun (1983)',
    'Mackay, D. &#x0026; Yeun, A. T. K.: <span class="cmti-10">Mass transfer</span> <span class="cmti-10">coefficient correlations for volatilization of organic solutes from water</span>, Environ. Sci. Technol., 17, 211–217, <a href="https://doi.org/10.1021/ES00110A006" >doi:10.1021/ES00110A006</a> (1983). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '490',
    'Mackay et&nbsp;al. (1979)',
    'Mackay, D., Shiu, W. Y., &#x0026; Sutherland, R. P.: <span class="cmti-10">Determination of air–water Henry&#x2019;s law</span> <span class="cmti-10">constants for hydrophobic pollutants</span>, Environ. Sci. Technol., 13, 333–337, <a href="https://doi.org/10.1021/ES60151A012" >doi:10.1021/ES60151A012</a> (1979). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '633',
    'Mackay et&nbsp;al. (1992a)',
    'Mackay, D., Shiu, W. Y., &#x0026; Ma, K. C.: Illustrated Handbook of Physical-Chemical Properties and Environmental Fate for Organic Chemicals, vol. I of <span class="cmti-10">Monoaromatic</span> <span class="cmti-10">Hydrocarbons, Chlorobenzenes, and PCBs</span>, Lewis Publishers, Boca Raton, ISBN 0873715136 (1992a). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '634',
    'Mackay et&nbsp;al. (1992b)',
    'Mackay, D., Shiu, W. Y., &#x0026; Ma, K. C.: Illustrated Handbook of Physical-Chemical Properties and Environmental Fate for Organic Chemicals, vol. II of <span class="cmti-10">Polynuclear</span> <span class="cmti-10">Aromatic Hydrocarbons, Polychlorinated Dioxins, and Dibenzofurans</span>, Lewis Publishers, Boca Raton, ISBN 0873715837 (1992b). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '635',
    'Mackay et&nbsp;al. (1993)',
    'Mackay, D., Shiu, W. Y., &#x0026; Ma, K. C.: Illustrated Handbook of Physical-Chemical Properties and Environmental Fate for Organic Chemicals, vol. III of <span class="cmti-10">Volatile Organic</span> <span class="cmti-10">Chemicals</span>, Lewis Publishers, Boca Raton, ISBN 0873719735 (1993). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '636',
    'Mackay et&nbsp;al. (1995)',
    'Mackay, D., Shiu, W. Y., &#x0026; Ma, K. C.: Illustrated Handbook of Physical-Chemical Properties and Environmental Fate for Organic Chemicals, vol. IV of <span class="cmti-10">Oxygen, Nitrogen,</span> <span class="cmti-10">and Sulfur Containing Compounds</span>, Lewis Publishers, Boca Raton, ISBN 1566700353 (1995). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2611',
    'Mackay et&nbsp;al. (2006a)',
    'Mackay, D., Shiu, W. Y., Ma, K. C., &#x0026; Lee, S. C.: Handbook of Physical-Chemical Properties and Environmental Fate for Organic Chemicals, vol. I of <span class="cmti-10">Introduction and Hydrocarbons</span>, CRC/Taylor &#x0026; Francis Group, <a href="https://doi.org/10.1201/9781420044393" >doi:10.1201/9781420044393</a> (2006a). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2612',
    'Mackay et&nbsp;al. (2006b)',
    'Mackay, D., Shiu, W. Y., Ma, K. C., &#x0026; Lee, S. C.: Handbook of Physical-Chemical Properties and Environmental Fate for Organic Chemicals, vol. II of <span class="cmti-10">Halogenated Hydrocarbons</span>, CRC/Taylor &#x0026; Francis Group, <a href="https://doi.org/10.1201/9781420044393" >doi:10.1201/9781420044393</a> (2006b). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2613',
    'Mackay et&nbsp;al. (2006c)',
    'Mackay, D., Shiu, W. Y., Ma, K. C., &#x0026; Lee, S. C.: Handbook of Physical-Chemical Properties and Environmental Fate for Organic Chemicals, vol. III of <span class="cmti-10">Oxygen Containing</span> <span class="cmti-10">Compounds</span>, CRC/Taylor &#x0026; Francis Group, <a href="https://doi.org/10.1201/9781420044393" >doi:10.1201/9781420044393</a> (2006c). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2614',
    'Mackay et&nbsp;al. (2006d)',
    'Mackay, D., Shiu, W. Y., Ma, K. C., &#x0026; Lee, S. C.: Handbook of Physical-Chemical Properties and Environmental Fate for Organic Chemicals, vol. IV of <span class="cmti-10">Nitrogen and</span> <span class="cmti-10">Sulfur Containing Compounds and Pesticides</span>, CRC/Taylor &#x0026; Francis Group, <a href="https://doi.org/10.1201/9781420044393" >doi:10.1201/9781420044393</a> (2006d). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '844',
    'Magi et&nbsp;al. (1997)',
    'Magi, L., Schweitzer, F., Pallares, C., Cherif, S., Mirabel, P., &#x0026; George, C.: <span class="cmti-10">Investigation of the uptake rate of ozone and methyl</span> <span class="cmti-10">hydroperoxide by water surfaces</span>, J. Phys. Chem. A, 101, 4943–4949, <a href="https://doi.org/10.1021/JP970646M" >doi:10.1021/JP970646M</a> (1997). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3596',
    'Mailfert (1894)',
    'Mailfert, M.: <span class="cmti-10">Sur la solubilit</span><span class="cmti-10">é de l&#x2019;ozone</span>, C. R. Hebd. Séances Acad. Sci., 119, 951–953 (1894). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3750',
    'Maillard and Rosenthal (1952)',
    'Maillard, A. &#x0026; Rosenthal, W.: <span class="cmti-10">Solubilit</span><span class="cmti-10">é de</span> <span class="cmti-10">l&#x2019;ac</span><span class="cmti-10">étyl</span><span class="cmti-10">ène dans divers liquides organiques</span>, C. R. Hebd. Séances Acad. Sci., 234, 2546–2548 (1952). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3549',
    'Maniere et&nbsp;al. (2011)',
    'Maniere, I., Bouneb, F., Fastier, A., Courty, B., Dumenil, J., Poupard, M., &#x0026; Mercier, T.: <span class="cmti-10">AGRITOX-Database on pesticide active substances</span>, Toxicol. Lett., 205S, S231–S232, <a href="https://doi.org/10.1016/J.TOXLET.2011.05.792" >doi:10.1016/J.TOXLET.2011.05.792</a>, URL https://www.data.gouv.fr/fr/datasets/base-de-donnees-agritox (2011). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1992',
    'Manogue and Pigford (1960)',
    'Manogue, W. H. &#x0026; Pigford, R. L.: <span class="cmti-10">The kinetics</span> <span class="cmti-10">of the absorption of phosgene into water and aqueous solutions</span>, AIChE J., 6, 494–500, <a href="https://doi.org/10.1002/AIC.690060329" >doi:10.1002/AIC.690060329</a> (1960). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3563',
    'Mansfield (2020)',
    'Mansfield, M. L.: <span class="cmti-10">Mass transport of gases across the</span> <span class="cmti-10">air–water interface: implications for aldehyde emissions in the Uinta</span> <span class="cmti-10">Basin, Utah, USA</span>, Atmos., 11, 1057, <a href="https://doi.org/10.3390/ATMOS11101057" >doi:10.3390/ATMOS11101057</a> (2020). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2964',
    'Marin et&nbsp;al. (1999)',
    'Marin, M., Baek, I., &#x0026; Taylor, A. J.: <span class="cmti-10">Volatile release from aqueous solutions</span> <span class="cmti-10">under dynamic headspace dilution conditions</span>, J. Agric. Food Chem., 47, 4750–4755, <a href="https://doi.org/10.1021/JF990470G" >doi:10.1021/JF990470G</a> (1999). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2607',
    'Markham and Kobe (1941)',
    'Markham, A. E. &#x0026; Kobe, K. A.: <span class="cmti-10">The solubility</span> <span class="cmti-10">of gases in liquids</span>, Chem. Rev., 28, 519–588, <a href="https://doi.org/10.1021/CR60091A003" >doi:10.1021/CR60091A003</a> (1941). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '167',
    'Marsh and McElroy (1985)',
    'Marsh, A. R. W. &#x0026; McElroy, W. J.: <span class="cmti-10">The dissociation constant and Henry&#x2019;s law</span> <span class="cmti-10">constant of</span> HCl <span class="cmti-10">in aqueous solution</span>, Atmos. Environ., 19, 1075–1080, <a href="https://doi.org/10.1016/0004-6981(85)90192-1" >doi:10.1016/0004-6981(85)90192-1</a> (1985). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '769',
    'Marti et&nbsp;al. (1997)',
    'Marti, J. J., Jefferson, A., Cai, X. P., Richert, C., McMurry, P. H., &#x0026; Eisele, F.: H<sub><span class="cmr-7">2</span></sub>SO<sub><span class="cmr-7">4</span></sub> <span class="cmti-10">vapor pressure of sulfuric acid and ammonium sulfate</span> <span class="cmti-10">solutions</span>, J. Geophys. Res., 102, 3725–3735, <a href="https://doi.org/10.1029/96JD03064" >doi:10.1029/96JD03064</a> (1997). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '74',
    'Martin (1984)',
    'Martin, L. R.: <span class="cmti-10">Kinetic studies of sulfite oxidation in aqueous</span> <span class="cmti-10">solution</span>, in: SO<sub><span class="cmr-7">2</span></sub>, NO and NO<sub><span class="cmr-7">2</span></sub> Oxidation Mechanisms: Atmospheric Considerations, edited by Calvert, J. G., pp. 63–100, Butterworth Publishers, Boston, MA, ISBN 0250405687 (1984). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '43',
    'Martin and Damschen (1981)',
    'Martin, L. R. &#x0026; Damschen, D. E.: <span class="cmti-10">Aqueous</span> <span class="cmti-10">oxidation of sulfur dioxide by hydrogen peroxide at low pH</span>, Atmos. Environ., 15, 1615–1621, <a href="https://doi.org/10.1016/0004-6981(81)90146-3" >doi:10.1016/0004-6981(81)90146-3</a> (1981). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3678',
    'Martins et&nbsp;al. (2017)',
    'Martins, M. A. R., Silva, L. P., Ferreira, O., Schröder, B., Coutinho, J. A. P., &#x0026; Pinho, S. P.: <span class="cmti-10">Terpenes solubility in water</span> <span class="cmti-10">and their environmental distribution</span>, J. Mol. Liq., 241, 996–1002, <a href="https://doi.org/10.1016/J.MOLLIQ.2017.06.099" >doi:10.1016/J.MOLLIQ.2017.06.099</a> (2017). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3951',
    'Mavu (2011)',
    'Mavu, D. M.: Pharmaceutical formulation and in-vitro testing of Dioxy MP 14 (stabilised chlorine dioxide) against mycobacteria tuberculosis, Master&#x2019;s thesis, University of the Western Cape, South Africa, URL https://etd.uwc.ac.za/xmlui/handle/11394/5372 (2011). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3669',
    'Mazza (1980)',
    'Mazza, G.: <span class="cmti-10">Relative volatilities of some onion flavour components</span>, Int. J. Food Sci. Technol., 15, 35–41, <a href="https://doi.org/10.1111/J.1365-2621.1980.TB00916.X" >doi:10.1111/J.1365-2621.1980.TB00916.X</a> (1980). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3095',
    'Mazzoni et&nbsp;al. (1997)',
    'Mazzoni, S. M., Roy, S., &#x0026; Grigoras, S.: <span class="cmti-10">Eco-relevant properties of selected organosilicon</span> <span class="cmti-10">materials</span>, in: The Handbook of Environmental Chemistry, Vol. 3. Part H. Organosilicon Materials, edited by Chandra, G., pp. 53–81, Springer Verlag, Berlin, <a href="https://doi.org/10.1007/978-3-540-68331-5" >doi:10.1007/978-3-540-68331-5</a> (1997). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3923',
    'McAuliffe (1963)',
    'McAuliffe, C.: <span class="cmti-10">Solubility in water of</span> C<sub><span class="cmr-7">1</span></sub><span class="cmti-10">-</span>C<sub><span class="cmr-7">9</span></sub> <span class="cmti-10">hydrocarbons</span>, Nature, 200, 1092–1093, <a href="https://doi.org/10.1038/2001092A0" >doi:10.1038/2001092A0</a> (1963). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3924',
    'McAuliffe (1966)',
    'McAuliffe, C.: <span class="cmti-10">Solubility in water of paraffin,</span> <span class="cmti-10">cycloparaffin, olefin, acetylene, cycloolefin, and aromatic hydrocarbons</span>, J. Phys. Chem., 70, 1267–1275, <a href="https://doi.org/10.1021/J100876A049" >doi:10.1021/J100876A049</a> (1966). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    'mcauliffe71',
    'McAuliffe (1971)',
    'McAuliffe, C.: <span class="cmti-10">Gas chromatographic determination of</span> <span class="cmti-10">solutes by multiple phase equilibrium</span>, Chem. Technol., 1, 46–51 (1971). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    'mccarty80',
    'McCarty (1980)',
    'McCarty, P. L.: <span class="cmti-10">Organics in water – an engineering</span> <span class="cmti-10">challenge</span>, J. Environ. Eng. Div., 106, 1–17 (1980). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '543',
    'McConnell et&nbsp;al. (1975)',
    'McConnell, G., Ferguson, D. M., &#x0026; Pearson, C. R.: <span class="cmti-10">Chlorinated hydrocarbons and the</span> <span class="cmti-10">environment</span>, Endeavour, 34, 13–18, <a href="https://doi.org/10.1016/0160-9327(75)90062-9" >doi:10.1016/0160-9327(75)90062-9</a> (1975). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3232',
    'McCoy et&nbsp;al. (1990)',
    'McCoy, W. F., Blatchley, III, E. R., &#x0026; Johnson, R. W.: <span class="cmti-10">Hypohalous acid and</span> <span class="cmti-10">haloamine flashoff in industrial evaporative cooling systems</span>, Tech. rep., Cooling Tower Institute, paper no.: TP90-09 (1990). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3723',
    'McFall et&nbsp;al. (2020)',
    'McFall, A. S., Johnson, A. W., &#x0026; Anastasio, C.: <span class="cmti-10">Air–water partitioning</span> <span class="cmti-10">of biomass-burning phenols and the effects of temperature and salinity</span>, Environ. Sci. Technol., 54, 3823–3830, <a href="https://doi.org/10.1021/ACS.EST.9B06443" >doi:10.1021/ACS.EST.9B06443</a> (2020). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3672',
    'McIntosh and Heffron (2000)',
    'McIntosh, J. M. &#x0026; Heffron, J. J. A.: <span class="cmti-10">Modelling</span> <span class="cmti-10">alterations in the partition coefficient in in vitro biological systems</span> <span class="cmti-10">using headspace gas chromatography</span>, J. Chromatogr. B, 738, 207–216, <a href="https://doi.org/10.1016/S0378-4347(99)00506-X" >doi:10.1016/S0378-4347(99)00506-X</a> (2000). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3641',
    'McKeown and Stowell (1927)',
    'McKeown, A. &#x0026; Stowell, F. P.: <span class="cmti-10">XVI.—The</span> <span class="cmti-10">vapour pressures of mixtures of (a) methyl acetate and water ; (b)</span> <span class="cmti-10">methyl acetate, sucrose, and water</span>, J. Chem. Soc., pp. 97–103, <a href="https://doi.org/10.1039/JR9270000097" >doi:10.1039/JR9270000097</a> (1927). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2975',
    'McLachlan et&nbsp;al. (1990)',
    'McLachlan, M., Mackay, D., &#x0026; Jones, P. H.: <span class="cmti-10">A conceptual model of</span> <span class="cmti-10">organic chemical volatilization at waterfalls</span>, Environ. Sci. Technol., 24, 252–257, <a href="https://doi.org/10.1021/ES00072A015" >doi:10.1021/ES00072A015</a> (1990). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1014',
    'McLinden (1989)',
    'McLinden, M. O.: <span class="cmti-10">Physical properties of alternatives to</span> <span class="cmti-10">the fully halogenated chlorofluorocarbons</span>, in: WMO Report 20, Scientific Assessment of Stratospheric Ozone: 1989, Volume II, pp. 11–38, World Meteorol. Organ., Geneva, ISBN 9280712551 (1989). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3098',
    'McNeill et&nbsp;al. (2012)',
    'McNeill, V. F., Woo, J. L., Kim, D. D., Schwier, A. N., Wannell, N. J., Sumner, A. J., &#x0026; Barakat, J. M.: <span class="cmti-10">Aqueous-phase secondary organic</span> <span class="cmti-10">aerosol and organosulfate formation in atmospheric aerosols: a modeling</span> <span class="cmti-10">study</span>, Environ. Sci. Technol., 46, 8075–8081, <a href="https://doi.org/10.1021/ES3002986" >doi:10.1021/ES3002986</a> (2012). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3009',
    'McPhedran et&nbsp;al. (2013)',
    'McPhedran, K. N., Seth, R., &#x0026; Drouillard, K. G.: <span class="cmti-10">Evaluation of the gas</span> <span class="cmti-10">stripping technique for calculation of Henry&#x2019;s law constants using the</span> <span class="cmti-10">initial slope method for 1,2,4,5-tetrachlorobenzene, pentachlorobenzene,</span> <span class="cmti-10">and hexachlorobenzene</span>, Chemosphere, 91, 1648–1652, <a href="https://doi.org/10.1016/J.CHEMOSPHERE.2012.12.017" >doi:10.1016/J.CHEMOSPHERE.2012.12.017</a> (2013). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '505',
    'Meadows and Spedding (1974)',
    'Meadows, R. W. &#x0026; Spedding, D. J.: <span class="cmti-10">The</span> <span class="cmti-10">solubility of very low concentrations of carbon monoxide in aqueous</span> <span class="cmti-10">solution</span>, Tellus, 26, 143–149, <a href="https://doi.org/10.3402/TELLUSA.V26I1-2.9745" >doi:10.3402/TELLUSA.V26I1-2.9745</a> (1974). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3436',
    'Mentel et&nbsp;al. (1999)',
    'Mentel, T. F., Sohn, M., &#x0026; Wahner, A.: <span class="cmti-10">Nitrate effect in the heterogeneous hydrolysis of dinitrogen</span> <span class="cmti-10">pentoxide on aqueous aerosols</span>, Phys. Chem. Chem. Phys., 1, 5451–5457, <a href="https://doi.org/10.1039/A905338G" >doi:10.1039/A905338G</a> (1999). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1658',
    'Mentel et&nbsp;al. (2004)',
    'Mentel, T. F., Folkers, M., Tillmann, R., Henk, H., Wahner, A., Otjes, R., Blom, M., &#x0026; ten Brink, H. M.: <span class="cmti-10">Determination of the Henry</span> <span class="cmti-10">coefficients for organic aerosol components</span>, Geophys. Res. Abstr., 6, 1525 (2004). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3657',
    'Merk and Riederer (1997)',
    'Merk, S. &#x0026; Riederer, M.: <span class="cmti-10">Sorption of volatile</span> <span class="cmti-10">C1 to C6 alkanols in plant cuticles</span>, J. Exp. Bot., 48, 1095–1104, <a href="https://doi.org/10.1093/JXB/48.5.1095" >doi:10.1093/JXB/48.5.1095</a> (1997). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2454',
    'Metcalfe et&nbsp;al. (1980)',
    'Metcalfe, C. D., McLeese, D. W., &#x0026; Zitko, V.: <span class="cmti-10">Rate of volatilization of fenitrothion from</span> <span class="cmti-10">fresh water</span>, Chemosphere, 9, 151–155, <a href="https://doi.org/10.1016/0045-6535(80)90086-7" >doi:10.1016/0045-6535(80)90086-7</a> (1980). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1145',
    'Meylan and Howard (1991)',
    'Meylan, W. M. &#x0026; Howard, P. H.: <span class="cmti-10">Bond</span> <span class="cmti-10">contribution method for estimating Henry&#x2019;s law constants</span>, Environ. Toxicol. Chem., 10, 1283–1293, <a href="https://doi.org/10.1002/ETC.5620101007" >doi:10.1002/ETC.5620101007</a> (1991). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3650',
    'Meynier et&nbsp;al. (2003)',
    'Meynier, A., Garillon, A., Lethuaut, L., &#x0026; Genot, C.: <span class="cmti-10">Partition of five aroma</span> <span class="cmti-10">compounds between air and skim milk, anhydrous milk fat or full-fat</span> <span class="cmti-10">cream</span>, Lait, 83, 223–235, <a href="https://doi.org/10.1051/LAIT:2003012" >doi:10.1051/LAIT:2003012</a> (2003). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3552',
    'Mick et&nbsp;al. (2016)',
    'Mick, J. R., Barhaghi, M. S., &#x0026; Potoff, J. J.: <span class="cmti-10">Prediction of radon-222 phase behavior by Monte Carlo</span> <span class="cmti-10">simulation</span>, J. Chem. Eng. Data, 61, 1625–1631, <a href="https://doi.org/10.1021/ACS.JCED.5B01002" >doi:10.1021/ACS.JCED.5B01002</a> (2016). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3261',
    'Miguel et&nbsp;al. (2000)',
    'Miguel, A. A. F., Ferreira, A. G. M., &#x0026; Fonseca, I. M. A.: <span class="cmti-10">Solubilities</span> <span class="cmti-10">of some new refrigerants in water</span>, Fluid Phase Equilib., 173, 97–107, <a href="https://doi.org/10.1016/S0378-3812(00)00390-3" >doi:10.1016/S0378-3812(00)00390-3</a> (2000). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1928',
    'Miller and Stuart (2000)',
    'Miller, M. E. &#x0026; Stuart, J. D.: <span class="cmti-10">Measurement of</span> <span class="cmti-10">aqueous Henry&#x2019;s law constants for oxygenates and aromatics found in</span> <span class="cmti-10">gasolines by the static headspace method</span>, Anal. Chem., 72, 622–625, <a href="https://doi.org/10.1021/AC990757C" >doi:10.1021/AC990757C</a> (2000). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1927',
    'Miller and Stuart (2003)',
    'Miller, M. E. &#x0026; Stuart, J. D.: <span class="cmti-10">Correction: Measurement of aqueous Henry&#x2019;s law constants</span> <span class="cmti-10">for oxygenates and aromatics found in gasolines by the static headspace</span> <span class="cmti-10">method</span>, Anal. Chem., 75, 1037, <a href="https://doi.org/10.1021/AC034002O" >doi:10.1021/AC034002O</a> (2003). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3605',
    'Millero et&nbsp;al. (2002a)',
    'Millero, F. J., Huang, F., &#x0026; Laferiere, A. L.: <span class="cmti-10">Solubility of oxygen in the major sea salts as a</span> <span class="cmti-10">function of concentration and temperature</span>, Mar. Chem., 78, 217–230, <a href="https://doi.org/10.1016/S0304-4203(02)00034-8" >doi:10.1016/S0304-4203(02)00034-8</a> (2002a). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3606',
    'Millero et&nbsp;al. (2002b)',
    'Millero, F. J., Huang, F., &#x0026; Laferiere, A. L.: <span class="cmti-10">The solubility of oxygen in the major sea salts</span> <span class="cmti-10">and their mixtures at 25</span><span class="cmsy-7">∘</span>C, Geochim. Cosmochim. Acta, 66, 2349–2359, <a href="https://doi.org/10.1016/S0016-7037(02)00838-4" >doi:10.1016/S0016-7037(02)00838-4</a> (2002b). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '671',
    'Mirabel et&nbsp;al. (1996)',
    'Mirabel, P., George, C., Magi, L., &#x0026; Ponche, J. L.: <span class="cmti-10">Chapter</span> <span class="cmti-10">6.3: Gas-liquid interactions</span>, in: Heterogeneous and Liquid-Phase Processes, edited by Warneck, P., pp. 175–181, Springer Verlag, Berlin, <a href="https://doi.org/10.1007/978-3-642-61445-3_6" >doi:10.1007/978-3-642-61445-3_6</a> (1996). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3082',
    'Mirvish et&nbsp;al. (1976)',
    'Mirvish, S. S., Issenberg, P., &#x0026; Sornson, H. C.: <span class="cmti-10">Air–water and ether-water distribution</span> <span class="cmti-10">of N-nitroso compounds: implications for laboratory safety, analytic</span> <span class="cmti-10">methodology, and carcinogenicity for the rat esophagus, nose, and liver</span>, J. Natl. Cancer Inst., 56, 1125–1129, <a href="https://doi.org/10.1093/JNCI/56.6.1125" >doi:10.1093/JNCI/56.6.1125</a> (1976). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3512',
    'Modarresi et&nbsp;al. (2005)',
    'Modarresi, H., Modarress, H., &#x0026; Dearden, J. C.: <span class="cmti-10">Henry&#x2019;s law constant of hydrocarbons</span> <span class="cmti-10">in air–water system: The cavity ovality effect on the non-electrostatic</span> <span class="cmti-10">contribution term of solvation free energy</span>, SAR QSAR Environ. Res., 16, 461–482, <a href="https://doi.org/10.1080/10659360500319869" >doi:10.1080/10659360500319869</a> (2005). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2530',
    'Modarresi et&nbsp;al. (2007)',
    'Modarresi, H., Modarress, H., &#x0026; Dearden, J. C.: <span class="cmti-10">QSPR model of Henry&#x2019;s law</span> <span class="cmti-10">constant for a diverse set of organic chemicals based on genetic</span> <span class="cmti-10">algorithm-radial basis function network approach</span>, Chemosphere, 66, 2067–2076, <a href="https://doi.org/10.1016/J.CHEMOSPHERE.2006.09.049" >doi:10.1016/J.CHEMOSPHERE.2006.09.049</a> (2007). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3117',
    'Mohebbi et&nbsp;al. (2012)',
    'Mohebbi, V., Naderifar, A., Behbahani, R. M., &#x0026; Moshfeghian, M.: <span class="cmti-10">Determination of Henry&#x2019;s law constant of light hydrocarbon</span> <span class="cmti-10">gases at low temperatures</span>, J. Chem. Thermodyn., 51, 8–11, <a href="https://doi.org/10.1016/J.JCT.2012.02.014" >doi:10.1016/J.JCT.2012.02.014</a> (2012). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '507',
    'Möller and Mauersberger (1992)',
    'Möller, D. &#x0026; Mauersberger, G.: <span class="cmti-10">Aqueous</span> <span class="cmti-10">phase chemical reaction system used in cloud chemistry modelling</span>, in: EUROTRAC Special Publication: Clouds: Models and Mechanisms, edited by Flossmann, A., Cvitaš, T., Möller, D., &#x0026; Mauersberger, G., pp. 77–93 (1992). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1026',
    'Moore (2000)',
    'Moore, R. M.: <span class="cmti-10">The</span> <span class="cmti-10">solubility of a suite of low molecular weight organochlorine compounds</span> <span class="cmti-10">in seawater and implications for estimating the marine source of methyl</span> <span class="cmti-10">chloride to the atmosphere</span>, Chemosphere Global Change Sci., 2, 95–99, <a href="https://doi.org/10.1016/S1465-9972(99)00045-8" >doi:10.1016/S1465-9972(99)00045-8</a> (2000). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '583',
    'Moore et&nbsp;al. (1995)',
    'Moore, R. M., Geen, C. E., &#x0026; Tait, V. K.: <span class="cmti-10">Determination of Henry&#x2019;s law constants for a suite of</span> <span class="cmti-10">naturally occuring halogenated methanes in seawater</span>, Chemosphere, 30, 1183–1191, <a href="https://doi.org/10.1016/0045-6535(95)00009-W" >doi:10.1016/0045-6535(95)00009-W</a> (1995). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3783',
    'Morrison and Billett (1952)',
    'Morrison, T. J. &#x0026; Billett, F.: <span class="cmti-10">730. The salting-out of non-electrolytes.</span> <span class="cmti-10">Part II. The effect of variation in non-electrolyte</span>, J. Chem. Soc., pp. 3819–3822, <a href="https://doi.org/10.1039/JR9520003819" >doi:10.1039/JR9520003819</a> (1952). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '764',
    'Morrison and Johnstone (1954)',
    'Morrison, T. J. &#x0026; Johnstone, N. B.: <span class="cmti-10">Solubilities of the inert gases in water</span>, J. Chem. Soc., pp. 3441–3446, <a href="https://doi.org/10.1039/JR9540003441" >doi:10.1039/JR9540003441</a> (1954). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3950',
    'Morrow et&nbsp;al. (2006)',
    'Morrow, M., McMahon, T., Leighton, T., Shamim, N., Angle, G., Chen, J., Carlisle, S., Isbell, D., Slotnick, J., Mitchell, E., Henson, W., Koch, E., &#x0026; Knorr, M.: <span class="cmti-10">Reregistration eligibility decision (RED)</span> <span class="cmti-10">for chlorine dioxide and sodium chlorite (case 4023)</span>, Tech. Rep. EPA 738-R-06-007, United States Environmental Protection Agency, URL https://www3.epa.gov/pesticides/chem_search/reg_actions/reregistration/red_PC-020503_3-Aug-06.pdf (2006). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '189',
    'Mozurkewich (1986)',
    'Mozurkewich, M.: <span class="cmti-10">Comment on “Possible role of</span> NO<sub><span class="cmr-7">3</span></sub> <span class="cmti-10">in the nighttime chemistry of a cloud” by William L.</span><span class="cmti-10"> Chameides</span>, J. Geophys. Res., 91, 14 569–14 570, <a href="https://doi.org/10.1029/JD091ID13P14569" >doi:10.1029/JD091ID13P14569</a> (1986). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '276',
    'Mozurkewich (1995)',
    'Mozurkewich, M.: <span class="cmti-10">Mechanisms for the release of</span> <span class="cmti-10">halogens from sea-salt particles by free radical reactions</span>, J. Geophys. Res., 100, 14 199–14 207, <a href="https://doi.org/10.1029/94JD00358" >doi:10.1029/94JD00358</a> (1995). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3926',
    'Muccitelli and Wen (1978)',
    'Muccitelli, J. A. &#x0026; Wen, W.-Y.: <span class="cmti-10">Solubilities of</span> <span class="cmti-10">hydrogen and deuterium gases in water and their isotope fractionation</span> <span class="cmti-10">factor</span>, J. Solution Chem., 7, 257–267, <a href="https://doi.org/10.1007/BF00644273" >doi:10.1007/BF00644273</a> (1978). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2965',
    'Muir et&nbsp;al. (2004)',
    'Muir, D. C. G., Teixeira, C., &#x0026; Wania, F.: <span class="cmti-10">Empirical and modeling evidence of regional atmospheric</span> <span class="cmti-10">transport of current-use pesticides</span>, Environ. Toxicol. Chem., 23, 2421–2432, <a href="https://doi.org/10.1897/03-457" >doi:10.1897/03-457</a> (2004). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1514',
    'Müller and Heal (2001)',
    'Müller, B. &#x0026; Heal, M. R.: <span class="cmti-10">The Henry&#x2019;s law</span> <span class="cmti-10">coefficient of 2-nitrophenol over the temperature range 278–303 </span>K, Chemosphere, 45, 309–314, <a href="https://doi.org/10.1016/S0045-6535(00)00592-0" >doi:10.1016/S0045-6535(00)00592-0</a> (2001). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3534',
    'Munder et&nbsp;al. (2000)',
    'Munder, B., Lidal, H., &#x0026; Sandall, O. C.: <span class="cmti-10">Physical solubility of hydrogen sulfide in aqueous</span> <span class="cmti-10">solutions of 2-(tert-butylamino)ethanol</span>, J. Chem. Eng. Data, 45, 1201–1204, <a href="https://doi.org/10.1021/JE000166F" >doi:10.1021/JE000166F</a> (2000). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2446',
    'Munson et&nbsp;al. (1964)',
    'Munson, E. S., Saidman, L. J., &#x0026; Eger, E. I.: <span class="cmti-10">Solubility of</span> <span class="cmti-10">fluroxene in blood and tissue homogenates</span>, Anesthesiology, 25, 638–640, <a href="https://doi.org/10.1097/00000542-196409000-00010" >doi:10.1097/00000542-196409000-00010</a> (1964). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2903',
    'Munz and Roberts (1986)',
    'Munz, C. &#x0026; Roberts, P. V.: <span class="cmti-10">Effects of solute</span> <span class="cmti-10">concentration and cosolvents on the aqueous activity coefficient</span> <span class="cmti-10">of halogenated hydrocarbons</span>, Environ. Sci. Technol., 20, 830–836, <a href="https://doi.org/10.1021/ES00150A013" >doi:10.1021/ES00150A013</a> (1986). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2243',
    'Munz and Roberts (1987)',
    'Munz, C. &#x0026; Roberts, P. V.: <span class="cmti-10">Air–water phase</span> <span class="cmti-10">equilibria of volatile organic solutes</span>, J. Am. Water Works Assoc., 79, 62–69, <a href="https://doi.org/10.1002/J.1551-8833.1987.TB02844.X" >doi:10.1002/J.1551-8833.1987.TB02844.X</a> (1987). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3797',
    'Murphy et&nbsp;al. (1983a)',
    'Murphy, T. J., Pokojowczyk, J. C., &#x0026; Mullin, M. D.: <span class="cmti-10">Vapor exchange</span> <span class="cmti-10">of PCBs with Lake Michigan: The atmosphere as a sink for</span> <span class="cmti-10">PCBs</span>, Tech. Rep. EPA/600/D-83/097 (NTIS PB83250316), United States Environmental Protection Agency, URL https://ntrl.ntis.gov/NTRL/dashboard/searchResults.xhtml?searchQuery=PB83250316 (1983a). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    'murphy83',
    'Murphy et&nbsp;al. (1983b)',
    'Murphy, T. J., Pokojowczyk, J. C., &#x0026; Mullin, M. D.: <span class="cmti-10">Vapor exchange of PCBs</span> <span class="cmti-10">with Lake Michigan: The atmosphere as a sink for PCBs</span>, in: Physical Behavior of PCBs in the Great Lakes, edited by Mackay, D., Patterson, S., Eisenreich, S. J., &#x0026; Simmons, M. S., pp. 49–58, Ann Arbor Science, Ann Arbor, Mich. (1983b). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '853',
    'Murphy et&nbsp;al. (1987)',
    'Murphy, T. J., Mullin, M. D., &#x0026; Meyer, J. A.: <span class="cmti-10">Equilibration of polychlorinated</span> <span class="cmti-10">biphenyls and toxaphene with air and water</span>, Environ. Sci. Technol., 21, 155–162, <a href="https://doi.org/10.1021/ES00156A005" >doi:10.1021/ES00156A005</a> (1987). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3566',
    'Murray and Riley (1969)',
    'Murray, C. N. &#x0026; Riley, J. P.: <span class="cmti-10">The solubility of</span> <span class="cmti-10">gases in distilled water and sea water — II. Oxygen</span>, Deep-Sea Res. Oceanogr. Abstr., 16, 311–320, <a href="https://doi.org/10.1016/0011-7471(69)90021-7" >doi:10.1016/0011-7471(69)90021-7</a> (1969). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3567',
    'Murray and Riley (1970)',
    'Murray, C. N. &#x0026; Riley, J. P.: <span class="cmti-10">The solubility of</span> <span class="cmti-10">gases in distilled water and sea water — III. Argon</span>, Deep-Sea Res. Oceanogr. Abstr., 17, 203–209, <a href="https://doi.org/10.1016/0011-7471(70)90100-2" >doi:10.1016/0011-7471(70)90100-2</a> (1970). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3568',
    'Murray and Riley (1971)',
    'Murray, C. N. &#x0026; Riley, J. P.: <span class="cmti-10">The solubility of</span> <span class="cmti-10">gases in distilled water and sea water — IV. Carbon dioxide</span>, Deep-Sea Res. Oceanogr. Abstr., 18, 533–541, <a href="https://doi.org/10.1016/0011-7471(71)90077-5" >doi:10.1016/0011-7471(71)90077-5</a> (1971). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3565',
    'Murray et&nbsp;al. (1969)',
    'Murray, C. N., Riley, J. P., &#x0026; Wilson, T. R. S.: <span class="cmti-10">The solubility of gases in distilled water and sea</span> <span class="cmti-10">water — I. Nitrogen</span>, Deep-Sea Res. Oceanogr. Abstr., 16, 297–310, <a href="https://doi.org/10.1016/0011-7471(69)90020-5" >doi:10.1016/0011-7471(69)90020-5</a> (1969). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2542',
    'Myrdal and Yalkowsky (1994)',
    'Myrdal, P. &#x0026; Yalkowsky, S. H.: <span class="cmti-10">A simple</span> <span class="cmti-10">scheme for calculating aqueous solubility, vapor pressure and Henry&#x2019;s law</span> <span class="cmti-10">constant: application to the chlorobenzenes</span>, SAR QSAR Environ. Res., 2, 17–28, <a href="https://doi.org/10.1080/10629369408028837" >doi:10.1080/10629369408028837</a> (1994). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3644',
    'Nahon et&nbsp;al. (2000)',
    'Nahon, D. F., Harrison, M., &#x0026; Roozen, J. P.: <span class="cmti-10">Modeling flavor release from aqueous sucrose</span> <span class="cmti-10">solutions, using mass transfer and partition coefficients</span>, J. Agric. Food Chem., 48, 1278–1284, <a href="https://doi.org/10.1021/JF990464K" >doi:10.1021/JF990464K</a> (2000). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2387',
    'Nelson and Hoff (1968)',
    'Nelson, P. E. &#x0026; Hoff, J. E.: <span class="cmti-10">Food volatiles: Gas chromatographic determination</span> <span class="cmti-10">of partition coefficients in water-lipid systems</span>, Int. J. Mass Spectrom., 228, 479–482, <a href="https://doi.org/10.1111/J.1365-2621.1968.TB03659.X" >doi:10.1111/J.1365-2621.1968.TB03659.X</a> (1968). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3584',
    'Nguyen (2013)',
    'Nguyen, T.: Amine Volatility in CO<sub><span class="cmr-7">2</span></sub> Capture, Ph.D. thesis, The University of Texas at Austin, USA, URL https://rochelle.che.utexas.edu/files/2015/02/Nguyen-2013-Amine-Volatility-in-CO2-Capture.pdf (2013). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '531',
    'Nicholson et&nbsp;al. (1984)',
    'Nicholson, B. C., Maguire, B. P., &#x0026; Bursill, D. B.: <span class="cmti-10">Henry&#x2019;s law constants for the</span> <span class="cmti-10">trihalomethanes: Effects of water composition and temperature</span>, Environ. Sci. Technol., 18, 518–521, <a href="https://doi.org/10.1021/ES00125A006" >doi:10.1021/ES00125A006</a> (1984). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '622',
    'Nielsen et&nbsp;al. (1994)',
    'Nielsen, F., Olsen, E., &#x0026; Fredenslund, A.: <span class="cmti-10">Henry&#x2019;s law constants and infinite dilution activity</span> <span class="cmti-10">coefficients for volatile organic compounds in water by a validated</span> <span class="cmti-10">batch air stripping method</span>, Environ. Sci. Technol., 28, 2133–2138, <a href="https://doi.org/10.1021/ES00061A022" >doi:10.1021/ES00061A022</a> (1994). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2487',
    'Niinemets and Reichstein (2002)',
    'Niinemets, U. &#x0026; Reichstein, M.: <span class="cmti-10">A model</span> <span class="cmti-10">analysis of the effects of nonspecific monoterpenoid storage in</span> <span class="cmti-10">leaf tissues on emission kinetics and composition in Mediterranean</span> <span class="cmti-10">sclerophyllous Quercus species</span>, Global Biogeochem. Cycles, 16, 1110, <a href="https://doi.org/10.1029/2002GB001927" >doi:10.1029/2002GB001927</a> (2002). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '984',
    'Nirmalakhandan et&nbsp;al. (1997)',
    'Nirmalakhandan, N., Brennan, R. A., &#x0026; Speece, R. E.: <span class="cmti-10">Predicting</span> <span class="cmti-10">Henry&#x2019;s law constant and the effect of temperature on Henry&#x2019;s law</span> <span class="cmti-10">constant</span>, Wat. Res., 31, 1471–1481, <a href="https://doi.org/10.1016/S0043-1354(96)00395-8" >doi:10.1016/S0043-1354(96)00395-8</a> (1997). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2482',
    'Nirmalakhandan and Speece (1988)',
    'Nirmalakhandan, N. N. &#x0026; Speece, R. E.: <span class="cmti-10">QSAR model for predicting Henry&#x2019;s constant</span>, Environ. Sci. Technol., 22, 1349–1357, <a href="https://doi.org/10.1021/ES00176A016" >doi:10.1021/ES00176A016</a> (1988). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3532',
    'Nozière and Riemer (2003)',
    'Nozière, B. &#x0026; Riemer, D. D.: <span class="cmti-10">The chemical processing of gas-phase</span> <span class="cmti-10">carbonyl compounds by sulfuric acid aerosols: 2,4-pentanedione</span>, Atmos. Environ., 37, 841–851, <a href="https://doi.org/10.1016/S1352-2310(02)00934-2" >doi:10.1016/S1352-2310(02)00934-2</a> (2003). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3705',
    'Nunn (1958)',
    'Nunn, J. F.: <span class="cmti-10">Respiratory measurements in the presence of</span> <span class="cmti-10">nitrous oxide: storage of gas samples and chemical methods of analysis</span>, Br. J. Anaesth., 30, 254–263, <a href="https://doi.org/10.1093/BJA/30.6.254" >doi:10.1093/BJA/30.6.254</a> (1958). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3732',
    'Odabasi and Adali (2016)',
    'Odabasi, M. &#x0026; Adali, M.: <span class="cmti-10">Determination of</span> <span class="cmti-10">temperature dependent Henry&#x2019;s law constants of polychlorinated</span> <span class="cmti-10">naphthalenes: Application to air-sea exchange in Izmir Bay, Turkey</span>, Atmos. Environ., 147, 200–208, <a href="https://doi.org/10.1016/J.ATMOSENV.2016.10.009" >doi:10.1016/J.ATMOSENV.2016.10.009</a> (2016). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2819',
    'Odabasi et&nbsp;al. (2006)',
    'Odabasi, M., Cetin, B., &#x0026; Sofuoglu, A.: <span class="cmti-10">Henry&#x2019;s law constant, octanol-air partition coefficient</span> <span class="cmti-10">and supercooled liquid vapor pressure of carbazole as a function of</span> <span class="cmti-10">temperature: Application to gas/particle partitioning in the atmosphere</span>, Chemosphere, 62, 1087–1096, <a href="https://doi.org/10.1016/J.CHEMOSPHERE.2005.05.035" >doi:10.1016/J.CHEMOSPHERE.2005.05.035</a> (2006). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3526',
    'O&#x2019;Farrell and Waghorne (2010)',
    'O&#x2019;Farrell, C. E. &#x0026; Waghorne, W. E.: <span class="cmti-10">Henry&#x2019;s law constants of organic compounds in water and </span><span class="cmmi-10">n</span><span class="cmti-10">-octane at T</span> <span class="cmti-10">= 293.2K</span>, J. Chem. Eng. Data, 55, 1655–1658, <a href="https://doi.org/10.1021/JE900711H" >doi:10.1021/JE900711H</a> (2010). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1139',
    'Oliver (1985)',
    'Oliver, B. G.: <span class="cmti-10">Desorption of chlorinated hydrocarbons from</span> <span class="cmti-10">spiked and anthropogenically contaminated sediments</span>, Chemosphere, 14, 1087–1106, <a href="https://doi.org/10.1016/0045-6535(85)90029-3" >doi:10.1016/0045-6535(85)90029-3</a> (1985). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3246',
    'Olsen et&nbsp;al. (2016)',
    'Olsen, R., Kvamme, B., &#x0026; Kuznetsova, T.: <span class="cmti-10">Free energy of solvation and Henry&#x2019;s law solubility</span> <span class="cmti-10">constants for mono-, di- and tri-ethylene glycol in water and methane</span>, Fluid Phase Equilib., 418, 152–159, <a href="https://doi.org/10.1016/J.FLUID.2015.10.019" >doi:10.1016/J.FLUID.2015.10.019</a> (2016). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1110',
    'Olson (1998)',
    'Olson, J. D.: <span class="cmti-10">The</span> <span class="cmti-10">vapor pressure of pure and aqueous glutaraldehyde</span>, Fluid Phase Equilib., 150–151, 713–720, <a href="https://doi.org/10.1016/S0378-3812(98)00351-3" >doi:10.1016/S0378-3812(98)00351-3</a> (1998). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3303',
    'Ömür-Özbek and Dietrich (2005)',
    'Ömür-Özbek, P. &#x0026; Dietrich, A. M.: <span class="cmti-10">Determination of temperature-dependent Henry&#x2019;s law constants</span> <span class="cmti-10">of odorous contaminants and their application to human perception</span>, Environ. Sci. Technol., 39, 3957–3963, <a href="https://doi.org/10.1021/ES0480264" >doi:10.1021/ES0480264</a> (2005). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3305',
    'Ondo and Dohnal (2007)',
    'Ondo, D. &#x0026; Dohnal, V.: <span class="cmti-10">Temperature dependence</span> <span class="cmti-10">of limiting activity coefficients and Henry&#x2019;s law constants of cyclic</span> <span class="cmti-10">and open-chain ethers in water</span>, Fluid Phase Equilib., 262, 121–136, <a href="https://doi.org/10.1016/J.FLUID.2007.08.013" >doi:10.1016/J.FLUID.2007.08.013</a> (2007). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3564',
    'Ooki and Yokouchi (2011)',
    'Ooki, A. &#x0026; Yokouchi, Y.: <span class="cmti-10">Determination of</span> <span class="cmti-10">Henry&#x2019;s law constant of halocarbons in seawater and analysis of</span> <span class="cmti-10">sea-to-air flux of iodoethane (</span>C<sub><span class="cmr-7">2</span></sub>H<sub><span class="cmr-7">5</span></sub>I<span class="cmti-10">) in the Indian and Southern</span> <span class="cmti-10">Oceans based on partial pressure measurements</span>, Geochem. J., 45, e1–e7, <a href="https://doi.org/10.2343/GEOCHEMJ.1.0122" >doi:10.2343/GEOCHEMJ.1.0122</a> (2011). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3121',
    'Opresko et&nbsp;al. (1998)',
    'Opresko, D. M., Young, R. A., Faust, R. A., Talmage, S. S., Watson, A. P., Ross, R. H., Davidson, K. A., &#x0026; King, J.: <span class="cmti-10">Chemical warfare</span> <span class="cmti-10">agents: estimating oral reference doses</span>, Rev. Environ. Contam. Toxicol., 156, 1–183, <a href="https://doi.org/10.1007/978-1-4612-1722-0_1" >doi:10.1007/978-1-4612-1722-0_1</a> (1998). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3702',
    'Orcutt and Seevers (1937a)',
    'Orcutt, F. S. &#x0026; Seevers, M. H.: <span class="cmti-10">A method for</span> <span class="cmti-10">determining the solubility of gases in pure liquids or solutions by the</span> <span class="cmti-10">Van Slyke-Neill manometric apparatus</span>, J. Biol. Chem., 117, 501–507, <a href="https://doi.org/10.1016/S0021-9258(18)74550-X" >doi:10.1016/S0021-9258(18)74550-X</a> (1937a). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    'orcutt37',
    'Orcutt and Seevers (1937b)',
    'Orcutt, F. S. &#x0026; Seevers, M. H.: <span class="cmti-10">The solubility</span> <span class="cmti-10">coefficients of cyclopropane for water, oils and human blood</span>, J. Pharmacol. Exp. Ther., 59, 206–210 (1937b). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3770',
    'Ordóñez et&nbsp;al. (2012)',
    'Ordóñez, C., Lamarque, J.-F., Tilmes, S., Kinnison, D. E., Atlas, E. L., Blake, D. R., Sousa Santos, G., Brasseur, G., &#x0026; Saiz-Lopez, A.: <span class="cmti-10">Bromine</span> <span class="cmti-10">and iodine chemistry in a global chemistry-climate model: description</span> <span class="cmti-10">and evaluation of very short-lived oceanic sources</span>, Atmos. Chem. Phys., 12, 1423–1447, <a href="https://doi.org/10.5194/ACP-12-1423-2012" >doi:10.5194/ACP-12-1423-2012</a> (2012). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '516',
    'O&#x2019;Sullivan et&nbsp;al. (1996)',
    'O&#x2019;Sullivan, D. W., Lee, M., Noone, B. C., &#x0026; Heikes, B. G.: <span class="cmti-10">Henry&#x2019;s</span> <span class="cmti-10">law constant determinations for hydrogen peroxide, methyl hydroperoxide,</span> <span class="cmti-10">hydroxymethyl hydroperoxide, ethyl hydroperoxide, and peroxyacetic acid</span>, J. Phys. Chem., 100, 3241–3247, <a href="https://doi.org/10.1021/JP951168N" >doi:10.1021/JP951168N</a> (1996). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2836',
    'Otto et&nbsp;al. (1997)',
    'Otto, S., Riello, L., Düring, R.-A., Hummel, H. E., &#x0026; Zanin, G.: <span class="cmti-10">Herbicide dissipation</span> <span class="cmti-10">and dynamics modelling in three different tillage systems</span>, Chemosphere, 34, 163–178, <a href="https://doi.org/10.1016/S0045-6535(96)00356-6" >doi:10.1016/S0045-6535(96)00356-6</a> (1997). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3809',
    'Ourisson and Kastner (1939)',
    'Ourisson, J. &#x0026; Kastner, M.: <span class="cmti-10">Determination des</span> <span class="cmti-10">tensions de vapeurs des solutions d&#x2019;acide hypochloreux </span><span class="cmti-10">à 10</span><span class="cmsy-7">∘</span><span class="cmti-10"> et 20</span><span class="cmsy-7">∘</span><span class="cmti-10"> C</span>, Bull. Soc. Chim. Memoirs, 6, 1307–1311 (1939). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3626',
    'Owens et&nbsp;al. (1986)',
    'Owens, J. W., Wasik, S. P., &#x0026; DeVoe, H.: <span class="cmti-10">Aqueous</span> <span class="cmti-10">solubilities and enthalpies of solution of </span><span class="cmmi-10">n</span><span class="cmti-10">-alkylbenzenes</span>, J. Chem. Eng. Data, 31, 47–51, <a href="https://doi.org/10.1021/JE00043A016" >doi:10.1021/JE00043A016</a> (1986). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2563',
    'Paasivirta and Sinkkonen (2009)',
    'Paasivirta, J. &#x0026; Sinkkonen, S. I.: <span class="cmti-10">Environmentally relevant properties of all 209</span> <span class="cmti-10">polychlorinated biphenyl congeners for modeling their fate in different</span> <span class="cmti-10">natural and climatic conditions</span>, J. Chem. Eng. Data, 54, 1189–1213, <a href="https://doi.org/10.1021/JE800501H" >doi:10.1021/JE800501H</a> (2009). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1143',
    'Paasivirta et&nbsp;al. (1999)',
    'Paasivirta, J., Sinkkonen, S., Mikkelson, P., Rantio, T., &#x0026; Wania, F.: <span class="cmti-10">Estimation of vapor pressures, solubilities and Henry&#x2019;s law constants</span> <span class="cmti-10">of selected persistent organic pollutants as functions of temperature</span>, Chemosphere, 39, 811–832, <a href="https://doi.org/10.1016/S0045-6535(99)00016-8" >doi:10.1016/S0045-6535(99)00016-8</a> (1999). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '582',
    'Palmer et&nbsp;al. (1985)',
    'Palmer, D. A., Ramette, R. W., &#x0026; Mesmer, R. E.: <span class="cmti-10">The hydrolysis of</span> <span class="cmti-10">iodine: Equilibria at high temperatures</span>, J. Nucl. Mater., 130, 280–286, <a href="https://doi.org/10.1016/0022-3115(85)90317-4" >doi:10.1016/0022-3115(85)90317-4</a> (1985). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '34',
    'Pandis and Seinfeld (1989)',
    'Pandis, S. N. &#x0026; Seinfeld, J. H.: <span class="cmti-10">Sensitivity analysis of a chemical mechanism for</span> <span class="cmti-10">aqueous-phase atmospheric chemistry</span>, J. Geophys. Res., 94, 1105–1126, <a href="https://doi.org/10.1029/JD094ID01P01105" >doi:10.1029/JD094ID01P01105</a> (1989). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2431',
    'Pankow et&nbsp;al. (1996)',
    'Pankow, J. F., Rathbun, R. E., &#x0026; Zogorski, J. S.: <span class="cmti-10">Calculated volatilization rates</span> <span class="cmti-10">of fuel oxygenate compounds and other gasoline-related compounds from</span> <span class="cmti-10">rivers and streams</span>, Chemosphere, 33, 921–937, <a href="https://doi.org/10.1016/0045-6535(96)00227-5" >doi:10.1016/0045-6535(96)00227-5</a> (1996). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2449',
    'Park et&nbsp;al. (1987)',
    'Park, J. H., Hussam, A., Couasnon, P., Fritz, D., &#x0026; Carr, P. W.: <span class="cmti-10">Experimental</span> <span class="cmti-10">reexamination of selected partition coefficients from Rohrschneider&#x2019;s data</span> <span class="cmti-10">set</span>, Anal. Chem., 59, 1970–1976, <a href="https://doi.org/10.1021/AC00142A016" >doi:10.1021/AC00142A016</a> (1987). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '592',
    'Park and Lee (1988)',
    'Park, J.-Y. &#x0026; Lee, Y.-N.: <span class="cmti-10">Solubility and decomposition</span> <span class="cmti-10">kinetics of nitrous acid in aqueous solution</span>, J. Phys. Chem., 92, 6294–6302, <a href="https://doi.org/10.1021/J100333A025" >doi:10.1021/J100333A025</a> (1988). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2905',
    'Park et&nbsp;al. (1997)',
    'Park, S.-J., Han, S.-D., &#x0026; Ryu, S.-A.: <span class="cmti-10">Measurement of air/water partition coefficient (Henry&#x2019;s law constant)</span> <span class="cmti-10">by using EPICS method and their relationship with vapor pressure and</span> <span class="cmti-10">water solubility</span>, J. Korean Inst. Chem. Eng., 35, 915–920 (1997). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2486',
    'Park et&nbsp;al. (1982)',
    'Park, T., Rettich, T. R., Battino, R., Peterson, D., &#x0026; Wilhelm, E.: <span class="cmti-10">Solubility of</span> <span class="cmti-10">gases in liquids. 14. Bunsen coefficients for several fluorine-containing</span> <span class="cmti-10">gases (Freons) dissolved in water at 298.15K</span>, J. Chem. Eng. Data, 27, 324–326, <a href="https://doi.org/10.1021/JE00029A027" >doi:10.1021/JE00029A027</a> (1982). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3544',
    'Parker (1992)',
    'Parker, V. D.: <span class="cmti-10">The reversible reduction potential of the</span> <span class="cmti-10">proton in water and in non-aqueous solvents</span>, Acta Chem. Scand., 46, 692–694, <a href="https://doi.org/10.3891/ACTA.CHEM.SCAND.46-0692" >doi:10.3891/ACTA.CHEM.SCAND.46-0692</a> (1992). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3400',
    'Parnis et&nbsp;al. (2015)',
    'Parnis, J. M., Mackay, D., &#x0026; Harner, T.: <span class="cmti-10">Temperature dependence of Henry&#x2019;s law constants and</span> <span class="cmmi-10">K</span><sub><span class="cmr-7">OA</span></sub> <span class="cmti-10">for simple and heteroatom-substituted PAHs by COSMO-RS</span>, Atmos. Environ., 110, 27–35, <a href="https://doi.org/10.1016/J.ATMOSENV.2015.03.032" >doi:10.1016/J.ATMOSENV.2015.03.032</a> (2015). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '724',
    'Parsons et&nbsp;al. (1971)',
    'Parsons, G. H., Rochester, C. H., &#x0026; Wood, C. E. C.: <span class="cmti-10">Effect of 4-substitution on</span> <span class="cmti-10">the thermodynamics of hydration of phenol and the phenoxide anion</span>, J. Chem. Soc. B, pp. 533–536, <a href="https://doi.org/10.1039/J29710000533" >doi:10.1039/J29710000533</a> (1971). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '725',
    'Parsons et&nbsp;al. (1972)',
    'Parsons, G. H., Rochester, C. H., Rostron, A., &#x0026; Sykes, P. C.: <span class="cmti-10">The</span> <span class="cmti-10">thermodynamics of hydration of phenols</span>, J. Chem. Soc. Perkin Trans. 2, pp. 136–138, <a href="https://doi.org/10.1039/P29720000136" >doi:10.1039/P29720000136</a> (1972). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '544',
    'Pearson and McConnell (1975)',
    'Pearson, C. R. &#x0026; McConnell, G.: <span class="cmti-10">Chlorinated</span> C<sub><span class="cmr-7">1</span></sub> <span class="cmti-10">and</span> C<sub><span class="cmr-7">2</span></sub> <span class="cmti-10">hydrocarbons in the marine environment</span>, Proc. R. Soc. Lond. B, 189, 305–332, <a href="https://doi.org/10.1098/RSPB.1975.0059" >doi:10.1098/RSPB.1975.0059</a> (1975). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '720',
    'Pecsar and Martin (1966)',
    'Pecsar, R. E. &#x0026; Martin, J. J.: <span class="cmti-10">Solution thermodynamics from gas-liquid chromatography</span>, Anal. Chem., 38, 1661–1669, <a href="https://doi.org/10.1021/AC60244A009" >doi:10.1021/AC60244A009</a> (1966). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '837',
    'Peng and Wan (1997)',
    'Peng, J. &#x0026; Wan, A.: <span class="cmti-10">Measurement of Henry&#x2019;s constants</span> <span class="cmti-10">of high-volatility organic compounds using a headspace autosampler</span>, Environ. Sci. Technol., 31, 2998–3003, <a href="https://doi.org/10.1021/ES970240N" >doi:10.1021/ES970240N</a> (1997). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1114',
    'Peng and Wan (1998)',
    'Peng, J. &#x0026; Wan, A.: <span class="cmti-10">Effect of ionic strength on Henry&#x2019;s</span> <span class="cmti-10">constants of volatile organic compounds</span>, Chemosphere, 36, 2731–2740, <a href="https://doi.org/10.1016/S0045-6535(97)10232-6" >doi:10.1016/S0045-6535(97)10232-6</a> (1998). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1229',
    'Perlinger et&nbsp;al. (1993)',
    'Perlinger, J. A., Eisenreich, S. J., &#x0026; Capel, P. D.: <span class="cmti-10">Application of headspace analysis to the</span> <span class="cmti-10">study of sorption of hydrophobic organic chemicals to</span> <span class="cmmi-10">α</span><span class="cmsy-10">−</span>Al<sub><span class="cmr-7">2</span></sub>O<sub><span class="cmr-7">3</span></sub>, Environ. Sci. Technol., 27, 928–937, <a href="https://doi.org/10.1021/ES00042A016" >doi:10.1021/ES00042A016</a> (1993). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    'perry73',
    'Perry and Chilton (1973)',
    'Perry, R. H. &#x0026; Chilton, C. H.: Chemical Engineers&#x2019; Handbook, 5th edition, McGraw-Hill, Inc., ISBN 0070855471 (1973). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2286',
    'Petersen et&nbsp;al. (1998)',
    'Petersen, G., Pleijel, J. M. K., Bloxam, R., &#x0026; Vinod Kumar, A.: <span class="cmti-10">A comprehensive Eulerian modeling</span> <span class="cmti-10">framework for airborne mercury species: Development and testing of the</span> <span class="cmti-10">tropospheric chemistry module (TCM)</span>, Atmos. Environ., 32, 829–843, <a href="https://doi.org/10.1016/S1352-2310(97)00049-6" >doi:10.1016/S1352-2310(97)00049-6</a> (1998). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2556',
    'Petrasek et&nbsp;al. (1983)',
    'Petrasek, A. C., Kugelman, I. J., Austern, B. M., Pressley, T. A., Winslow, L. A., &#x0026; Wise, R. H.: <span class="cmti-10">Fate of toxic organic compounds</span> <span class="cmti-10">in wastewater treatment plants</span>, J. Water Pollut. Control Fed., 55, 1286–1296 (1983). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1524',
    'Pfeifer et&nbsp;al. (2001)',
    'Pfeifer, O., Lohmann, U., &#x0026; Ballschmiter, K.: <span class="cmti-10">Halogenated methyl-phenyl</span> <span class="cmti-10">ethers (anisoles) in the environment: Determination of vapor pressures,</span> <span class="cmti-10">aqueous solubilities, Henry&#x2019;s law constants, and gas/water- (</span><span class="cmmi-10">K</span><sub><span class="cmr-7">gw</span></sub><span class="cmti-10">),</span> <span class="cmmi-10">n</span><span class="cmti-10">-octanol/water- (</span><span class="cmmi-10">K</span><sub><span class="cmr-7">ow</span></sub><span class="cmti-10">) and gas/n-octanol (</span><span class="cmmi-10">K</span><sub><span class="cmr-7">go</span></sub><span class="cmti-10">) partition coefficients</span>, Fresenius J. Anal. Chem., 371, 598–606, <a href="https://doi.org/10.1007/S002160101077" >doi:10.1007/S002160101077</a> (2001). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3642',
    'Philippe et&nbsp;al. (2003)',
    'Philippe, E., Seuvre, A.-M., Colas, B., Langendorff, V., Schippa, C., &#x0026; Voilley, A.: <span class="cmti-10">Behavior of flavor compounds in model food systems:</span> <span class="cmti-10">a thermodynamic study</span>, J. Agric. Food Chem., 51, 1393–1398, <a href="https://doi.org/10.1021/JF020862E" >doi:10.1021/JF020862E</a> (2003). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2223',
    'Pierotti et&nbsp;al. (1959)',
    'Pierotti, G. J., Deal, C. H., &#x0026; Derr, E. L.: <span class="cmti-10">Activity coefficients and molecular structure</span>, Ind. Eng. Chem., 51, 95–102, <a href="https://doi.org/10.1021/IE50589A048" >doi:10.1021/IE50589A048</a>, (data available in supplement, document no. 5782, American Documentation Institute, Library of Congress, Washington, D.C.) (1959). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '766',
    'Pierotti (1965)',
    'Pierotti, R. A.: <span class="cmti-10">Aqueous solutions of nonpolar gases</span>, J. Phys. Chem., 69, 281–288, <a href="https://doi.org/10.1021/J100885A043" >doi:10.1021/J100885A043</a> (1965). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3648',
    'Pividal et&nbsp;al. (1992)',
    'Pividal, K. A., Birtigh, A., &#x0026; Sandler, S. I.: <span class="cmti-10">Infinite dilution activity coefficients for oxygenate</span> <span class="cmti-10">systems determined using a differential static cell</span>, J. Chem. Eng. Data, 37, 484–487, <a href="https://doi.org/10.1021/JE00008A025" >doi:10.1021/JE00008A025</a> (1992). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2994',
    'Plassmann et&nbsp;al. (2010)',
    'Plassmann, M. M., Meyer, T., Lei, Y. D., Wania, F., McLachlan, M. S., &#x0026; Berger, U.: <span class="cmti-10">Theoretical and experimental simulation of the fate</span> <span class="cmti-10">of semifluorinated </span><span class="cmmi-10">n</span><span class="cmti-10">-alkanes during snowmelt</span>, Environ. Sci. Technol., 44, 6692–6697, <a href="https://doi.org/10.1021/ES101562W" >doi:10.1021/ES101562W</a> (2010). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2991',
    'Plassmann et&nbsp;al. (2011)',
    'Plassmann, M. M., Meyer, T., Lei, Y. D., Wania, F., McLachlan, M. S., &#x0026; Berger, U.: <span class="cmti-10">Laboratory studies on the fate of perfluoroalkyl</span> <span class="cmti-10">carboxylates and sulfonates during snowmelt</span>, Environ. Sci. Technol., 45, 6872–6878, <a href="https://doi.org/10.1021/ES201249D" >doi:10.1021/ES201249D</a> (2011). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3015',
    'Plyasunov (2012)',
    'Plyasunov, A. V.: <span class="cmti-10">Thermodynamics of</span> Si(OH)<sub><span class="cmr-7">4</span></sub> <span class="cmti-10">in the</span> <span class="cmti-10">vapor phase of water: Henry&#x2019;s and vapor-liquid distribution constants,</span> <span class="cmti-10">fugacity and cross virial coefficients</span>, Geochim. Cosmochim. Acta, 77, 215–231, <a href="https://doi.org/10.1016/J.GCA.2011.11.019" >doi:10.1016/J.GCA.2011.11.019</a> (2012). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3673',
    'Plyasunov and Shock (2000)',
    'Plyasunov, A. V. &#x0026; Shock, E. L.: <span class="cmti-10">Thermodynamic functions of hydration of hydrocarbons</span> <span class="cmti-10">at 298.15K and 0.1MPa</span>, Geochim. Cosmochim. Acta, 64, 439–468, <a href="https://doi.org/10.1016/S0016-7037(99)00330-0" >doi:10.1016/S0016-7037(99)00330-0</a> (2000). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3617',
    'Plyasunov and Shock (2001)',
    'Plyasunov, A. V. &#x0026; Shock, E. L.: <span class="cmti-10">Group</span> <span class="cmti-10">contribution values of the infinite dilution thermodynamic functions of</span> <span class="cmti-10">hydration for aliphatic noncyclic hydrocarbons, alcohols, and ketones</span> <span class="cmti-10">at 298.15 </span>K <span class="cmti-10">and 0.1</span> MPa, J. Chem. Eng. Data, 46, 1016–1019, <a href="https://doi.org/10.1021/JE0002282" >doi:10.1021/JE0002282</a> (2001). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3674',
    'Plyasunov et&nbsp;al. (2001)',
    'Plyasunov, A. V., O&#x2019;Connell, J. P., Wood, R. H., &#x0026; Shock, E. L.: <span class="cmti-10">Semiempirical equation of state for the infinite dilution thermodynamic</span> <span class="cmti-10">functions of hydration of nonelectrolytes over wide ranges of</span> <span class="cmti-10">temperature and pressure</span>, Fluid Phase Equilib., 183–184, 133–142, <a href="https://doi.org/10.1016/S0378-3812(01)00427-7" >doi:10.1016/S0378-3812(01)00427-7</a> (2001). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3616',
    'Plyasunov et&nbsp;al. (2004)',
    'Plyasunov, A. V., Plyasunova, N. V., &#x0026; Shock, E. L.: <span class="cmti-10">Group contribution values for</span> <span class="cmti-10">the thermodynamic functions of hydration of aliphatic esters at 298.15 </span>K<span class="cmti-10">,</span> <span class="cmti-10">0.1</span> MPa, J. Chem. Eng. Data, 49, 1152–1167, <a href="https://doi.org/10.1021/JE049850A" >doi:10.1021/JE049850A</a> (2004). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3621',
    'Plyasunov et&nbsp;al. (2006)',
    'Plyasunov, A. V., Plyasunova, N. V., &#x0026; Shock, E. L.: <span class="cmti-10">Group contribution values</span> <span class="cmti-10">for the thermodynamic functions of hydration at 298.15 </span>K<span class="cmti-10">, 0.1</span> MPa<span class="cmti-10">. 4.</span> <span class="cmti-10">aliphatic nitriles and dinitriles</span>, J. Chem. Eng. Data, 51, 1481–1490, <a href="https://doi.org/10.1021/JE060129+" >doi:10.1021/JE060129+</a> (2006). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3618',
    'Plyasunova et&nbsp;al. (2004)',
    'Plyasunova, N. V., Plyasunov, A. V., &#x0026; Shock, E. L.: <span class="cmti-10">Group contribution values</span> <span class="cmti-10">for the thermodynamic functions of hydration at 298.15 </span>K<span class="cmti-10">, 0.1</span> MPa<span class="cmti-10">. 2.</span> <span class="cmti-10">aliphatic thiols, alkyl sulfides, and polysulfides</span>, J. Chem. Eng. Data, 50, 246–253, <a href="https://doi.org/10.1021/JE0497045" >doi:10.1021/JE0497045</a> (2004). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2946',
    'Podoll et&nbsp;al. (1986)',
    'Podoll, R. T., Jaber, H. M., &#x0026; Mill, T.: <span class="cmti-10">Tetrachlorodibenzodioxin: rates of volatilization and</span> <span class="cmti-10">photolysis in the environment</span>, Environ. Sci. Technol., 20, 490–492, <a href="https://doi.org/10.1021/ES00147A008" >doi:10.1021/ES00147A008</a> (1986). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1923',
    'Pollien et&nbsp;al. (2003)',
    'Pollien, P., Jordan, A., Lindinger, W., &#x0026; Yeretzian, C.: <span class="cmti-10">Liquid-air</span> <span class="cmti-10">partitioning of volatile compounds in coffee: dynamic measurements using</span> <span class="cmti-10">proton-transfer-reaction mass spectrometry</span>, Int. J. Mass Spectrom., 228, 69–80, <a href="https://doi.org/10.1016/S1387-3806(03)00197-0" >doi:10.1016/S1387-3806(03)00197-0</a> (2003). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3547',
    'Potter II and Clynne (1978)',
    'Potter II, R. W. &#x0026; Clynne, M. A.: <span class="cmti-10">The</span> <span class="cmti-10">solubility of the noble gases He, Ne, Ar, Kr, and Xe in water up to the</span> <span class="cmti-10">critical point</span>, J. Solution Chem., 7, 837–844, <a href="https://doi.org/10.1007/BF00650811" >doi:10.1007/BF00650811</a> (1978). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2822',
    'Poulain et&nbsp;al. (2010)',
    'Poulain, L., Katrib, Y., Isikli, E., Liu, Y., Wortham, H., Mirabel, P., Le Calvé, S., &#x0026; Monod, A.: <span class="cmti-10">In-cloud multiphase behaviour of</span> <span class="cmti-10">acetone in the troposphere: Gas uptake, Henry&#x2019;s law equilibrium</span> <span class="cmti-10">and aqueous phase photooxidation</span>, Chemosphere, 81, 312–320, <a href="https://doi.org/10.1016/J.CHEMOSPHERE.2010.07.032" >doi:10.1016/J.CHEMOSPHERE.2010.07.032</a> (2010). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3787',
    'Power and Stegall (1970)',
    'Power, G. G. &#x0026; Stegall, H.: <span class="cmti-10">Solubility of gases</span> <span class="cmti-10">in human red blood cell ghosts</span>, J. Appl. Physiol., 29, 145–149, <a href="https://doi.org/10.1152/JAPPL.1970.29.2.145" >doi:10.1152/JAPPL.1970.29.2.145</a> (1970). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '522',
    'Przyjazny et&nbsp;al. (1983)',
    'Przyjazny, A., Janicki, W., Chrzanowski, W., &#x0026; Staszewski, R.: <span class="cmti-10">Headspace gas</span> <span class="cmti-10">chromatographic determination of distribution coefficients of selected</span> <span class="cmti-10">organosulphur compounds and their dependence on some parameters</span>, J. Chromatogr., 280, 249–260, <a href="https://doi.org/10.1016/S0021-9673(00)91567-X" >doi:10.1016/S0021-9673(00)91567-X</a> (1983). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3583',
    'Pye et&nbsp;al. (2013)',
    'Pye, H. O. T., Pinder, R. W., Piletic, I. R., Xie, Y., Capps, S. L., Lin, Y.-H., Surratt, J. D., Zhang, Z., Gold, A., Luecken, D. J., Hutzell, W. T., Jaoui, M., Offenberg, J. H., Kleindienst, T. E., Lewandowski, M., &#x0026; Edney, E. O.: <span class="cmti-10">Epoxide pathways improve model predictions of</span> <span class="cmti-10">isoprene markers and reveal key role of acidity in aerosol formation</span>, Environ. Sci. Technol., 47, 11 056–11 064, <a href="https://doi.org/10.1021/ES402106H" >doi:10.1021/ES402106H</a> (2013). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3575',
    'Qin et&nbsp;al. (2021)',
    'Qin, C., Gou, Y., Wang, Y., Mao, Y., Liao, H., Wang, Q., &#x0026; Xie, M.: <span class="cmti-10">Gas–particle</span> <span class="cmti-10">partitioning of polyol tracers at a suburban site in Nanjing, east China:</span> <span class="cmti-10">increased partitioning to the particle phase</span>, Atmos. Chem. Phys., 21, 12 141–12 153, <a href="https://doi.org/10.5194/ACP-21-12141-2021" >doi:10.5194/ACP-21-12141-2021</a> (2021). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2930',
    'Ramachandran et&nbsp;al. (1996)',
    'Ramachandran, B. R., Allen, J. M., &#x0026; Halpern, A. M.: <span class="cmti-10">Air–water</span> <span class="cmti-10">partitioning of environmentally important organic compounds</span>, J. Chem. Educ., 73, 1058–1061, <a href="https://doi.org/10.1021/ED073P1058" >doi:10.1021/ED073P1058</a> (1996). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3546',
    'Ramstedt (1911)',
    'Ramstedt, E.: <span class="cmti-10">Sur la solubilit</span><span class="cmti-10">é de l&#x2019;</span><span class="cmti-10">émanation du</span> <span class="cmti-10">radium dans les liquides organiques</span>, Radium (Paris), 8, 253–256, <a href="https://doi.org/10.1051/RADIUM:0191100807025301" >doi:10.1051/RADIUM:0191100807025301</a> (1911). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2234',
    'Rathbun and Tai (1982)',
    'Rathbun, R. E. &#x0026; Tai, D. Y.: <span class="cmti-10">Volatilization</span> <span class="cmti-10">of ketones from water</span>, Water Air Soil Pollut., 17, 281–293, <a href="https://doi.org/10.1007/BF00283158" >doi:10.1007/BF00283158</a> (1982). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2546',
    'Raventos-Duran et&nbsp;al. (2010)',
    'Raventos-Duran, T., Camredon, M., Valorso, R., Mouchel-Vallon, C., &#x0026; Aumont, B.: <span class="cmti-10">Structure-activity relationships to estimate the effective</span> <span class="cmti-10">Henry&#x2019;s law constants of organics of atmospheric interest</span>, Atmos. Chem. Phys., 10, 7643–7654, <a href="https://doi.org/10.5194/ACP-10-7643-2010" >doi:10.5194/ACP-10-7643-2010</a> (2010). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3608',
    'Razumovskii and Zaikov (1971)',
    'Razumovskii, S. D. &#x0026; Zaikov, G. E.: <span class="cmti-10">The</span> <span class="cmti-10">solubility of ozone in various solvents</span>, Russ. Chem. Bull., 20, 616–620, <a href="https://doi.org/10.1007/BF00853885" >doi:10.1007/BF00853885</a> (1971). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '797',
    'Régimbal and Mozurkewich (1997)',
    'Régimbal, J.-M. &#x0026; Mozurkewich, M.: <span class="cmti-10">Peroxynitric acid decay mechanisms and kinetics at low pH</span>, J. Phys. Chem. A, 101, 8822–8829, <a href="https://doi.org/10.1021/JP971908N" >doi:10.1021/JP971908N</a> (1997). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2013',
    'Reichl (1995)',
    'Reichl, A.: Messung und Korrelierung von Gaslöslichkeiten halogenierter Kohlenwasserstoffe, Ph.D. thesis, Technische Universität Berlin, Germany (1995). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '491',
    'Rettich et&nbsp;al. (1981)',
    'Rettich, T. R., Handa, Y. P., Battino, R., &#x0026; Wilhelm, E.: <span class="cmti-10">Solubility of gases in liquids.</span> <span class="cmti-10">13.</span><span class="cmti-10"> High-precision determination of Henry&#x2019;s constants for methane and</span> <span class="cmti-10">ethane in liquid water at 275 to 328 </span>K, J. Phys. Chem., 85, 3230–3237, <a href="https://doi.org/10.1021/J150622A006" >doi:10.1021/J150622A006</a> (1981). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3529',
    'Rettich et&nbsp;al. (1982)',
    'Rettich, T. R., Battino, R., &#x0026; Wilhelm, E.: <span class="cmti-10">Solubility of gases in liquids. 15. High-precision</span> <span class="cmti-10">determination of Henry coefficients for carbon monoxide in liquid</span> <span class="cmti-10">water at 278 to 323K</span>, Ber. Bunsenges. Phys. Chem., 86, 1128–1132, <a href="https://doi.org/10.1002/BBPC.198200051" >doi:10.1002/BBPC.198200051</a> (1982). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2434',
    'Rettich et&nbsp;al. (1984)',
    'Rettich, T. R., Battino, R., &#x0026; Wilhelm, E.: <span class="cmti-10">Solubility of gases in liquids. XVI. Henry&#x2019;s law</span> <span class="cmti-10">coefficients for nitrogen in water at 5 to 50</span><span class="cmsy-7">∘</span>C, J. Solution Chem., 13, 335–348, <a href="https://doi.org/10.1007/BF00645706" >doi:10.1007/BF00645706</a> (1984). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2435',
    'Rettich et&nbsp;al. (1992)',
    'Rettich, T. R., Battino, R., &#x0026; Wilhelm, E.: <span class="cmti-10">Solubility of gases in liquids. 18. High-precision</span> <span class="cmti-10">determination of Henry fugacities for argon in liquid water at 2 to 40</span><span class="cmsy-7">∘</span>C, J. Solution Chem., 21, 987–1004, <a href="https://doi.org/10.1007/BF00650874" >doi:10.1007/BF00650874</a> (1992). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3412',
    'Rettich et&nbsp;al. (2000)',
    'Rettich, T. R., Battino, R., &#x0026; Wilhelm, E.: <span class="cmti-10">Solubility of gases in liquids. 22. High-precision</span> <span class="cmti-10">determination of Henry&#x2019;s law constants of oxygen in liquid water from</span> <span class="cmti-10">T = 274K to T = 328K</span>, J. Chem. Thermodyn., 32, 1145–1156, <a href="https://doi.org/10.1006/JCHT.1999.0581" >doi:10.1006/JCHT.1999.0581</a> (2000). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '863',
    'Rex (1906)',
    'Rex, A.: <span class="cmti-10">Über die L</span><span class="cmti-10">öslichkeit der Halogenderivate der</span> <span class="cmti-10">Kohlenwasserstoffe in Wasser</span>, Z. Phys. Chem., 55, 355–370, <a href="https://doi.org/10.1515/ZPCH-1906-5519" >doi:10.1515/ZPCH-1906-5519</a> (1906). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2815',
    'Reyes-Pérez et&nbsp;al. (2008)',
    'Reyes-Pérez, E., Le Calvé, S., &#x0026; Mirabel, P.: <span class="cmti-10">UV absorption spectrum</span> <span class="cmti-10">and Henry&#x2019;s law constant of EPTC</span>, Atmos. Environ., 42, 7940–7946, <a href="https://doi.org/10.1016/J.ATMOSENV.2008.07.017" >doi:10.1016/J.ATMOSENV.2008.07.017</a> (2008). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2489',
    'Reza and Trejo (2004)',
    'Reza, J. &#x0026; Trejo, A.: <span class="cmti-10">Temperature dependence of</span> <span class="cmti-10">the infinite dilution activity coefficient and Henry&#x2019;s law constant of</span> <span class="cmti-10">polycyclic aromatic hydrocarbons in water</span>, Chemosphere, 56, 537–547, <a href="https://doi.org/10.1016/J.CHEMOSPHERE.2004.04.020" >doi:10.1016/J.CHEMOSPHERE.2004.04.020</a> (2004). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3791',
    'Rice et&nbsp;al. (1997a)',
    'Rice, C. P., Chernyak, S. M., Hapeman, C. J., &#x0026; Biboulian, S.: <span class="cmti-10">Air–water</span> <span class="cmti-10">distribution of the endosulfan isomers</span>, J. Environ. Qual., 26, 1101–1106, <a href="https://doi.org/10.2134/JEQ1997.00472425002600040022X" >doi:10.2134/JEQ1997.00472425002600040022X</a> (1997a). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '893',
    'Rice et&nbsp;al. (1997b)',
    'Rice, C. P., Chernyak, S. M., &#x0026; McConnell, L. L.: <span class="cmti-10">Henry&#x2019;s law constants for pesticides</span> <span class="cmti-10">measured as a function of temperature and salinity</span>, J. Agric. Food Chem., 45, 2291–2298, <a href="https://doi.org/10.1021/JF960834U" >doi:10.1021/JF960834U</a> (1997b). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3635',
    'Richon et&nbsp;al. (1985)',
    'Richon, D., Sorrentino, F., &#x0026; Voilley, A.: <span class="cmti-10">Infinite dilution activity coefficients by the inert</span> <span class="cmti-10">gas stripping method: extension to the study of viscous and foaming</span> <span class="cmti-10">mixtures</span>, Ind. Eng. Chem. Process Des. Dev., 24, 1160–1165, <a href="https://doi.org/10.1021/I200031A044" >doi:10.1021/I200031A044</a> (1985). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2966',
    'Riederer (1990)',
    'Riederer, M.: <span class="cmti-10">Estimating partitioning and transport</span> <span class="cmti-10">of organic chemicals in the foliage/atmosphere system: discussion</span> <span class="cmti-10">of a fugacity-based model</span>, Environ. Sci. Technol., 24, 829–837, <a href="https://doi.org/10.1021/ES00076A006" >doi:10.1021/ES00076A006</a> (1990). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2929',
    'Rinker and Sandall (2000)',
    'Rinker, E. B. &#x0026; Sandall, O. C.: <span class="cmti-10">Physical</span> <span class="cmti-10">solubility of hydrogen sulfide in several aqueous solvents</span>, Can. J. Chem. Eng., 78, 232–236, <a href="https://doi.org/10.1002/CJCE.5450780130" >doi:10.1002/CJCE.5450780130</a> (2000). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3414',
    'Rischbieter et&nbsp;al. (2000)',
    'Rischbieter, E., Stein, H., &#x0026; Schumpe, A.: <span class="cmti-10">Ozone solubilities in water and aqueous</span> <span class="cmti-10">salt solutions</span>, J. Chem. Eng. Data, 45, 338–340, <a href="https://doi.org/10.1021/JE990263C" >doi:10.1021/JE990263C</a> (2000). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3578',
    'Rivera-Rios (2018)',
    'Rivera-Rios, J. C.: Atmospheric chemistry of isoprene hydroxyhydroperoxides, Ph.D. thesis, Graduate School of Arts &#x0026; Sciences, Harvard University, USA, URL https://dash.harvard.edu/handle/1/41127811 (2018). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1481',
    'Riveros et&nbsp;al. (1998)',
    'Riveros, P. A., Koren, D., McNamara, V. M., &#x0026; Binvignat, J.: <span class="cmti-10">Cyanide recovery</span> <span class="cmti-10">from a gold mill barren solution containing high levels of copper</span>, CIM Bull., 91, 73–81 (1998). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '599',
    'Robbins et&nbsp;al. (1993)',
    'Robbins, G. A., Wang, S., &#x0026; Stuart, J. D.: <span class="cmti-10">Using the headspace method to determine Henry&#x2019;s</span> <span class="cmti-10">law constants</span>, Anal. Chem., 65, 3113–3118, <a href="https://doi.org/10.1021/AC00069A026" >doi:10.1021/AC00069A026</a> (1993). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2389',
    'Roberts and Pollien (1997)',
    'Roberts, D. D. &#x0026; Pollien, P.: <span class="cmti-10">Analysis of aroma</span> <span class="cmti-10">release during microwave heating</span>, J. Agric. Food Chem., 45, 4388–4392, <a href="https://doi.org/10.1021/JF9702508" >doi:10.1021/JF9702508</a> (1997). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3525',
    'Roberts and Liu (2019)',
    'Roberts, J. M. &#x0026; Liu, Y.: <span class="cmti-10">Solubility and solution-phase chemistry of isocyanic acid, methyl</span> <span class="cmti-10">isocyanate, and cyanogen halides</span>, Atmos. Chem. Phys., 19, 4419–4437, <a href="https://doi.org/10.5194/ACP-19-4419-2019" >doi:10.5194/ACP-19-4419-2019</a> (2019). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2360',
    'Roberts et&nbsp;al. (2008)',
    'Roberts, J. M., Osthoff, H. D., Brown, S. S., &#x0026; Ravishankara, A. R.: N<sub><span class="cmr-7">2</span></sub>O<sub><span class="cmr-7">5</span></sub> <span class="cmti-10">oxidizes chloride to</span> Cl<sub><span class="cmr-7">2</span></sub> <span class="cmti-10">in acidic atmospheric aerosol</span>, Science, 321, 1059, <a href="https://doi.org/10.1126/SCIENCE.1158777" >doi:10.1126/SCIENCE.1158777</a> (2008). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2805',
    'Roberts et&nbsp;al. (2011)',
    'Roberts, J. M., Veres, P. R., Cochran, A. K., Warneke, C., Burling, I. R., Yokelson, R. J., Lerner, B., Gilman, J. B., Kuster, W. C., Fall, R., &#x0026; de Gouw, J.: <span class="cmti-10">Isocyanic acid in the atmosphere and its possible</span> <span class="cmti-10">link to smoke-related health effects</span>, Proc. Natl. Acad. Sci. USA, 108, 8966–8971, <a href="https://doi.org/10.1073/PNAS.1103352108" >doi:10.1073/PNAS.1103352108</a> (2011). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3726',
    'Roberts et&nbsp;al. (2022)',
    'Roberts, J. M., Neuman, J. A., Brown, S. S., Veres, P. R., Coggon, M. M., Stockwell, C. E., Warneke, C., Peischl, J., &#x0026; Robinson, M. A.: <span class="cmti-10">Furoyl peroxynitrate (fur-PAN), a product of VOC-NOx photochemistry</span> <span class="cmti-10">from biomass burning emissions: photochemical synthesis, calibration,</span> <span class="cmti-10">chemical characterization, and first atmospheric observations</span>, Environ. Sci. Atmos., 2, 1087–1100, <a href="https://doi.org/10.1039/D2EA00068G" >doi:10.1039/D2EA00068G</a> (2022). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3961',
    'Robinson et&nbsp;al. (1997)',
    'Robinson, G. N., Worsnop, D. R., Jayne, J. T., , Kolb, C. E., &#x0026; Davidovits, P.: <span class="cmti-10">Heterogeneous uptake of</span> ClONO<sub><span class="cmr-7">2</span></sub> <span class="cmti-10">and</span> N<sub><span class="cmr-7">2</span></sub>O<sub><span class="cmr-7">5</span></sub> <span class="cmti-10">by sulfuric</span> <span class="cmti-10">acid solutions</span>, J. Geophys. Res., 102, 3583–3601, <a href="https://doi.org/10.1029/96JD03457" >doi:10.1029/96JD03457</a> (1997). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '727',
    'Rochester and Symonds (1973)',
    'Rochester, H. &#x0026; Symonds, J. R.: <span class="cmti-10">Thermodynamic studies of fluoroalcohols. Part 3. – The thermodynamics</span> <span class="cmti-10">of transfer of five fluoroalcohols from the gas-phase to aqueous solution</span>, J. Chem. Soc. Faraday Trans. 1, 69, 1577–1585, <a href="https://doi.org/10.1039/F19736901577" >doi:10.1039/F19736901577</a> (1973). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    'rodriguez2001',
    'Rodríguez-Sevilla et&nbsp;al. (2001)',
    'Rodríguez-Sevilla, J., Álvarez Diaz, M., Diaz Garcia, C., &#x0026; Limiñana de la Fe, G.: <span class="cmti-10">Thermodynamic equilibrium of</span> SO<sub><span class="cmr-7">2</span></sub><span class="cmti-10">-</span>H<sub><span class="cmr-7">2</span></sub>O <span class="cmti-10">system at low partial</span> <span class="cmti-10">pressures</span>, Afinidad, 492, 141–146 (2001). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3536',
    'Rodríguez-Sevilla et&nbsp;al. (2002)',
    'Rodríguez-Sevilla, J., Álvarez, M., Limiñana, G., &#x0026; Díaz, M. C.: <span class="cmti-10">Dilute</span> SO<sub><span class="cmr-7">2</span></sub> <span class="cmti-10">absorption equilibria in aqueous</span> HCl <span class="cmti-10">and</span> NaCl <span class="cmti-10">solutions at</span> <span class="cmti-10">298.15K</span>, J. Chem. Eng. Data, 47, 1339–1345, <a href="https://doi.org/10.1021/JE015538E" >doi:10.1021/JE015538E</a> (2002). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3530',
    'Roduner and Bartels (1992)',
    'Roduner, E. &#x0026; Bartels, D. M.: <span class="cmti-10">Solvent and</span> <span class="cmti-10">isotope effects on addition of atomic hydrogen to benzene in</span> <span class="cmti-10">aqueous solution</span>, Ber. Bunsenges. Phys. Chem., 96, 1037–1042, <a href="https://doi.org/10.1002/BBPC.19920960813" >doi:10.1002/BBPC.19920960813</a> (1992). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '792',
    'Rohrschneider (1973)',
    'Rohrschneider, L.: <span class="cmti-10">Solvent characterization by</span> <span class="cmti-10">gas-liquid partition coefficients of selected solutes</span>, Anal. Chem., 45, 1241–1247, <a href="https://doi.org/10.1021/AC60329A023" >doi:10.1021/AC60329A023</a> (1973). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3066',
    'Ross and Hudson (1957)',
    'Ross, S. &#x0026; Hudson, J. B.: <span class="cmti-10">Henry&#x2019;s law constants of</span> <span class="cmti-10">butadiene in aqueous solutions of a cationic surfactant</span>, J. Colloid Sci., 12, 523–525, <a href="https://doi.org/10.1016/0095-8522(57)90054-5" >doi:10.1016/0095-8522(57)90054-5</a> (1957). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2549',
    'Roth and Sullivan (1981)',
    'Roth, J. A. &#x0026; Sullivan, D. E.: <span class="cmti-10">Solubility of ozone</span> <span class="cmti-10">in water</span>, Ind. Eng. Chem. Fund., 20, 137–140 (1981). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3944',
    'Roth (1897)',
    'Roth, W.: <span class="cmti-10">Ueber die Absorption des Stickoxyduls in w</span><span class="cmti-10">ässrigen</span> <span class="cmti-10">L</span><span class="cmti-10">ösungen verschieden dissociierter Stoffe</span>, Z. Phys. Chem., 24, 114–151, <a href="https://doi.org/10.1515/ZPCH-1897-2408" >doi:10.1515/ZPCH-1897-2408</a> (1897). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3810',
    'Roth (1929)',
    'Roth, W. A.: <span class="cmti-10">Zur Thermochemie</span> <span class="cmti-10">des Chlors und der unterchlorigen S</span><span class="cmti-10">äure</span>, Z. Phys. Chem., 145, 289–297, <a href="https://doi.org/10.1515/ZPCH-1929-14525" >doi:10.1515/ZPCH-1929-14525</a> (1929). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3949',
    'Roth (1942)',
    'Roth, W. A.: <span class="cmti-10">Notiz zur Thermochemie des Chlormonoxydes</span>, Z. Phys. Chem., A191, 248–250, <a href="https://doi.org/10.1515/ZPCH-1942-19117" >doi:10.1515/ZPCH-1942-19117</a> (1942). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3089',
    'Rubbiani (2013)',
    'Rubbiani, M.: <span class="cmti-10">CLH Report for Brodifacoum</span>, Tech. rep., European Chemicals Agency (ECHA), URL https://echa.europa.eu/documents/10162/71fd5c43-4db1-d6ac-bb74-a6359304c54a (2013). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '585',
    'Rudich et&nbsp;al. (1996)',
    'Rudich, Y., Talukdar, R. K., Ravishankara, A. R., &#x0026; Fox, R. W.: <span class="cmti-10">Reactive</span> <span class="cmti-10">uptake of</span> NO<sub><span class="cmr-7">3</span></sub> <span class="cmti-10">on pure water and ionic solutions</span>, J. Geophys. Res., 101, 21 023–21 031, <a href="https://doi.org/10.1029/96JD01844" >doi:10.1029/96JD01844</a> (1996). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3784',
    'Ruetschi and Amlie (1966)',
    'Ruetschi, P. &#x0026; Amlie, R. F.: <span class="cmti-10">Solubility of</span> <span class="cmti-10">hydrogen in potassium hydroxide and sulfuric acid. Salting-out and</span> <span class="cmti-10">hydration</span>, J. Phys. Chem., 70, 718–723, <a href="https://doi.org/10.1021/J100875A018" >doi:10.1021/J100875A018</a> (1966). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3572',
    'Ruiz-Bevia and Fernandez-Torres (2010)',
    'Ruiz-Bevia, F. &#x0026; Fernandez-Torres, M. J.: <span class="cmti-10">Determining the Henry&#x2019;s law constants</span> <span class="cmti-10">of THMs in seawater by means of purge-and-trap gas chromatography</span> <span class="cmti-10">(PT-GC): The influence of seawater as sample matrix</span>, Anal. Sci., 26, 723–726, <a href="https://doi.org/10.2116/ANALSCI.26.723" >doi:10.2116/ANALSCI.26.723</a> (2010). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3539',
    'Rumble (2021)',
    'Rumble, J. R.: CRC Handbook of Chemistry and Physics, 102nd Edition, CRC Press, Boca Raton, FL, URL https://hbcp.chemnetbase.com (2021). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '731',
    'Russell et&nbsp;al. (1992)',
    'Russell, C. J., Dixon, S. L., &#x0026; Jurs, P. C.: <span class="cmti-10">Computer-assisted study of the relationship between</span> <span class="cmti-10">molecular structure and Henry&#x2019;s law constant</span>, Anal. Chem., 64, 1350–1355, <a href="https://doi.org/10.1021/AC00037A009" >doi:10.1021/AC00037A009</a> (1992). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2235',
    'Ryan et&nbsp;al. (1988)',
    'Ryan, J. A., Bell, R. M., Davidson, J. M., &#x0026; O&#x2019;Connor, G. A.: <span class="cmti-10">Plant uptake of</span> <span class="cmti-10">non-ionic organic chemicals from soils</span>, Chemosphere, 17, 2299–2323, <a href="https://doi.org/10.1016/0045-6535(88)90142-7" >doi:10.1016/0045-6535(88)90142-7</a> (1988). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2218',
    'Rytting et&nbsp;al. (1978)',
    'Rytting, J. H., Huston, L. P., &#x0026; Higuchi, T.: <span class="cmti-10">Thermodynamic group contributions for</span> <span class="cmti-10">hydroxyl, amino, and methylene groups</span>, J. Pharm. Sci., 69, 615–618, <a href="https://doi.org/10.1002/JPS.2600670510" >doi:10.1002/JPS.2600670510</a> (1978). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2935',
    'Ryu and Park (1999)',
    'Ryu, S.-A. &#x0026; Park, S.-J.: <span class="cmti-10">A rapid determination method</span> <span class="cmti-10">of the air/water partition coefficient and its application</span>, Fluid Phase Equilib., 161, 295–304, <a href="https://doi.org/10.1016/S0378-3812(99)00193-4" >doi:10.1016/S0378-3812(99)00193-4</a> (1999). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1141',
    'Sabljić and Güsten (1989)',
    'Sabljić, A. &#x0026; Güsten, H.: <span class="cmti-10">Predicting Henry&#x2019;s law</span> <span class="cmti-10">constants for polychlorinated biphenyls</span>, Chemosphere, 19, 1503–1511, <a href="https://doi.org/10.1016/0045-6535(89)90495-5" >doi:10.1016/0045-6535(89)90495-5</a> (1989). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2915',
    'Saçan et&nbsp;al. (2005)',
    'Saçan, M. T., Özkul, M., &#x0026; Erdem, S. S.: <span class="cmti-10">Physico-chemical properties</span> <span class="cmti-10">of PCDD/PCDFs and phthalate esters</span>, SAR QSAR Environ. Res., 16, 443–459, <a href="https://doi.org/10.1080/10659360500320602" >doi:10.1080/10659360500320602</a> (2005). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1142',
    'Sagebiel et&nbsp;al. (1992)',
    'Sagebiel, J. C., Seiber, J. N., &#x0026; Woodrow, J. E.: <span class="cmti-10">Comparison of headspace and gas-stripping</span> <span class="cmti-10">methods for determining the Henry&#x2019;s law constant (</span><span class="cmmi-10">H</span><span class="cmti-10">) for organic</span> <span class="cmti-10">compounds of low to intermediate </span><span class="cmmi-10">H</span>, Chemosphere, 25, 1763–1768, <a href="https://doi.org/10.1016/0045-6535(92)90017-L" >doi:10.1016/0045-6535(92)90017-L</a> (1992). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2216',
    'Sahsuvar et&nbsp;al. (2003)',
    'Sahsuvar, L., Helm, P. A., Jantunen, L. M., &#x0026; Bidleman, T. F.: <span class="cmti-10">Henry&#x2019;s law</span> <span class="cmti-10">constants for </span><span class="cmmi-10">α</span><span class="cmti-10">-, </span><span class="cmmi-10">β</span><span class="cmti-10">-, and </span><span class="cmmi-10">γ</span><span class="cmti-10">-hexachlorocyclohexanes (HCHs) as a function</span> <span class="cmti-10">of temperature and revised estimates of gas exchange in Arctic regions</span>, Atmos. Environ., 37, 983–992, <a href="https://doi.org/10.1016/S1352-2310(02)00936-6" >doi:10.1016/S1352-2310(02)00936-6</a> (2003). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3710',
    'Saidman et&nbsp;al. (1966)',
    'Saidman, L. J., Eger, E. I., Munson, E. S., &#x0026; Severinghaus, J. W.: <span class="cmti-10">A method for</span> <span class="cmti-10">determining solubility of anesthetics utilizing the Scholander apparatus</span>, Anesthesiology, 27, 180–184, <a href="https://doi.org/10.1097/00000542-196603000-00011" >doi:10.1097/00000542-196603000-00011</a> (1966). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2312',
    'Saiz-Lopez et&nbsp;al. (2008)',
    'Saiz-Lopez, A., Plane, J. M. C., Mahajan, A. S., Anderson, P. S., Bauguitte, S. J.-B., Jones, A. E., Roscoe, H. K., Salmon, R. A., Bloss, W. J., Lee, J. D., &#x0026; Heard, D. E.: <span class="cmti-10">On the vertical distribution of</span> <span class="cmti-10">boundary layer halogens over coastal Antarctica: implications for</span> O<sub><span class="cmr-7">3</span></sub><span class="cmti-10">,</span> HO<sub><span class="cmr-7">x</span></sub><span class="cmti-10">,</span> NO<sub><span class="cmr-7">x</span></sub> <span class="cmti-10">and the</span> Hg <span class="cmti-10">lifetime</span>, Atmos. Chem. Phys., 8, 887–900, <a href="https://doi.org/10.5194/ACP-8-887-2008" >doi:10.5194/ACP-8-887-2008</a> (2008). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3760',
    'Saiz-Lopez et&nbsp;al. (2014)',
    'Saiz-Lopez, A., Fernandez, R. P., Ordóñez, C., Kinnison, D. E., Gómez Martín, J. C., Lamarque, J.-F., &#x0026; Tilmes, S.: <span class="cmti-10">Iodine chemistry in</span> <span class="cmti-10">the troposphere and its effect on ozone</span>, Atmos. Chem. Phys., 14, 13 119–13 143, <a href="https://doi.org/10.5194/ACP-14-13119-2014" >doi:10.5194/ACP-14-13119-2014</a> (2014). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '958',
    'Sander (1999)',
    'Sander, R.: <span class="cmti-10">Modeling atmospheric chemistry: Interactions</span> <span class="cmti-10">between gas-phase species and liquid cloud/aerosol particles</span>, Surv. Geophys., 20, 1–31, <a href="https://doi.org/10.1023/A:1006501706704" >doi:10.1023/A:1006501706704</a> (1999). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2000',
    'Sander (2015)',
    'Sander, R.: <span class="cmti-10">Compilation of Henry&#x2019;s law constants (version</span> <span class="cmti-10">4.0) for water as solvent</span>, Atmos. Chem. Phys., 15, 4399–4981, <a href="https://doi.org/10.5194/ACP-15-4399-2015" >doi:10.5194/ACP-15-4399-2015</a> (2015). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '271',
    'Sander and Crutzen (1996)',
    'Sander, R. &#x0026; Crutzen, P. J.: <span class="cmti-10">Model study</span> <span class="cmti-10">indicating halogen activation and ozone destruction in polluted air</span> <span class="cmti-10">masses transported to the sea</span>, J. Geophys. Res., 101, 9121–9138, <a href="https://doi.org/10.1029/95JD03793" >doi:10.1029/95JD03793</a> (1996). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3509',
    'Sander et&nbsp;al. (2022)',
    'Sander, R., Acree Jr., W. E., De Visscher, A., Schwartz, S. E., &#x0026; Wallington, T. J.: <span class="cmti-10">Henry&#x2019;s law constants (IUPAC Recommendations</span> <span class="cmti-10">2021)</span>, Pure Appl. Chem., 94, 71–85, <a href="https://doi.org/10.1515/PAC-2020-0302" >doi:10.1515/PAC-2020-0302</a> (2022). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1945',
    'Sander et&nbsp;al. (2006)',
    'Sander, S. P., Friedl, R. R., Golden, D. M., Kurylo, M. J., Moortgat, G. K., Keller-Rudek, H., Wine, P. H., Ravishankara, A. R., Kolb, C. E., Molina, M. J., Finlayson-Pitts, B. J., Huie, R. E., &#x0026; Orkin, V. L.: <span class="cmti-10">Chemical Kinetics and Photochemical</span> <span class="cmti-10">Data for Use in Atmospheric Studies, Evaluation Number 15</span>, JPL Publication 06-2, Jet Propulsion Laboratory, Pasadena, CA, URL https://jpldataeval.jpl.nasa.gov (2006). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2626',
    'Sander et&nbsp;al. (2011)',
    'Sander, S. P., Abbatt, J., Barker, J. R., Burkholder, J. B., Friedl, R. R., Golden, D. M., Huie, R. E., Kolb, C. E., Kurylo, M. J., Moortgat, G. K., Orkin, V. L., &#x0026; Wine, P. H.: <span class="cmti-10">Chemical Kinetics and</span> <span class="cmti-10">Photochemical Data for Use in Atmospheric Studies, Evaluation No.</span> <span class="cmti-10">17</span>, JPL Publication 10-6, Jet Propulsion Laboratory, Pasadena, URL https://jpldataeval.jpl.nasa.gov (2011). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2455',
    'Sanders and Seiber (1983)',
    'Sanders, P. F. &#x0026; Seiber, J. N.: <span class="cmti-10">A chamber for</span> <span class="cmti-10">measuring volatilization of pesticides from model soil and water disposal</span> <span class="cmti-10">systems</span>, Chemosphere, 12, 999–1012, <a href="https://doi.org/10.1016/0045-6535(83)90252-7" >doi:10.1016/0045-6535(83)90252-7</a> (1983). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2280',
    'Sanemasa (1975)',
    'Sanemasa, I.: <span class="cmti-10">The solubility of elemental mercury vapor in</span> <span class="cmti-10">water</span>, Bull. Chem. Soc. Jpn., 48, 1795–1798, <a href="https://doi.org/10.1246/BCSJ.48.1795" >doi:10.1246/BCSJ.48.1795</a> (1975). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2984',
    'Sanemasa et&nbsp;al. (1981)',
    'Sanemasa, I., Akari, M., Deguchi, T., &#x0026; Nagai, H.: <span class="cmti-10">Solubilities of benzene and the</span> <span class="cmti-10">alkylbenzenes in water – method for obtaining aqueous solutions saturated</span> <span class="cmti-10">with vapours in equilibrium with organic liquids</span>, Chem. Lett., 10, 225–228, <a href="https://doi.org/10.1246/CL.1981.225" >doi:10.1246/CL.1981.225</a> (1981). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2453',
    'Sanemasa et&nbsp;al. (1982)',
    'Sanemasa, I., Araki, M., Deguchi, T., &#x0026; Nagai, H.: <span class="cmti-10">Solubility measurements of benzene</span> <span class="cmti-10">and the alkylbenzenes in water by making use of solute vapor</span>, Bull. Chem. Soc. Jpn., 55, 1054–1062, <a href="https://doi.org/10.1246/BCSJ.55.1054" >doi:10.1246/BCSJ.55.1054</a> (1982). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '644',
    'Santl et&nbsp;al. (1994)',
    'Santl, H., Brandsch, R., &#x0026; Gruber, L.: <span class="cmti-10">Experimental determination of Henry&#x2019;s law constant (HLC)</span> <span class="cmti-10">for some lower chlorinated dibenzodioxins</span>, Chemosphere, 29, 2209–2214, <a href="https://doi.org/10.1016/0045-6535(94)90388-3" >doi:10.1016/0045-6535(94)90388-3</a> (1994). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3214',
    'Sanz and Gmehling (2005)',
    'Sanz, M. T. &#x0026; Gmehling, J.: <span class="cmti-10">Isothermal</span> <span class="cmti-10">vapor-liquid equilibrium, excess enthalpy data, and activity coefficients at</span> <span class="cmti-10">infinite dilution for the binary system water + methyl lactate</span>, J. Chem. Eng. Data, 50, 85–88, <a href="https://doi.org/10.1021/JE049824C" >doi:10.1021/JE049824C</a> (2005). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2554',
    'Sarraute et&nbsp;al. (2004)',
    'Sarraute, S., Delepine, H., Costa Gomes, M. F., &#x0026; Majer, V.: <span class="cmti-10">Aqueous</span> <span class="cmti-10">solubility, Henry&#x2019;s law constants and air/water partition coefficients of</span> <span class="cmmi-10">n</span><span class="cmti-10">-octane and two halogenated octanes</span>, Chemosphere, 57, 1543–1551, <a href="https://doi.org/10.1016/J.CHEMOSPHERE.2004.07.046" >doi:10.1016/J.CHEMOSPHERE.2004.07.046</a> (2004). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2122',
    'Sarraute et&nbsp;al. (2006)',
    'Sarraute, S., Mokbel, I., Costa Gomes, M. F., Majer, V., Delepine, H., &#x0026; Jose, J.: <span class="cmti-10">Vapour pressures, aqueous solubility,</span> <span class="cmti-10">Henry&#x2019;s law constants and air/water partition coefficients of</span> <span class="cmti-10">1,8-dichlorooctane and 1,8-dibromooctane</span>, Chemosphere, 64, 1829–1836, <a href="https://doi.org/10.1016/J.CHEMOSPHERE.2006.01.057" >doi:10.1016/J.CHEMOSPHERE.2006.01.057</a> (2006). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2917',
    'Sato and Nakajima (1979a)',
    'Sato, A. &#x0026; Nakajima, T.: <span class="cmti-10">Partition coefficients</span> <span class="cmti-10">of some aromatic hydrocarbons and ketones in water, blood and oil</span>, Br. J. Ind. Med., 36, 231–234, <a href="https://doi.org/10.1136/OEM.36.3.231" >doi:10.1136/OEM.36.3.231</a> (1979a). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2918',
    'Sato and Nakajima (1979b)',
    'Sato, A. &#x0026; Nakajima, T.: <span class="cmti-10">A structure-activity</span> <span class="cmti-10">relationship of some chlorinated hydrocarbons</span>, Arch. Environ. Health, 34, 69–75, <a href="https://doi.org/10.1080/00039896.1979.10667371" >doi:10.1080/00039896.1979.10667371</a> (1979b). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1200',
    'Sauer (1997)',
    'Sauer, F.: Bestimmung von H<sub><span class="cmr-7">2</span></sub>O<sub><span class="cmr-7">2</span></sub> und organischen Peroxiden in Labor- und Feldmessungen mittels Umkehrphasen-Hochdruck-Flüssigkeitschromatographie und enzymatischer Nachsäulenderivatisierung, Ph.D. thesis, Johannes Gutenberg-Universität, Mainz, Germany (1997). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3025',
    'Savary et&nbsp;al. (2014)',
    'Savary, G., Hucher, N., Petibon, O., &#x0026; Grisel, M.: <span class="cmti-10">Study of interactions between aroma</span> <span class="cmti-10">compounds and acacia gum using headspace measurements</span>, Food Hydrocolloids, 37, 1–6, <a href="https://doi.org/10.1016/J.FOODHYD.2013.10.026" >doi:10.1016/J.FOODHYD.2013.10.026</a> (2014). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '588',
    'Saxena and Hildemann (1996)',
    'Saxena, P. &#x0026; Hildemann, L. M.: <span class="cmti-10">Water-soluble organics in atmospheric particles: A critical review</span> <span class="cmti-10">of the literature and application of thermodynamics to identify candidate</span> <span class="cmti-10">compounds</span>, J. Atmos. Chem., 24, 57–109, <a href="https://doi.org/10.1007/BF00053823" >doi:10.1007/BF00053823</a> (1996). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2491',
    'Saylor et&nbsp;al. (1938)',
    'Saylor, J. H., Stuckey, J. M., &#x0026; Gross, P. M.: <span class="cmti-10">Solubility studies. V. the validity of Henry&#x2019;s law for</span> <span class="cmti-10">the calculation of vapor solubilities</span>, J. Am. Chem. Soc., 60, 373–376, <a href="https://doi.org/10.1021/JA01269A041" >doi:10.1021/JA01269A041</a> (1938). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '735',
    'Schäfer and Lax (1962)',
    'Schäfer, K. &#x0026; Lax, E., eds.: Landolt-Börnstein. Zahlenwerte und Funktionen aus Physik, Chemie, Astronomie, Geophysik und Technik. II. Band. Eigenschaften der Materie in ihren Aggregatzuständen. 2. Teil. Gleichgewichte ausser Schmelzgleichgewichten. Bandteil b. Lösungsgleichgewichte I, Springer Verlag, Berlin-Göttingen-Heidelberg, ISBN 9783540028680 (1962). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '859',
    'Schaffer and Daubert (1969)',
    'Schaffer, D. L. &#x0026; Daubert, T. E.: <span class="cmti-10">Gas-liquid chromatographic determination of</span> <span class="cmti-10">solution properties of oxygenated compounds in water</span>, Anal. Chem., 41, 1585–1589, <a href="https://doi.org/10.1021/AC60281A016" >doi:10.1021/AC60281A016</a> (1969). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3662',
    'Scharlin (1996)',
    'Scharlin, P.: IUPAC Solubility Data Series, Volume 62, Carbon Dioxide in Water and Aqueous Electrolyte Solutions, Oxford University Press (1996). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2485',
    'Scharlin and Battino (1994)',
    'Scharlin, P. &#x0026; Battino, R.: <span class="cmti-10">Solubility of</span> CCl<sub><span class="cmr-7">2</span></sub>F<sub><span class="cmr-7">2</span></sub><span class="cmti-10">,</span> CClF<sub><span class="cmr-7">3</span></sub><span class="cmti-10">,</span> CF<sub><span class="cmr-7">4</span></sub> <span class="cmti-10">and c-</span>C<sub><span class="cmr-7">4</span></sub>F<sub><span class="cmr-7">8</span></sub> <span class="cmti-10">in</span> H<sub><span class="cmr-7">2</span></sub>O <span class="cmti-10">and</span> D<sub><span class="cmr-7">2</span></sub>O <span class="cmti-10">at 288 to 318 </span>K <span class="cmti-10">and</span> <span class="cmti-10">101.325kPa. Thermodynamics of transfer of gases from</span> H<sub><span class="cmr-7">2</span></sub>O <span class="cmti-10">to</span> D<sub><span class="cmr-7">2</span></sub>O, Fluid Phase Equilib., 95, 137–147, <a href="https://doi.org/10.1016/0378-3812(94)80066-9" >doi:10.1016/0378-3812(94)80066-9</a> (1994). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3569',
    'Scharlin and Battino (1995)',
    'Scharlin, P. &#x0026; Battino, R.: <span class="cmti-10">Solubility of</span> CCl<sub><span class="cmr-7">2</span></sub>F<sub><span class="cmr-7">2</span></sub><span class="cmti-10">,</span> CClF<sub><span class="cmr-7">3</span></sub><span class="cmti-10">,</span> CF<sub><span class="cmr-7">4</span></sub><span class="cmti-10">, and</span> CH<sub><span class="cmr-7">4</span></sub> <span class="cmti-10">in water</span> <span class="cmti-10">and seawater at 288.15-303.15K and 101.325kPa</span>, J. Chem. Eng. Data, 40, 167–169, <a href="https://doi.org/10.1021/JE00017A036" >doi:10.1021/JE00017A036</a> (1995). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1060',
    'Scheer et&nbsp;al. (1997)',
    'Scheer, V., Frenzel, A., Behnke, W., Zetzsch, C., Magi, L., George, C., &#x0026; Mirabel, P.: <span class="cmti-10">Uptake of nitrosyl chloride (</span>NOCl<span class="cmti-10">) by aqueous solutions</span>, J. Phys. Chem. A, 101, 9359–9366, <a href="https://doi.org/10.1021/JP972143M" >doi:10.1021/JP972143M</a> (1997). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3777',
    'Schmidt (1979)',
    'Schmidt, U.: <span class="cmti-10">The solubility of carbon monoxide and hydrogen in water</span> <span class="cmti-10">and sea-water at partial pressures of about </span>10<sup><span class="cmsy-7">−</span><span class="cmr-7">5</span></sup> <span class="cmti-10">atmospheres</span>, Tellus, 31, 68–74, <a href="https://doi.org/10.1111/J.2153-3490.1979.TB00883.X" >doi:10.1111/J.2153-3490.1979.TB00883.X</a> (1979). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    'schoen23',
    'Schoen (1923)',
    'Schoen, R.: <span class="cmti-10">Zur Kenntnis der Acetylenwirkung. II.</span> <span class="cmti-10">Mitteilung. Die L</span><span class="cmti-10">öslichkeit von Acetylen in Wasser und Blut</span>, Z. Physiol. Chem., 127, 243–259, <a href="https://doi.org/10.1515/BCHM2.1923.127.4-6.243" >doi:10.1515/BCHM2.1923.127.4-6.243</a> (1923). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1331',
    'Schoene and Steinhanses (1985)',
    'Schoene, K. &#x0026; Steinhanses, J.: <span class="cmti-10">Determination of Henry&#x2019;s law constant by automated</span> <span class="cmti-10">head space-gas chromatography</span>, Fresenius J. Anal. Chem., 321, 538–543, <a href="https://doi.org/10.1007/BF00464360" >doi:10.1007/BF00464360</a> (1985). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3933',
    'Schoenfeld (1855)',
    'Schoenfeld, F.: <span class="cmti-10">Ueber den Absorptionsco</span><span class="cmti-10">ëfficienten der</span> <span class="cmti-10">schwefligen S</span><span class="cmti-10">äure, des Chlors und des Schwefelwasserstoffs</span>, Liebigs Ann. Chem., 95, 1–23, <a href="https://doi.org/10.1002/JLAC.18550950102" >doi:10.1002/JLAC.18550950102</a> (1855). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3597',
    'Schöne (1873)',
    'Schöne, E.: <span class="cmti-10">Ueber das Verhalten von Ozon und Wasser zu einander</span>, Ber. Dtsch. Chem. Ges., 6, 1224–1229, <a href="https://doi.org/10.1002/CBER.187300602111" >doi:10.1002/CBER.187300602111</a> (1873). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3665',
    'Schröder et&nbsp;al. (2010)',
    'Schröder, B., Santos, L. M. N. B. F., Rocha, M. A. A., Oliveira, M. B., Marrucho, I. M., &#x0026; Coutinho, J. A. P.: <span class="cmti-10">Prediction of environmental</span> <span class="cmti-10">parameters of polycyclic aromatic hydrocarbons with COSMO-RS</span>, Chemosphere, 79, 821–829, <a href="https://doi.org/10.1016/J.CHEMOSPHERE.2010.02.059" >doi:10.1016/J.CHEMOSPHERE.2010.02.059</a> (2010). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3666',
    'Schröder et&nbsp;al. (2011)',
    'Schröder, B., Freire, M. G., Varanda, F. R., Marrucho, I. M., Santos, L. M. N. B. F., &#x0026; Coutinho, J. A. P.: <span class="cmti-10">Aqueous solubility, effects of salts</span> <span class="cmti-10">on aqueous solubility, and partitioning behavior of hexafluorobenzene:</span> <span class="cmti-10">Experimental results and COSMO-RS predictions</span>, Chemosphere, 84, 415–422, <a href="https://doi.org/10.1016/J.CHEMOSPHERE.2011.03.055" >doi:10.1016/J.CHEMOSPHERE.2011.03.055</a> (2011). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3655',
    'Schröder et&nbsp;al. (2013)',
    'Schröder, B., Coutinho, J., &#x0026; Santos, L. M. N. B. F.: <span class="cmti-10">Predicting</span> <span class="cmti-10">physico-chemical properties of alkylated naphthalenes with COSMO-RS</span>, Polycyclic Aromat. Compd., 33, 1–19, <a href="https://doi.org/10.1080/10406638.2012.683231" >doi:10.1080/10406638.2012.683231</a> (2013). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2171',
    'Schroeder and Munthe (1998)',
    'Schroeder, W. H. &#x0026; Munthe, J.: <span class="cmti-10">Atmospheric mercury – An overview</span>, Atmos. Environ., 32, 809–822, <a href="https://doi.org/10.1016/S1352-2310(97)00293-8" >doi:10.1016/S1352-2310(97)00293-8</a> (1998). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2947',
    'Schroy et&nbsp;al. (1985)',
    'Schroy, J. M., Hileman, F. D., &#x0026; Cheng, S. C.: <span class="cmti-10">Physical/chemical properties of 2,3,7,8-TCDD</span>, Chemosphere, 14, 877–880, <a href="https://doi.org/10.1016/0045-6535(85)90207-3" >doi:10.1016/0045-6535(85)90207-3</a> (1985). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2823',
    'Schuhfried et&nbsp;al. (2011)',
    'Schuhfried, E., Biasioli, F., Aprea, E., Cappellin, L., Soukoulis, C., Ferrigno, A., Märk, T. D., &#x0026; Gasperi, F.: <span class="cmti-10">PTR-MS measurements</span> <span class="cmti-10">and analysis of models for the calculation of Henry&#x2019;s law constants</span> <span class="cmti-10">of monosulfides and disulfides</span>, Chemosphere, 83, 311–317, <a href="https://doi.org/10.1016/J.CHEMOSPHERE.2010.12.051" >doi:10.1016/J.CHEMOSPHERE.2010.12.051</a> (2011). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3423',
    'Schuhfried et&nbsp;al. (2015)',
    'Schuhfried, E., Aprea, E., Märk, T. D., &#x0026; Biasioli, F.: <span class="cmti-10">Refined</span> <span class="cmti-10">measurements of Henry&#x2019;s law constant of terpenes with inert gas</span> <span class="cmti-10">stripping coupled with PTR-MS</span>, Water Air Soil Pollut., 226, 120, <a href="https://doi.org/10.1007/S11270-015-2337-2" >doi:10.1007/S11270-015-2337-2</a> (2015). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3767',
    'Schumpe (1993)',
    'Schumpe, A.: <span class="cmti-10">The estimation of gas solubilities in salt solutions</span>, Chem. Eng. Sci., 48, 153–158, <a href="https://doi.org/10.1016/0009-2509(93)80291-W" >doi:10.1016/0009-2509(93)80291-W</a> (1993). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '672',
    'Schurath et&nbsp;al. (1996)',
    'Schurath, U., Bongartz, A., Kames, J., Wunderlich, C., &#x0026; Carstens, T.: <span class="cmti-10">Chapter 6.4: Laboratory determination of physico-chemical rate</span> <span class="cmti-10">parameters pertinent to mass transfer into cloud and fog droplets</span>, in: Heterogeneous and Liquid-Phase Processes, edited by Warneck, P., pp. 182–189, Springer Verlag, Berlin, <a href="https://doi.org/10.1007/978-3-642-61445-3_6" >doi:10.1007/978-3-642-61445-3_6</a> (1996). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2165',
    'Schüürmann (2000)',
    'Schüürmann, G.: <span class="cmti-10">Prediction of Henry&#x2019;s law constant of</span> <span class="cmti-10">benzene derivatives using quantum chemical continuum-solvation models</span>, J. Comput. Chem., 21, 17–34, <a href="https://doi.org/10.1002/(SICI)1096-987X(20000115)21:1<17::AID-JCC3>3.0.CO;2-5" >doi:10.1002/(SICI)1096-987X(20000115)21:1<17::AID-JCC3>3.0.CO;2-5</a> (2000). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3681',
    'Schwardt et&nbsp;al. (2021)',
    'Schwardt, A., Dahmke, A., &#x0026; Köber, R.: <span class="cmti-10">Henry&#x2019;s law constants of volatile organic</span> <span class="cmti-10">compounds between 0 and 95</span><span class="cmsy-7">∘</span>C <span class="cmti-10">– Data compilation and complementation</span> <span class="cmti-10">in</span> <span class="cmti-10">context of urban temperature increases of the subsurface</span>, Chemosphere, 272, 129 858, <a href="https://doi.org/10.1016/J.CHEMOSPHERE.2021.129858" >doi:10.1016/J.CHEMOSPHERE.2021.129858</a> (2021). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3722',
    'Schwardt et&nbsp;al. (2022)',
    'Schwardt, A., Dahmke, A., &#x0026; Köber, R.: <span class="cmti-10">Corrigendum to “Henry&#x2019;s law constants</span> <span class="cmti-10">of volatile organic compounds between 0 and 95</span><span class="cmsy-7">∘</span>C <span class="cmti-10">– Data compilation</span> <span class="cmti-10">and complementation in context of urban temperature increases of the</span> <span class="cmti-10">subsurface” [Chem. 272 (2021) 129858]</span>, Chemosphere, 298, 134 683, <a href="https://doi.org/10.1016/J.CHEMOSPHERE.2022.134683" >doi:10.1016/J.CHEMOSPHERE.2022.134683</a> (2022). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '209',
    'Schwartz (1984)',
    'Schwartz, S. E.: <span class="cmti-10">Gas- and aqueous-phase chemistry of</span> HO<sub><span class="cmr-7">2</span></sub> <span class="cmti-10">in liquid water clouds</span>, J. Geophys. Res., 89, 11 589–11 598, <a href="https://doi.org/10.1029/JD089ID07P11589" >doi:10.1029/JD089ID07P11589</a> (1984). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '19',
    'Schwartz (1986)',
    'Schwartz, S. E.: <span class="cmti-10">Mass-transport considerations pertinent</span> <span class="cmti-10">to aqueous phase reactions of gases in liquid-water clouds</span>, in: Chemistry of Multiphase Atmospheric Systems, NATO ASI Series, Vol. G6, edited by Jaeschke, W., pp. 415–471, Springer Verlag, Berlin, <a href="https://doi.org/10.1007/978-3-642-70627-1_16" >doi:10.1007/978-3-642-70627-1_16</a> (1986). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '449',
    'Schwartz and White (1981)',
    'Schwartz, S. E. &#x0026; White, W. H.: <span class="cmti-10">Solubility</span> <span class="cmti-10">equilibria of the nitrogen oxides and oxyacids in dilute aqueous solution</span>, in: Advances in Environmental Science and Engineering, edited by Pfafflin, J. R. &#x0026; Ziegler, E. N., vol. 4, pp. 1–45, Gordon and Breach Science Publishers, NY (1981). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2458',
    'Schwarz and Wasik (1977)',
    'Schwarz, F. P. &#x0026; Wasik, S. P.: <span class="cmti-10">A fluorescence</span> <span class="cmti-10">method for the measurement of the partition coefficients of naphthalene,</span> <span class="cmti-10">1-methylnaphthalene, and 1-ethylnaphthalene in water</span>, J. Chem. Eng. Data, 22, 270–273, <a href="https://doi.org/10.1021/JE60074A009" >doi:10.1021/JE60074A009</a> (1977). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '762',
    'Schwarz and Bielski (1986)',
    'Schwarz, H. A. &#x0026; Bielski, B. H. J.: <span class="cmti-10">Reactions of</span> HO<sub><span class="cmr-7">2</span></sub> <span class="cmti-10">and</span> O<sub><span class="cmr-7">2</span></sub><sup><span class="cmsy-7">−</span></sup> <span class="cmti-10">with iodine and bromine and the</span> I<sub><span class="cmr-7">2</span></sub><sup><span class="cmsy-7">−</span></sup> <span class="cmti-10">and </span>I <span class="cmti-10">atom reduction</span> <span class="cmti-10">potentials</span>, J. Phys. Chem., 90, 1445–1448, <a href="https://doi.org/10.1021/J100398A045" >doi:10.1021/J100398A045</a> (1986). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '761',
    'Schwarz and Dodson (1984)',
    'Schwarz, H. A. &#x0026; Dodson, R. W.: <span class="cmti-10">Equilibrium</span> <span class="cmti-10">between hydroxyl radicals and thallium(II) and the oxidation potential</span> <span class="cmti-10">of</span> OH(aq), J. Phys. Chem., 88, 3643–3647, <a href="https://doi.org/10.1021/J150660A053" >doi:10.1021/J150660A053</a> (1984). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '941',
    'Schwarzenbach et&nbsp;al. (1988)',
    'Schwarzenbach, R. P., Stierli, R., Folsom, B. R., &#x0026; Zeyer, J.: <span class="cmti-10">Compound properties relevant for</span> <span class="cmti-10">assessing the environmental partitioning of nitrophenols</span>, Environ. Sci. Technol., 22, 83–92, <a href="https://doi.org/10.1021/ES00166A009" >doi:10.1021/ES00166A009</a> (1988). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3807',
    'Secoy and Cady (1941)',
    'Secoy, C. H. &#x0026; Cady, G. H.: <span class="cmti-10">The effect of</span> <span class="cmti-10">temperature and pressure on the solubility of chlorine monoxide in water</span>, J. Am. Chem. Soc., 63, 2504–2508, <a href="https://doi.org/10.1021/JA01854A055" >doi:10.1021/JA01854A055</a> (1941). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '523',
    'Seinfeld (1986)',
    'Seinfeld, J. H.: Atmospheric Chemistry and Physics of Air Pollution, Wiley-Interscience Publication, NY, ISBN 0471828572 (1986). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '935',
    'Seinfeld and Pandis (1997)',
    'Seinfeld, J. H. &#x0026; Pandis, S. N.: Atmospheric Chemistry and Physics, John Wiley &#x0026; Sons, Inc., ISBN 0471178160 (1997). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3612',
    'Serra and Palavra (2003)',
    'Serra, M. C. C. &#x0026; Palavra, A. M. F.: <span class="cmti-10">Solubility of</span> <span class="cmti-10">1-butene in water and in a medium for cultivation of a bacterial strain</span>, J. Solution Chem., 32, 527–534, <a href="https://doi.org/10.1023/A:1025313916280" >doi:10.1023/A:1025313916280</a> (2003). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '520',
    'Servant et&nbsp;al. (1991)',
    'Servant, J., Kouadio, G., Cros, B., &#x0026; Delmas, R.: <span class="cmti-10">Carboxylic monoacids</span> <span class="cmti-10">in the air of Mayombe forest (Congo): Role of the forest as a source or</span> <span class="cmti-10">sink</span>, J. Atmos. Chem., 12, 367–380, <a href="https://doi.org/10.1007/BF00114774" >doi:10.1007/BF00114774</a> (1991). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3102',
    'Setschenow (1889)',
    'Setschenow, J.: <span class="cmti-10">Über die Konstitution der Salzl</span><span class="cmti-10">ösungen</span> <span class="cmti-10">auf Grund ihres Verhaltens zu Kohlens</span><span class="cmti-10">äure</span>, Z. Phys. Chem., 4, 117–125, <a href="https://doi.org/10.1515/ZPCH-1889-0409" >doi:10.1515/ZPCH-1889-0409</a> (1889). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2572',
    'Severit (1997)',
    'Severit, P.: <span class="cmti-10">Experimentelle Untersuchung der Desorption</span> <span class="cmti-10">von Quecksilber und Quecksilberverbindungen aus w</span><span class="cmti-10">ässrigen L</span><span class="cmti-10">ösungen</span>, Diplomarbeit, Universität Köln, Germany (1997). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2829',
    'Seyfioglu and Odabasi (2007)',
    'Seyfioglu, R. &#x0026; Odabasi, M.: <span class="cmti-10">Determination</span> <span class="cmti-10">of Henry&#x2019;s law constant of formaldehyde as a function of temperature:</span> <span class="cmti-10">Application to air–water exchange in Tahtali lake in Izmir, Turkey</span>, Environ. Monit. Assess., 128, 343–349, <a href="https://doi.org/10.1007/S10661-006-9317-3" >doi:10.1007/S10661-006-9317-3</a> (2007). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1930',
    'Sheikheldin et&nbsp;al. (2001)',
    'Sheikheldin, S. Y., Cardwell, T. J., Cattrall, R. W., Luque de Castro, M. D., &#x0026; Kolev, S. D.: <span class="cmti-10">Determination of Henry&#x2019;s law constants of</span> <span class="cmti-10">phenols by pervaporation-flow injection analysis</span>, Environ. Sci. Technol., 35, 178–181, <a href="https://doi.org/10.1021/ES001406E" >doi:10.1021/ES001406E</a> (2001). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2948',
    'Shen and Wania (2005)',
    'Shen, L. &#x0026; Wania, F.: <span class="cmti-10">Compilation, evaluation, and</span> <span class="cmti-10">selection of physical-chemical property data for organochlorine pesticides</span>, J. Chem. Eng. Data, 50, 742–768, <a href="https://doi.org/10.1021/JE049693F" >doi:10.1021/JE049693F</a> (2005). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3083',
    'Shen (1982)',
    'Shen, T. T.: <span class="cmti-10">Estimation of organic compound emissions</span> <span class="cmti-10">from waste lagoons</span>, J. Air Pollut. Control Assoc., 32, 79–82, <a href="https://doi.org/10.1080/00022470.1982.10465374" >doi:10.1080/00022470.1982.10465374</a> (1982). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '548',
    'Shepson et&nbsp;al. (1996)',
    'Shepson, P. B., Mackay, E., &#x0026; Muthuramu, K.: <span class="cmti-10">Henry&#x2019;s law constants</span> <span class="cmti-10">and removal processes for several atmospheric </span><span class="cmmi-10">β</span><span class="cmti-10">-hydroxy alkyl nitrates</span>, Environ. Sci. Technol., 30, 3618–3623, <a href="https://doi.org/10.1021/ES960538Y" >doi:10.1021/ES960538Y</a> (1996). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3679',
    'Sherblom et&nbsp;al. (1992)',
    'Sherblom, P. M., Gschwend, P. M., &#x0026; Eganhouse, R. P.: <span class="cmti-10">Aqueous</span> <span class="cmti-10">solubilities, vapor pressures, and 1-octanol-water partition coefficients</span> <span class="cmti-10">for</span> C<sub><span class="cmr-7">9</span></sub><span class="cmti-10">–</span>C<sub><span class="cmr-7">14</span></sub> <span class="cmti-10">linear alkylbenzenes</span>, J. Chem. Eng. Data, 37, 394–399, <a href="https://doi.org/10.1021/JE00008A005" >doi:10.1021/JE00008A005</a> (1992). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3603',
    'Sherwood et&nbsp;al. (1991)',
    'Sherwood, J. E., Stagnitti, F., Kokkinn, M. J., &#x0026; Williams, W. D.: <span class="cmti-10">Dissolved oxygen concentrations in hypersaline waters</span>, Limnol. Oceanogr., 36, 235–250, <a href="https://doi.org/10.4319/LO.1991.36.2.0235" >doi:10.4319/LO.1991.36.2.0235</a> (1991). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3003',
    'Shi et&nbsp;al. (1999)',
    'Shi, Q., Davidovits, P., Jayne, J. T., Worsnop, D. R., &#x0026; Kolb, C. E.: <span class="cmti-10">Uptake of</span> <span class="cmti-10">gas-phase ammonia. 1. Uptake by aqueous surfaces as a function of pH</span>, J. Phys. Chem. A, 103, 8812–8823, <a href="https://doi.org/10.1021/JP991696P" >doi:10.1021/JP991696P</a> (1999). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2897',
    'Shimotori and Arnold (2003)',
    'Shimotori, T. &#x0026; Arnold, W. A.: <span class="cmti-10">Measurement</span> <span class="cmti-10">and estimation of Henry&#x2019;s law constants of chlorinated ethylenes</span> <span class="cmti-10">in aqueous surfactant solutions</span>, J. Chem. Eng. Data, 48, 253–261, <a href="https://doi.org/10.1021/JE025553Z" >doi:10.1021/JE025553Z</a> (2003). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2338',
    'Shiu and Ma (2000)',
    'Shiu, W. Y. &#x0026; Ma, K.-C.: <span class="cmti-10">Temperature dependence</span> <span class="cmti-10">of physical-chemical properties of selected chemicals of environmental</span> <span class="cmti-10">interest. I. mononuclear and polynuclear aromatic hydrocarbons</span>, J. Phys. Chem. Ref. Data, 29, 41–130, <a href="https://doi.org/10.1063/1.556055" >doi:10.1063/1.556055</a> (2000). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2302',
    'Shiu and Mackay (1986)',
    'Shiu, W. Y. &#x0026; Mackay, D.: <span class="cmti-10">A critical review</span> <span class="cmti-10">of aqueous solubilities, vapor pressures, Henry&#x2019;s law constants, and</span> <span class="cmti-10">octanol-water partition coefficients of the polychlorinated biphenyls</span>, J. Phys. Chem. Ref. Data, 15, 911–929, <a href="https://doi.org/10.1063/1.555755" >doi:10.1063/1.555755</a> (1986). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2339',
    'Shiu and Mackay (1997)',
    'Shiu, W.-Y. &#x0026; Mackay, D.: <span class="cmti-10">Henry&#x2019;s law constants</span> <span class="cmti-10">of selected aromatic hydrocarbons, alcohols, and ketones</span>, J. Chem. Eng. Data, 42, 27–30, <a href="https://doi.org/10.1021/JE960218U" >doi:10.1021/JE960218U</a> (1997). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '854',
    'Shiu et&nbsp;al. (1988)',
    'Shiu, W. Y., Doucette, W., Gobas, F. A. P. C., Andren, A., &#x0026; Mackay, D.: <span class="cmti-10">Physical-chemical properties of chlorinated dibenzo-p-dioxins</span>, Environ. Sci. Technol., 22, 651–658, <a href="https://doi.org/10.1021/ES00171A006" >doi:10.1021/ES00171A006</a> (1988). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '638',
    'Shiu et&nbsp;al. (1994)',
    'Shiu, W.-Y., Ma, K.-C., Varhaníčková, D., &#x0026; Mackay, D.: <span class="cmti-10">Chlorophenols and alkylphenols:</span> <span class="cmti-10">A review and correlation of environmentally relevant properties and</span> <span class="cmti-10">fate in an evaluative environment</span>, Chemosphere, 29, 1155–1224, <a href="https://doi.org/10.1016/0045-6535(94)90252-6" >doi:10.1016/0045-6535(94)90252-6</a> (1994). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2285',
    'Shon et&nbsp;al. (2005)',
    'Shon, Z.-H., Kim, K.-H., Kim, M.-Y., &#x0026; Lee, M.: <span class="cmti-10">Modeling</span> <span class="cmti-10">study of reactive gaseous mercury in the urban air</span>, Atmos. Environ., 39, 749–761, <a href="https://doi.org/10.1016/J.ATMOSENV.2004.09.071" >doi:10.1016/J.ATMOSENV.2004.09.071</a> (2005). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3785',
    'Shoor et&nbsp;al. (1969)',
    'Shoor, S. K., Walker, Jr., R. D., &#x0026; Gubbins, K. E.: <span class="cmti-10">Salting out of nonpolar gases in</span> <span class="cmti-10">aqueous potassium hydroxide solutions</span>, J. Phys. Chem., 73, 312–317, <a href="https://doi.org/10.1021/J100722A006" >doi:10.1021/J100722A006</a> (1969). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2999',
    'Shunthirasingham et&nbsp;al. (2013)',
    'Shunthirasingham, C., Cao, X., Lei, Y. D., &#x0026; Wania, F.: <span class="cmti-10">Large bubbles</span> <span class="cmti-10">reduce the surface sorption artifact during inert gas stripping</span>, J. Chem. Eng. Data, 58, 792–797, <a href="https://doi.org/10.1021/JE301326T" >doi:10.1021/JE301326T</a> (2013). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3704',
    'Siebeck (1909)',
    'Siebeck, R.: <span class="cmti-10">Über die</span> <span class="cmti-10">Aufnahme von Stickoxydul im Blut</span>, Skand. Arch. Physiol., 21, 368–382, <a href="https://doi.org/10.1111/J.1748-1716.1909.TB00063.X" >doi:10.1111/J.1748-1716.1909.TB00063.X</a> (1909). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2973',
    'Siebers and Mattusch (1996)',
    'Siebers, J. &#x0026; Mattusch, P.: <span class="cmti-10">Determination</span> <span class="cmti-10">of airborne residues in greenhouses after application of pesticides</span>, Chemosphere, 33, 1597–1607, <a href="https://doi.org/10.1016/0045-6535(96)00279-2" >doi:10.1016/0045-6535(96)00279-2</a> (1996). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2967',
    'Siebers et&nbsp;al. (1994)',
    'Siebers, J., Gottschild, D., &#x0026; Nolting, H.-G.: <span class="cmti-10">Pesticides in precipitation in northern Germany</span>, Chemosphere, 28, 1559–1570, <a href="https://doi.org/10.1016/0045-6535(94)90249-6" >doi:10.1016/0045-6535(94)90249-6</a> (1994). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3135',
    'Sieg et&nbsp;al. (2008)',
    'Sieg, K., Fries, E., &#x0026; Püttmann, W.: <span class="cmti-10">Analysis of benzene, toluene, ethylbenzene, xylenes and </span><span class="cmmi-10">n</span><span class="cmti-10">-aldehydes</span> <span class="cmti-10">in melted snow water via solid-phase dynamic extraction combined</span> <span class="cmti-10">with gas chromatography/mass spectrometry</span>, J. Chromatogr. A, 1178, 178–186, <a href="https://doi.org/10.1016/J.CHROMA.2007.11.025" >doi:10.1016/J.CHROMA.2007.11.025</a> (2008). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2645',
    'Sieg et&nbsp;al. (2009)',
    'Sieg, K., Starokozheva, E., Schmidt, M. U., &#x0026; Püttmann, W.: <span class="cmti-10">Inverse temperature dependence of Henry&#x2019;s law coefficients for volatile</span> <span class="cmti-10">organic compounds in supercooled water</span>, Chemosphere, 77, 8–14, <a href="https://doi.org/10.1016/J.CHEMOSPHERE.2009.06.028" >doi:10.1016/J.CHEMOSPHERE.2009.06.028</a> (2009). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '795',
    'Signer et&nbsp;al. (1969)',
    'Signer, R., Arm, H., &#x0026; Daenicker, H.: <span class="cmti-10">Dampfdr</span><span class="cmti-10">ücke, Dichten,</span> <span class="cmti-10">thermodynamische Mischfunktionen und Brechungsindices der bin</span><span class="cmti-10">ären</span> <span class="cmti-10">Systeme Wasser-Tetrahydrofuran und Wasser-Di</span><span class="cmti-10">äthyl</span><span class="cmti-10">äther bei 25</span><span class="cmsy-7">∘</span>, Helv. Chim. Acta, 52, 2347–2351, <a href="https://doi.org/10.1002/HLCA.19690520816" >doi:10.1002/HLCA.19690520816</a> (1969). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2551',
    'Simpson and Lovell (1962)',
    'Simpson, L. B. &#x0026; Lovell, F. P.: <span class="cmti-10">Solubility of</span> <span class="cmti-10">methyl, ethyl, and vinyl acetylene in several solvents</span>, J. Chem. Eng. Data, 7, 498–552, <a href="https://doi.org/10.1021/JE60015A017" >doi:10.1021/JE60015A017</a> (1962). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3808',
    'Sisi et&nbsp;al. (1971)',
    'Sisi, J. C., Dubeau, C., &#x0026; Ozanne, N.: <span class="cmti-10">Solubility of hydrogen selenide gas in water</span>, J. Chem. Eng. Data, 16, 78–79, <a href="https://doi.org/10.1021/JE60048A023" >doi:10.1021/JE60048A023</a> (1971). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2465',
    'Slater and Spedding (1981)',
    'Slater, R. M. &#x0026; Spedding, D. J.: <span class="cmti-10">Transport of</span> <span class="cmti-10">dieldrin between air and water</span>, Arch. Environ. Contam. Toxicol., 10, 25–33, <a href="https://doi.org/10.1007/BF01057572" >doi:10.1007/BF01057572</a> (1981). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2104',
    'Smith and Harvey (2007)',
    'Smith, F. L. &#x0026; Harvey, A. H.: <span class="cmti-10">Avoid common</span> <span class="cmti-10">pitfalls when using Henry&#x2019;s law</span>, Chem. Eng. Prog., pp. 33–39 (2007). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3945',
    'Smith and Bomberger (1980)',
    'Smith, J. H. &#x0026; Bomberger, D. C.: <span class="cmti-10">Prediction</span> <span class="cmti-10">of volatilization rate of chemicals in water</span>, in: Hydrocarbons and Halogenated Hydrocarbons in the Aquatic Environment, edited by Afghan, B. K., Mackay, D., Braun, H. E., Chau, A. S. Y., Lawrence, J., Lean, D. R. S., Meresz, O., Miles, J. R. W., Pierce, R. C., Rees, G. A. V., White, R. E., Whittle, D. M., &#x0026; Williams, D. T., pp. 445–451, Plenum Press New York (1980). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2236',
    'Smith et&nbsp;al. (1981a)',
    'Smith, J. H., Bomberger, D. C., &#x0026; Haynes, D. L.: <span class="cmti-10">Volatilization rates</span> <span class="cmti-10">of intermediate and low volatility chemicals from water</span>, Chemosphere, 10, 281–289, <a href="https://doi.org/10.1016/0045-6535(81)90028-X" >doi:10.1016/0045-6535(81)90028-X</a> (1981a). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3071',
    'Smith et&nbsp;al. (1993)',
    'Smith, J. R., Neuhauser, E. F., Middleton, A. C., Cunningham, J. J., Weightman, R. L., &#x0026; Linz, D. G.: <span class="cmti-10">Treatment of organically</span> <span class="cmti-10">contaminated groundwaters in municipal activated sludge systems</span>, Water Environ. Res., 65, 804–818, <a href="https://doi.org/10.2175/WER.65.7.2" >doi:10.2175/WER.65.7.2</a> (1993). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2445',
    'Smith et&nbsp;al. (1981b)',
    'Smith, R. A., Porter, E. G., &#x0026; Miller, K. W.: <span class="cmti-10">The solubility of anesthetic gases in lipid bilayers</span>, Biochim. Biophys. Acta - Biomembranes, 645, 327–338 (1981b). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '483',
    'Snider and Dawson (1985)',
    'Snider, J. R. &#x0026; Dawson, G. A.: <span class="cmti-10">Tropospheric</span> <span class="cmti-10">light alcohols, carbonyls, and acetonitrile: Concentrations in the</span> <span class="cmti-10">southwestern United States and Henry&#x2019;s law data</span>, J. Geophys. Res., 90, 3797–3805, <a href="https://doi.org/10.1029/JD090ID02P03797" >doi:10.1029/JD090ID02P03797</a> (1985). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3005',
    'Sotelo et&nbsp;al. (1989)',
    'Sotelo, J. L., Beltrán, F. J., Benitez, F. J., &#x0026; Beltrán-Heredia, J.: <span class="cmti-10">Henry&#x2019;s</span> <span class="cmti-10">law constant for the ozone-water system</span>, Wat. Res., 23, 1239–1246, <a href="https://doi.org/10.1016/0043-1354(89)90186-3" >doi:10.1016/0043-1354(89)90186-3</a> (1989). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3671',
    'Souchon et&nbsp;al. (2004)',
    'Souchon, I., Athès, V., Pierre, F.-X., &#x0026; Marin, M.: <span class="cmti-10">Liquid-liquid extraction and air stripping</span> <span class="cmti-10">in membrane contactor: application to aroma compounds recovery</span>, Desalination, 163, 39–46, <a href="https://doi.org/10.1016/S0011-9164(04)90174-9" >doi:10.1016/S0011-9164(04)90174-9</a> (2004). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2459',
    'Southworth (1979)',
    'Southworth, G. R.: <span class="cmti-10">The role of volatilization in</span> <span class="cmti-10">removing polycyclic aromatic hydrocarbons from aquatic environments</span>, Bull. Environ. Contam. Toxicol., 21, 507–514, <a href="https://doi.org/10.1007/BF01685462" >doi:10.1007/BF01685462</a> (1979). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3064',
    'St-Pierre et&nbsp;al. (2014)',
    'St-Pierre, J., Wetton, B., Zhai, Y., &#x0026; Gea, J.: <span class="cmti-10">Liquid water scavenging</span> <span class="cmti-10">of PEMFC contaminants</span>, J. Electrochem. Soc., 161, E3357–E3364, <a href="https://doi.org/10.1149/2.0291409JES" >doi:10.1149/2.0291409JES</a> (2014). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '799',
    'Staffelbach and Kok (1993)',
    'Staffelbach, T. A. &#x0026; Kok, G. L.: <span class="cmti-10">Henry&#x2019;s</span> <span class="cmti-10">law constants for aqueous solutions of hydrogen peroxide and</span> <span class="cmti-10">hydroxymethyl hydroperoxide</span>, J. Geophys. Res., 98, 12 713–12 717, <a href="https://doi.org/10.1029/93JD01022" >doi:10.1029/93JD01022</a> (1993). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2958',
    'Staples et&nbsp;al. (1997)',
    'Staples, C. A., Peterson, D. R., Parkerton, T. F., &#x0026; Adams, W. J.: <span class="cmti-10">The</span> <span class="cmti-10">environmental fate of phthalate esters: A literature review</span>, Chemosphere, 35, 667–749, <a href="https://doi.org/10.1016/S0045-6535(97)00195-1" >doi:10.1016/S0045-6535(97)00195-1</a> (1997). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '747',
    'Staudinger and Roberts (1996)',
    'Staudinger, J. &#x0026; Roberts, P. V.: <span class="cmti-10">A critical</span> <span class="cmti-10">review of Henry&#x2019;s</span> <span class="cmti-10">law constants for environmental applications</span>, Crit. Rev. Environ. Sci. Technol., 26, 205–297, <a href="https://doi.org/10.1080/10643389609388492" >doi:10.1080/10643389609388492</a> (1996). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1525',
    'Staudinger and Roberts (2001)',
    'Staudinger, J. &#x0026; Roberts, P. V.: <span class="cmti-10">A critical</span> <span class="cmti-10">compilation of Henry&#x2019;s law constant temperature dependence relations</span> <span class="cmti-10">for organic compounds in dilute aqueous solutions</span>, Chemosphere, 44, 561–576, <a href="https://doi.org/10.1016/S0045-6535(00)00505-1" >doi:10.1016/S0045-6535(00)00505-1</a> (2001). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2441',
    'Steward et&nbsp;al. (1973)',
    'Steward, A., Allott, P. R., Cowles, A. L., &#x0026; Mapleson, W. W.: <span class="cmti-10">Solubility</span> <span class="cmti-10">coefficients for inhaled anaesthetics for water, oil and biological media</span>, Br. J. Anaesth., 45, 282–293, <a href="https://doi.org/10.1093/BJA/45.3.282" >doi:10.1093/BJA/45.3.282</a> (1973). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2933',
    'Stock and Kuß (1917)',
    'Stock, A. &#x0026; Kuß, E.: <span class="cmti-10">Zur Kenntnis des Kohlenoxysulfides COS</span>, Ber. Dtsch. Chem. Ges., 50, 159–164, <a href="https://doi.org/10.1002/CBER.19170500125" >doi:10.1002/CBER.19170500125</a> (1917). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2467',
    'Stoelting and Longshore (1972)',
    'Stoelting, R. K. &#x0026; Longshore, R. E.: <span class="cmti-10">The</span> <span class="cmti-10">effects of</span> <span class="cmti-10">temperature on fluroxene, halothane, and methoxyflurane blood-gas and</span> <span class="cmti-10">cerebrospinal fluid-gas partition coefficients</span>, Anesthesiology, 36, 503–505, <a href="https://doi.org/10.1097/00000542-197205000-00018" >doi:10.1097/00000542-197205000-00018</a> (1972). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1937',
    'Straver and de Loos (2005)',
    'Straver, E. J. M. &#x0026; de Loos, T. W.: <span class="cmti-10">Determination of Henry&#x2019;s law constants and activity</span> <span class="cmti-10">coefficients at infinite dilution of flavor compounds in water at 298 </span>K <span class="cmti-10">with a gas-chromatographic method</span>, J. Chem. Eng. Data, 50, 1171–1176, <a href="https://doi.org/10.1021/JE0495942" >doi:10.1021/JE0495942</a> (2005). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1571',
    'Strekowski and George (2005)',
    'Strekowski, R. S. &#x0026; George, C.: <span class="cmti-10">Measurement</span> <span class="cmti-10">of Henry&#x2019;s law constants for acetone, 2-butanone, 2,3-butanedione and</span> <span class="cmti-10">isobutyraldehyde using a horizontal flow reactor</span>, J. Chem. Eng. Data, 50, 804–810, <a href="https://doi.org/10.1021/JE034137R" >doi:10.1021/JE034137R</a> (2005). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3592',
    'Stumm (1958)',
    'Stumm, W.: <span class="cmti-10">Ozone as a disinfectant for water and sewage</span>, J. Boston Soc. Civil Eng., 45, 68–79 (1958). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '997',
    'Suleimenov and Krupp (1994)',
    'Suleimenov, O. M. &#x0026; Krupp, R. E.: <span class="cmti-10">Solubility</span> <span class="cmti-10">of hydrogen sulfide in pure water and in</span> NaCl <span class="cmti-10">solutions, from 20 to 320</span><span class="cmsy-7">∘</span>C <span class="cmti-10">and at saturation pressures</span>, Geochim. Cosmochim. Acta, 58, 2433–2444, <a href="https://doi.org/10.1016/0016-7037(94)90022-1" >doi:10.1016/0016-7037(94)90022-1</a> (1994). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1157',
    'Suntio et&nbsp;al. (1988)',
    'Suntio, L. R., Shiu, W. Y., Mackay, D., Seiber, J. N., &#x0026; Glotfelty, D.: <span class="cmti-10">Critical</span> <span class="cmti-10">review of Henry&#x2019;s law constants for pesticides</span>, Rev. Environ. Contam. Toxicol., 103, 1–59, <a href="https://doi.org/10.1007/978-1-4612-3850-8_1" >doi:10.1007/978-1-4612-3850-8_1</a> (1988). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1162',
    'Suzuki et&nbsp;al. (1992)',
    'Suzuki, T., Ohtaguchi, K., &#x0026; Koide, K.: <span class="cmti-10">Application of principal components analysis to calculate</span> <span class="cmti-10">Henry&#x2019;s constant from molecular structure</span>, Comput. Chem., 16, 41–52, <a href="https://doi.org/10.1016/0097-8485(92)85007-L" >doi:10.1016/0097-8485(92)85007-L</a> (1992). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1340',
    'Swain and Thornton (1962)',
    'Swain, C. G. &#x0026; Thornton, E. R.: <span class="cmti-10">Initial-state</span> <span class="cmti-10">and transition-state isotope effects of methyl halides in light and heavy</span> <span class="cmti-10">water</span>, J. Am. Chem. Soc., 84, 822–826, <a href="https://doi.org/10.1021/JA00864A029" >doi:10.1021/JA00864A029</a> (1962). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3703',
    'Sy and Hasbrouck (1964)',
    'Sy, W. P. &#x0026; Hasbrouck, J. D.: <span class="cmti-10">Solubility of</span> <span class="cmti-10">nitrous oxide in water and in canine blood</span>, Anesthesiology, 25, 59–63, <a href="https://doi.org/10.1097/00000542-196401000-00010" >doi:10.1097/00000542-196401000-00010</a> (1964). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2451',
    'Tabai et&nbsp;al. (1997)',
    'Tabai, S., Rogalski, M., Solimando, R., &#x0026; Malanowski, S. K.: <span class="cmti-10">Activity coefficients</span> <span class="cmti-10">of chlorophenols in water at infinite dilution</span>, J. Chem. Eng. Data, 42, 1147–1150, <a href="https://doi.org/10.1021/JE960336H" >doi:10.1021/JE960336H</a> (1997). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2531',
    'Taft et&nbsp;al. (1985)',
    'Taft, R. W., Abraham, M. H., Doherty, R. M., &#x0026; Kamlet, M. J.: <span class="cmti-10">The</span> <span class="cmti-10">molecular properties governing solubilities of organic nonelectrolytes in</span> <span class="cmti-10">water</span>, Nature, 313, 384–386, <a href="https://doi.org/10.1038/313384A0" >doi:10.1038/313384A0</a> (1985). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2289',
    'Talmi and Mesmer (1975)',
    'Talmi, Y. &#x0026; Mesmer, R. E.: <span class="cmti-10">Studies on vaporization and halogen decomposition</span> <span class="cmti-10">of methyl mercury compounds using gc with a microwave detector</span>, Wat. Res., 9, 547–552, <a href="https://doi.org/10.1016/0043-1354(75)90080-9" >doi:10.1016/0043-1354(75)90080-9</a> (1975). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '598',
    'Tancrède and Yanagisawa (1990)',
    'Tancrède, M. V. &#x0026; Yanagisawa, Y.: <span class="cmti-10">An</span> <span class="cmti-10">analytical method to determine Henry&#x2019;s law constant for selected volatile</span> <span class="cmti-10">organic compounds at concentrations and temperatures corresponding</span> <span class="cmti-10">to tap water use</span>, J. Air Waste Manage. Assoc., 40, 1658–1663, <a href="https://doi.org/10.1080/10473289.1990.10466813" >doi:10.1080/10473289.1990.10466813</a> (1990). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3966',
    'Taube and Dodgen (1949)',
    'Taube, H. &#x0026; Dodgen, H.: <span class="cmti-10">Applications of</span> <span class="cmti-10">radioactive chlorine to the study of the mechanisms of reactions involving</span> <span class="cmti-10">changes in the oxidation state of chlorine</span>, J. Am. Chem. Soc., 71, 3330–3336, <a href="https://doi.org/10.1021/JA01178A016" >doi:10.1021/JA01178A016</a> (1949). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3132',
    'Teja et&nbsp;al. (2001)',
    'Teja, A. S., Gupta, A. K., Bullock, K., Chai, X.-S., &#x0026; Zhu, J.: <span class="cmti-10">Henry&#x2019;s constants of methanol</span> <span class="cmti-10">in aqueous systems containing salts</span>, Fluid Phase Equilib., 185, 265–274, <a href="https://doi.org/10.1016/S0378-3812(01)00476-9" >doi:10.1016/S0378-3812(01)00476-9</a> (2001). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2807',
    'Templeton and King (1971)',
    'Templeton, J. C. &#x0026; King, E. L.: <span class="cmti-10">Kinetic and</span> <span class="cmti-10">equilibrium studies on azidochromium(III) ion in concentrated perchloric</span> <span class="cmti-10">acid</span>, J. Am. Chem. Soc., 93, 7160–7166, <a href="https://doi.org/10.1021/JA00755A009" >doi:10.1021/JA00755A009</a> (1971). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1146',
    'ten Hulscher et&nbsp;al. (1992)',
    'ten Hulscher, T. E. M., van der Velde, L. E., &#x0026; Bruggeman, W. A.: <span class="cmti-10">Temperature dependence</span> <span class="cmti-10">of Henry&#x2019;s law constants for selected chlorobenzenes, polychlorinated</span> <span class="cmti-10">biphenyls and polycyclic aromatic hydrocarbons</span>, Environ. Toxicol. Chem., 11, 1595–1603, <a href="https://doi.org/10.1002/ETC.5620111109" >doi:10.1002/ETC.5620111109</a> (1992). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3122',
    'Terraglio and Manganelli (1967)',
    'Terraglio, F. P. &#x0026; Manganelli, R. M.: <span class="cmti-10">The</span> <span class="cmti-10">absorption of atmospheric sulfur dioxide by water solutions</span>, J. Air Pollut. Control Assoc., 17, 403–406, <a href="https://doi.org/10.1080/00022470.1967.10468999" >doi:10.1080/00022470.1967.10468999</a> (1967). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3948',
    'Thomas et&nbsp;al. (2006)',
    'Thomas, J. E., Ou, L.-T., Allen Jr., L. H., Vu, J. C., &#x0026; Dickson, D. W.: <span class="cmti-10">Henry&#x2019;s law constants and mass transfer coefficients for methyl bromide</span> <span class="cmti-10">and 1,3-dichloropropene applied to Florida sandy field soil</span>, Chemosphere, 62, 980–988, <a href="https://doi.org/10.1016/J.CHEMOSPHERE.2005.06.017" >doi:10.1016/J.CHEMOSPHERE.2005.06.017</a> (2006). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '895',
    'Thomas et&nbsp;al. (1998)',
    'Thomas, K., Volz-Thomas, A., Mihelcic, D., Smit, H. G. J., &#x0026; Kley, D.: <span class="cmti-10">On the exchange of</span> NO<sub><span class="cmr-7">3</span></sub> <span class="cmti-10">radicals with aqueous solutions:</span> <span class="cmti-10">Solubility and sticking coefficient</span>, J. Atmos. Chem., 29, 17–43, <a href="https://doi.org/10.1023/A:1005860312363" >doi:10.1023/A:1005860312363</a> (1998). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '203',
    'Thompson and Zafiriou (1983)',
    'Thompson, A. M. &#x0026; Zafiriou, O. C.: <span class="cmti-10">Air-sea</span> <span class="cmti-10">fluxes of transient atmospheric species</span>, J. Geophys. Res., 88, 6696–6708, <a href="https://doi.org/10.1029/JC088IC11P06696" >doi:10.1029/JC088IC11P06696</a> (1983). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3680',
    'Thompson et&nbsp;al. (2018)',
    'Thompson, J. G., Matin, N. S., Abad, K., Onneweer, F., Bhatnagar, S., &#x0026; Liu, K.: <span class="cmti-10">Determining the Henry&#x2019;s volatility coefficient of nitrosamines</span> <span class="cmti-10">in</span> CO<sub><span class="cmr-7">2</span></sub> <span class="cmti-10">capture solvents</span>, Int. J. Greenhouse Gas Control, 73, 104–110, <a href="https://doi.org/10.1016/J.IJGGC.2018.04.004" >doi:10.1016/J.IJGGC.2018.04.004</a> (2018). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    'timmermans60',
    'Timmermans (1960)',
    'Timmermans, J.: The Physico-Chemical Constants of Binary Systems in Concentrated Solutions, Vol. 4, Interscience Publisher, Inc., New York, NY (1960). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3712',
    'Timofejew (1890)',
    'Timofejew, W.: <span class="cmti-10">Über die Absorption von Wasserstoff</span> <span class="cmti-10">und Sauerstoff in Wasser und Alkohol</span>, Z. Phys. Chem., 6, 141–152, <a href="https://doi.org/10.1515/ZPCH-1890-0614" >doi:10.1515/ZPCH-1890-0614</a> (1890). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2494',
    'Tittlemier et&nbsp;al. (2002)',
    'Tittlemier, S. A., Halldorson, T., Stern, G. A., &#x0026; Tomy, G. T.: <span class="cmti-10">Vapor</span> <span class="cmti-10">pressures, aqueous solubilities, and Henry&#x2019;s law constants of some</span> <span class="cmti-10">brominated flame retardants</span>, Environ. Toxicol. Chem., 21, 1804–1810, <a href="https://doi.org/10.1002/ETC.5620210907" >doi:10.1002/ETC.5620210907</a> (2002). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2469',
    'Tittlemier et&nbsp;al. (2004)',
    'Tittlemier, S. A., Braekevelt, E., Halldorson, T., Reddy, C. M., &#x0026; Norstrom, R. J.: <span class="cmti-10">Vapour pressures, aqueous solubilities, Henry&#x2019;s</span> <span class="cmti-10">Law constants, and octanol/water partition coefficients of a series of</span> <span class="cmti-10">mixed halogenated dimethyl bipyrroles</span>, Chemosphere, 57, 1373–1381, <a href="https://doi.org/10.1016/J.CHEMOSPHERE.2004.08.061" >doi:10.1016/J.CHEMOSPHERE.2004.08.061</a> (2004). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    'tomlin98',
    'Tomlin (1998)',
    'Tomlin, C. D. S.: The Pesticide Manual, 11th Edition, British Crop Production Council, ISBN 1901396118 (1998). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2443',
    'Trampe and Eckert (1993)',
    'Trampe, D. B. &#x0026; Eckert, C. A.: <span class="cmti-10">A dew point</span> <span class="cmti-10">technique for limiting activity coefficients in nonionic solutions</span>, AIChE J., 39, 1045–1050, <a href="https://doi.org/10.1002/AIC.690390613" >doi:10.1002/AIC.690390613</a> (1993). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1155',
    'Tremp et&nbsp;al. (1993)',
    'Tremp, J., Mattrel, P., Fingler, S., &#x0026; Giger, W.: <span class="cmti-10">Phenols</span> <span class="cmti-10">and nitrophenols as tropospheric pollutants: Emissions from automobile</span> <span class="cmti-10">exhausts and phase transfer in the atmosphere</span>, Water Air Soil Pollut., 68, 113–123, <a href="https://doi.org/10.1007/BF00479396" >doi:10.1007/BF00479396</a> (1993). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1217',
    'Treves et&nbsp;al. (2000)',
    'Treves, K., Shragina, L., &#x0026; Rudich, Y.: <span class="cmti-10">Henry&#x2019;s law constants of some </span><span class="cmmi-10">β</span><span class="cmti-10">-, </span><span class="cmmi-10">γ</span><span class="cmti-10">-, and </span><span class="cmmi-10">δ</span><span class="cmti-10">-hydroxy</span> <span class="cmti-10">nitrates of atmospheric interest</span>, Environ. Sci. Technol., 34, 1197–1203, <a href="https://doi.org/10.1021/ES990558A" >doi:10.1021/ES990558A</a> (2000). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '856',
    'Tse et&nbsp;al. (1992)',
    'Tse, G., Orbey, H., &#x0026; Sandler, S. I.: <span class="cmti-10">Infinite dilution activity coefficients and Henry&#x2019;s law coefficients</span> <span class="cmti-10">of some priority water pollutants determined by a relative gas</span> <span class="cmti-10">chromatographic method</span>, Environ. Sci. Technol., 26, 2017–2022, <a href="https://doi.org/10.1021/ES00034A021" >doi:10.1021/ES00034A021</a> (1992). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2922',
    'Tsibul&#x2019;skii et&nbsp;al. (1979)',
    'Tsibul&#x2019;skii, V. V., Tsibul&#x2019;skaya, I. A., &#x0026; Yaglitskaya, N. N.: <span class="cmti-10">Sampling</span> <span class="cmti-10">and storage of samples for the gas-chromatographic Determination of</span> <span class="cmti-10">aromatic-hydrocarbons as microimpurities in gases</span>, J. Anal. Chem. USSR, 34, 1052–1055 (1979). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2911',
    'Tsonopoulos and Wilson (1983)',
    'Tsonopoulos, C. &#x0026; Wilson, G. M.: <span class="cmti-10">High-temperature mutual solubilities</span> <span class="cmti-10">of hydrocarbons and water. Part I: Benzene, cyclohexane and </span><span class="cmmi-10">n</span><span class="cmti-10">-hexane</span>, AIChE J., 29, 990–999, <a href="https://doi.org/10.1002/AIC.690290618" >doi:10.1002/AIC.690290618</a> (1983). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3668',
    'Tsuji et&nbsp;al. (1990)',
    'Tsuji, M., Nakano, T., &#x0026; T.Okuno: <span class="cmti-10">Desorption of odor substances</span> <span class="cmti-10">from water bodies to the atmosphere</span>, Atmos. Environ., 24, 2019–2021, <a href="https://doi.org/10.1016/0960-1686(90)90236-G" >doi:10.1016/0960-1686(90)90236-G</a> (1990). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2980',
    'Tucker et&nbsp;al. (1981)',
    'Tucker, E. E., Lane, E. H., &#x0026; Christian, S. D.: <span class="cmti-10">Vapor pressure studies of hydrophobic interactions. formation of</span> <span class="cmti-10">benzene-benzene and cyclohexane-cyclohexanol dimers in dilute aqueous</span> <span class="cmti-10">solution</span>, J. Solution Chem., 10, 1–20, <a href="https://doi.org/10.1007/BF00652776" >doi:10.1007/BF00652776</a> (1981). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2463',
    'Turner et&nbsp;al. (1996)',
    'Turner, L. H., Chiew, Y. C., Ahlert, R. C., &#x0026; Kosson, D. S.: <span class="cmti-10">Measuring vapor-liquid</span> <span class="cmti-10">equilibrium for aqueous-organic systems: Review and a new technique</span>, AIChE J., 42, 1772–1788, <a href="https://doi.org/10.1002/AIC.690420629" >doi:10.1002/AIC.690420629</a> (1996). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1516',
    'Ueberfeld et&nbsp;al. (2001)',
    'Ueberfeld, J., Zbinden, H., Gisin, N., &#x0026; Pellaux, J. P.: <span class="cmti-10">Determination of Henry&#x2019;s</span> <span class="cmti-10">constant using a photoacoustic sensor</span>, J. Chem. Thermodyn., 33, 755–764, <a href="https://doi.org/10.1006/JCHT.2000.0776" >doi:10.1006/JCHT.2000.0776</a> (2001). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    'vankrevelen49',
    'Van Krevelen et&nbsp;al. (1949)',
    'Van Krevelen, D. W., Hoftijzer, P. J., &#x0026; Huntjens, F. J.: <span class="cmti-10">Composition</span> <span class="cmti-10">and vapor pressures of aqueous solutions of ammonia, carbon dioxide and</span> <span class="cmti-10">hydrogen sulfide</span>, Recl. Trav. Chim. Pays-Bas, 68, 191–216 (1949). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2125',
    'van Roon et&nbsp;al. (2005)',
    'van Roon, A., Parsons, J. R., Kloeze, A. M. T., &#x0026; Govers, H. A. J.: <span class="cmti-10">Fate and transport of monoterpenes through soils. Part I. Prediction of</span> <span class="cmti-10">temperature dependent soil fate model input-parameters</span>, Chemosphere, 61, 599–609, <a href="https://doi.org/10.1016/J.CHEMOSPHERE.2005.02.081" >doi:10.1016/J.CHEMOSPHERE.2005.02.081</a> (2005). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3670',
    'van Ruth and Villeneuve (2002)',
    'van Ruth, S. M. &#x0026; Villeneuve, E.: <span class="cmti-10">Influence</span> <span class="cmti-10">of </span><span class="cmmi-10">β</span><span class="cmti-10">-lactoglobulin, pH and presence of other aroma compounds on</span> <span class="cmti-10">the air/liquid partition coefficients of 20 aroma compounds varying</span> <span class="cmti-10">in functional group and chain length</span>, Food Chem., 79, 157–164, <a href="https://doi.org/10.1016/S0308-8146(02)00124-3" >doi:10.1016/S0308-8146(02)00124-3</a> (2002). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3611',
    'van Ruth et&nbsp;al. (2001)',
    'van Ruth, S. M., Grossmann, I., Geary, M., &#x0026; Delahunty, C. M.: <span class="cmti-10">Interactions</span> <span class="cmti-10">between artificial saliva and 20 aroma compounds in water and oil model</span> <span class="cmti-10">systems</span>, J. Agric. Food Chem., 49, 2409–2413, <a href="https://doi.org/10.1021/JF001510F" >doi:10.1021/JF001510F</a> (2001). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3643',
    'van Ruth et&nbsp;al. (2002)',
    'van Ruth, S. M., de Vries, G., Geary, M., &#x0026; Giannouli, P.: <span class="cmti-10">Influence of composition</span> <span class="cmti-10">and structure of oil-in-water emulsions on retention of aroma</span> <span class="cmti-10">compounds</span>, J. Sci. Food Agric., 82, 1028–1035, <a href="https://doi.org/10.1002/JSFA.1137" >doi:10.1002/JSFA.1137</a> (2002). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3707',
    'Van Slyke et&nbsp;al. (1934)',
    'Van Slyke, D. D., Dillon, R. T., &#x0026; Margaria, R.: <span class="cmti-10">Studies of gas and electrolyte</span> <span class="cmti-10">equilibria in blood: XVIII. Solubility and physical state of atmospheric</span> <span class="cmti-10">nitrogen in blood cells and plasma</span>, J. Biol. Chem., 105, 571–596, <a href="https://doi.org/10.1016/S0021-9258(18)75528-2" >doi:10.1016/S0021-9258(18)75528-2</a> (1934). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2896',
    'Vane and Giroux (2000)',
    'Vane, L. M. &#x0026; Giroux, E. L.: <span class="cmti-10">Henry&#x2019;s law constants</span> <span class="cmti-10">and micellar partitioning of volatile organic compounds in surfactant</span> <span class="cmti-10">solutions</span>, J. Chem. Eng. Data, 45, 38–47, <a href="https://doi.org/10.1021/JE990195U" >doi:10.1021/JE990195U</a> (2000). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3582',
    'Vasilakos et&nbsp;al. (2021)',
    'Vasilakos, P., Hu, Y., Russell, A., &#x0026; Nenes, A.: <span class="cmti-10">Determining the role of acidity, fate</span> <span class="cmti-10">and formation of IEPOX-derived SOA in CMAQ</span>, Atmos., 12, 707, <a href="https://doi.org/10.3390/ATMOS12060707" >doi:10.3390/ATMOS12060707</a> (2021). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '995',
    'Villalta et&nbsp;al. (1996)',
    'Villalta, P. W., Lovejoy, E. R., &#x0026; Hanson, D. R.: <span class="cmti-10">Reaction probability of peroxyacetyl</span> <span class="cmti-10">radical on aqueous surfaces</span>, Geophys. Res. Lett., 23, 1765–1768, <a href="https://doi.org/10.1029/96GL01286" >doi:10.1029/96GL01286</a> (1996). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2925',
    'Vitenberg and Dobryakov (2008)',
    'Vitenberg, A. G. &#x0026; Dobryakov, Y. G.: <span class="cmti-10">Gas-chromatographic determination of the distribution ratios of volatile</span> <span class="cmti-10">substances in gas-liquid systems</span>, Russ. J. Appl. Chem., 81, 339–359, <a href="https://doi.org/10.1134/S1070427208030014" >doi:10.1134/S1070427208030014</a> (2008). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1492',
    'Vitenberg et&nbsp;al. (1974)',
    'Vitenberg, A. G., Ioffe, B. V., &#x0026; Borisov, V. N.: <span class="cmti-10">Application of phase equilibria to gas chromatographic</span> <span class="cmti-10">trace analysis</span>, Chromatographia, 7, 610–619, <a href="https://doi.org/10.1007/BF02269053" >doi:10.1007/BF02269053</a> (1974). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '728',
    'Vitenberg et&nbsp;al. (1975)',
    'Vitenberg, A. G., Ioffe, B. V., Dimitrova, Z. S., &#x0026; Butaeva, I. L.: <span class="cmti-10">Determination of</span> <span class="cmti-10">gas-liquid partition coefficients by means of gas chromatographic analysis</span>, J. Chromatogr., 112, 319–327, <a href="https://doi.org/10.1016/S0021-9673(00)99964-3" >doi:10.1016/S0021-9673(00)99964-3</a> (1975). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '446',
    'Vogt et&nbsp;al. (1996)',
    'Vogt, R., Crutzen, P. J., &#x0026; Sander, R.: <span class="cmti-10">A mechanism for halogen release from sea-salt aerosol</span> <span class="cmti-10">in the remote marine boundary layer</span>, Nature, 383, 327–330, <a href="https://doi.org/10.1038/383327A0" >doi:10.1038/383327A0</a> (1996). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '897',
    'Vogt et&nbsp;al. (1999)',
    'Vogt, R., Sander, R., von Glasow, R., &#x0026; Crutzen, P. J.: <span class="cmti-10">Iodine chemistry and its role in</span> <span class="cmti-10">halogen activation and ozone loss in the marine boundary layer: A model</span> <span class="cmti-10">study</span>, J. Atmos. Chem., 32, 375–395, <a href="https://doi.org/10.1023/A:1006179901037" >doi:10.1023/A:1006179901037</a> (1999). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3134',
    'Volkamer et&nbsp;al. (2009)',
    'Volkamer, R., Ziemann, P. J., &#x0026; Molina, M. J.: <span class="cmti-10">Secondary organic</span> <span class="cmti-10">aerosol formation from acetylene (</span>C<sub><span class="cmr-7">2</span></sub>H<sub><span class="cmr-7">2</span></sub><span class="cmti-10">): seed effect on SOA yields due</span> <span class="cmti-10">to organic photochemistry in the aerosol aqueous phase</span>, Atmos. Chem. Phys., 9, 1907–1928, <a href="https://doi.org/10.5194/ACP-9-1907-2009" >doi:10.5194/ACP-9-1907-2009</a> (2009). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3714',
    'von Antropoff (1910)',
    'von Antropoff, A.: <span class="cmti-10">The solubility of xenon, krypton,</span> <span class="cmti-10">argon, neon, and helium in water</span>, Proc. R. Soc. Lond. A, 83, 474–482, <a href="https://doi.org/10.1098/RSPA.1910.0036" >doi:10.1098/RSPA.1910.0036</a> (1910). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1721',
    'von Hartungen et&nbsp;al. (2004)',
    'von Hartungen, E., Wisthaler, A., Mikoviny, T., Jaksch, D., Boscaini, E., Dunphy, P. J., &#x0026; Märk, T. D.: <span class="cmti-10">Proton-transfer-reaction mass</span> <span class="cmti-10">spectrometry (PTR-MS) of carboxylic acids. Determination of Henry&#x2019;s</span> <span class="cmti-10">law constants and axillary odour investigations</span>, Int. J. Mass Spectrom., 239, 243–248, <a href="https://doi.org/10.1016/J.IJMS.2004.09.009" >doi:10.1016/J.IJMS.2004.09.009</a> (2004). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3551',
    'Vrabec et&nbsp;al. (2001)',
    'Vrabec, J., Stoll, J., &#x0026; Hasse, H.: <span class="cmti-10">A set of molecular models for symmetric quadrupolar fluids</span>, J. Phys. Chem. B, 105, 12 126–12 133, <a href="https://doi.org/10.1021/JP012542O" >doi:10.1021/JP012542O</a> (2001). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    'vitovec68',
    'Vtovec (1968)',
    'Vtovec, J.: <span class="cmti-10">Absorption of acetylene and carbon dioxide in</span> <span class="cmti-10">water, xylene and methanol in a packed column</span>, Collect. Czech. Chem. Commun., 33, 1203–1210, <a href="https://doi.org/10.1135/CCCC19681203" >doi:10.1135/CCCC19681203</a> (1968). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '489',
    'Wagman et&nbsp;al. (1982)',
    'Wagman, D. D., Evans, W. H., Parker, V. B., Schumm, R. H., Halow, I., Bailey, S. M., Churney, K. L., &#x0026; Nuttall, R. L.: <span class="cmti-10">The NBS tables of</span> <span class="cmti-10">chemical thermodynamic properties; Selected values for inorganic and</span> C<sub><span class="cmr-7">1</span></sub> <span class="cmti-10">and</span> C<sub><span class="cmr-7">2</span></sub> <span class="cmti-10">organic substances in SI units</span>, J. Phys. Chem. Ref. Data, 11, suppl. 2, URL https://srd.nist.gov/JPCRD/jpcrdS2Vol11.pdf (1982). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2555',
    'Wagner and Pruss (1993)',
    'Wagner, W. &#x0026; Pruss, A.: <span class="cmti-10">International equations</span> <span class="cmti-10">for the saturation properties of ordinary water substance. Revised</span> <span class="cmti-10">according to the international temperature scale of 1990. Addendum to</span> <span class="cmti-10">J.</span><span class="cmti-10"> Phys.</span><span class="cmti-10"> Chem.</span><span class="cmti-10"> Ref.</span><span class="cmti-10"> Data 16, 893 (1987)</span>, J. Phys. Chem. Ref. Data, 22, 783–787, <a href="https://doi.org/10.1063/1.555926" >doi:10.1063/1.555926</a> (1993). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3409',
    'Wang et&nbsp;al. (2017)',
    'Wang, C., Yuan, T., Wood, S. A., Goss, K.-U., Li, J., Ying, Q., &#x0026; Wania, F.: <span class="cmti-10">Uncertain Henry&#x2019;s law constants compromise equilibrium partitioning</span> <span class="cmti-10">calculations of atmospheric oxidation products</span>, Atmos. Chem. Phys., 17, 7529–7540, <a href="https://doi.org/10.5194/ACP-17-7529-2017" >doi:10.5194/ACP-17-7529-2017</a> (2017). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '318',
    'Wang et&nbsp;al. (1994)',
    'Wang, T. X., Kelley, M. D., Cooper, J. N., Beckwith, R. C., &#x0026; Margerum, D. W.: <span class="cmti-10">Equilibrium, kinetic, and UV-spectral characteristics of aqueous</span> <span class="cmti-10">bromine chloride, bromine, and chlorine species</span>, Inorg. Chem., 33, 5872–5878, <a href="https://doi.org/10.1021/IC00103A040" >doi:10.1021/IC00103A040</a> (1994). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2949',
    'Wang and Wong (2002)',
    'Wang, Y. H. &#x0026; Wong, P. K.: <span class="cmti-10">Mathematical</span> <span class="cmti-10">relationships between vapor pressure, water solubility, Henry&#x2019;s law</span> <span class="cmti-10">constant, </span><span class="cmmi-10">n</span><span class="cmti-10">-octanol/water partition coefficent and gas chromatographic</span> <span class="cmti-10">retention index of polychlorinated-dibenzo-dioxins</span>, Wat. Res., 36, 350–355, <a href="https://doi.org/10.1016/S0043-1354(01)00192-0" >doi:10.1016/S0043-1354(01)00192-0</a> (2002). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2536',
    'Wania and Dugani (2003)',
    'Wania, F. &#x0026; Dugani, C. B.: <span class="cmti-10">Assessing the</span> <span class="cmti-10">long-range transport potential of polybrominated diphenyl ethers: A</span> <span class="cmti-10">comparison of four multimedia models</span>, Environ. Toxicol. Chem., 22, 1252–1261, <a href="https://doi.org/10.1002/ETC.5620220610" >doi:10.1002/ETC.5620220610</a> (2003). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '67',
    'Warneck (1988)',
    'Warneck, P.: Chemistry of the Natural Atmosphere, Acad., San Diego, CA, ISBN 0127356304 (1988). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1257',
    'Warneck (1999)',
    'Warneck, P.: <span class="cmti-10">The relative importance of various pathways</span> <span class="cmti-10">for the oxidation of sulfur dioxide and nitrogen dioxide in sunlit</span> <span class="cmti-10">continental fair weather clouds</span>, Phys. Chem. Chem. Phys., 1, 5471–5483, <a href="https://doi.org/10.1039/A906558J" >doi:10.1039/A906558J</a> (1999). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2432',
    'Warneck (2003)',
    'Warneck, P.: <span class="cmti-10">The solubility of ozone in water</span>, in: Chemicals in the Atmosphere: Solubility, Sources and Reactivity, edited by Fogg, P. &#x0026; Sangster, J., pp. 225–228, John Wiley &#x0026; Sons, Inc., ISBN 978-0-471-98651-5 (2003). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2212',
    'Warneck (2005)',
    'Warneck, P.: <span class="cmti-10">Multi-phase chemistry of</span> C<sub><span class="cmr-7">2</span></sub> <span class="cmti-10">and</span> C<sub><span class="cmr-7">3</span></sub> <span class="cmti-10">organic</span> <span class="cmti-10">compounds in the marine atmosphere</span>, J. Atmos. Chem., 51, 119–159, <a href="https://doi.org/10.1007/S10874-005-5984-7" >doi:10.1007/S10874-005-5984-7</a> (2005). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1831',
    'Warneck (2006)',
    'Warneck, P.: <span class="cmti-10">A note on the temperature dependence of</span> <span class="cmti-10">Henry&#x2019;s Law coefficients for methanol and ethanol</span>, Atmos. Environ., 40, 7146–7151, <a href="https://doi.org/10.1016/J.ATMOSENV.2006.06.024" >doi:10.1016/J.ATMOSENV.2006.06.024</a> (2006). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1855',
    'Warneck (2007)',
    'Warneck, P.: <span class="cmti-10">A review of Henry&#x2019;s law coefficients for</span> <span class="cmti-10">chlorine-containing</span> C<sub><span class="cmr-7">1</span></sub> <span class="cmti-10">and</span> C<sub><span class="cmr-7">2</span></sub> <span class="cmti-10">hydrocarbons</span>, Chemosphere, 69, 347–361, <a href="https://doi.org/10.1016/J.CHEMOSPHERE.2007.04.088" >doi:10.1016/J.CHEMOSPHERE.2007.04.088</a> (2007). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2828',
    'Warneck and Williams (2012)',
    'Warneck, P. &#x0026; Williams, J.: The Atmospheric Chemist&#x2019;s Companion: Numerical Data for Use in the Atmospheric Sciences, Springer Verlag, <a href="https://doi.org/10.1007/978-94-007-2275-0" >doi:10.1007/978-94-007-2275-0</a> (2012). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '669',
    'Warneck et&nbsp;al. (1996)',
    'Warneck, P., Mirabel, P., Salmon, G. A., van Eldik, R., Vinckier, C., Wannowius, K. J., &#x0026; Zetzsch, C.: <span class="cmti-10">Chapter 2: Review of the</span> <span class="cmti-10">activities and achievements of the EUROTRAC subproject HALIPP</span>, in: Heterogeneous and Liquid-Phase Processes, edited by Warneck, P., pp. 7–74, Springer Verlag, Berlin, <a href="https://doi.org/10.1007/978-3-642-61445-3_2" >doi:10.1007/978-3-642-61445-3_2</a> (1996). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2900',
    'Warner et&nbsp;al. (1980)',
    'Warner, H. P., Cohen, J. M., &#x0026; Ireland, J. C.: <span class="cmti-10">Determination of Henry&#x2019;s</span> <span class="cmti-10">law constants of selected priority pollutants</span>, Tech. rep., U.S. EPA, Municipal Environmental Research Laboratory, Wastewater Research Division, Cincinnati, Ohio, 45268, USA (1980). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2240',
    'Warner and Weiss (1985)',
    'Warner, M. J. &#x0026; Weiss, R. F.: <span class="cmti-10">Solubilities of</span> <span class="cmti-10">chlorofluorocarbons 11 and 12 in water and seawater</span>, Deep-Sea Res. A, 32, 1485–1497 (1985). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3550',
    'Warr et&nbsp;al. (2015)',
    'Warr, O., Ballentine, C. J., Mu, J., &#x0026; Masters, A.: <span class="cmti-10">Optimizing noble gas-water interactions</span> <span class="cmti-10">via Monte Carlo simulations</span>, J. Phys. Chem. B, 119, 14 486–14 495, <a href="https://doi.org/10.1021/ACS.JPCB.5B06389" >doi:10.1021/ACS.JPCB.5B06389</a> (2015). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '791',
    'Wasik and Tsang (1970)',
    'Wasik, S. P. &#x0026; Tsang, W.: <span class="cmti-10">Gas chromatographic</span> <span class="cmti-10">determination of partition coefficients of some unsaturated hydrocarbons</span> <span class="cmti-10">and their deuterated isomers in aqueous silver nitrate solutions</span>, J. Phys. Chem., 74, 2970–2976, <a href="https://doi.org/10.1021/J100709A023" >doi:10.1021/J100709A023</a> (1970). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2538',
    'Watanabe (1993)',
    'Watanabe, T.: <span class="cmti-10">Relationship between volatilization rates</span> <span class="cmti-10">and physicochemical properties of some pesticides</span>, J. Pestic. Sci., 18, 201–209, <a href="https://doi.org/10.1584/JPESTICS.18.3_201" >doi:10.1584/JPESTICS.18.3_201</a> (1993). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '824',
    'Watts and Brimblecombe (1987)',
    'Watts, S. F. &#x0026; Brimblecombe, P.: <span class="cmti-10">The</span> <span class="cmti-10">Henry&#x2019;s law constant of dimethyl sulphoxide</span>, Environ. Technol. Lett., 8, 483–486, <a href="https://doi.org/10.1080/09593338709384509" >doi:10.1080/09593338709384509</a> (1987). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2375',
    'Wauchope and Haque (1972)',
    'Wauchope, R. D. &#x0026; Haque, R.: <span class="cmti-10">Aqueous</span> <span class="cmti-10">solutions of nonpolar compounds. Heat-capacity effects</span>, Can. J. Chem., 50, 133–138, <a href="https://doi.org/10.1139/V72-022" >doi:10.1139/V72-022</a> (1972). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2537',
    'Webster et&nbsp;al. (1985)',
    'Webster, G. R. B., Friesen, K. J., Sarna, L. P., &#x0026; Muir, D. C. G.: <span class="cmti-10">Environmental</span> <span class="cmti-10">fate modelling of chlorodioxins: Determination of physical constants</span>, Chemosphere, 14, 609–622, <a href="https://doi.org/10.1016/0045-6535(85)90169-9" >doi:10.1016/0045-6535(85)90169-9</a> (1985). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '205',
    'Weinstein-Lloyd and Schwartz (1991)',
    'Weinstein-Lloyd, J. &#x0026; Schwartz, S. E.: <span class="cmti-10">Low-intensity radiolysis study of free-radical reactions in cloudwater:</span> H<sub><span class="cmr-7">2</span></sub>O<sub><span class="cmr-7">2</span></sub> <span class="cmti-10">production and destruction</span>, Environ. Sci. Technol., 25, 791–800, <a href="https://doi.org/10.1021/ES00016A027" >doi:10.1021/ES00016A027</a> (1991). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3746',
    'Weisenberger and Schumpe (1996)',
    'Weisenberger, S. &#x0026; Schumpe, A.: <span class="cmti-10">Estimation of gas solubilities in salt</span> <span class="cmti-10">solutions at temperatures from 273K to 363K</span>, AIChE J., 42, 298–300, <a href="https://doi.org/10.1002/AIC.690420130" >doi:10.1002/AIC.690420130</a> (1996). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1779',
    'Weiss (1974)',
    'Weiss, R. F.: <span class="cmti-10">Carbon dioxide in water and seawater:</span> <span class="cmti-10">The solubility of a non-ideal gas</span>, Mar. Chem., 2, 203–215, <a href="https://doi.org/10.1016/0304-4203(74)90015-2" >doi:10.1016/0304-4203(74)90015-2</a> (1974). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2832',
    'Weiss and Price (1980)',
    'Weiss, R. F. &#x0026; Price, B. A.: <span class="cmti-10">Nitrous oxide solubility in water and seawater</span>, Mar. Chem., 8, 347–359, <a href="https://doi.org/10.1016/0304-4203(80)90024-9" >doi:10.1016/0304-4203(80)90024-9</a> (1980). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3646',
    'Welke et&nbsp;al. (1998)',
    'Welke, B., Ettlinger, K., &#x0026; Riederer, M.: <span class="cmti-10">Sorption of volatile organic chemicals in plant surfaces</span>, Environ. Sci. Technol., 32, 1099–1104, <a href="https://doi.org/10.1021/ES970763V" >doi:10.1021/ES970763V</a> (1998). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2484',
    'Wen and Muccitelli (1979)',
    'Wen, W.-Y. &#x0026; Muccitelli, J. A.: <span class="cmti-10">Thermodynamics of some perfluorocarbon gases in</span> <span class="cmti-10">water</span>, J. Solution Chem., 8, 225–246, <a href="https://doi.org/10.1007/BF00648882" >doi:10.1007/BF00648882</a> (1979). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '849',
    'Westcott et&nbsp;al. (1981)',
    'Westcott, J. W., Simon, C. G., &#x0026; Bidleman, T. F.: <span class="cmti-10">Determination of polychlorinated</span> <span class="cmti-10">biphenyl vapor pressures by a semimicro gas saturation method</span>, Environ. Sci. Technol., 15, 1375–1378, <a href="https://doi.org/10.1021/ES00093A012" >doi:10.1021/ES00093A012</a> (1981). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '776',
    'Westheimer and Ingraham (1956)',
    'Westheimer, F. H. &#x0026; Ingraham, L. L.: <span class="cmti-10">The entropy of chelation</span>, J. Phys. Chem., 60, 1668–1670, <a href="https://doi.org/10.1021/J150546A024" >doi:10.1021/J150546A024</a> (1956). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3799',
    'Wetlaufer et&nbsp;al. (1964)',
    'Wetlaufer, D. B., Malik, S. K., Stoller, L., &#x0026; Coffin, R. L.: <span class="cmti-10">Nonpolar group</span> <span class="cmti-10">participation in the denaturation of proteins by urea and guanidinium</span> <span class="cmti-10">salts. Model compound studies</span>, J. Am. Chem. Soc., 86, 508–514, <a href="https://doi.org/10.1021/JA01057A045" >doi:10.1021/JA01057A045</a> (1964). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3541',
    'Whitney and Vivian (1941a)',
    'Whitney, R. P. &#x0026; Vivian, J. E.: <span class="cmti-10">Solubility of chlorine in water</span>, Ind. Eng. Chem., 33, 741–744, <a href="https://doi.org/10.1021/IE50378A014" >doi:10.1021/IE50378A014</a> (1941a). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3928',
    'Whitney and Vivian (1941b)',
    'Whitney, R. P. &#x0026; Vivian, J. E.: <span class="cmti-10">Solubility of</span> <span class="cmti-10">chlorine in water</span>, Pap. Trade J., 113, 31–32 (1941b). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3070',
    'WHO (1990)',
    'WHO: <span class="cmti-10">Environmental Health Criteria 101 – methylmercury</span>, Tech. rep., World Health Organization, URL https://www.inchem.org/documents/ehc/ehc/ehc101.htm (1990). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3215',
    'Wieland et&nbsp;al. (2015)',
    'Wieland, F., Neff, A., Gloess, A. N., Poisson, L., Atlan, S., Larrain, D., Prêtre, D., Blank, I., &#x0026; Yeretzian, C.: <span class="cmti-10">Temperature dependence of</span> <span class="cmti-10">Henry&#x2019;s law constants: An automated, high-throughput gas stripping cell</span> <span class="cmti-10">design coupled to PTR-ToF-MS</span>, Int. J. Mass Spectrom., 387, 69–77, <a href="https://doi.org/10.1016/J.IJMS.2015.07.015" >doi:10.1016/J.IJMS.2015.07.015</a> (2015). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3765',
    'Wieser et&nbsp;al. (2023)',
    'Wieser, F., Sander, R., &#x0026; Taraborrelli, D.: <span class="cmti-10">Development of a multiphase chemical mechanism to</span> <span class="cmti-10">improve secondary organic aerosol formation</span> <span class="cmti-10">in CAABA/MECCA (version 4.5.6-rc.1)</span>, Geosci. Model Dev. Discuss., <a href="https://doi.org/10.5194/GMD-2023-102" >doi:10.5194/GMD-2023-102</a>, in review (2023). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '190',
    'Wilhelm et&nbsp;al. (1977)',
    'Wilhelm, E., Battino, R., &#x0026; Wilcock, R. J.: <span class="cmti-10">Low-pressure solubility of gases in liquid water</span>, Chem. Rev., 77, 219–262, <a href="https://doi.org/10.1021/CR60306A003" >doi:10.1021/CR60306A003</a> (1977). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3271',
    'Willey et&nbsp;al. (2017)',
    'Willey, J. D., Powell, J. P., Avery, G. B., Kieber, R. J., &#x0026; Mead, R. N.: <span class="cmti-10">Use of experimentally determined Henry&#x2019;s Law and salting-out</span> <span class="cmti-10">constants for ethanol in seawater for determination of the saturation</span> <span class="cmti-10">state of ethanol in coastal waters</span>, Chemosphere, 182, 426–432, <a href="https://doi.org/10.1016/J.CHEMOSPHERE.2017.05.044" >doi:10.1016/J.CHEMOSPHERE.2017.05.044</a> (2017). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '160',
    'Winiwarter et&nbsp;al. (1988)',
    'Winiwarter, W., Puxbaum, H., Fuzzi, S., Facchini, M. C., Orsi, G., Beltz, N., Enderle, K.-H., &#x0026; Jaeschke, W.: <span class="cmti-10">Organic acid gas and liquid-phase</span> <span class="cmti-10">measurements in Po valley fall-winter conditions in the presence of fog</span>, Tellus, 40B, 348–357, <a href="https://doi.org/10.1111/J.1600-0889.1988.TB00109.X" >doi:10.1111/J.1600-0889.1988.TB00109.X</a> (1988). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3718',
    'Winkler (1907)',
    'Winkler, L.: <span class="cmti-10">A g</span><span class="cmti-10">ázok oldhat</span><span class="cmti-10">ós</span><span class="cmti-10">ága vzben (Solubility of gases</span> <span class="cmti-10">in water)</span>, Math. Termész. Értesitö, 25, 86–108 (1907). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3026',
    'Winkler (1891a)',
    'Winkler, L. W.: <span class="cmti-10">Die</span> <span class="cmti-10">L</span><span class="cmti-10">öslichkeit der Gase in Wasser (erste Abhandlung)</span>, Ber. Dtsch. Chem. Ges., 24, 89–101, <a href="https://doi.org/10.1002/CBER.18910240116" >doi:10.1002/CBER.18910240116</a> (1891a). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3027',
    'Winkler (1891b)',
    'Winkler, L. W.: <span class="cmti-10">Die L</span><span class="cmti-10">öslichkeit der Gase in Wasser</span> <span class="cmti-10">(zweite Abhandlung)</span>, Ber. Dtsch. Chem. Ges., 24, 3602–3610, <a href="https://doi.org/10.1002/CBER.189102402237" >doi:10.1002/CBER.189102402237</a> (1891b). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '871',
    'Winkler (1899)',
    'Winkler, L. W.: <span class="cmti-10">L</span><span class="cmti-10">öslichkeit des Broms in Wasser</span>, Chem. Ztg., 23, 687–689 (1899). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2834',
    'Winkler (1901)',
    'Winkler, L. W.: <span class="cmti-10">Die L</span><span class="cmti-10">öslichkeit der Gase in Wasser</span> <span class="cmti-10">(dritte Abhandlung)</span>, Ber. Dtsch. Chem. Ges., 34, 1408–1422, <a href="https://doi.org/10.1002/CBER.19010340210" >doi:10.1002/CBER.19010340210</a> (1901). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '862',
    'Winkler (1906)',
    'Winkler, L. W.: <span class="cmti-10">Gesetzm</span><span class="cmti-10">ässigkeit bei</span> <span class="cmti-10">der Absorption der Gase in Fl</span><span class="cmti-10">üssigkeiten</span>, Z. Phys. Chem., 55, 344–354, <a href="https://doi.org/10.1515/ZPCH-1906-5518" >doi:10.1515/ZPCH-1906-5518</a> (1906). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2830',
    'Wisegarver and Cline (1985)',
    'Wisegarver, D. P. &#x0026; Cline, J. D.: <span class="cmti-10">Solubility</span> <span class="cmti-10">of trichlorofluoromethane (F-11) and dichlorodifluoromethane (F-12) in</span> <span class="cmti-10">seawater and its relationship to surface concentrations in the North</span> <span class="cmti-10">Pacific</span>, Deep-Sea Res. A, 32, 97–106 (1985). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3636',
    'Wittig et&nbsp;al. (2001)',
    'Wittig, R., Lohmann, J., Joh, R., Horstmann, S., &#x0026; Gmehling, J.: <span class="cmti-10">Vapor-liquid equilibria and enthalpies of mixing in a temperature</span> <span class="cmti-10">range from 298.15 to 413.15K for the further development of</span> <span class="cmti-10">modified UNIFAC (Dortmund)</span>, Ind. Eng. Chem. Res., 40, 5831–5838, <a href="https://doi.org/10.1021/IE010444J" >doi:10.1021/IE010444J</a> (2001). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2956',
    'Wolfe et&nbsp;al. (1980)',
    'Wolfe, N. L., Burns, L. A., &#x0026; Steen, W. C.: <span class="cmti-10">Use of linear free energy</span> <span class="cmti-10">relationships and an evaluative model to assess the fate and transport of</span> <span class="cmti-10">phthalate esters in the aquatic environment</span>, Chemosphere, 9, 393–402, <a href="https://doi.org/10.1016/0045-6535(80)90022-3" >doi:10.1016/0045-6535(80)90022-3</a> (1980). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2529',
    'Wolfe et&nbsp;al. (1982)',
    'Wolfe, N. L., Zepp, R. G., Schlotzhauer, P., &#x0026; Sink, M.: <span class="cmti-10">Transformation pathways of</span> <span class="cmti-10">hexachlorocyclopentadiene in the aquatic environment</span>, Chemosphere, 11, 91–101, <a href="https://doi.org/10.1016/0045-6535(82)90160-6" >doi:10.1016/0045-6535(82)90160-6</a> (1982). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2379',
    'Wolfenden (1976)',
    'Wolfenden, R.: <span class="cmti-10">Free energies of hydration</span> <span class="cmti-10">and hydrolysis of gaseous acetamide</span>, J. Am. Chem. Soc., 98, 1987–1988, <a href="https://doi.org/10.1021/JA00423A068" >doi:10.1021/JA00423A068</a> (1976). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3084',
    'Wolfenden and Williams (1983)',
    'Wolfenden, R. &#x0026; Williams, R.: <span class="cmti-10">Affinities of</span> <span class="cmti-10">phosphoric acids, esters, and amides for solvent water</span>, J. Am. Chem. Soc., 105, 1028–1031, <a href="https://doi.org/10.1021/JA00342A063" >doi:10.1021/JA00342A063</a> (1983). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '983',
    'Wong and Wang (1997)',
    'Wong, P. K. &#x0026; Wang, Y. H.: <span class="cmti-10">Determination of the</span> <span class="cmti-10">Henry&#x2019;s law constant for dimethyl sulfide in seawater</span>, Chemosphere, 35, 535–544, <a href="https://doi.org/10.1016/S0045-6535(97)00118-5" >doi:10.1016/S0045-6535(97)00118-5</a> (1997). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3581',
    'Woo and McNeill (2015)',
    'Woo, J. L. &#x0026; McNeill, V. F.: <span class="cmti-10">simpleGAMMA v1.0</span> <span class="cmti-10">– a reduced model of secondary organic aerosol formation in the</span> <span class="cmti-10">aqueous aerosol phase (aaSOA)</span>, Geosci. Model Dev., 8, 1821–1829, <a href="https://doi.org/10.5194/GMD-8-1821-2015" >doi:10.5194/GMD-8-1821-2015</a> (2015). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3090',
    'Woodrow et&nbsp;al. (1990)',
    'Woodrow, J. E., McChesney, M. M., &#x0026; Seiber, J. N.: <span class="cmti-10">Modeling the volatilization</span> <span class="cmti-10">of pesticides and their distribution in the atmosphere</span>, in: Long Range Transport of Pesticides, edited by Kurtz, D. A., pp. 61–81, CRC Press (1990). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2804',
    'Worthington and Wade (2007)',
    'Worthington, E. K. &#x0026; Wade, E. A.: <span class="cmti-10">Henry&#x2019;s</span> <span class="cmti-10">Law coefficients of chloropicrin and methyl isothiocyanate</span>, Atmos. Environ., 41, 5510–5515, <a href="https://doi.org/10.1016/J.ATMOSENV.2007.02.019" >doi:10.1016/J.ATMOSENV.2007.02.019</a> (2007). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '855',
    'Wright et&nbsp;al. (1992)',
    'Wright, D. A., Sandler, S. I., &#x0026; DeVoll, D.: <span class="cmti-10">Infinite dilution activity coefficients and solubilities</span> <span class="cmti-10">of halogenated hydrocarbons in water at ambient temperatures</span>, Environ. Sci. Technol., 26, 1828–1831, <a href="https://doi.org/10.1021/ES00033A018" >doi:10.1021/ES00033A018</a> (1992). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3719',
    'Wu et&nbsp;al. (2022a)',
    'Wu, S., Hayati, S. K., Kim, E., de la Mata, A. P., Harynuk, J. J., Wang, C., &#x0026; Zhao, R.: <span class="cmti-10">Henry&#x2019;s law constants and indoor partitioning</span> <span class="cmti-10">of microbial volatile organic compounds</span>, Environ. Sci. Technol., 56, 7143–7152, <a href="https://doi.org/10.1021/ACS.EST.1C07882" >doi:10.1021/ACS.EST.1C07882</a> (2022a). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3776',
    'Wu et&nbsp;al. (2022b)',
    'Wu, S., Kim, E., Vethanayagam, D., &#x0026; Zhao, R.: <span class="cmti-10">Indoor partitioning and potential</span> <span class="cmti-10">thirdhand exposure to carbonyl flavoring agents added in e-cigarettes</span> <span class="cmti-10">and hookah tobacco</span>, Environ. Sci. Processes Impacts, 24, 2294–2309, <a href="https://doi.org/10.1039/D2EM00365A" >doi:10.1039/D2EM00365A</a> (2022b). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3013',
    'Wu and Chang (2011)',
    'Wu, Y. &#x0026; Chang, V. W.-C.: <span class="cmti-10">The effect of surface</span> <span class="cmti-10">adsorption and molecular geometry on the determination of Henry&#x2019;s law</span> <span class="cmti-10">constants for fluorotelomer alcohols</span>, J. Chem. Eng. Data, 56, 3442–3448, <a href="https://doi.org/10.1021/JE200466W" >doi:10.1021/JE200466W</a> (2011). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2978',
    'Xiao et&nbsp;al. (2004)',
    'Xiao, H., Li, N., &#x0026; Wania, F.: <span class="cmti-10">Compilation, evaluation, and selection of physical-chemical property data</span> <span class="cmti-10">for </span><span class="cmmi-10">α</span><span class="cmti-10">-, </span><span class="cmmi-10">β</span><span class="cmti-10">-, and </span><span class="cmmi-10">γ</span><span class="cmti-10">-hexachlorocyclohexane</span>, J. Chem. Eng. Data, 49, 173–185, <a href="https://doi.org/10.1021/JE034214I" >doi:10.1021/JE034214I</a> (2004). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2990',
    'Xiao et&nbsp;al. (2012)',
    'Xiao, H., Shen, L., Su, Y., Barresi, E., DeJong, M., Hung, H., Lei, Y.-D., Wania, F., Reiner, E. J., Sverko, E., &#x0026; Kang, S.-C.: <span class="cmti-10">Atmospheric</span> <span class="cmti-10">concentrations of halogenated flame retardants at two remote locations:</span> <span class="cmti-10">The Canadian High Arctic and the Tibetan Plateau</span>, Environ. Pollut., 161, 154–161, <a href="https://doi.org/10.1016/J.ENVPOL.2011.09.041" >doi:10.1016/J.ENVPOL.2011.09.041</a> (2012). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1942',
    'Xie et&nbsp;al. (2004)',
    'Xie, Z., Le Calvé, S., Feigenbrugel, V., Preuß, T. G., Vinken, R., Ebinghaus, R., &#x0026; Ruck, W.: <span class="cmti-10">Henry&#x2019;s law constants measurements</span> <span class="cmti-10">of the nonylphenol isomer 4(3&#x2019;,5&#x2019;-dimethyl-3&#x2019;-heptyl)-phenol, tertiary</span> <span class="cmti-10">octylphenol and </span><span class="cmmi-10">γ</span><span class="cmti-10">-hexachlorocyclohexane between 278 and 298 </span>K, Atmos. Environ., 38, 4859–4868, <a href="https://doi.org/10.1016/J.ATMOSENV.2004.05.013" >doi:10.1016/J.ATMOSENV.2004.05.013</a> (2004). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3096',
    'Xu and Kropscott (2012)',
    'Xu, S. &#x0026; Kropscott, B.: <span class="cmti-10">A method for simultaneous determination of partition coefficients for</span> <span class="cmti-10">cyclic volatile methylsiloxanes and dimethylsilanediol</span>, Anal. Chem., 84, 1948–1955, <a href="https://doi.org/10.1021/AC202953T" >doi:10.1021/AC202953T</a> (2012). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3094',
    'Xu and Kropscott (2014)',
    'Xu, S. &#x0026; Kropscott, B.: <span class="cmti-10">Evaluation of the</span> <span class="cmti-10">three-phase equilibrium method for measuring temperature dependence of</span> <span class="cmti-10">internally consistent partition coefficients (</span><span class="cmmi-10">K</span><sub><span class="cmr-7">OW</span></sub><span class="cmti-10">, </span><span class="cmmi-10">K</span><sub><span class="cmr-7">OA</span></sub><span class="cmti-10">, and </span><span class="cmmi-10">K</span><sub><span class="cmr-7">AW</span></sub><span class="cmti-10">) for</span> <span class="cmti-10">volatile methylsiloxanes and trimethylsilanol</span>, Environ. Toxicol. Chem., 33, 2702–2710, <a href="https://doi.org/10.1002/ETC.2754" >doi:10.1002/ETC.2754</a> (2014). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2535',
    'Yaffe et&nbsp;al. (2003)',
    'Yaffe, D., Cohen, Y., Espinosa, G., Arenas, A., &#x0026; Giralt, F.: <span class="cmti-10">A fuzzy</span> <span class="cmti-10">ARTMAP-based quantitative structure-property relationship (QSPR) for</span> <span class="cmti-10">the Henry&#x2019;s law constant of organic compounds</span>, J. Chem. Inf. Comput. Sci., 43, 85–112, <a href="https://doi.org/10.1021/CI025561J" >doi:10.1021/CI025561J</a> (2003). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3937',
    'Yakovkin (1900)',
    'Yakovkin, A. A.: <span class="cmti-10">About the hydrolysis of chlorine</span>, J. Russ. Phys. Chem. Soc., 32, 673–721, (in Russian) (1900). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3731',
    'Yao et&nbsp;al. (2002)',
    'Yao, X., aand X. Zhang, M. L., Hu, Z., &#x0026; Fan, B.: <span class="cmti-10">Radial basis</span> <span class="cmti-10">function network-based quantitative structure-property relationship for</span> <span class="cmti-10">the prediction of Henry&#x2019;s law constant</span>, Anal. Chim. Acta, 462, 101–117, <a href="https://doi.org/10.1016/S0003-2670(02)00273-8" >doi:10.1016/S0003-2670(02)00273-8</a> (2002). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1330',
    'Yates and Gan (1998)',
    'Yates, S. R. &#x0026; Gan, J. Y.: <span class="cmti-10">Volatility, adsorption, and</span> <span class="cmti-10">degradation of propargyl bromide as a soil fumigant</span>, J. Agric. Food Chem., 46, 755–761, <a href="https://doi.org/10.1021/JF9707849" >doi:10.1021/JF9707849</a> (1998). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2440',
    'Yaws (1999)',
    'Yaws, C. L.: Chemical Properties Handbook, McGraw-Hill, Inc., ISBN 0070734011 (1999). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    'yaws2003handbook',
    'Yaws (2003)',
    'Yaws, C. L.: Yaws&#x2019; Handbook of Thermodynamic and Physical Properties of Chemical Compounds, Knovel: Norwich, NY, USA, ISBN 1591244447 (2003). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '789',
    'Yaws and Yang (1992)',
    'Yaws, C. L. &#x0026; Yang, H.-C.: <span class="cmti-10">Henry&#x2019;s law constant for</span> <span class="cmti-10">compound in water</span>, in: Thermodynamic and Physical Property Data, edited by Yaws, C. L., pp. 181–206, Gulf Publishing Company, Houston, TX, ISBN 0884150313 (1992). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1115',
    'Yaws et&nbsp;al. (1997)',
    'Yaws, C. L., Hopper, J. R., Sheth, S. D., Han, M., &#x0026; Pike, R. W.: <span class="cmti-10">Solubility and</span> <span class="cmti-10">Henry&#x2019;s law constant for alcohols in water</span>, Waste Manage., 17, 541–547, <a href="https://doi.org/10.1016/S0956-053X(97)10057-5" >doi:10.1016/S0956-053X(97)10057-5</a> (1997). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3091',
    'Yaws et&nbsp;al. (1998)',
    'Yaws, C. L., Sheth, S. D., &#x0026; Han, M.: <span class="cmti-10">Using solubility and Henry&#x2019;s law constant data for ketones in water</span>, Pollut. Eng., 30, 44–46 (1998). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3811',
    'Yaws et&nbsp;al. (1999)',
    'Yaws, C. L., Hopper, J. R., Wang, X., Rathinsamy, A. K., &#x0026; Pike, R. W.: <span class="cmti-10">Calculating solubility &#x0026; Henry&#x2019;s law constants for gases in water</span>, Chem. Eng., pp. 102–105 (1999). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    'yaws2001',
    'Yaws et&nbsp;al. (2001)',
    'Yaws, C. L., Hopper, J. R., Mishra, S. R., &#x0026; Pike, R. W.: <span class="cmti-10">Solubility and Henry&#x2019;s law</span> <span class="cmti-10">constants for amines in water</span>, Chem. Eng., 108, 84–88 (2001). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3812',
    'Yaws et&nbsp;al. (2003)',
    'Yaws, C. L., Bajaj, P., Singh, H., &#x0026; Pike, R. W.: <span class="cmti-10">Solubility &#x0026; Henry&#x2019;s law constants for sulfur</span> <span class="cmti-10">compounds in water</span>, Chem. Eng., pp. 60–64 (2003). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    'yaws2005',
    'Yaws et&nbsp;al. (2005)',
    'Yaws, C. L., Narasimhan, P. K., Lou, H. H., &#x0026; Pike, R. W.: <span class="cmti-10">Solubility &#x0026; Henry&#x2019;s law</span> <span class="cmti-10">constants for chlorinated compounds in water</span>, Chem. Eng., 112, 50–56 (2005). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '852',
    'Yin and Hassett (1986)',
    'Yin, C. &#x0026; Hassett, J. P.: <span class="cmti-10">Gas-partitioning approach</span> <span class="cmti-10">for laboratory and fiels studies of mirex fugacity in water</span>, Environ. Sci. Technol., 20, 1213–1217, <a href="https://doi.org/10.1021/ES00154A003" >doi:10.1021/ES00154A003</a> (1986). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3085',
    'Yoo et&nbsp;al. (1986)',
    'Yoo, K.-P., Lee, S. Y., &#x0026; Lee, W. H.: <span class="cmti-10">Ionization and Henry&#x2019;s law constants for volatile, weak electrolyte water</span> <span class="cmti-10">pollutants</span>, Korean J. Chem. Eng., 3, 67–72, <a href="https://doi.org/10.1007/BF02697525" >doi:10.1007/BF02697525</a> (1986). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2971',
    'Yoshida et&nbsp;al. (1983)',
    'Yoshida, K., Shigeoka, T., &#x0026; Yamauchi, F.: <span class="cmti-10">Non-steady state equilibrium model for</span> <span class="cmti-10">the preliminary prediction of the fate of chemicals in the environment</span>, Ecotoxicol. Environ. Saf., 7, 179–190, <a href="https://doi.org/10.1016/0147-6513(83)90064-7" >doi:10.1016/0147-6513(83)90064-7</a> (1983). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2292',
    'Yoshida et&nbsp;al. (1987)',
    'Yoshida, K., Shigeoka, T., &#x0026; Yamauchi, F.: <span class="cmti-10">Evaluation of aquatic environmental</span> <span class="cmti-10">fate of 2,4,6-trichlorophenol with a mathematical model</span>, Chemosphere, 16, 2531–2544, <a href="https://doi.org/10.1016/0045-6535(87)90311-0" >doi:10.1016/0045-6535(87)90311-0</a> (1987). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '527',
    'Yoshizumi et&nbsp;al. (1984)',
    'Yoshizumi, K., Aoki, K., Nouchi, I., Okita, T., Kobayashi, T., Kamakura, S., &#x0026; Tajima, M.: <span class="cmti-10">Measurements of the concentration in rainwater and</span> <span class="cmti-10">of the Henry&#x2019;s law constant of hydrogen peroxide</span>, Atmos. Environ., 18, 395–401, <a href="https://doi.org/10.1016/0004-6981(84)90114-8" >doi:10.1016/0004-6981(84)90114-8</a> (1984). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3852',
    'Young (1981a)',
    'Young, C. L.: IUPAC Solubility Data Series, Volume 5/6, Hydrogen and Deuterium, Pergamon Press, Oxford, ISBN 0080239277 (1981a). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3854',
    'Young (1981b)',
    'Young, C. L.: IUPAC Solubility Data Series, Volume 8, Oxides of Nitrogen, Pergamon Press, Oxford, <a href="https://doi.org/10.1016/C2009-0-00222-0" >doi:10.1016/C2009-0-00222-0</a> (1981b). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3857',
    'Young (1983)',
    'Young, C. L.: IUPAC Solubility Data Series, Volume 12, Sulfur Dioxide, Chlorine, Fluorine and Chlorine Oxides, Pergamon Press, Oxford, <a href="https://doi.org/10.1016/C2013-0-03419-6" >doi:10.1016/C2013-0-03419-6</a> (1983). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3675',
    'Yu (1992)',
    'Yu, H.-Z.: The use of Henry&#x2019;s law constants in the determination of factors that influence VOC concentration in aqueous and gaseous phases in wastewater treatment plant, Master&#x2019;s thesis, New Jersey Institute of Technology, USA (1992). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2479',
    'Yurteri et&nbsp;al. (1987)',
    'Yurteri, C., Ryan, D. F., Callow, J. J., &#x0026; Gurol, M. D.: <span class="cmti-10">The effect of chemical</span> <span class="cmti-10">composition of water on Henry&#x2019;s law constant</span>, J. Water Pollut. Control Fed., 59, 950–956 (1987). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '559',
    'Zafiriou and McFarland (1980)',
    'Zafiriou, O. C. &#x0026; McFarland, M.: <span class="cmti-10">Determination of trace levels of nitric oxide in aqueous solution</span>, Anal. Chem., 52, 1662–1667, <a href="https://doi.org/10.1021/AC50061A029" >doi:10.1021/AC50061A029</a> (1980). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2940',
    'Zhang et&nbsp;al. (2002)',
    'Zhang, S. B. L., Wang, S., &#x0026; Franzblau, A.: <span class="cmti-10">Partition coefficients for the trihalomethanes among</span> <span class="cmti-10">blood, urine, water, milk and air</span>, Sci. Total Environ., 284, 237–247, <a href="https://doi.org/10.1016/S0048-9697(01)00890-7" >doi:10.1016/S0048-9697(01)00890-7</a> (2002). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2921',
    'Zhang et&nbsp;al. (2013)',
    'Zhang, W., Huang, L., Yang, C., &#x0026; Ying, W.: <span class="cmti-10">Experimental method for estimating Henry&#x2019;s law</span> <span class="cmti-10">constant of volatile organic compound</span>, Asian J. Chem., 25, 2647–2650, <a href="https://doi.org/10.14233/AJCHEM.2013.13584" >doi:10.14233/AJCHEM.2013.13584</a> (2013). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2995',
    'Zhang et&nbsp;al. (2010)',
    'Zhang, X., Brown, T. N., Wania, F., Heimstad, E. S., &#x0026; Goss, K.-U.: <span class="cmti-10">Assessment of chemical screening outcomes based on different</span> <span class="cmti-10">partitioning property estimation methods</span>, Environ. Int., 36, 514–520, <a href="https://doi.org/10.1016/J.ENVINT.2010.03.010" >doi:10.1016/J.ENVINT.2010.03.010</a> (2010). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '2937',
    'Zhang and Pawliszyn (1993)',
    'Zhang, Z. &#x0026; Pawliszyn, J.: <span class="cmti-10">Headspace solid-phase microextraction</span>, Anal. Chem., 65, 1843–1852, <a href="https://doi.org/10.1021/AC00062A008" >doi:10.1021/AC00062A008</a> (1993). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '921',
    'Zheng et&nbsp;al. (1997)',
    'Zheng, D.-Q., Guo, T.-M., &#x0026; Knapp, H.: <span class="cmti-10">Experimental and modeling studies on the solubility of</span> CO<sub><span class="cmr-7">2</span></sub><span class="cmti-10">,</span> CHClF<sub><span class="cmr-7">2</span></sub><span class="cmti-10">,</span> CHF<sub><span class="cmr-7">3</span></sub><span class="cmti-10">,</span> C<sub><span class="cmr-7">2</span></sub>H<sub><span class="cmr-7">2</span></sub>F<sub><span class="cmr-7">4</span></sub> <span class="cmti-10">and</span> C<sub><span class="cmr-7">2</span></sub>H<sub><span class="cmr-7">4</span></sub>F<sub><span class="cmr-7">2</span></sub> <span class="cmti-10">in water and aqueous</span> NaCl <span class="cmti-10">solutions under low pressures</span>, Fluid Phase Equilib., 129, 197–209, <a href="https://doi.org/10.1016/S0378-3812(96)03177-9" >doi:10.1016/S0378-3812(96)03177-9</a> (1997). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '800',
    'Zhou and Lee (1992)',
    'Zhou, X. &#x0026; Lee, Y.-N.: <span class="cmti-10">Aqueous solubility and reaction</span> <span class="cmti-10">kinetics of hydroxymethyl hydroperoxide</span>, J. Phys. Chem., 96, 265–272, <a href="https://doi.org/10.1021/J100180A051" >doi:10.1021/J100180A051</a> (1992). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '630',
    'Zhou and Mopper (1990)',
    'Zhou, X. &#x0026; Mopper, K.: <span class="cmti-10">Apparent partition</span> <span class="cmti-10">coefficients of 15 carbonyl compounds between air and seawater and</span> <span class="cmti-10">between air and freshwater; Implications for air-sea exchange</span>, Environ. Sci. Technol., 24, 1864–1869, <a href="https://doi.org/10.1021/ES00082A013" >doi:10.1021/ES00082A013</a> (1990). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '1574',
    'Zhu et&nbsp;al. (2000)',
    'Zhu, J. Y., Liu, P. H., Chai, X. S., Bullock, K. R., &#x0026; Teja, A. S.: <span class="cmti-10">Henry&#x2019;s law constant of</span> <span class="cmti-10">methanol in pulping spent liquors</span>, Environ. Sci. Technol., 34, 1742–1746, <a href="https://doi.org/10.1021/ES990415O" >doi:10.1021/ES990415O</a> (2000). ');
INSERT INTO literature (bibtexkey, quotation, bibliography) VALUES (
    '3306',
    'Zin et&nbsp;al. (2016)',
    'Zin, R. M., Coquelet, C., Valtz, A., Abdul Mutalib, M. I., &#x0026; Sabil, K. M.: <span class="cmti-10">Measurement of Henry&#x2019;s Law constant and infinite</span> <span class="cmti-10">dilution activity coefficient of isopropyl mercaptan and isobutyl mercaptan</span> <span class="cmti-10">in (methyldiethanolamine (1) + water (2)) with </span><span class="cmmi-10">w</span><sub><span class="cmr-7">1</span></sub> <span class="cmti-10">= 0.25 and 0.50 at</span> <span class="cmti-10">temperature of (298 to 348) K using inert gas stripping method</span>, J. Chem. Thermodyn., 93, 193–199, <a href="https://doi.org/10.1016/J.JCT.2015.10.005" >doi:10.1016/J.JCT.2015.10.005</a> (2016). ');
-- -*- mode: sql; sql-product: postgres; -*-
-- created by henry_psql.f90, do not edit!

INSERT INTO categories (catname) VALUES (
    'Inorganic species');
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Oxygen (O)',
    (SELECT id from categories WHERE catname='Inorganic species'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'oxygen',
    'O<sub>2</sub>',
    '',
    '7782-44-7',
    'MYMOFIZGZYHOMD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygen (O)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '1500',
    'L',
    (SELECT id from species WHERE iupac='oxygen'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'moreTdep',
    '', 'A detailed temperature dependence with more than one parameter is available in the original publication. Here, only the temperature dependence at 298.15&nbsp;K according to the van ''t Hoff equation is presented.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '1500',
    'L',
    (SELECT id from species WHERE iupac='oxygen'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'L',
    (SELECT id from species WHERE iupac='oxygen'),
    (SELECT id from literature WHERE bibtexkey='3410'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3410_O2',
    '3410,3412', 'Clever et&nbsp;al. (2014) recommend the data from Rettich et&nbsp;al. (2000).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3410_O2'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '1700',
    'L',
    (SELECT id from species WHERE iupac='oxygen'),
    (SELECT id from literature WHERE bibtexkey='2828'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '1500',
    'L',
    (SELECT id from species WHERE iupac='oxygen'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '1500',
    'L',
    (SELECT id from species WHERE iupac='oxygen'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '1400',
    'L',
    (SELECT id from species WHERE iupac='oxygen'),
    (SELECT id from literature WHERE bibtexkey='2105'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2105',
    '2555', 'The vapor pressure for water from Wagner and Pruss (1993) was used to calculate H<sub>s</sub>.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2105'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '1500',
    'L',
    (SELECT id from species WHERE iupac='oxygen'),
    (SELECT id from literature WHERE bibtexkey='2301'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '1500',
    'L',
    (SELECT id from species WHERE iupac='oxygen'),
    (SELECT id from literature WHERE bibtexkey='3853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '1500',
    'L',
    (SELECT id from species WHERE iupac='oxygen'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '1400',
    'L',
    (SELECT id from species WHERE iupac='oxygen'),
    (SELECT id from literature WHERE bibtexkey='3431'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '1600',
    'M',
    (SELECT id from species WHERE iupac='oxygen'),
    (SELECT id from literature WHERE bibtexkey='3605'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3605-7782-44-7-ABC',
    '3605', 'The data from Millero et&nbsp;al. (2002a) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;130.91491 +6700.12242/T +17.04684&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3605-7782-44-7-ABC'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3605-sameas3606',
    '3606', 'Almost the same data were also published in Millero et&nbsp;al. (2002b).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3605-sameas3606'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '1600',
    'M',
    (SELECT id from species WHERE iupac='oxygen'),
    (SELECT id from literature WHERE bibtexkey='3606'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3606-7782-44-7-ABC',
    '3606', 'The data from Millero et&nbsp;al. (2002b) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;118.73105 +6163.97787/T +15.22401&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3606-7782-44-7-ABC'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3606-sameas3605',
    '3605', 'Almost the same data were also published in Millero et&nbsp;al. (2002a).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3606-sameas3605'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '1500',
    'M',
    (SELECT id from species WHERE iupac='oxygen'),
    (SELECT id from literature WHERE bibtexkey='3412'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3412-7782-44-7-ABC',
    '3412', 'The data from Rettich et&nbsp;al. (2000) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;179.13831 +8707.17767/T +24.33473&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3412-7782-44-7-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '1400',
    'M',
    (SELECT id from species WHERE iupac='oxygen'),
    (SELECT id from literature WHERE bibtexkey='3603'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3603-7782-44-7-ABC',
    '3603', 'The data from Sherwood et&nbsp;al. (1991) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;197.67462 +9515.09306/T +27.11204&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3603-7782-44-7-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '1500',
    'M',
    (SELECT id from species WHERE iupac='oxygen'),
    (SELECT id from literature WHERE bibtexkey='491'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0491-7782-44-7-ABC',
    '491', 'The data from Rettich et&nbsp;al. (1981) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;178.21340 +8672.23354/T +24.19307&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0491-7782-44-7-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '1500',
    'M',
    (SELECT id from species WHERE iupac='oxygen'),
    (SELECT id from literature WHERE bibtexkey='3601'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'highTextrapol',
    '', 'Measured at high temperature and extrapolated to T<sup>&ominus;</sup>&nbsp;= 298.15&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='oxygen'),
    (SELECT id from literature WHERE bibtexkey='3600'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'at293K',
    '', 'Value at T = 293&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '1400',
    'M',
    (SELECT id from species WHERE iupac='oxygen'),
    (SELECT id from literature WHERE bibtexkey='3628'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '1400',
    'M',
    (SELECT id from species WHERE iupac='oxygen'),
    (SELECT id from literature WHERE bibtexkey='2437'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='oxygen'),
    (SELECT id from literature WHERE bibtexkey='3608'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'at273K',
    '', 'Value at T = 273&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at273K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='oxygen'),
    (SELECT id from literature WHERE bibtexkey='3787'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'at310K',
    '', 'Value at T = 310&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '1500',
    'M',
    (SELECT id from species WHERE iupac='oxygen'),
    (SELECT id from literature WHERE bibtexkey='3566'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3566-7782-44-7-ABC',
    '3566', 'The data from Murray and Riley (1969) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;180.22078 +8760.50130/T +24.49289&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3566-7782-44-7-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '1200',
    'M',
    (SELECT id from species WHERE iupac='oxygen'),
    (SELECT id from literature WHERE bibtexkey='3785'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3785-7782-44-7-ABC',
    '3785', 'The data from Shoor et&nbsp;al. (1969) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;91.44799 +4548.67245/T +11.38821&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3785-7782-44-7-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '1600',
    'M',
    (SELECT id from species WHERE iupac='oxygen'),
    (SELECT id from literature WHERE bibtexkey='525'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0525-7782-44-7-ABC',
    '525', 'The data from Carpenter (1966) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;130.04464 +6687.45227/T +16.90114&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0525-7782-44-7-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '1500',
    'M',
    (SELECT id from species WHERE iupac='oxygen'),
    (SELECT id from literature WHERE bibtexkey='3783'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3783-7782-44-7-ABC',
    '3783', 'The data from Morrison and Billett (1952) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;167.89288 +8254.02144/T +22.62741&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3783-7782-44-7-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='oxygen'),
    (SELECT id from literature WHERE bibtexkey='3702'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '1500',
    'M',
    (SELECT id from species WHERE iupac='oxygen'),
    (SELECT id from literature WHERE bibtexkey='3716'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '1700',
    'M',
    (SELECT id from species WHERE iupac='oxygen'),
    (SELECT id from literature WHERE bibtexkey='3711'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '1400',
    'M',
    (SELECT id from species WHERE iupac='oxygen'),
    (SELECT id from literature WHERE bibtexkey='3027'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3027-7782-44-7-ABC',
    '3027', 'The data from Winkler (1891b) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;155.30315 +7638.78869/T +20.77945&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3027-7782-44-7-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '1400',
    'M',
    (SELECT id from species WHERE iupac='oxygen'),
    (SELECT id from literature WHERE bibtexkey='3713'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '1800',
    'M',
    (SELECT id from species WHERE iupac='oxygen'),
    (SELECT id from literature WHERE bibtexkey='3712'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '1200',
    'M',
    (SELECT id from species WHERE iupac='oxygen'),
    (SELECT id from literature WHERE bibtexkey='3717'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '1600',
    'V',
    (SELECT id from species WHERE iupac='oxygen'),
    (SELECT id from literature WHERE bibtexkey='2375'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '1600',
    'V',
    (SELECT id from species WHERE iupac='oxygen'),
    (SELECT id from literature WHERE bibtexkey='2375'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '1500',
    'V',
    (SELECT id from species WHERE iupac='oxygen'),
    (SELECT id from literature WHERE bibtexkey='2375'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='oxygen'),
    (SELECT id from literature WHERE bibtexkey='766'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='oxygen'),
    (SELECT id from literature WHERE bibtexkey='3705'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='oxygen'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3728',
    '', 'Calculated using machine learning matrix completion methods (MCMs).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '1500',
    '?',
    (SELECT id from species WHERE iupac='oxygen'),
    (SELECT id from literature WHERE bibtexkey='3811'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'whichref',
    '', 'Several references are given in the list of Henry''s law constants but not assigned to specific species.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='oxygen'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '1500',
    '?',
    (SELECT id from species WHERE iupac='oxygen'),
    (SELECT id from literature WHERE bibtexkey='379'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0379-7782-44-7-ABC',
    '379', 'The data from Dean and Lange (1999) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;161.84252 +7966.66767/T +21.73409&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0379-7782-44-7-ABC'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '379',
    '3803,379', 'The partial pressure of water vapor (needed to convert some Henry''s law constants) was calculated using the formula given by Buck (1981). The quantities A and &#945; from Dean and Lange (1999) were assumed to be identical.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='379'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='oxygen'),
    (SELECT id from literature WHERE bibtexkey='523'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='oxygen'),
    (SELECT id from literature WHERE bibtexkey='3945'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'atroomT',
    '', 'Value at "room temperature".');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ozone',
    'O<sub>3</sub>',
    '',
    '10028-15-6',
    'CBENFWSGALASAD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygen (O)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;4</sup>',
    '2800',
    'L',
    (SELECT id from species WHERE iupac='ozone'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;4</sup>',
    '2800',
    'L',
    (SELECT id from species WHERE iupac='ozone'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'L',
    (SELECT id from species WHERE iupac='ozone'),
    (SELECT id from literature WHERE bibtexkey='3410'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3410_O3',
    '3410,3853', 'Clever et&nbsp;al. (2014) recommend the data from Battino (1981).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3410_O3'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;4</sup>',
    '2800',
    'L',
    (SELECT id from species WHERE iupac='ozone'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;4</sup>',
    '2800',
    'L',
    (SELECT id from species WHERE iupac='ozone'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;5</sup>',
    '3700',
    'L',
    (SELECT id from species WHERE iupac='ozone'),
    (SELECT id from literature WHERE bibtexkey='3589'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '2400',
    'L',
    (SELECT id from species WHERE iupac='ozone'),
    (SELECT id from literature WHERE bibtexkey='2432'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'L',
    (SELECT id from species WHERE iupac='ozone'),
    (SELECT id from literature WHERE bibtexkey='3853'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3853_O3',
    '3853,2549', 'Battino (1981) concludes that ozone aqueous chemistry needs further clarification. Data from Roth and Sullivan (1981) are recommended, in spite of limitations and assumptions of the data.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3853_O3'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '2000',
    'L',
    (SELECT id from species WHERE iupac='ozone'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ozone'),
    (SELECT id from literature WHERE bibtexkey='3392'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '2300',
    'M',
    (SELECT id from species WHERE iupac='ozone'),
    (SELECT id from literature WHERE bibtexkey='2512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;5</sup>',
    '2600',
    'M',
    (SELECT id from species WHERE iupac='ozone'),
    (SELECT id from literature WHERE bibtexkey='3414'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;5</sup>',
    '2600',
    'M',
    (SELECT id from species WHERE iupac='ozone'),
    (SELECT id from literature WHERE bibtexkey='3590'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '1400',
    'M',
    (SELECT id from species WHERE iupac='ozone'),
    (SELECT id from literature WHERE bibtexkey='3005'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '2300',
    'M',
    (SELECT id from species WHERE iupac='ozone'),
    (SELECT id from literature WHERE bibtexkey='480'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ozone'),
    (SELECT id from literature WHERE bibtexkey='3591'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'M',
    (SELECT id from species WHERE iupac='ozone'),
    (SELECT id from literature WHERE bibtexkey='2549'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2549',
    '2549', 'Roth and Sullivan (1981) found that H<sub>s</sub> depends on the concentration of OH<sup>&#8722;</sup>.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '1900',
    'M',
    (SELECT id from species WHERE iupac='ozone'),
    (SELECT id from literature WHERE bibtexkey='3592'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;5</sup>',
    '2600',
    'M',
    (SELECT id from species WHERE iupac='ozone'),
    (SELECT id from literature WHERE bibtexkey='3593'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '2000',
    'M',
    (SELECT id from species WHERE iupac='ozone'),
    (SELECT id from literature WHERE bibtexkey='528'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ozone'),
    (SELECT id from literature WHERE bibtexkey='3594'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;5</sup>',
    '2900',
    'M',
    (SELECT id from species WHERE iupac='ozone'),
    (SELECT id from literature WHERE bibtexkey='3595'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '4100',
    'M',
    (SELECT id from species WHERE iupac='ozone'),
    (SELECT id from literature WHERE bibtexkey='3596'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ozone'),
    (SELECT id from literature WHERE bibtexkey='3597'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'at291K',
    '', 'Value at T = 291&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at291K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '2600',
    'T',
    (SELECT id from species WHERE iupac='ozone'),
    (SELECT id from literature WHERE bibtexkey='87'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ozone'),
    (SELECT id from literature WHERE bibtexkey='perry73'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'from492',
    '492', 'Value given here as quoted by Durham et&nbsp;al. (1981).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from492'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ozone'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    '?',
    (SELECT id from species WHERE iupac='ozone'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '477_O3',
    '477,3853', 'Lide and Frederikse (1995) present an unusually low value for the Henry solubility of ozone. They refer to Battino (1981) as the source, but the quoted value cannot be found there.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='477_O3'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;5</sup>',
    '2500',
    '?',
    (SELECT id from species WHERE iupac='ozone'),
    (SELECT id from literature WHERE bibtexkey='523'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;5</sup>',
    '2500',
    '?',
    (SELECT id from species WHERE iupac='ozone'),
    (SELECT id from literature WHERE bibtexkey='103'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Hydrogen (H)',
    (SELECT id from categories WHERE catname='Inorganic species'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hydrogen atom',
    'H',
    '',
    '12385-13-6',
    'YZCKVEUIGOORGS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Hydrogen (H)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='hydrogen atom'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='hydrogen atom'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='hydrogen atom'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='hydrogen atom'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;6</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='hydrogen atom'),
    (SELECT id from literature WHERE bibtexkey='3562'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;6</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='hydrogen atom'),
    (SELECT id from literature WHERE bibtexkey='3544'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3544',
    '3544', 'Parker (1992) assumes that the free energy of solvation of atomic hydrogen is equal to that of He because of a similar van der Waals radius.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3544'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    '?',
    (SELECT id from species WHERE iupac='hydrogen atom'),
    (SELECT id from literature WHERE bibtexkey='3530'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3530',
    '3530', 'Roduner and Bartels (1992) say that the free energy of solvation &#8710;G<sup><span class="roman">H</span></sup><sub><span class="roman">solv</span></sub> (and therefore Henry''s law constant) of atomic hydrogen is approximated well by that of molecular hydrogen. However, they apparently do not give a value for &#8710;G<sup><span class="roman">H</span></sup><sub><span class="roman">solv</span></sub>.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hydrogen',
    'H<sub>2</sub>',
    '',
    '1333-74-0',
    'UFHFLCQGNIYNRP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Hydrogen (H)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;6</sup>',
    '530',
    'L',
    (SELECT id from species WHERE iupac='hydrogen'),
    (SELECT id from literature WHERE bibtexkey='2105'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2105'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;6</sup>',
    '490',
    'L',
    (SELECT id from species WHERE iupac='hydrogen'),
    (SELECT id from literature WHERE bibtexkey='3852'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;6</sup>',
    '490',
    'L',
    (SELECT id from species WHERE iupac='hydrogen'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;6</sup>',
    '600',
    'L',
    (SELECT id from species WHERE iupac='hydrogen'),
    (SELECT id from literature WHERE bibtexkey='3431'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;6</sup>',
    '620',
    'M',
    (SELECT id from species WHERE iupac='hydrogen'),
    (SELECT id from literature WHERE bibtexkey='3777'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'HTdep_r2_lessthan_0.9',
    '', 'Fitting the temperature dependence <span class="roman">d</span>lnH/<span class="roman">d</span>(1/T) produced a low correlation coefficient (r<sup>2</sup> &lt; 0.9). The data should be treated with caution.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HTdep_r2_lessthan_0.9'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3777',
    '3777', 'Data digitized from Figs.&nbsp;2 and 3 in Schmidt (1979).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3777'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;6</sup>',
    '480',
    'M',
    (SELECT id from species WHERE iupac='hydrogen'),
    (SELECT id from literature WHERE bibtexkey='3782'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3782-1333-74-0-ABC',
    '3782', 'The data from Gordon et&nbsp;al. (1977) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;158.95051 +6959.76267/T +21.73478&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3782-1333-74-0-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;6</sup>',
    '520',
    'M',
    (SELECT id from species WHERE iupac='hydrogen'),
    (SELECT id from literature WHERE bibtexkey='3781'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3781-1333-74-0-ABC',
    '3781', 'The data from Crozier and Yamamoto (1974) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;129.44163 +5676.58091/T +17.31002&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3781-1333-74-0-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;6</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='hydrogen'),
    (SELECT id from literature WHERE bibtexkey='3786'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;6</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='hydrogen'),
    (SELECT id from literature WHERE bibtexkey='3787'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'M',
    (SELECT id from species WHERE iupac='hydrogen'),
    (SELECT id from literature WHERE bibtexkey='3785'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3785hydrogen',
    '3785', 'The data presented for hydrogen in Table&nbsp;II of Shoor et&nbsp;al. (1969) appear to be incorrect and are not reproduced here.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3785hydrogen'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;6</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='hydrogen'),
    (SELECT id from literature WHERE bibtexkey='3784'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'at303K',
    '', 'Value at T = 303&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at303K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;6</sup>',
    '510',
    'M',
    (SELECT id from species WHERE iupac='hydrogen'),
    (SELECT id from literature WHERE bibtexkey='3783'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3783-1333-74-0-ABC',
    '3783', 'The data from Morrison and Billett (1952) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;94.36490 +4110.23880/T +12.07743&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3783-1333-74-0-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;6</sup>',
    '540',
    'M',
    (SELECT id from species WHERE iupac='hydrogen'),
    (SELECT id from literature WHERE bibtexkey='3711'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;6</sup>',
    '1500',
    'M',
    (SELECT id from species WHERE iupac='hydrogen'),
    (SELECT id from literature WHERE bibtexkey='3795'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3795-1333-74-0-ABC',
    '3795', 'The data from Braun (1900) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( 171.59451 &#8722;6856.02728/T &#8722;28.14739&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3795-1333-74-0-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;6</sup>',
    '500',
    'M',
    (SELECT id from species WHERE iupac='hydrogen'),
    (SELECT id from literature WHERE bibtexkey='3026'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3026-1333-74-0-ABC',
    '3026', 'The data from Winkler (1891a) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;103.47250 +4506.63123/T +13.44160&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3026-1333-74-0-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;6</sup>',
    '550',
    'M',
    (SELECT id from species WHERE iupac='hydrogen'),
    (SELECT id from literature WHERE bibtexkey='3713'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;6</sup>',
    '610',
    'M',
    (SELECT id from species WHERE iupac='hydrogen'),
    (SELECT id from literature WHERE bibtexkey='3712'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;6</sup>',
    '20',
    'M',
    (SELECT id from species WHERE iupac='hydrogen'),
    (SELECT id from literature WHERE bibtexkey='3717'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'HTdep_r2_lessthan_0.5',
    '', 'Fitting the temperature dependence <span class="roman">d</span>lnH/<span class="roman">d</span>(1/T) produced a very low correlation coefficient (r<sup>2</sup> &lt; 0.5). The data should be treated with caution.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HTdep_r2_lessthan_0.5'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3717',
    '3717,3927,3930', 'The paper by Bunsen (1855a) was written in German. English versions with the same data were published by Bunsen (1855b) and Bunsen (1855c).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3717'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;6</sup>',
    '500',
    'V',
    (SELECT id from species WHERE iupac='hydrogen'),
    (SELECT id from literature WHERE bibtexkey='2375'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;6</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='hydrogen'),
    (SELECT id from literature WHERE bibtexkey='714'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;6</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='hydrogen'),
    (SELECT id from literature WHERE bibtexkey='766'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydrogen'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;6</sup>',
    '490',
    '?',
    (SELECT id from species WHERE iupac='hydrogen'),
    (SELECT id from literature WHERE bibtexkey='3811'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='hydrogen'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;6</sup>',
    '500',
    '?',
    (SELECT id from species WHERE iupac='hydrogen'),
    (SELECT id from literature WHERE bibtexkey='379'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0379-1333-74-0-ABC',
    '379', 'The data from Dean and Lange (1999) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;98.78036 +4298.15060/T +12.74131&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0379-1333-74-0-ABC'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='379'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'deuterium',
    'D<sub>2</sub>',
    '',
    '7782-39-0',
    'UFHFLCQGNIYNRP-VVKOMZTBSA-N',
    (SELECT id from subcategories WHERE subcatname='Hydrogen (H)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'L',
    (SELECT id from species WHERE iupac='deuterium'),
    (SELECT id from literature WHERE bibtexkey='3852'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3852',
    '3852,3926', 'Young (1981a) recommend the data from Muccitelli and Wen (1978).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3852'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;6</sup>',
    '720',
    'M',
    (SELECT id from species WHERE iupac='deuterium'),
    (SELECT id from literature WHERE bibtexkey='3926'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3926-7782-39-0-ABC',
    '3926', 'The data from Muccitelli and Wen (1978) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;103.11330 +4676.56978/T +13.28348&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3926-7782-39-0-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;6</sup>',
    '720',
    'M',
    (SELECT id from species WHERE iupac='deuterium'),
    (SELECT id from literature WHERE bibtexkey='3926'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='deuterium'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hydroxyl radical',
    'OH',
    '',
    '3352-57-6',
    'TUJKJAMUKRIRHC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Hydrogen (H)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='hydroxyl radical'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3500-E0',
    '', 'The free energy of solution was calculated based on electrochemical reduction potentials and related free energies.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3500-E0'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='hydroxyl radical'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3500-E0'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='hydroxyl radical'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3500-E0'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='hydroxyl radical'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3500-E0'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '4300',
    'T',
    (SELECT id from species WHERE iupac='hydroxyl radical'),
    (SELECT id from literature WHERE bibtexkey='515'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='hydroxyl radical'),
    (SELECT id from literature WHERE bibtexkey='189'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '3100',
    'T',
    (SELECT id from species WHERE iupac='hydroxyl radical'),
    (SELECT id from literature WHERE bibtexkey='763'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '763',
    '', 'Calculated from correlation between the polarizabilities and solubilities of stable gases. The temperature dependence is an estimate of the upper limit.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='763'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='hydroxyl radical'),
    (SELECT id from literature WHERE bibtexkey='31'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'C',
    (SELECT id from species WHERE iupac='hydroxyl radical'),
    (SELECT id from literature WHERE bibtexkey='31'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='hydroxyl radical'),
    (SELECT id from literature WHERE bibtexkey='31'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '5300',
    'C',
    (SELECT id from species WHERE iupac='hydroxyl radical'),
    (SELECT id from literature WHERE bibtexkey='46'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '46OH',
    '46', 'Jacob (1986) assumed the temperature dependence to be the same as for water.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='46OH'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hydroperoxy radical',
    'HO<sub>2</sub>',
    '',
    '3170-83-0',
    'MHAJPDPJQMAIIY-UHFFFAOYSA-M',
    (SELECT id from subcategories WHERE subcatname='Hydrogen (H)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>1</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='hydroperoxy radical'),
    (SELECT id from literature WHERE bibtexkey='797'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8',
    '',
    'T',
    (SELECT id from species WHERE iupac='hydroperoxy radical'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3500-E0'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8',
    '',
    'T',
    (SELECT id from species WHERE iupac='hydroperoxy radical'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3500-E0'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8',
    '',
    'T',
    (SELECT id from species WHERE iupac='hydroperoxy radical'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3500-E0'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8',
    '',
    'T',
    (SELECT id from species WHERE iupac='hydroperoxy radical'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3500-E0'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>1</sup>',
    '5900',
    'T',
    (SELECT id from species WHERE iupac='hydroperoxy radical'),
    (SELECT id from literature WHERE bibtexkey='515'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>1</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='hydroperoxy radical'),
    (SELECT id from literature WHERE bibtexkey='205'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>1</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='hydroperoxy radical'),
    (SELECT id from literature WHERE bibtexkey='87'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='hydroperoxy radical'),
    (SELECT id from literature WHERE bibtexkey='209'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '209HO2',
    '209,31,34,46', 'In the abstract, Schwartz (1984) gives a range of 9.9&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>  &lt;  H<sub>s</sub><sup>cp</sup> &lt;  3.0&times;10<sup>1</sup>&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>. The mean value of this range (2.0&times;10<sup>1</sup>&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>) has been used by Lelieveld and Crutzen (1991), Pandis and Seinfeld (1989), and Jacob (1986).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='209HO2'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>1</sup>',
    '4800',
    'T',
    (SELECT id from species WHERE iupac='hydroperoxy radical'),
    (SELECT id from literature WHERE bibtexkey='763'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='763'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6600',
    'E',
    (SELECT id from species WHERE iupac='hydroperoxy radical'),
    (SELECT id from literature WHERE bibtexkey='46'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '46HO2',
    '209', 'The value of H<sub>s</sub><sup>&ominus;</sup> was taken from Schwartz (1984).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='46HO2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hydrogen peroxide',
    'H<sub>2</sub>O<sub>2</sub>',
    '',
    '7722-84-1',
    'MHAJPDPJQMAIIY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Hydrogen (H)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>2</sup>',
    '7300',
    'L',
    (SELECT id from species WHERE iupac='hydrogen peroxide'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>2</sup>',
    '7300',
    'L',
    (SELECT id from species WHERE iupac='hydrogen peroxide'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>2</sup>',
    '7200',
    'L',
    (SELECT id from species WHERE iupac='hydrogen peroxide'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>2</sup>',
    '6600',
    'L',
    (SELECT id from species WHERE iupac='hydrogen peroxide'),
    (SELECT id from literature WHERE bibtexkey='2828'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>2</sup>',
    '7600',
    'L',
    (SELECT id from species WHERE iupac='hydrogen peroxide'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>2</sup>',
    '7300',
    'L',
    (SELECT id from species WHERE iupac='hydrogen peroxide'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>2</sup>',
    '6100',
    'L',
    (SELECT id from species WHERE iupac='hydrogen peroxide'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '1943-7722-84-1-erratum',
    '1943', 'Erratum for page 264 of Fogg and Sangster (2003): the second value from their Ref.&nbsp;[10] refers to 291.15&nbsp;K, not 281.15&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1943-7722-84-1-erratum'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '5900',
    'M',
    (SELECT id from species WHERE iupac='hydrogen peroxide'),
    (SELECT id from literature WHERE bibtexkey='3578'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '7000',
    'M',
    (SELECT id from species WHERE iupac='hydrogen peroxide'),
    (SELECT id from literature WHERE bibtexkey='2827'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>2</sup>',
    '7400',
    'M',
    (SELECT id from species WHERE iupac='hydrogen peroxide'),
    (SELECT id from literature WHERE bibtexkey='516'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>2</sup>',
    '6300',
    'M',
    (SELECT id from species WHERE iupac='hydrogen peroxide'),
    (SELECT id from literature WHERE bibtexkey='311'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '311',
    '258', 'This value is a correction of the solubility published by Lind and Kok (1986).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='311'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'M',
    (SELECT id from species WHERE iupac='hydrogen peroxide'),
    (SELECT id from literature WHERE bibtexkey='799'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '799h2o2',
    '311', 'This value was measured at low pH. It is superseded by a later publication of the same group (Lind and Kok, 1994).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='799h2o2'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>2</sup>',
    '6500',
    'M',
    (SELECT id from species WHERE iupac='hydrogen peroxide'),
    (SELECT id from literature WHERE bibtexkey='800'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>2</sup>',
    '7900',
    'M',
    (SELECT id from species WHERE iupac='hydrogen peroxide'),
    (SELECT id from literature WHERE bibtexkey='488'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='hydrogen peroxide'),
    (SELECT id from literature WHERE bibtexkey='527'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>2</sup>',
    '6600',
    'T',
    (SELECT id from species WHERE iupac='hydrogen peroxide'),
    (SELECT id from literature WHERE bibtexkey='87'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>2</sup>',
    '7000',
    'T',
    (SELECT id from species WHERE iupac='hydrogen peroxide'),
    (SELECT id from literature WHERE bibtexkey='43'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydrogen peroxide'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>2</sup>',
    '7300',
    '?',
    (SELECT id from species WHERE iupac='hydrogen peroxide'),
    (SELECT id from literature WHERE bibtexkey='523'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>2</sup>',
    '7300',
    '?',
    (SELECT id from species WHERE iupac='hydrogen peroxide'),
    (SELECT id from literature WHERE bibtexkey='103'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='hydrogen peroxide'),
    (SELECT id from literature WHERE bibtexkey='34'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '34H2O2',
    '34,258,311', 'Pandis and Seinfeld (1989) cite an incorrect value from Lind and Kok (1986); see erratum by Lind and Kok (1994).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='34H2O2'));
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Nitrogen (N)',
    (SELECT id from categories WHERE catname='Inorganic species'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nitrogen',
    'N<sub>2</sub>',
    '',
    '7727-37-9',
    'IJGRMHOSHXDMSA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrogen (N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;6</sup>',
    '1300',
    'L',
    (SELECT id from species WHERE iupac='nitrogen'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;6</sup>',
    '1300',
    'L',
    (SELECT id from species WHERE iupac='nitrogen'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;6</sup>',
    '1600',
    'L',
    (SELECT id from species WHERE iupac='nitrogen'),
    (SELECT id from literature WHERE bibtexkey='2828'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;6</sup>',
    '1300',
    'L',
    (SELECT id from species WHERE iupac='nitrogen'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;6</sup>',
    '1300',
    'L',
    (SELECT id from species WHERE iupac='nitrogen'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;6</sup>',
    '1200',
    'L',
    (SELECT id from species WHERE iupac='nitrogen'),
    (SELECT id from literature WHERE bibtexkey='2105'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2105'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;6</sup>',
    '1200',
    'L',
    (SELECT id from species WHERE iupac='nitrogen'),
    (SELECT id from literature WHERE bibtexkey='2433'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;6</sup>',
    '1200',
    'L',
    (SELECT id from species WHERE iupac='nitrogen'),
    (SELECT id from literature WHERE bibtexkey='3856'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;6</sup>',
    '1300',
    'L',
    (SELECT id from species WHERE iupac='nitrogen'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='nitrogen'),
    (SELECT id from literature WHERE bibtexkey='2441'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;6</sup>',
    '1400',
    'L',
    (SELECT id from species WHERE iupac='nitrogen'),
    (SELECT id from literature WHERE bibtexkey='3696'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;6</sup>',
    '1300',
    'L',
    (SELECT id from species WHERE iupac='nitrogen'),
    (SELECT id from literature WHERE bibtexkey='3431'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;6</sup>',
    '1300',
    'M',
    (SELECT id from species WHERE iupac='nitrogen'),
    (SELECT id from literature WHERE bibtexkey='2434'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2434-7727-37-9-ABC',
    '2434', 'The data from Rettich et&nbsp;al. (1984) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;187.67954 +8903.42524/T +25.60079&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2434-7727-37-9-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;6</sup>',
    '1300',
    'M',
    (SELECT id from species WHERE iupac='nitrogen'),
    (SELECT id from literature WHERE bibtexkey='3601'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;6</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='nitrogen'),
    (SELECT id from literature WHERE bibtexkey='3787'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;6</sup>',
    '1300',
    'M',
    (SELECT id from species WHERE iupac='nitrogen'),
    (SELECT id from literature WHERE bibtexkey='3565'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3565-7727-37-9-ABC',
    '3565', 'The data from Murray et&nbsp;al. (1969) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;174.95275 +8370.22025/T +23.67878&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3565-7727-37-9-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;6</sup>',
    '1400',
    'M',
    (SELECT id from species WHERE iupac='nitrogen'),
    (SELECT id from literature WHERE bibtexkey='3783'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3783-7727-37-9-ABC',
    '3783', 'The data from Morrison and Billett (1952) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;193.68175 +9249.63150/T +26.45117&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3783-7727-37-9-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;6</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='nitrogen'),
    (SELECT id from literature WHERE bibtexkey='3702'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;6</sup>',
    '1100',
    'M',
    (SELECT id from species WHERE iupac='nitrogen'),
    (SELECT id from literature WHERE bibtexkey='3707'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;6</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='nitrogen'),
    (SELECT id from literature WHERE bibtexkey='3715'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'at311K',
    '', 'Value at T = 311&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at311K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;6</sup>',
    '1200',
    'M',
    (SELECT id from species WHERE iupac='nitrogen'),
    (SELECT id from literature WHERE bibtexkey='3716'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;6</sup>',
    '2200',
    'M',
    (SELECT id from species WHERE iupac='nitrogen'),
    (SELECT id from literature WHERE bibtexkey='3795'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3795-7727-37-9-ABC',
    '3795', 'The data from Braun (1900) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( 291.66324 &#8722;11637.66767/T &#8722;46.44134&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3795-7727-37-9-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;6</sup>',
    '1300',
    'M',
    (SELECT id from species WHERE iupac='nitrogen'),
    (SELECT id from literature WHERE bibtexkey='3027'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3027-7727-37-9-ABC',
    '3027', 'The data from Winkler (1891b) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;164.15156 +7906.86704/T +22.05399&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3027-7727-37-9-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;6</sup>',
    '1400',
    'M',
    (SELECT id from species WHERE iupac='nitrogen'),
    (SELECT id from literature WHERE bibtexkey='3713'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;6</sup>',
    '1200',
    'M',
    (SELECT id from species WHERE iupac='nitrogen'),
    (SELECT id from literature WHERE bibtexkey='3717'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3717'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;6</sup>',
    '1300',
    'V',
    (SELECT id from species WHERE iupac='nitrogen'),
    (SELECT id from literature WHERE bibtexkey='2375'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;6</sup>',
    '1300',
    'V',
    (SELECT id from species WHERE iupac='nitrogen'),
    (SELECT id from literature WHERE bibtexkey='2375'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;6</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='nitrogen'),
    (SELECT id from literature WHERE bibtexkey='766'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;6</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='nitrogen'),
    (SELECT id from literature WHERE bibtexkey='3705'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nitrogen'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;6</sup>',
    '1600',
    '?',
    (SELECT id from species WHERE iupac='nitrogen'),
    (SELECT id from literature WHERE bibtexkey='3407'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;6</sup>',
    '1200',
    '?',
    (SELECT id from species WHERE iupac='nitrogen'),
    (SELECT id from literature WHERE bibtexkey='3811'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='nitrogen'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;6</sup>',
    '1300',
    '?',
    (SELECT id from species WHERE iupac='nitrogen'),
    (SELECT id from literature WHERE bibtexkey='379'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0379-7727-37-9-ABC',
    '379', 'The data from Dean and Lange (1999) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;163.64571 +7887.30480/T +21.97696&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0379-7727-37-9-ABC'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='379'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ammonia',
    'NH<sub>3</sub>',
    '',
    '7664-41-7',
    'QGZKDVFQNNGYKY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrogen (N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;1</sup>',
    '4200',
    'L',
    (SELECT id from species WHERE iupac='ammonia'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;1</sup>',
    '4200',
    'L',
    (SELECT id from species WHERE iupac='ammonia'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;1</sup>',
    '4200',
    'L',
    (SELECT id from species WHERE iupac='ammonia'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;1</sup>',
    '4200',
    'L',
    (SELECT id from species WHERE iupac='ammonia'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;1</sup>',
    '4400',
    'L',
    (SELECT id from species WHERE iupac='ammonia'),
    (SELECT id from literature WHERE bibtexkey='3085'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;1</sup>',
    '4200',
    'L',
    (SELECT id from species WHERE iupac='ammonia'),
    (SELECT id from literature WHERE bibtexkey='540'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '1500',
    'L',
    (SELECT id from species WHERE iupac='ammonia'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '3200',
    'M',
    (SELECT id from species WHERE iupac='ammonia'),
    (SELECT id from literature WHERE bibtexkey='3003'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9',
    '6600',
    'M',
    (SELECT id from species WHERE iupac='ammonia'),
    (SELECT id from literature WHERE bibtexkey='3668'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3668',
    '3668', 'Tsuji et&nbsp;al. (1990) provide effective Henry''s law constants at several pH values. Here, only the value at pH = 5.8 is shown for the (acidic) S compounds and the value at pH = 8.6 for the alkaline N compounds.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3668'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;1</sup>',
    '4200',
    'M',
    (SELECT id from species WHERE iupac='ammonia'),
    (SELECT id from literature WHERE bibtexkey='620'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;1</sup>',
    '4100',
    'M',
    (SELECT id from species WHERE iupac='ammonia'),
    (SELECT id from literature WHERE bibtexkey='487'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ammonia'),
    (SELECT id from literature WHERE bibtexkey='287'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;1</sup>',
    '3700',
    'M',
    (SELECT id from species WHERE iupac='ammonia'),
    (SELECT id from literature WHERE bibtexkey='482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '4200',
    'T',
    (SELECT id from species WHERE iupac='ammonia'),
    (SELECT id from literature WHERE bibtexkey='487'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;1</sup>',
    '4100',
    'T',
    (SELECT id from species WHERE iupac='ammonia'),
    (SELECT id from literature WHERE bibtexkey='87'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;1</sup>',
    '4100',
    'T',
    (SELECT id from species WHERE iupac='ammonia'),
    (SELECT id from literature WHERE bibtexkey='3540'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ammonia'),
    (SELECT id from literature WHERE bibtexkey='vankrevelen49'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'from510',
    '510', 'Value given here as quoted by Betterton (1992).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from510'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ammonia'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '2400',
    '?',
    (SELECT id from species WHERE iupac='ammonia'),
    (SELECT id from literature WHERE bibtexkey='379'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0379-7664-41-7-ABC',
    '379', 'The data from Dean and Lange (1999) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( 206.08500 &#8722;7165.18642/T &#8722;32.18383&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0379-7664-41-7-ABC'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='379'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ammonia'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;1</sup>',
    '4100',
    '?',
    (SELECT id from species WHERE iupac='ammonia'),
    (SELECT id from literature WHERE bibtexkey='523'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;1</sup>',
    '4100',
    '?',
    (SELECT id from species WHERE iupac='ammonia'),
    (SELECT id from literature WHERE bibtexkey='103'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ammonia'),
    (SELECT id from literature WHERE bibtexkey='641'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '641amine',
    '641,793', 'Bone et&nbsp;al. (1983) give Carter et&nbsp;al. (1968) as the source. However, no data were found in that reference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='641amine'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hydrazoic acid',
    'HN<sub>3</sub>',
    '',
    '7782-79-8',
    'JUINSXZKUKVTMD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrogen (N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '3800',
    'L',
    (SELECT id from species WHERE iupac='hydrazoic acid'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2626typo',
    '2626', 'There is a typo in Sander et&nbsp;al. (2011): the value for A should be &#8722;10.19 not 10.19.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2626typo'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;2</sup>',
    '3100',
    'L',
    (SELECT id from species WHERE iupac='hydrazoic acid'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '3700',
    'M',
    (SELECT id from species WHERE iupac='hydrazoic acid'),
    (SELECT id from literature WHERE bibtexkey='2806'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='hydrazoic acid'),
    (SELECT id from literature WHERE bibtexkey='2807'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at303K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '4200',
    'M',
    (SELECT id from species WHERE iupac='hydrazoic acid'),
    (SELECT id from literature WHERE bibtexkey='4017'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydrazoic acid'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2530',
    '2530', 'Modarresi et&nbsp;al. (2007) use different descriptors for their calculations. They conclude that a genetic algorithm/radial basis function network (GA/RBFN) is the best QSPR model. Only these results are shown here.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='hydrazoic acid'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3500-7782-79-8',
    '3500', 'Incorrect data are given by Burkholder et&nbsp;al. (2019) for HN<sub>3</sub>. The correct parameter for the temperature dependence is A = &#8722;10.19 (Robert E.&nbsp;Huie, personal communication, 2021).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3500-7782-79-8'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='hydrazoic acid'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3245-7782-79-8',
    '3245', 'Incorrect data are given by Burkholder et&nbsp;al. (2015) for HN<sub>3</sub>. The correct parameter for the temperature dependence is A = &#8722;10.19 (Robert E.&nbsp;Huie, personal communication, 2021).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3245-7782-79-8'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hydrazine',
    'H<sub>4</sub>N<sub>2</sub>',
    '',
    '302-01-2',
    'OAKJQQAXSVQMHS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrogen (N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hydrazine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dinitrogen monoxide',
    'N<sub>2</sub>O',
    'nitrous oxide; laughing gas',
    '10024-97-2',
    'GQPLMRYTRLFLPF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrogen (N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;4</sup>',
    '2600',
    'L',
    (SELECT id from species WHERE iupac='dinitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;4</sup>',
    '2600',
    'L',
    (SELECT id from species WHERE iupac='dinitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'seawater',
    '', 'Solubility in sea water.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;4</sup>',
    '2600',
    'L',
    (SELECT id from species WHERE iupac='dinitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;4</sup>',
    '2600',
    'L',
    (SELECT id from species WHERE iupac='dinitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;4</sup>',
    '2700',
    'L',
    (SELECT id from species WHERE iupac='dinitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='2828'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;4</sup>',
    '2600',
    'L',
    (SELECT id from species WHERE iupac='dinitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;4</sup>',
    '2600',
    'L',
    (SELECT id from species WHERE iupac='dinitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;4</sup>',
    '2500',
    'L',
    (SELECT id from species WHERE iupac='dinitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='3854'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;4</sup>',
    '2600',
    'L',
    (SELECT id from species WHERE iupac='dinitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='dinitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='2441'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '2500',
    'L',
    (SELECT id from species WHERE iupac='dinitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='3696'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;4</sup>',
    '2500',
    'M',
    (SELECT id from species WHERE iupac='dinitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='2832'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2832-10024-97-2-ABC',
    '2832', 'The data from Weiss and Price (1980) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;180.63611 +9824.20147/T +24.46112&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2832-10024-97-2-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '2300',
    'M',
    (SELECT id from species WHERE iupac='dinitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='3701'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dinitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='2833'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dinitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='3697'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;4</sup>',
    '2400',
    'M',
    (SELECT id from species WHERE iupac='dinitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='3710'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dinitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='3703'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dinitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='3705'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'at296K',
    '', 'Value at T = 296&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at296K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dinitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='3702'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;4</sup>',
    '2500',
    'M',
    (SELECT id from species WHERE iupac='dinitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='3709'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;4</sup>',
    '2400',
    'M',
    (SELECT id from species WHERE iupac='dinitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='3704'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;4</sup>',
    '2700',
    'M',
    (SELECT id from species WHERE iupac='dinitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='3711'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;4</sup>',
    '2900',
    'M',
    (SELECT id from species WHERE iupac='dinitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='3944'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3944-10024-97-2-ABC',
    '3944', 'The data from Roth (1897) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;125.17909 +7706.80638/T +15.96486&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3944-10024-97-2-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '2600',
    'M',
    (SELECT id from species WHERE iupac='dinitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='3708'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;4</sup>',
    '2500',
    'X',
    (SELECT id from species WHERE iupac='dinitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='gordon1895'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'from3701',
    '3701', 'Value given here as quoted by Gabel and Schultz (1973).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3701'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dinitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='harris51'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'from3703',
    '3703', 'Value given here as quoted by Sy and Hasbrouck (1964).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3703'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dinitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='macintosh58'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3703'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dinitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='orcutt37'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at311K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3703'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;4</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='dinitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='3705'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dinitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3600',
    'Q',
    (SELECT id from species WHERE iupac='dinitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2700',
    '?',
    (SELECT id from species WHERE iupac='dinitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;4</sup>',
    '2500',
    '?',
    (SELECT id from species WHERE iupac='dinitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='3811'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dinitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;4</sup>',
    '2800',
    '?',
    (SELECT id from species WHERE iupac='dinitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='379'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='379'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dinitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='523'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dinitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='563'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nitrogen monoxide',
    'NO',
    'nitric oxide',
    '10102-43-9',
    'MWUXSHHQAYIFBG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrogen (N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '1600',
    'L',
    (SELECT id from species WHERE iupac='nitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='2828'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '1600',
    'L',
    (SELECT id from species WHERE iupac='nitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2626-10102-43-9-consicheck',
    '2626', 'The H298 and A, B, C data listed in Table&nbsp;5.4 of Sander et&nbsp;al. (2011) are inconsistent, with 94&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2626-10102-43-9-consicheck'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '1600',
    'L',
    (SELECT id from species WHERE iupac='nitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '1945-10102-43-9-consicheck',
    '1945', 'The H298 and A, B, C data listed in Table&nbsp;5.4 of Sander et&nbsp;al. (2006) are inconsistent, with 94&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1945-10102-43-9-consicheck'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '1500',
    'L',
    (SELECT id from species WHERE iupac='nitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='449'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '1400',
    'L',
    (SELECT id from species WHERE iupac='nitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='3854'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3854-10102-43-9',
    '3854', 'A minus sign is missing in the fitting parameter presented by Young (1981b). It should be &#8722;62.8086, not 62.8086.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3854-10102-43-9'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='nitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='559'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'at297K',
    '', 'Value at T = 297&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at297K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;5</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='nitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='3120'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'at288K',
    '', 'Value at T = 288&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '1500',
    'M',
    (SELECT id from species WHERE iupac='nitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='1138'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '1400',
    'M',
    (SELECT id from species WHERE iupac='nitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='2834'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2834-10102-43-9-ABC',
    '2834', 'The data from Winkler (1901) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;184.00012 +8924.34832/T +25.13228&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2834-10102-43-9-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;5</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='nitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='766'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '1300',
    'C',
    (SELECT id from species WHERE iupac='nitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='732'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0732-10102-43-9-ABC',
    '732', 'The data from Loomis (1928) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;223.88313 +10620.37030/T +31.13453&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0732-10102-43-9-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '1500',
    'Q',
    (SELECT id from species WHERE iupac='nitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '1600',
    '?',
    (SELECT id from species WHERE iupac='nitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '1400',
    '?',
    (SELECT id from species WHERE iupac='nitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='3811'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '1500',
    '?',
    (SELECT id from species WHERE iupac='nitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='379'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0379-10102-43-9-ABC',
    '379', 'The data from Dean and Lange (1999) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;160.19223 +7888.02642/T +21.56401&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0379-10102-43-9-ABC'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='379'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='nitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='523'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='nitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='1151'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='nitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3500-10102-43-9',
    '3500', 'Incorrect data are given by Burkholder et&nbsp;al. (2019) for NO. The correct parameters for the temperature dependence are A = &#8722;163.86, B = 8234, C = 22.816 (Robert E.&nbsp;Huie, personal communication, 2021).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3500-10102-43-9'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='nitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3245-10102-43-9',
    '3245', 'Incorrect data are given by Burkholder et&nbsp;al. (2015) for NO. The correct parameters for the temperature dependence are A = &#8722;163.86, B = 8234, C = 22.816 (Robert E.&nbsp;Huie, personal communication, 2021).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3245-10102-43-9'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='nitrogen monoxide'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '190',
    '190', 'The fitting parameters A, B, C, and D in Table&nbsp;I of Wilhelm et&nbsp;al. (1977) do not reproduce the data in their Table&nbsp;III.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='190'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nitrogen dioxide',
    'NO<sub>2</sub>',
    '',
    '10102-44-0',
    'JCXJVPUVTGWSNB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrogen (N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '2400',
    'L',
    (SELECT id from species WHERE iupac='nitrogen dioxide'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '2400',
    'L',
    (SELECT id from species WHERE iupac='nitrogen dioxide'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='nitrogen dioxide'),
    (SELECT id from literature WHERE bibtexkey='2828'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '2400',
    'L',
    (SELECT id from species WHERE iupac='nitrogen dioxide'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='nitrogen dioxide'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='nitrogen dioxide'),
    (SELECT id from literature WHERE bibtexkey='449'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '2400',
    'M',
    (SELECT id from species WHERE iupac='nitrogen dioxide'),
    (SELECT id from literature WHERE bibtexkey='1502'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;5</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='nitrogen dioxide'),
    (SELECT id from literature WHERE bibtexkey='59'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'at295K',
    '', 'Value at T = 295&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='nitrogen dioxide'),
    (SELECT id from literature WHERE bibtexkey='3120'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '2500',
    'T',
    (SELECT id from species WHERE iupac='nitrogen dioxide'),
    (SELECT id from literature WHERE bibtexkey='87'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '1800',
    'T',
    (SELECT id from species WHERE iupac='nitrogen dioxide'),
    (SELECT id from literature WHERE bibtexkey='763'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='763'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='nitrogen dioxide'),
    (SELECT id from literature WHERE bibtexkey='34'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '34NO2wrongref',
    '34,209', 'Pandis and Seinfeld (1989) refer to Schwartz (1984) as the source, but the quoted value cannot be found there.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='34NO2wrongref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='nitrogen dioxide'),
    (SELECT id from literature WHERE bibtexkey='523'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='nitrogen dioxide'),
    (SELECT id from literature WHERE bibtexkey='1151'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nitrogen trioxide',
    'NO<sub>3</sub>',
    'nitrate radical',
    '12033-49-7',
    'YPJKMVATUPSWOH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrogen (N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='nitrogen trioxide'),
    (SELECT id from literature WHERE bibtexkey='895'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='nitrogen trioxide'),
    (SELECT id from literature WHERE bibtexkey='585'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '585NO3',
    '', 'Value obtained by estimating the diffusion coefficient for NO<sub>3</sub> to be D&nbsp;= 1.0&times;10<sup>&#8722;5</sup>&nbsp;cm<sup>2</sup>/s.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='585NO3'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;4</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='nitrogen trioxide'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3500-E0'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;4</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='nitrogen trioxide'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3500-E0'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;4</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='nitrogen trioxide'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3500-E0'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;4</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='nitrogen trioxide'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3500-E0'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '1900',
    'T',
    (SELECT id from species WHERE iupac='nitrogen trioxide'),
    (SELECT id from literature WHERE bibtexkey='88'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '2000',
    'T',
    (SELECT id from species WHERE iupac='nitrogen trioxide'),
    (SELECT id from literature WHERE bibtexkey='763'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='763'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'E',
    (SELECT id from species WHERE iupac='nitrogen trioxide'),
    (SELECT id from literature WHERE bibtexkey='46'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '46NO3',
    '46', 'Jacob (1986) assumes that NO<sub>3</sub> has the same Henry''s law constant as HNO<sub>3</sub>.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='46NO3'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    '?',
    (SELECT id from species WHERE iupac='nitrogen trioxide'),
    (SELECT id from literature WHERE bibtexkey='935'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '935',
    '935,34', 'Seinfeld and Pandis (1997) probably refer to the incorrect value given by Pandis and Seinfeld (1989).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='935'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dinitrogen trioxide',
    'N<sub>2</sub>O<sub>3</sub>',
    '',
    '10544-73-7',
    'LZDSILRDTDCIQT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrogen (N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='dinitrogen trioxide'),
    (SELECT id from literature WHERE bibtexkey='449'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dinitrogen trioxide'),
    (SELECT id from literature WHERE bibtexkey='1138'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dinitrogen tetroxide',
    'N<sub>2</sub>O<sub>4</sub>',
    '',
    '10544-72-6',
    'WFPZPJSADLPSON-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrogen (N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='dinitrogen tetroxide'),
    (SELECT id from literature WHERE bibtexkey='449'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dinitrogen tetroxide'),
    (SELECT id from literature WHERE bibtexkey='3120'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '3500',
    'M',
    (SELECT id from species WHERE iupac='dinitrogen tetroxide'),
    (SELECT id from literature WHERE bibtexkey='1138'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dinitrogen tetroxide'),
    (SELECT id from literature WHERE bibtexkey='1151'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '1100',
    'M',
    (SELECT id from species WHERE iupac='dinitrogen tetroxide'),
    (SELECT id from literature WHERE bibtexkey='3123'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dinitrogen pentoxide',
    'N<sub>2</sub>O<sub>5</sub>',
    'nitric anhydride',
    '10102-03-1',
    'ZWWCURLKEXEFQT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrogen (N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='dinitrogen pentoxide'),
    (SELECT id from literature WHERE bibtexkey='3962'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3962',
    '', 'Calculated from the solvation free energy.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3962'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='dinitrogen pentoxide'),
    (SELECT id from literature WHERE bibtexkey='3963'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3963',
    '', 'Calculated from the solvation free energy.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3963'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;3</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='dinitrogen pentoxide'),
    (SELECT id from literature WHERE bibtexkey='3964'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3964',
    '', 'Calculated from the solvation free energy.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3964'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;4</sup>',
    '3600',
    'T',
    (SELECT id from species WHERE iupac='dinitrogen pentoxide'),
    (SELECT id from literature WHERE bibtexkey='514'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '514N2O5',
    '', 'This value was extrapolated from data at T = 230&nbsp;K and T = 273&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='514N2O5'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '4300',
    'Q',
    (SELECT id from species WHERE iupac='dinitrogen pentoxide'),
    (SELECT id from literature WHERE bibtexkey='3961'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3961_N2O5',
    '3961,449', 'Robinson et&nbsp;al. (1997) applied an empirical correlation between Henry''s law solubilities and boiling points from Schwartz and White (1981).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3961_N2O5'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='dinitrogen pentoxide'),
    (SELECT id from literature WHERE bibtexkey='3436'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3436',
    '449', 'Estimate based on the relation between boiling points and Henry''s law constants for other nitrogen oxides from Schwartz and White (1981).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3436'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&#8734;',
    '',
    'E',
    (SELECT id from species WHERE iupac='dinitrogen pentoxide'),
    (SELECT id from literature WHERE bibtexkey='271'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'infty',
    '', 'Fast, irreversible hydrolysis is assumed, which is equivalent to an infinite effective Henry''s law constant.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='infty'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&#8734;',
    '',
    'E',
    (SELECT id from species WHERE iupac='dinitrogen pentoxide'),
    (SELECT id from literature WHERE bibtexkey='46'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='infty'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hydroxylamine',
    'H<sub>3</sub>NO',
    '',
    '7803-49-8',
    'AVXURJPOCDRRFD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrogen (N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydroxylamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3088-1145',
    '1145', 'Calculated based on the method by Meylan and Howard (1991).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nitrous acid',
    'HNO<sub>2</sub>',
    '',
    '7782-77-6',
    'IOVCWXUNBOPUCH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrogen (N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;1</sup>',
    '4800',
    'L',
    (SELECT id from species WHERE iupac='nitrous acid'),
    (SELECT id from literature WHERE bibtexkey='449'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '4900',
    'M',
    (SELECT id from species WHERE iupac='nitrous acid'),
    (SELECT id from literature WHERE bibtexkey='1056'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '4900',
    'M',
    (SELECT id from species WHERE iupac='nitrous acid'),
    (SELECT id from literature WHERE bibtexkey='625'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;1</sup>',
    '4900',
    'M',
    (SELECT id from species WHERE iupac='nitrous acid'),
    (SELECT id from literature WHERE bibtexkey='592'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '9000',
    'M',
    (SELECT id from species WHERE iupac='nitrous acid'),
    (SELECT id from literature WHERE bibtexkey='1138'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '4700',
    'T',
    (SELECT id from species WHERE iupac='nitrous acid'),
    (SELECT id from literature WHERE bibtexkey='74'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;1</sup>',
    '4800',
    'T',
    (SELECT id from species WHERE iupac='nitrous acid'),
    (SELECT id from literature WHERE bibtexkey='87'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='nitrous acid'),
    (SELECT id from literature WHERE bibtexkey='523'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nitric acid',
    'HNO<sub>3</sub>',
    '',
    '7697-37-2',
    'GRYLNZFGIOXLOG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrogen (N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='nitric acid'),
    (SELECT id from literature WHERE bibtexkey='492'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '8700',
    'R',
    (SELECT id from species WHERE iupac='nitric acid'),
    (SELECT id from literature WHERE bibtexkey='31'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '31HNO3',
    '31,449', 'Lelieveld and Crutzen (1991) assume the temperature dependence to be the same as for a(H<sup>+</sup>)a(NO<sub>3</sub><sup>&#8722;</sup>)/p(HNO<sub>3</sub>) in Schwartz and White (1981).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='31HNO3'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'T',
    (SELECT id from species WHERE iupac='nitric acid'),
    (SELECT id from literature WHERE bibtexkey='2839'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2839-7697-37-2',
    '', 'H<sub>s</sub>&#8242;&nbsp;= 2.6&times;10<sup>7</sup>&times;exp(8700&nbsp;K (1/T&#8722;1/T<sup>&ominus;</sup>))&nbsp;mol<sup>2</sup>/(m<sup>6</sup>&nbsp;Pa)');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2839-7697-37-2'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'T',
    (SELECT id from species WHERE iupac='nitric acid'),
    (SELECT id from literature WHERE bibtexkey='530'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '530-7697-37-2',
    '', 'H<sub>s</sub>&#8242;&nbsp;= 2.4&times;10<sup>7</sup>&times;exp(8700&nbsp;K (1/T&#8722;1/T<sup>&ominus;</sup>))&nbsp;mol<sup>2</sup>/(m<sup>6</sup>&nbsp;Pa)');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='530-7697-37-2'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>4</sup>',
    '8700',
    'T',
    (SELECT id from species WHERE iupac='nitric acid'),
    (SELECT id from literature WHERE bibtexkey='87'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='nitric acid'),
    (SELECT id from literature WHERE bibtexkey='449'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='nitric acid'),
    (SELECT id from literature WHERE bibtexkey='34'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '34HNO3',
    '34,209,449', 'Pandis and Seinfeld (1989) refer to Schwartz (1984) as the source, but it is probably from Schwartz and White (1981).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='34HNO3'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='nitric acid'),
    (SELECT id from literature WHERE bibtexkey='523'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>3</sup>',
    '8800',
    '?',
    (SELECT id from species WHERE iupac='nitric acid'),
    (SELECT id from literature WHERE bibtexkey='103'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='nitric acid'),
    (SELECT id from literature WHERE bibtexkey='260'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '260',
    '530', 'The value is incorrect. See erratum by Brimblecombe and Clegg (1989).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='260'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pernitric acid',
    'HNO<sub>4</sub>',
    '',
    '26404-66-0',
    'UUZZMWZGAZGXSF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrogen (N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '8400',
    'L',
    (SELECT id from species WHERE iupac='pernitric acid'),
    (SELECT id from literature WHERE bibtexkey='1182'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='pernitric acid'),
    (SELECT id from literature WHERE bibtexkey='670'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '6900',
    'T',
    (SELECT id from species WHERE iupac='pernitric acid'),
    (SELECT id from literature WHERE bibtexkey='797'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='pernitric acid'),
    (SELECT id from literature WHERE bibtexkey='1257'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '0',
    'C',
    (SELECT id from species WHERE iupac='pernitric acid'),
    (SELECT id from literature WHERE bibtexkey='76'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'E',
    (SELECT id from species WHERE iupac='pernitric acid'),
    (SELECT id from literature WHERE bibtexkey='507'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '507HNO4',
    '507', 'Möller and Mauersberger (1992) assumed the solubility of HNO<sub>4</sub> to be comparable to that of HNO<sub>3</sub>.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='507HNO4'));
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Fluorine (F)',
    (SELECT id from categories WHERE catname='Inorganic species'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fluorine atom',
    'F',
    '',
    '14762-94-8',
    'YCKRFDGAMUMZLT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Fluorine (F)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;4</sup>',
    '400',
    'T',
    (SELECT id from species WHERE iupac='fluorine atom'),
    (SELECT id from literature WHERE bibtexkey='763'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='763'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hydrogen fluoride',
    'HF',
    '',
    '7664-39-3',
    'KRHYYFGTRYWZRS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Fluorine (F)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='hydrogen fluoride'),
    (SELECT id from literature WHERE bibtexkey='1914'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'T',
    (SELECT id from species WHERE iupac='hydrogen fluoride'),
    (SELECT id from literature WHERE bibtexkey='530'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '530-7664-39-3',
    '', 'H<sub>s</sub>&#8242;&nbsp;= 9.4&times;10<sup>1</sup>&times;exp(7400&nbsp;K (1/T&#8722;1/T<sup>&ominus;</sup>))&nbsp;mol<sup>2</sup>/(m<sup>6</sup>&nbsp;Pa)');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='530-7664-39-3'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydrogen fluoride'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='hydrogen fluoride'),
    (SELECT id from literature WHERE bibtexkey='260'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='260'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'difluorine monoxide',
    'F<sub>2</sub>O',
    '',
    '7783-41-7',
    'UJMWVICAENGCRF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Fluorine (F)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;5</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='difluorine monoxide'),
    (SELECT id from literature WHERE bibtexkey='735'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nitrogen trifluoride',
    'NF<sub>3</sub>',
    '',
    '7783-54-2',
    'GVGCUCJTUSOZKP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Fluorine (F)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;6</sup>',
    '1900',
    'L',
    (SELECT id from species WHERE iupac='nitrogen trifluoride'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;6</sup>',
    '1900',
    'L',
    (SELECT id from species WHERE iupac='nitrogen trifluoride'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;6</sup>',
    '1900',
    'L',
    (SELECT id from species WHERE iupac='nitrogen trifluoride'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;6</sup>',
    '1900',
    'L',
    (SELECT id from species WHERE iupac='nitrogen trifluoride'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;6</sup>',
    '1700',
    'M',
    (SELECT id from species WHERE iupac='nitrogen trifluoride'),
    (SELECT id from literature WHERE bibtexkey='3806'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3806-7783-54-2-ABC',
    '3806', 'The data from Dean et&nbsp;al. (1973) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;164.52717 +8214.77776/T +21.97482&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3806-7783-54-2-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;6</sup>',
    '1900',
    'M',
    (SELECT id from species WHERE iupac='nitrogen trifluoride'),
    (SELECT id from literature WHERE bibtexkey='2831'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2831-7783-54-2-ABC',
    '2831', 'The data from Ashton et&nbsp;al. (1968) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;279.21972 +13536.60588/T +38.97386&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2831-7783-54-2-ABC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dinitrogen tetrafluoride',
    'N<sub>2</sub>F<sub>4</sub>',
    'tetrafluorohydrazine',
    '10036-47-2',
    'GFADZIUESKAXAK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Fluorine (F)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;6</sup>',
    '2500',
    'L',
    (SELECT id from species WHERE iupac='dinitrogen tetrafluoride'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;6</sup>',
    '2500',
    'L',
    (SELECT id from species WHERE iupac='dinitrogen tetrafluoride'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;6</sup>',
    '2500',
    'L',
    (SELECT id from species WHERE iupac='dinitrogen tetrafluoride'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;6</sup>',
    '2500',
    'L',
    (SELECT id from species WHERE iupac='dinitrogen tetrafluoride'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;6</sup>',
    '2400',
    'M',
    (SELECT id from species WHERE iupac='dinitrogen tetrafluoride'),
    (SELECT id from literature WHERE bibtexkey='3806'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3806-10036-47-2-ABC',
    '3806', 'The data from Dean et&nbsp;al. (1973) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;318.29953 +15733.17858/T +44.55320&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3806-10036-47-2-ABC'));
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Chlorine (Cl)',
    (SELECT id from categories WHERE catname='Inorganic species'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chlorine (molecular)',
    'Cl<sub>2</sub>',
    '',
    '7782-50-5',
    'KZBUYRJDOAKODT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorine (Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'L',
    (SELECT id from species WHERE iupac='chlorine (molecular)'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'HeffCl2',
    '', 'The value presented here appears to be the total solubility of chlorine (i.e., the sum of Cl<sub>2</sub> and HOCl) at a partial pressure of p(Cl<sub>2</sub>)&nbsp; = 101325&nbsp;Pa. This is different from Henry''s law constant, which is defined at extrapolation to infinite dilution.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HeffCl2'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'L',
    (SELECT id from species WHERE iupac='chlorine (molecular)'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HeffCl2'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'L',
    (SELECT id from species WHERE iupac='chlorine (molecular)'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HeffCl2'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'L',
    (SELECT id from species WHERE iupac='chlorine (molecular)'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HeffCl2'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'L',
    (SELECT id from species WHERE iupac='chlorine (molecular)'),
    (SELECT id from literature WHERE bibtexkey='3857'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3857_Cl2',
    '3857,3925', 'Young (1983) recommends values calculated from Table&nbsp;1 of Adams and Edmonds (1937). Thus, the data refer to effective values that take into account the hydrolysis in the aqueous phase: <br clear="all" /><table border="0" width="100%"><tr><td><table align="center" cellspacing="0"  cellpadding="2"><tr><td nowrap="nowrap" align="center">H<sub><span class="roman">s</span><span class="roman">,</span><span class="roman">eff</span></sub> = ([Cl<sub>2</sub>]+[HOCl])/p(Cl<sub>2</sub>).</td></tr></table></td></tr></table> In addition, the values apply to a partial pressure of p(Cl<sub>2</sub>)&nbsp; = 101325&nbsp;Pa, and not to infinite dilution.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3857_Cl2'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;4</sup>',
    '3200',
    'M',
    (SELECT id from species WHERE iupac='chlorine (molecular)'),
    (SELECT id from literature WHERE bibtexkey='3535'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '3500',
    'M',
    (SELECT id from species WHERE iupac='chlorine (molecular)'),
    (SELECT id from literature WHERE bibtexkey='3541'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3541',
    '3928', 'The same experimental data were also published by Whitney and Vivian (1941b).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3541'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'M',
    (SELECT id from species WHERE iupac='chlorine (molecular)'),
    (SELECT id from literature WHERE bibtexkey='3934'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HeffCl2'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'M',
    (SELECT id from species WHERE iupac='chlorine (molecular)'),
    (SELECT id from literature WHERE bibtexkey='3718'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HeffCl2'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;4</sup>',
    '3000',
    'M',
    (SELECT id from species WHERE iupac='chlorine (molecular)'),
    (SELECT id from literature WHERE bibtexkey='3937'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3937-7782-50-5-ABC',
    '3937', 'The data from Yakovkin (1900) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;122.31264 +7690.40834/T +15.63947&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3937-7782-50-5-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'M',
    (SELECT id from species WHERE iupac='chlorine (molecular)'),
    (SELECT id from literature WHERE bibtexkey='3938'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HeffCl2'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'M',
    (SELECT id from species WHERE iupac='chlorine (molecular)'),
    (SELECT id from literature WHERE bibtexkey='3935'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HeffCl2'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'M',
    (SELECT id from species WHERE iupac='chlorine (molecular)'),
    (SELECT id from literature WHERE bibtexkey='3933'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HeffCl2'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;4</sup>',
    '2600',
    'R',
    (SELECT id from species WHERE iupac='chlorine (molecular)'),
    (SELECT id from literature WHERE bibtexkey='1230'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;4</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='chlorine (molecular)'),
    (SELECT id from literature WHERE bibtexkey='3929'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3929',
    '3929,3925', 'Leaist (1986) converted the total solubility of chlorine in pure water from Adams and Edmonds (1937) to an intrinsic Henry''s law constant.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3929'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3200',
    'R',
    (SELECT id from species WHERE iupac='chlorine (molecular)'),
    (SELECT id from literature WHERE bibtexkey='750'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'R',
    (SELECT id from species WHERE iupac='chlorine (molecular)'),
    (SELECT id from literature WHERE bibtexkey='3925'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3925',
    '3925,3937,3942', 'Adams and Edmonds (1937) re-analyzed the data from Yakovkin (1900) and Arkadiev (1918), considering deviations from the perfect gas law. They calculated the total solubility of chlorine (i.e., the sum of Cl<sub>2</sub> and HOCl) at several partial pressures of Cl<sub>2</sub>. This is different from Henry''s law constant, which is defined at extrapolation to infinite dilution.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3925'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'R',
    (SELECT id from species WHERE iupac='chlorine (molecular)'),
    (SELECT id from literature WHERE bibtexkey='3942'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3942',
    '3942,3937', 'Arkadiev (1918) re-analyzed the measurements of Yakovkin (1900). In addition to the data between 15&nbsp;<sup>&#176;</sup>C and 83.4&nbsp;<sup>&#176;</sup>C, he also analyzed the experimental results at 0&nbsp;<sup>&#176;</sup>C and obtained a dimensionless Henry solubility of H<sub>s</sub><sup>cc</sup> = 4.115 at that temperature.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3942'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;4</sup>',
    '2800',
    'T',
    (SELECT id from species WHERE iupac='chlorine (molecular)'),
    (SELECT id from literature WHERE bibtexkey='489'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorine (molecular)'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    '?',
    (SELECT id from species WHERE iupac='chlorine (molecular)'),
    (SELECT id from literature WHERE bibtexkey='1038'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HeffCl2'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '1038tdep',
    '1038', 'The value of &#8710;H<sup>&#176;</sup> listed in Table&nbsp;2 of Bartlett and Margerum (1999) is incorrect. The correct value can be found in the text on page 3411.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1038tdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    '?',
    (SELECT id from species WHERE iupac='chlorine (molecular)'),
    (SELECT id from literature WHERE bibtexkey='3811'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HeffCl2'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    '?',
    (SELECT id from species WHERE iupac='chlorine (molecular)'),
    (SELECT id from literature WHERE bibtexkey='379'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HeffCl2'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    '?',
    (SELECT id from species WHERE iupac='chlorine (molecular)'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '190_Cl2',
    '190,3927,3930,3541,3928', 'Wilhelm et&nbsp;al. (1977) present a fitting function for Cl<sub>2</sub> based on four papers which are cited in the footnotes of Table&nbsp;I. However, Bunsen (1855b) and Bunsen (1855c) do not contain any data for Cl<sub>2</sub>, and the data from Whitney and Vivian (1941a) and Whitney and Vivian (1941b) are inconsistent with the fitting function.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='190_Cl2'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HeffCl2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chlorine atom',
    'Cl',
    '',
    '22537-15-1',
    'ZAMOUSCENKQFHK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorine (Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='chlorine atom'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3500-E0'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='chlorine atom'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3500-E0'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='chlorine atom'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3500-E0'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='chlorine atom'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3500-E0'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='chlorine atom'),
    (SELECT id from literature WHERE bibtexkey='189'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '189ClBr',
    '761', 'Calculated from the free energy of solution by Schwarz and Dodson (1984).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='189ClBr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;4</sup>',
    '1500',
    'T',
    (SELECT id from species WHERE iupac='chlorine atom'),
    (SELECT id from literature WHERE bibtexkey='763'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='763'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hydrogen chloride',
    'HCl',
    '',
    '7647-01-0',
    'VEXZGXHMUGYJMC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorine (Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'L',
    (SELECT id from species WHERE iupac='hydrogen chloride'),
    (SELECT id from literature WHERE bibtexkey='1071'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '1071',
    '', 'H<sub>s</sub>&#8242;&nbsp;= 2.0&times;10<sup>7</sup>&nbsp;mol<sup>2</sup>/(m<sup>6</sup>&nbsp;Pa)');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1071'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='hydrogen chloride'),
    (SELECT id from literature WHERE bibtexkey='1137'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'T',
    (SELECT id from species WHERE iupac='hydrogen chloride'),
    (SELECT id from literature WHERE bibtexkey='2840'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2840-7647-01-0',
    '', 'H<sub>s</sub>&#8242;&nbsp;= 2.0&times;10<sup>7</sup>&times;exp(9000&nbsp;K (1/T&#8722;1/T<sup>&ominus;</sup>))&nbsp;mol<sup>2</sup>/(m<sup>6</sup>&nbsp;Pa)');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2840-7647-01-0'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'T',
    (SELECT id from species WHERE iupac='hydrogen chloride'),
    (SELECT id from literature WHERE bibtexkey='530'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '530-7647-01-0',
    '', 'H<sub>s</sub>&#8242;&nbsp;= 2.0&times;10<sup>7</sup>&times;exp(9000&nbsp;K (1/T&#8722;1/T<sup>&ominus;</sup>))&nbsp;mol<sup>2</sup>/(m<sup>6</sup>&nbsp;Pa)');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='530-7647-01-0'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '2300',
    'T',
    (SELECT id from species WHERE iupac='hydrogen chloride'),
    (SELECT id from literature WHERE bibtexkey='167'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'T',
    (SELECT id from species WHERE iupac='hydrogen chloride'),
    (SELECT id from literature WHERE bibtexkey='489'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '489HCl',
    '', 'H<sub>s</sub>&#8242;&nbsp;= 2.0&times;10<sup>7</sup>&times;exp(9000&nbsp;K (1/T&#8722;1/T<sup>&ominus;</sup>))&nbsp;mol<sup>2</sup>/(m<sup>6</sup>&nbsp;Pa)');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='489HCl'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='hydrogen chloride'),
    (SELECT id from literature WHERE bibtexkey='82'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydrogen chloride'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    '?',
    (SELECT id from species WHERE iupac='hydrogen chloride'),
    (SELECT id from literature WHERE bibtexkey='935'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='935'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '620',
    '?',
    (SELECT id from species WHERE iupac='hydrogen chloride'),
    (SELECT id from literature WHERE bibtexkey='379'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0379-7647-01-0-ABC',
    '379', 'The data from Dean and Lange (1999) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( 9.16427 +45.13997/T &#8722;1.92853&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0379-7647-01-0-ABC'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='379'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2',
    '2000',
    '?',
    (SELECT id from species WHERE iupac='hydrogen chloride'),
    (SELECT id from literature WHERE bibtexkey='34'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '34HClwrongref',
    '34,167', 'Pandis and Seinfeld (1989) refer to Marsh and McElroy (1985) as the source, but the quoted value cannot be found there.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='34HClwrongref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='hydrogen chloride'),
    (SELECT id from literature WHERE bibtexkey='523'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='hydrogen chloride'),
    (SELECT id from literature WHERE bibtexkey='260'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='260'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hypochlorous acid',
    'HOCl',
    '',
    '7790-92-3',
    'QWPPOHNGKGFGJK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorine (Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5',
    '5900',
    'L',
    (SELECT id from species WHERE iupac='hypochlorous acid'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5',
    '5900',
    'L',
    (SELECT id from species WHERE iupac='hypochlorous acid'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5',
    '5900',
    'L',
    (SELECT id from species WHERE iupac='hypochlorous acid'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5',
    '5900',
    'L',
    (SELECT id from species WHERE iupac='hypochlorous acid'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5',
    '5900',
    'L',
    (SELECT id from species WHERE iupac='hypochlorous acid'),
    (SELECT id from literature WHERE bibtexkey='315'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1',
    '',
    'M',
    (SELECT id from species WHERE iupac='hypochlorous acid'),
    (SELECT id from literature WHERE bibtexkey='288'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7',
    '1600',
    'M',
    (SELECT id from species WHERE iupac='hypochlorous acid'),
    (SELECT id from literature WHERE bibtexkey='183'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '183HOCl',
    '', 'This value was extrapolated from data at T = 215&nbsp;K and T = 263&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='183HOCl'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0',
    '',
    'M',
    (SELECT id from species WHERE iupac='hypochlorous acid'),
    (SELECT id from literature WHERE bibtexkey='3232'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0',
    '4900',
    'M',
    (SELECT id from species WHERE iupac='hypochlorous acid'),
    (SELECT id from literature WHERE bibtexkey='287'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '287HOCl',
    '', 'Value at pH = 6.5.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='287HOCl'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '5200',
    'M',
    (SELECT id from species WHERE iupac='hypochlorous acid'),
    (SELECT id from literature WHERE bibtexkey='3957'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4',
    '8900',
    'M',
    (SELECT id from species WHERE iupac='hypochlorous acid'),
    (SELECT id from literature WHERE bibtexkey='3809'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6',
    '5100',
    'T',
    (SELECT id from species WHERE iupac='hypochlorous acid'),
    (SELECT id from literature WHERE bibtexkey='489'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hypochlorous acid'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'perchloric acid',
    'HClO<sub>4</sub>',
    '',
    '7601-90-3',
    'VLTRZXGMWDSKGL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorine (Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>3</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='perchloric acid'),
    (SELECT id from literature WHERE bibtexkey='1536'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'at200K',
    '', 'Value at T = 200&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at200K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'monochlorine monoxide',
    'ClO',
    '',
    '14989-30-1',
    'MLWGAEVSWJXOQJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorine (Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;3</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='monochlorine monoxide'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3500-E0'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;3</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='monochlorine monoxide'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3500-E0'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;3</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='monochlorine monoxide'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3500-E0'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;3</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='monochlorine monoxide'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3500-E0'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dichlorine monoxide',
    'Cl<sub>2</sub>O',
    '',
    '7791-21-1',
    'RCJVRSBWZCNNQT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorine (Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'M',
    (SELECT id from species WHERE iupac='dichlorine monoxide'),
    (SELECT id from literature WHERE bibtexkey='3807'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3807',
    '3807', 'Secoy and Cady (1941) measured the gas-aqueous equilibrium constant p(Cl<sub>2</sub>O) / c(HOCl)<sup>2</sup> but not the intrinsic Henry''s law constant of Cl<sub>2</sub>O.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3807'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'M',
    (SELECT id from species WHERE iupac='dichlorine monoxide'),
    (SELECT id from literature WHERE bibtexkey='3809'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3809',
    '3809', 'Ourisson and Kastner (1939) measured the gas-aqueous equilibrium constant p(Cl<sub>2</sub>O) / c(HOCl)<sup>2</sup> but not the intrinsic Henry''s law constant of Cl<sub>2</sub>O.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3809'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '5900',
    'R',
    (SELECT id from species WHERE iupac='dichlorine monoxide'),
    (SELECT id from literature WHERE bibtexkey='this'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'refthis-7791-21-1-ABC',
    '', 'The data from this work were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( 1680.49677 &#8722;69933.08019/T &#8722;254.37188&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='refthis-7791-21-1-ABC'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'this_Cl2O',
    '3810', 'The gas-aqueous equilibrium constant p(Cl<sub>2</sub>O) / c(HOCl)<sup>2</sup> was combined with the temperature-dependent aqueous-phase hydration constant c(HOCl)<sup>2</sup> / c(Cl<sub>2</sub>O) from Roth (1929) in order to calculate the intrinsic Henry''s law constant of Cl<sub>2</sub>O.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='this_Cl2O'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'this_Cl2O_ref3807',
    '3807', 'Data for the equilibrium between gaseous Cl<sub>2</sub>O and aqueous HOCl were taken from Secoy and Cady (1941).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='this_Cl2O_ref3807'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;2</sup>',
    '5600',
    'R',
    (SELECT id from species WHERE iupac='dichlorine monoxide'),
    (SELECT id from literature WHERE bibtexkey='this'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='this_Cl2O'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'this_Cl2O_ref3809',
    '3809', 'Data for the equilibrium between gaseous Cl<sub>2</sub>O and aqueous HOCl were taken from Ourisson and Kastner (1939).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='this_Cl2O_ref3809'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;2</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='dichlorine monoxide'),
    (SELECT id from literature WHERE bibtexkey='3949'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'at277K',
    '', 'Value at T = 277&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at277K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    '?',
    (SELECT id from species WHERE iupac='dichlorine monoxide'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'JPL_Cl2O',
    '190,3807', 'The recommended value from Wilhelm et&nbsp;al. (1977) appears to be dubious as it refers to Secoy and Cady (1941), who do not provide a value for the intrinsic Henry''s law constant of Cl<sub>2</sub>O.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='JPL_Cl2O'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    '?',
    (SELECT id from species WHERE iupac='dichlorine monoxide'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='JPL_Cl2O'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    '?',
    (SELECT id from species WHERE iupac='dichlorine monoxide'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='JPL_Cl2O'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    '?',
    (SELECT id from species WHERE iupac='dichlorine monoxide'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='JPL_Cl2O'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    '?',
    (SELECT id from species WHERE iupac='dichlorine monoxide'),
    (SELECT id from literature WHERE bibtexkey='3857'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3857_Cl2O',
    '3857,3807', 'Young (1983) cites data from Secoy and Cady (1941). However, that paper only describes the equilibrium between gas-phase Cl<sub>2</sub>O and aqueous-phase HOCl. A Henry''s law constant of Cl<sub>2</sub>O is not provided. In addition, the values given by Young (1983) are not extrapolated to infinite dilution but to 1&nbsp;atm partial pressure of Cl<sub>2</sub>O. It is not explained how the nonlinear pressure dependence was extrapolated to 1&nbsp;atm.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3857_Cl2O'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='dichlorine monoxide'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '190_Cl2O',
    '190,3807', 'Wilhelm et&nbsp;al. (1977) cite Secoy and Cady (1941) as the source for their value. However, that paper only describes the equilibrium between gas-phase Cl<sub>2</sub>O and aqueous-phase HOCl. A Henry''s law constant of Cl<sub>2</sub>O is not provided.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='190_Cl2O'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chlorine dioxide',
    'ClO<sub>2</sub>',
    '',
    '10049-04-4',
    'OSVXSBDYLRYLIG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorine (Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '3500',
    'L',
    (SELECT id from species WHERE iupac='chlorine dioxide'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '3500',
    'L',
    (SELECT id from species WHERE iupac='chlorine dioxide'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '3500',
    'L',
    (SELECT id from species WHERE iupac='chlorine dioxide'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '3500',
    'L',
    (SELECT id from species WHERE iupac='chlorine dioxide'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '3300',
    'L',
    (SELECT id from species WHERE iupac='chlorine dioxide'),
    (SELECT id from literature WHERE bibtexkey='3857'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '3300',
    'L',
    (SELECT id from species WHERE iupac='chlorine dioxide'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '3200',
    'M',
    (SELECT id from species WHERE iupac='chlorine dioxide'),
    (SELECT id from literature WHERE bibtexkey='3956'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '3100',
    'M',
    (SELECT id from species WHERE iupac='chlorine dioxide'),
    (SELECT id from literature WHERE bibtexkey='3965'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='chlorine dioxide'),
    (SELECT id from literature WHERE bibtexkey='3966'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;3</sup>',
    '1200',
    'M',
    (SELECT id from species WHERE iupac='chlorine dioxide'),
    (SELECT id from literature WHERE bibtexkey='3967'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;3</sup>',
    '3600',
    'M',
    (SELECT id from species WHERE iupac='chlorine dioxide'),
    (SELECT id from literature WHERE bibtexkey='3969'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'C',
    (SELECT id from species WHERE iupac='chlorine dioxide'),
    (SELECT id from literature WHERE bibtexkey='3955'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3955',
    '3955,3969', 'Even though Haller and Northgraves (1955) have been cited several times as the source of the ClO<sub>2</sub> solubility data, they did not perform any measurements. They took the data from the 1952 edition of the Kirk-Othmer Encyclopedia of Chemical Technology which apparently reproduced data from Holst (1944).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3955'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '3100',
    '?',
    (SELECT id from species WHERE iupac='chlorine dioxide'),
    (SELECT id from literature WHERE bibtexkey='3951'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chlorine dioxide'),
    (SELECT id from literature WHERE bibtexkey='3950'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '3300',
    '?',
    (SELECT id from species WHERE iupac='chlorine dioxide'),
    (SELECT id from literature WHERE bibtexkey='3811'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'perchloryl fluoride',
    'ClO<sub>3</sub>F',
    '',
    '7616-94-6',
    'XHFXMNZYIKFCPN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorine (Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='perchloryl fluoride'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nitrosyl chloride',
    'NOCl',
    '',
    '2696-92-6',
    'VPCDQGACGWYTMC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorine (Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 4.9&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='nitrosyl chloride'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 4.9&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='nitrosyl chloride'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 4.9&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='nitrosyl chloride'),
    (SELECT id from literature WHERE bibtexkey='1060'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nitryl chloride',
    'ClNO<sub>2</sub>',
    '',
    '13444-90-1',
    'HSSFHZJIMRUXDM-UHFFFAOYSA-M',
    (SELECT id from subcategories WHERE subcatname='Chlorine (Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;4</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='nitryl chloride'),
    (SELECT id from literature WHERE bibtexkey='937'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;4</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='nitryl chloride'),
    (SELECT id from literature WHERE bibtexkey='536'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '536ClNO2',
    '', 'Derived as a fitting parameter used in numerical modeling.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='536ClNO2'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='nitryl chloride'),
    (SELECT id from literature WHERE bibtexkey='2360'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chlorine nitrate',
    'ClNO<sub>3</sub>',
    '',
    '14545-72-3',
    'XYLGPCWDPLOBGP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorine (Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;2</sup>',
    '4500',
    'Q',
    (SELECT id from species WHERE iupac='chlorine nitrate'),
    (SELECT id from literature WHERE bibtexkey='3961'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3961_ClNO2',
    '3961', 'Robinson et&nbsp;al. (1997) assumed that the entropy of vaporization is the same for HOCl and ClNO<sub>3</sub> according to Trouton''s rule. On their page 3592, they mention a value of 7&nbsp;M&nbsp;atm<sup>&#8722;1</sup> at 250&nbsp;K. However, checking their Fig.&nbsp;9 and applying the temperature-dependence equation from their Table&nbsp;3, it seems that the value of 7&nbsp;M&nbsp;atm<sup>&#8722;1</sup> refers to 298&nbsp;K, not 250&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3961_ClNO2'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&#8734;',
    '',
    'E',
    (SELECT id from species WHERE iupac='chlorine nitrate'),
    (SELECT id from literature WHERE bibtexkey='271'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='infty'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chloramine',
    'NH<sub>2</sub>Cl',
    'chloramide',
    '10599-90-3',
    'QDHHCQZDFGDHMP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorine (Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;1</sup>',
    '6000',
    'L',
    (SELECT id from species WHERE iupac='chloramine'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;1</sup>',
    '6000',
    'L',
    (SELECT id from species WHERE iupac='chloramine'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;1</sup>',
    '6000',
    'L',
    (SELECT id from species WHERE iupac='chloramine'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;1</sup>',
    '6000',
    'L',
    (SELECT id from species WHERE iupac='chloramine'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;1</sup>',
    '4800',
    'M',
    (SELECT id from species WHERE iupac='chloramine'),
    (SELECT id from literature WHERE bibtexkey='287'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloramine'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dichloramine',
    'NHCl<sub>2</sub>',
    'chlorimide',
    '3400-09-7',
    'JSYGRUBHOCKMGQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorine (Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '4200',
    'L',
    (SELECT id from species WHERE iupac='dichloramine'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '4200',
    'L',
    (SELECT id from species WHERE iupac='dichloramine'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '4200',
    'L',
    (SELECT id from species WHERE iupac='dichloramine'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '4200',
    'L',
    (SELECT id from species WHERE iupac='dichloramine'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '4200',
    'M',
    (SELECT id from species WHERE iupac='dichloramine'),
    (SELECT id from literature WHERE bibtexkey='287'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nitrogen trichloride',
    'NCl<sub>3</sub>',
    '',
    '10025-85-1',
    'QEHKBHWEUPXBCW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorine (Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;4</sup>',
    '4100',
    'L',
    (SELECT id from species WHERE iupac='nitrogen trichloride'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;4</sup>',
    '4100',
    'L',
    (SELECT id from species WHERE iupac='nitrogen trichloride'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;4</sup>',
    '4100',
    'L',
    (SELECT id from species WHERE iupac='nitrogen trichloride'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;4</sup>',
    '4100',
    'L',
    (SELECT id from species WHERE iupac='nitrogen trichloride'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;4</sup>',
    '4100',
    'M',
    (SELECT id from species WHERE iupac='nitrogen trichloride'),
    (SELECT id from literature WHERE bibtexkey='287'));
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Bromine (Br)',
    (SELECT id from categories WHERE catname='Inorganic species'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bromine (molecular)',
    'Br<sub>2</sub>',
    '',
    '7726-95-6',
    'GDTBXPJZTBHREO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine (Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;3</sup>',
    '4400',
    'L',
    (SELECT id from species WHERE iupac='bromine (molecular)'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;3</sup>',
    '4400',
    'L',
    (SELECT id from species WHERE iupac='bromine (molecular)'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;3</sup>',
    '4400',
    'L',
    (SELECT id from species WHERE iupac='bromine (molecular)'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;3</sup>',
    '4400',
    'L',
    (SELECT id from species WHERE iupac='bromine (molecular)'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '3600',
    'M',
    (SELECT id from species WHERE iupac='bromine (molecular)'),
    (SELECT id from literature WHERE bibtexkey='759'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '759',
    '759', 'Dubik et&nbsp;al. (1987) measured the solubility in concentrated salt solutions (natural brines).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='759'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='bromine (molecular)'),
    (SELECT id from literature WHERE bibtexkey='627'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='bromine (molecular)'),
    (SELECT id from literature WHERE bibtexkey='753'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;3</sup>',
    '4100',
    'M',
    (SELECT id from species WHERE iupac='bromine (molecular)'),
    (SELECT id from literature WHERE bibtexkey='626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='bromine (molecular)'),
    (SELECT id from literature WHERE bibtexkey='3934'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;3</sup>',
    '3800',
    'M',
    (SELECT id from species WHERE iupac='bromine (molecular)'),
    (SELECT id from literature WHERE bibtexkey='862'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;3</sup>',
    '3600',
    'M',
    (SELECT id from species WHERE iupac='bromine (molecular)'),
    (SELECT id from literature WHERE bibtexkey='871'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;3</sup>',
    '4100',
    'V',
    (SELECT id from species WHERE iupac='bromine (molecular)'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;3</sup>',
    '3900',
    'R',
    (SELECT id from species WHERE iupac='bromine (molecular)'),
    (SELECT id from literature WHERE bibtexkey='753'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;3</sup>',
    '4000',
    'T',
    (SELECT id from species WHERE iupac='bromine (molecular)'),
    (SELECT id from literature WHERE bibtexkey='489'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='bromine (molecular)'),
    (SELECT id from literature WHERE bibtexkey='giona69'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'from3232',
    '3232', 'Value given here as quoted by McCoy et&nbsp;al. (1990).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3232'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='bromine (molecular)'),
    (SELECT id from literature WHERE bibtexkey='1038'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1038tdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;3</sup>',
    '3900',
    '?',
    (SELECT id from species WHERE iupac='bromine (molecular)'),
    (SELECT id from literature WHERE bibtexkey='379'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0379-7726-95-6-ABC',
    '379', 'The data from Dean and Lange (1999) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;148.75612 +9709.79389/T +19.53402&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0379-7726-95-6-ABC'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='379'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bromine atom',
    'Br',
    '',
    '10097-32-2',
    'WKBOTKDWSSQWDR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine (Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='bromine atom'),
    (SELECT id from literature WHERE bibtexkey='189'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='189ClBr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '1800',
    'T',
    (SELECT id from species WHERE iupac='bromine atom'),
    (SELECT id from literature WHERE bibtexkey='763'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='763'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hydrogen bromide',
    'HBr',
    '',
    '10035-10-6',
    'CPELXLSAUQHCOX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine (Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'T',
    (SELECT id from species WHERE iupac='hydrogen bromide'),
    (SELECT id from literature WHERE bibtexkey='2840'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2840-10035-10-6',
    '', 'H<sub>s</sub>&#8242;&nbsp;= 8.2&times;10<sup>9</sup>&times;exp(10000&nbsp;K (1/T&#8722;1/T<sup>&ominus;</sup>))&nbsp;mol<sup>2</sup>/(m<sup>6</sup>&nbsp;Pa)');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2840-10035-10-6'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'T',
    (SELECT id from species WHERE iupac='hydrogen bromide'),
    (SELECT id from literature WHERE bibtexkey='530'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '530-10035-10-6',
    '', 'H<sub>s</sub>&#8242;&nbsp;= 1.3&times;10<sup>10</sup>&times;exp(10000&nbsp;K (1/T&#8722;1/T<sup>&ominus;</sup>))&nbsp;mol<sup>2</sup>/(m<sup>6</sup>&nbsp;Pa)');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='530-10035-10-6'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'T',
    (SELECT id from species WHERE iupac='hydrogen bromide'),
    (SELECT id from literature WHERE bibtexkey='489'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '489HBr',
    '', 'H<sub>s</sub>&#8242;&nbsp;= 7.0&times;10<sup>9</sup>&times;exp(10000&nbsp;K (1/T&#8722;1/T<sup>&ominus;</sup>))&nbsp;mol<sup>2</sup>/(m<sup>6</sup>&nbsp;Pa)');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='489HBr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydrogen bromide'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    '?',
    (SELECT id from species WHERE iupac='hydrogen bromide'),
    (SELECT id from literature WHERE bibtexkey='171'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '171HBr',
    '171,46,87', 'Chameides and Stelson (1992) give a value of H<sub>s</sub>&#8242;&nbsp;= 7.1&times;10<sup>9</sup>&times;exp(6100&nbsp;K (1/T&#8722;1/T<sup>&ominus;</sup>))&nbsp;mol<sup>2</sup>/(m<sup>6</sup>&nbsp;Pa). They refer to Jacob (1986) and Chameides (1984) as the source, but this value cannot be found there.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='171HBr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '250',
    '?',
    (SELECT id from species WHERE iupac='hydrogen bromide'),
    (SELECT id from literature WHERE bibtexkey='379'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0379-10035-10-6-ABC',
    '379', 'The data from Dean and Lange (1999) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;60.28318 +2830.41867/T +8.66642&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0379-10035-10-6-ABC'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='379'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='hydrogen bromide'),
    (SELECT id from literature WHERE bibtexkey='260'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='260'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hypobromous acid',
    'HOBr',
    '',
    '13517-11-8',
    'CUILPNURFADTPE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine (Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 1.3&times;10<sup>1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='hypobromous acid'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 1.3&times;10<sup>1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='hypobromous acid'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 1.9&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='hypobromous acid'),
    (SELECT id from literature WHERE bibtexkey='288'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='hypobromous acid'),
    (SELECT id from literature WHERE bibtexkey='3232'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '4000',
    'T',
    (SELECT id from species WHERE iupac='hypobromous acid'),
    (SELECT id from literature WHERE bibtexkey='276'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '276',
    '', 'The value is from Table&nbsp;1 of the paper. However, <i>J.&nbsp;Geophys.&nbsp;Res.</i> forgot to print the tables, and I received them directly from the author.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='276'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>1</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='hypobromous acid'),
    (SELECT id from literature WHERE bibtexkey='937'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;1</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='hypobromous acid'),
    (SELECT id from literature WHERE bibtexkey='446'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='hypobromous acid'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'JPL_HOBr',
    '3500', 'The value presented for HOBr is incorrect. A corrected version was later published by Burkholder et&nbsp;al. (2019).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='JPL_HOBr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='hypobromous acid'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='JPL_HOBr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='hypobromous acid'),
    (SELECT id from literature WHERE bibtexkey='910'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '910wrong',
    '910', 'Fickert (1998) extracted a value from wetted-wall flow tube experiments. However, it was later discovered that under the experimental conditions no evaluation of H<sub>s</sub> is possible (John Crowley, personal communication, 1999).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='910wrong'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nitryl bromide',
    'BrNO<sub>2</sub>',
    '',
    '13536-70-4',
    'SEYAFCXQVVHRPY-UHFFFAOYSA-M',
    (SELECT id from subcategories WHERE subcatname='Bromine (Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='nitryl bromide'),
    (SELECT id from literature WHERE bibtexkey='937'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bromine nitrate',
    'BrNO<sub>3</sub>',
    '',
    '40423-14-1',
    'RRTWEEAEXPZMPY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine (Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&#8734;',
    '',
    'E',
    (SELECT id from species WHERE iupac='bromine nitrate'),
    (SELECT id from literature WHERE bibtexkey='271'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='infty'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bromine chloride',
    'BrCl',
    '',
    '13863-41-7',
    'CODNYICXDISAEA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine (Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;3</sup>',
    '5600',
    'L',
    (SELECT id from species WHERE iupac='bromine chloride'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;3</sup>',
    '5600',
    'L',
    (SELECT id from species WHERE iupac='bromine chloride'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;3</sup>',
    '5600',
    'L',
    (SELECT id from species WHERE iupac='bromine chloride'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;3</sup>',
    '5600',
    'L',
    (SELECT id from species WHERE iupac='bromine chloride'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&lt; 6.2&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='bromine chloride'),
    (SELECT id from literature WHERE bibtexkey='1323'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'at275K',
    '', 'Value at T = 275&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at275K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='bromine chloride'),
    (SELECT id from literature WHERE bibtexkey='1018'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'at290K',
    '', 'Value at T = 290&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at290K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;3</sup>',
    '5600',
    'M',
    (SELECT id from species WHERE iupac='bromine chloride'),
    (SELECT id from literature WHERE bibtexkey='1038'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '4000',
    'M',
    (SELECT id from species WHERE iupac='bromine chloride'),
    (SELECT id from literature WHERE bibtexkey='759'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='759'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='bromine chloride'),
    (SELECT id from literature WHERE bibtexkey='this'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'BrClRS',
    '489,318', 'Calculated using data from Wagman et&nbsp;al. (1982) and the aqueous-phase equilibrium Cl<sub>2</sub> + Br<sub>2</sub> &harr;&nbsp;2 BrCl from Wang et&nbsp;al. (1994).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='BrClRS'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;4</sup>',
    '4000',
    'E',
    (SELECT id from species WHERE iupac='bromine chloride'),
    (SELECT id from literature WHERE bibtexkey='3770'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;3</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='bromine chloride'),
    (SELECT id from literature WHERE bibtexkey='937'));
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Iodine (I)',
    (SELECT id from categories WHERE catname='Inorganic species'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'iodine (molecular)',
    'I<sub>2</sub>',
    '',
    '7553-56-2',
    'PNDPGZBMCMUPRI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Iodine (I)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '4300',
    'M',
    (SELECT id from species WHERE iupac='iodine (molecular)'),
    (SELECT id from literature WHERE bibtexkey='1149'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '3900',
    'V',
    (SELECT id from species WHERE iupac='iodine (molecular)'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '4400',
    'R',
    (SELECT id from species WHERE iupac='iodine (molecular)'),
    (SELECT id from literature WHERE bibtexkey='582'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '4600',
    'R',
    (SELECT id from species WHERE iupac='iodine (molecular)'),
    (SELECT id from literature WHERE bibtexkey='763'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '4800',
    'T',
    (SELECT id from species WHERE iupac='iodine (molecular)'),
    (SELECT id from literature WHERE bibtexkey='489'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='iodine (molecular)'),
    (SELECT id from literature WHERE bibtexkey='203'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '203I2',
    '203', 'Thompson and Zafiriou (1983) quote a paper as the source that gives only the solubility but not the Henry''s law constant.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='203I2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'iodine atom',
    'I',
    '',
    '14362-44-8',
    'ZCYVEMRRCGMTRW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Iodine (I)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;4</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='iodine atom'),
    (SELECT id from literature WHERE bibtexkey='189'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '189I',
    '762', 'Calculated from the free energy of solution by Schwarz and Bielski (1986).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='189I'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;5</sup>',
    '2300',
    'T',
    (SELECT id from species WHERE iupac='iodine atom'),
    (SELECT id from literature WHERE bibtexkey='763'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='763'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hydrogen iodide',
    'HI',
    '',
    '10034-85-2',
    'XMBWDFGMSWQBCA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Iodine (I)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'T',
    (SELECT id from species WHERE iupac='hydrogen iodide'),
    (SELECT id from literature WHERE bibtexkey='530'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '530-10034-85-2',
    '', 'H<sub>s</sub>&#8242;&nbsp;= 2.5&times;10<sup>10</sup>&times;exp(9800&nbsp;K (1/T&#8722;1/T<sup>&ominus;</sup>))&nbsp;mol<sup>2</sup>/(m<sup>6</sup>&nbsp;Pa)');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='530-10034-85-2'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'T',
    (SELECT id from species WHERE iupac='hydrogen iodide'),
    (SELECT id from literature WHERE bibtexkey='489'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '489HI',
    '', 'H<sub>s</sub>&#8242;&nbsp;= 2.1&times;10<sup>10</sup>&times;exp(9800&nbsp;K (1/T&#8722;1/T<sup>&ominus;</sup>))&nbsp;mol<sup>2</sup>/(m<sup>6</sup>&nbsp;Pa)');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='489HI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '9800',
    'E',
    (SELECT id from species WHERE iupac='hydrogen iodide'),
    (SELECT id from literature WHERE bibtexkey='3770'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&#8734;',
    '',
    'E',
    (SELECT id from species WHERE iupac='hydrogen iodide'),
    (SELECT id from literature WHERE bibtexkey='897'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='infty'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='hydrogen iodide'),
    (SELECT id from literature WHERE bibtexkey='260'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='260'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'iodine monoxide',
    'IO',
    '',
    '14696-98-1',
    'AFSVSXMRDKPOEW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Iodine (I)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4',
    '',
    '?',
    (SELECT id from species WHERE iupac='iodine monoxide'),
    (SELECT id from literature WHERE bibtexkey='3760'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3760',
    '3760,2312', 'Saiz-Lopez et&nbsp;al. (2014) refer to Saiz-Lopez et&nbsp;al. (2008) as the source, but the quoted value cannot be found there.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3760'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'iodine dioxide',
    'OIO',
    '',
    '13494-92-3',
    'WXDJHDMIIZKXSK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Iodine (I)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='iodine dioxide'),
    (SELECT id from literature WHERE bibtexkey='3760'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3760'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diiodine dioxide',
    'I<sub>2</sub>O<sub>2</sub>',
    '',
    '215239-62-6',
    'IELAHHPSAVYAOC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Iodine (I)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&#8734;',
    '',
    'E',
    (SELECT id from species WHERE iupac='diiodine dioxide'),
    (SELECT id from literature WHERE bibtexkey='3771'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'whichisomer',
    '', 'It is unclear to which isomer the value of the Henry''s law constant refers to.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichisomer'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3771-IxOy',
    '', 'Assumed to be infinity by analogy with INO<sub>3</sub>.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3771-IxOy'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&#8734;',
    '',
    'E',
    (SELECT id from species WHERE iupac='diiodine dioxide'),
    (SELECT id from literature WHERE bibtexkey='897'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichisomer'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='infty'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='diiodine dioxide'),
    (SELECT id from literature WHERE bibtexkey='3760'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichisomer'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3760'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diiodine trioxide',
    'I<sub>2</sub>O<sub>3</sub>',
    '',
    '11085-17-9',
    'NMNCVPKLBXOKQA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Iodine (I)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&#8734;',
    '',
    'E',
    (SELECT id from species WHERE iupac='diiodine trioxide'),
    (SELECT id from literature WHERE bibtexkey='3771'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichisomer'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3771-IxOy'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='diiodine trioxide'),
    (SELECT id from literature WHERE bibtexkey='3760'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichisomer'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3760'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diiodine tetroxide',
    'I<sub>2</sub>O<sub>4</sub>',
    '',
    '1024652-24-1',
    'XHTWXUOEQMOFEJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Iodine (I)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&#8734;',
    '',
    'E',
    (SELECT id from species WHERE iupac='diiodine tetroxide'),
    (SELECT id from literature WHERE bibtexkey='3771'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichisomer'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3771-IxOy'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='diiodine tetroxide'),
    (SELECT id from literature WHERE bibtexkey='3760'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichisomer'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3760'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hypoiodous acid',
    'HOI',
    '',
    '14332-21-9',
    'GEOVEUCEIQCBKH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Iodine (I)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 4.1',
    '',
    'C',
    (SELECT id from species WHERE iupac='hypoiodous acid'),
    (SELECT id from literature WHERE bibtexkey='582'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'E',
    (SELECT id from species WHERE iupac='hypoiodous acid'),
    (SELECT id from literature WHERE bibtexkey='203'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '203HOI',
    '203', 'Thompson and Zafiriou (1983) assume that H<sub>s</sub><sup>cp</sup>(HOI) is between 4.4&times;10<sup>&#8722;1</sup>&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup> and 4.4&times;10<sup>2</sup>&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='203HOI'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'iodine nitrite',
    'INO<sub>2</sub>',
    '',
    '15465-40-4',
    'PSZTWRLUACEPOW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Iodine (I)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='iodine nitrite'),
    (SELECT id from literature WHERE bibtexkey='3771'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3771-INO2',
    '3771', 'Badia et&nbsp;al. (2019) assume that INO<sub>2</sub> has the same Henry''s law constant as BrNO<sub>2</sub>.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3771-INO2'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&#8734;',
    '',
    'E',
    (SELECT id from species WHERE iupac='iodine nitrite'),
    (SELECT id from literature WHERE bibtexkey='897'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='infty'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'iodine nitrate',
    'INO<sub>3</sub>',
    '',
    '14696-81-2',
    'CCJHDZZUWZIVJF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Iodine (I)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&#8734;',
    '',
    'E',
    (SELECT id from species WHERE iupac='iodine nitrate'),
    (SELECT id from literature WHERE bibtexkey='897'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='infty'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'iodine chloride',
    'ICl',
    '',
    '7790-99-0',
    'QZRGKCOWNLSUDK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Iodine (I)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'T',
    (SELECT id from species WHERE iupac='iodine chloride'),
    (SELECT id from literature WHERE bibtexkey='489'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'iodine bromide',
    'IBr',
    '',
    '7789-33-5',
    'CBEQRNSPHCCXSH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Iodine (I)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='iodine bromide'),
    (SELECT id from literature WHERE bibtexkey='489'));
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Sulfur (S)',
    (SELECT id from categories WHERE catname='Inorganic species'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'sulfur',
    'S',
    '',
    '7704-34-9',
    'NINIDFKCEFEMDL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='sulfur'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3549',
    '', 'Data taken from the AGRITOX database file agritox-20210608.zip.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hydrogen sulfide',
    'H<sub>2</sub>S',
    '',
    '7783-06-4',
    'RWSOTUBLDIXVET-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '2100',
    'L',
    (SELECT id from species WHERE iupac='hydrogen sulfide'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '2100',
    'L',
    (SELECT id from species WHERE iupac='hydrogen sulfide'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '2100',
    'L',
    (SELECT id from species WHERE iupac='hydrogen sulfide'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '2100',
    'L',
    (SELECT id from species WHERE iupac='hydrogen sulfide'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '2000',
    'L',
    (SELECT id from species WHERE iupac='hydrogen sulfide'),
    (SELECT id from literature WHERE bibtexkey='2105'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2105'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '2200',
    'L',
    (SELECT id from species WHERE iupac='hydrogen sulfide'),
    (SELECT id from literature WHERE bibtexkey='615'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '2000',
    'L',
    (SELECT id from species WHERE iupac='hydrogen sulfide'),
    (SELECT id from literature WHERE bibtexkey='3863'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3863_H2S',
    '3863', 'Fogg and Young (1988) provide two different fitting functions: one for T &lt; 283.2&nbsp;K and one for T &gt; 283.2&nbsp;K. At T=283.2&nbsp;K, the functions have different values and different slopes. Here, only the function that is valid at T<sup>&ominus;</sup> is used.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3863_H2S'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '2000',
    'L',
    (SELECT id from species WHERE iupac='hydrogen sulfide'),
    (SELECT id from literature WHERE bibtexkey='3085'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '2100',
    'L',
    (SELECT id from species WHERE iupac='hydrogen sulfide'),
    (SELECT id from literature WHERE bibtexkey='540'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '2100',
    'L',
    (SELECT id from species WHERE iupac='hydrogen sulfide'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;4</sup>',
    '1700',
    'M',
    (SELECT id from species WHERE iupac='hydrogen sulfide'),
    (SELECT id from literature WHERE bibtexkey='2929'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;4</sup>',
    '1600',
    'M',
    (SELECT id from species WHERE iupac='hydrogen sulfide'),
    (SELECT id from literature WHERE bibtexkey='3534'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;4</sup>',
    '2100',
    'M',
    (SELECT id from species WHERE iupac='hydrogen sulfide'),
    (SELECT id from literature WHERE bibtexkey='586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '2300',
    'M',
    (SELECT id from species WHERE iupac='hydrogen sulfide'),
    (SELECT id from literature WHERE bibtexkey='997'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '1700',
    'M',
    (SELECT id from species WHERE iupac='hydrogen sulfide'),
    (SELECT id from literature WHERE bibtexkey='3668'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3668'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;4</sup>',
    '2300',
    'M',
    (SELECT id from species WHERE iupac='hydrogen sulfide'),
    (SELECT id from literature WHERE bibtexkey='2928'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '2100',
    'M',
    (SELECT id from species WHERE iupac='hydrogen sulfide'),
    (SELECT id from literature WHERE bibtexkey='3917'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3917-7783-06-4-ABC',
    '3917', 'The data from Clarke and Glew (1971) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;133.37135 +7422.07576/T +17.82903&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3917-7783-06-4-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '2300',
    'M',
    (SELECT id from species WHERE iupac='hydrogen sulfide'),
    (SELECT id from literature WHERE bibtexkey='3718'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '2100',
    'M',
    (SELECT id from species WHERE iupac='hydrogen sulfide'),
    (SELECT id from literature WHERE bibtexkey='862'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '2000',
    'M',
    (SELECT id from species WHERE iupac='hydrogen sulfide'),
    (SELECT id from literature WHERE bibtexkey='3933'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3933-7783-06-4-ABC',
    '3933', 'The data from Schoenfeld (1855) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( 98.96644 &#8722;3021.28876/T &#8722;16.78233&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3933-7783-06-4-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;4</sup>',
    '2000',
    'R',
    (SELECT id from species WHERE iupac='hydrogen sulfide'),
    (SELECT id from literature WHERE bibtexkey='2630'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='hydrogen sulfide'),
    (SELECT id from literature WHERE bibtexkey='714'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '2300',
    'T',
    (SELECT id from species WHERE iupac='hydrogen sulfide'),
    (SELECT id from literature WHERE bibtexkey='3540'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydrogen sulfide'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '2000',
    '?',
    (SELECT id from species WHERE iupac='hydrogen sulfide'),
    (SELECT id from literature WHERE bibtexkey='3811'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '2100',
    '?',
    (SELECT id from species WHERE iupac='hydrogen sulfide'),
    (SELECT id from literature WHERE bibtexkey='379'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0379-7783-06-4-ABC',
    '379', 'The data from Dean and Lange (1999) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;122.57010 +6962.28299/T +16.20245&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0379-7783-06-4-ABC'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='379'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='hydrogen sulfide'),
    (SELECT id from literature WHERE bibtexkey='2629'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2629',
    '2630', 'The parameter fit for the temperature dependence is incorrect. A corrected version was later presented by Iliuta and Larachi (2007).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2629'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'deuterium sulfide',
    'D<sub>2</sub>S',
    '',
    '13536-94-2',
    'RWSOTUBLDIXVET-ZSJDYOACSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;4</sup>',
    '2100',
    'M',
    (SELECT id from species WHERE iupac='deuterium sulfide'),
    (SELECT id from literature WHERE bibtexkey='3917'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3917-13536-94-2-ABC',
    '3917', 'The data from Clarke and Glew (1971) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;152.96053 +8324.82999/T +20.73129&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3917-13536-94-2-ABC'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3917',
    '', 'Obtained with D<sub>2</sub>O as solvent.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'sulfur dioxide',
    'SO<sub>2</sub>',
    '',
    '7446-09-5',
    'RAHZWNYVWXNFOC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '2900',
    'L',
    (SELECT id from species WHERE iupac='sulfur dioxide'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '2900',
    'L',
    (SELECT id from species WHERE iupac='sulfur dioxide'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '2900',
    'L',
    (SELECT id from species WHERE iupac='sulfur dioxide'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '2900',
    'L',
    (SELECT id from species WHERE iupac='sulfur dioxide'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '3100',
    'L',
    (SELECT id from species WHERE iupac='sulfur dioxide'),
    (SELECT id from literature WHERE bibtexkey='3085'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '2900',
    'L',
    (SELECT id from species WHERE iupac='sulfur dioxide'),
    (SELECT id from literature WHERE bibtexkey='3857'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '3200',
    'L',
    (SELECT id from species WHERE iupac='sulfur dioxide'),
    (SELECT id from literature WHERE bibtexkey='834'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '3000',
    'L',
    (SELECT id from species WHERE iupac='sulfur dioxide'),
    (SELECT id from literature WHERE bibtexkey='540'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '2800',
    'L',
    (SELECT id from species WHERE iupac='sulfur dioxide'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='sulfur dioxide'),
    (SELECT id from literature WHERE bibtexkey='3064'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'at353K',
    '', 'Value at T = 353&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at353K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '3100',
    'M',
    (SELECT id from species WHERE iupac='sulfur dioxide'),
    (SELECT id from literature WHERE bibtexkey='1072'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '3400',
    'M',
    (SELECT id from species WHERE iupac='sulfur dioxide'),
    (SELECT id from literature WHERE bibtexkey='3933'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3933-7446-09-5-ABC',
    '3933', 'The data from Schoenfeld (1855) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( 265.79241 &#8722;9131.99684/T &#8722;42.01987&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3933-7446-09-5-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '1200',
    'V',
    (SELECT id from species WHERE iupac='sulfur dioxide'),
    (SELECT id from literature WHERE bibtexkey='3122'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '3100',
    'T',
    (SELECT id from species WHERE iupac='sulfur dioxide'),
    (SELECT id from literature WHERE bibtexkey='87'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '3100',
    'T',
    (SELECT id from species WHERE iupac='sulfur dioxide'),
    (SELECT id from literature WHERE bibtexkey='3540'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='sulfur dioxide'),
    (SELECT id from literature WHERE bibtexkey='rodriguez2001'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'from3536',
    '3536', 'Value given here as quoted by Rodríguez-Sevilla et&nbsp;al. (2002).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3536'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '3100',
    'C',
    (SELECT id from species WHERE iupac='sulfur dioxide'),
    (SELECT id from literature WHERE bibtexkey='34'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '3300',
    'C',
    (SELECT id from species WHERE iupac='sulfur dioxide'),
    (SELECT id from literature WHERE bibtexkey='821'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='sulfur dioxide'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '2900',
    '?',
    (SELECT id from species WHERE iupac='sulfur dioxide'),
    (SELECT id from literature WHERE bibtexkey='3811'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '3100',
    '?',
    (SELECT id from species WHERE iupac='sulfur dioxide'),
    (SELECT id from literature WHERE bibtexkey='379'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0379-7446-09-5-ABC',
    '379', 'The data from Dean and Lange (1999) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( 153.05871 &#8722;4328.05304/T &#8722;25.05397&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0379-7446-09-5-ABC'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='379'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '3100',
    '?',
    (SELECT id from species WHERE iupac='sulfur dioxide'),
    (SELECT id from literature WHERE bibtexkey='523'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '3100',
    '?',
    (SELECT id from species WHERE iupac='sulfur dioxide'),
    (SELECT id from literature WHERE bibtexkey='103'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'sulfur trioxide',
    'SO<sub>3</sub>',
    '',
    '7446-11-9',
    'AKEJUJNQAAGONA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='sulfur trioxide'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&#8734;',
    '',
    'E',
    (SELECT id from species WHERE iupac='sulfur trioxide'),
    (SELECT id from literature WHERE bibtexkey='271'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='infty'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'sulfuric acid',
    'H<sub>2</sub>SO<sub>4</sub>',
    '',
    '7664-93-9',
    'QAOWNCQODCNURD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'M',
    (SELECT id from species WHERE iupac='sulfuric acid'),
    (SELECT id from literature WHERE bibtexkey='769'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '769',
    '769', 'Marti et&nbsp;al. (1997) give partial pressures of H<sub>2</sub>SO<sub>4</sub> over a concentrated solution (e.g., 2.6&times;10<sup>&#8722;9</sup>&nbsp;Pa for 54.1&nbsp;wt&nbsp;% at 298&nbsp;K). Extrapolating this to dilute solutions can only be considered an order-of-magnitude approximation for H<sub>s</sub>.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='769'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'M',
    (SELECT id from species WHERE iupac='sulfuric acid'),
    (SELECT id from literature WHERE bibtexkey='201'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '201',
    '201', 'Ayers et&nbsp;al. (1980) give partial pressures of H<sub>2</sub>SO<sub>4</sub> over concentrated solutions at high temperatures. Extrapolating this to dilute solutions can only be considered an order-of-magnitude approximation for H<sub>s</sub>.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='201'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'M',
    (SELECT id from species WHERE iupac='sulfuric acid'),
    (SELECT id from literature WHERE bibtexkey='752'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '752',
    '752', 'Gmitro and Vermeulen (1964) give partial pressures of H<sub>2</sub>SO<sub>4</sub> over a concentrated solution (e.g., 10<sup>&#8722;7</sup>&nbsp;mmHg for 70&nbsp;wt&nbsp;% at 298&nbsp;K). Extrapolating this to dilute solutions can only be considered an order-of-magnitude approximation for H<sub>s</sub>.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='752'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='sulfuric acid'),
    (SELECT id from literature WHERE bibtexkey='2838'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2838',
    '2838', 'Clegg et&nbsp;al. (1998) estimate a Henry''s law constant of 5&times;10<sup>11</sup>&nbsp;atm<sup>&#8722;1</sup> at 303.15&nbsp;K for the reaction H<sub>2</sub>SO<sub>4</sub>(g) &harr; 2 H<sup>+</sup>(aq) + SO<sub>4</sub><sup>2&#8722;</sup>(aq) but do not give a definition for it. Probably it is defined as x<sup>2</sup>(H<sup>+</sup>)&times;x(SO<sub>4</sub><sup>2&#8722;</sup>)/p(H<sub>2</sub>SO<sub>4</sub>), where x is the aqueous-phase mixing ratio.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2838'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>13</sup>',
    '20000',
    'T',
    (SELECT id from species WHERE iupac='sulfuric acid'),
    (SELECT id from literature WHERE bibtexkey='140'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>7</sup>',
    '10000',
    'T',
    (SELECT id from species WHERE iupac='sulfuric acid'),
    (SELECT id from literature WHERE bibtexkey='1076'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'sulfur hexafluoride',
    'SF<sub>6</sub>',
    '',
    '2551-62-4',
    'SFZCNBIFKDRMGX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;6</sup>',
    '3100',
    'L',
    (SELECT id from species WHERE iupac='sulfur hexafluoride'),
    (SELECT id from literature WHERE bibtexkey='2828'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;6</sup>',
    '2100',
    'L',
    (SELECT id from species WHERE iupac='sulfur hexafluoride'),
    (SELECT id from literature WHERE bibtexkey='2105'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2105'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;6</sup>',
    '2400',
    'L',
    (SELECT id from species WHERE iupac='sulfur hexafluoride'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;6</sup>',
    '2700',
    'M',
    (SELECT id from species WHERE iupac='sulfur hexafluoride'),
    (SELECT id from literature WHERE bibtexkey='1776'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref1776-2551-62-4-ABC',
    '1776', 'The data from Bullister et&nbsp;al. (2002) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;281.50843 +14256.43847/T +38.73689&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref1776-2551-62-4-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='sulfur hexafluoride'),
    (SELECT id from literature WHERE bibtexkey='2924'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;6</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='sulfur hexafluoride'),
    (SELECT id from literature WHERE bibtexkey='2486'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;6</sup>',
    '260',
    'M',
    (SELECT id from species WHERE iupac='sulfur hexafluoride'),
    (SELECT id from literature WHERE bibtexkey='3601'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HTdep_r2_lessthan_0.5'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='sulfur hexafluoride'),
    (SELECT id from literature WHERE bibtexkey='3786'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='sulfur hexafluoride'),
    (SELECT id from literature WHERE bibtexkey='3787'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'M',
    (SELECT id from species WHERE iupac='sulfur hexafluoride'),
    (SELECT id from literature WHERE bibtexkey='3785'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3785SF6',
    '3785', 'The data presented for SF6 in Table&nbsp;II of Shoor et&nbsp;al. (1969) appear to be incorrect and are not reproduced here.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3785SF6'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;6</sup>',
    '2400',
    'M',
    (SELECT id from species WHERE iupac='sulfur hexafluoride'),
    (SELECT id from literature WHERE bibtexkey='2831'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2831-2551-62-4-ABC',
    '2831', 'The data from Ashton et&nbsp;al. (1968) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;431.90650 +20715.81650/T +61.33841&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2831-2551-62-4-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;6</sup>',
    '3500',
    'M',
    (SELECT id from species WHERE iupac='sulfur hexafluoride'),
    (SELECT id from literature WHERE bibtexkey='3801'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='sulfur hexafluoride'),
    (SELECT id from literature WHERE bibtexkey='3078'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='sulfur hexafluoride'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='sulfur hexafluoride'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='sulfur hexafluoride'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3586_val',
    '', 'Value from the validation set for checking whether the model is satisfactory for compounds that are absent from the training set.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3200',
    'Q',
    (SELECT id from species WHERE iupac='sulfur hexafluoride'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='sulfur hexafluoride'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3586_exp',
    '', 'Experimental value, extracted from HENRYWIN.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2800',
    '?',
    (SELECT id from species WHERE iupac='sulfur hexafluoride'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;6</sup>',
    '2400',
    '?',
    (SELECT id from species WHERE iupac='sulfur hexafluoride'),
    (SELECT id from literature WHERE bibtexkey='3811'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='sulfur hexafluoride'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'sulfuryl fluoride',
    'SO<sub>2</sub>F<sub>2</sub>',
    '',
    '2699-79-8',
    'OBTWBSRJZRCYQV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;5</sup>',
    '3100',
    'M',
    (SELECT id from species WHERE iupac='sulfuryl fluoride'),
    (SELECT id from literature WHERE bibtexkey='2203'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='sulfuryl fluoride'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3586_V',
    '', 'Estimation based on the quotient between vapor pressure and water solubility, extracted from HENRYWIN.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='sulfuryl fluoride'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='sulfuryl fluoride'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Rare gases (He, Ne, Ar, Kr, Xe, Rn)',
    (SELECT id from categories WHERE catname='Inorganic species'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'helium',
    'He',
    '',
    '7440-59-7',
    'SWQJXJOGLNCZEY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Rare gases (He, Ne, Ar, Kr, Xe, Rn)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;6</sup>',
    '15',
    'L',
    (SELECT id from species WHERE iupac='helium'),
    (SELECT id from literature WHERE bibtexkey='2105'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2105'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;6</sup>',
    '83',
    'L',
    (SELECT id from species WHERE iupac='helium'),
    (SELECT id from literature WHERE bibtexkey='1498'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;6</sup>',
    '83',
    'L',
    (SELECT id from species WHERE iupac='helium'),
    (SELECT id from literature WHERE bibtexkey='3849'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;6</sup>',
    '92',
    'L',
    (SELECT id from species WHERE iupac='helium'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;6</sup>',
    '320',
    'L',
    (SELECT id from species WHERE iupac='helium'),
    (SELECT id from literature WHERE bibtexkey='3431'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;6</sup>',
    '69',
    'M',
    (SELECT id from species WHERE iupac='helium'),
    (SELECT id from literature WHERE bibtexkey='2436'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'M',
    (SELECT id from species WHERE iupac='helium'),
    (SELECT id from literature WHERE bibtexkey='3785'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3785helium',
    '3785', 'The data presented for helium in Table&nbsp;II of Shoor et&nbsp;al. (1969) appear to be incorrect and are not reproduced here.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3785helium'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;6</sup>',
    '120',
    'M',
    (SELECT id from species WHERE iupac='helium'),
    (SELECT id from literature WHERE bibtexkey='764'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0764-7440-59-7-ABC',
    '764', 'The data from Morrison and Johnstone (1954) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;267.15298 +11440.04263/T +37.95994&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0764-7440-59-7-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;6</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='helium'),
    (SELECT id from literature WHERE bibtexkey='3801'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;6</sup>',
    '210',
    'M',
    (SELECT id from species WHERE iupac='helium'),
    (SELECT id from literature WHERE bibtexkey='3789'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3789-7440-59-7-ABC',
    '3789', 'The data from Lannung (1930) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( 84.35043 &#8722;4135.59197/T &#8722;14.55881&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3789-7440-59-7-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;6</sup>',
    '380',
    'M',
    (SELECT id from species WHERE iupac='helium'),
    (SELECT id from literature WHERE bibtexkey='3548'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;6</sup>',
    '-700',
    'M',
    (SELECT id from species WHERE iupac='helium'),
    (SELECT id from literature WHERE bibtexkey='3714'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HTdep_r2_lessthan_0.5'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;6</sup>',
    '220',
    'V',
    (SELECT id from species WHERE iupac='helium'),
    (SELECT id from literature WHERE bibtexkey='2375'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;6</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='helium'),
    (SELECT id from literature WHERE bibtexkey='766'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='helium'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;6</sup>',
    '4',
    'Q',
    (SELECT id from species WHERE iupac='helium'),
    (SELECT id from literature WHERE bibtexkey='3517'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HTdep_r2_lessthan_0.5'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;6</sup>',
    '71',
    'Q',
    (SELECT id from species WHERE iupac='helium'),
    (SELECT id from literature WHERE bibtexkey='3517'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HTdep_r2_lessthan_0.5'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3517-Warr',
    '3550', 'Calculated employing molecular force field models for the solutes from Warr et&nbsp;al. (2015).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3517-Warr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='helium'),
    (SELECT id from literature WHERE bibtexkey='3550'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;6</sup>',
    '83',
    '?',
    (SELECT id from species WHERE iupac='helium'),
    (SELECT id from literature WHERE bibtexkey='3811'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='helium'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;6</sup>',
    '200',
    '?',
    (SELECT id from species WHERE iupac='helium'),
    (SELECT id from literature WHERE bibtexkey='379'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0379-7440-59-7-ABC',
    '379', 'The data from Dean and Lange (1999) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;153.15219 +6434.36008/T +20.89911&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0379-7440-59-7-ABC'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='379'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='helium'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'neon',
    'Ne',
    '',
    '7440-01-9',
    'GKAOGPIIYCISHV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Rare gases (He, Ne, Ar, Kr, Xe, Rn)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;6</sup>',
    '430',
    'L',
    (SELECT id from species WHERE iupac='neon'),
    (SELECT id from literature WHERE bibtexkey='2105'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2105'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;6</sup>',
    '470',
    'L',
    (SELECT id from species WHERE iupac='neon'),
    (SELECT id from literature WHERE bibtexkey='1498'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;6</sup>',
    '470',
    'L',
    (SELECT id from species WHERE iupac='neon'),
    (SELECT id from literature WHERE bibtexkey='3849'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;6</sup>',
    '450',
    'L',
    (SELECT id from species WHERE iupac='neon'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;6</sup>',
    '440',
    'M',
    (SELECT id from species WHERE iupac='neon'),
    (SELECT id from literature WHERE bibtexkey='2436'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;6</sup>',
    '510',
    'M',
    (SELECT id from species WHERE iupac='neon'),
    (SELECT id from literature WHERE bibtexkey='2557'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;6</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='neon'),
    (SELECT id from literature WHERE bibtexkey='3787'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;6</sup>',
    '460',
    'M',
    (SELECT id from species WHERE iupac='neon'),
    (SELECT id from literature WHERE bibtexkey='764'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0764-7440-01-9-ABC',
    '764', 'The data from Morrison and Johnstone (1954) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;171.84866 +7492.61303/T +23.58966&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0764-7440-01-9-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;6</sup>',
    '37',
    'M',
    (SELECT id from species WHERE iupac='neon'),
    (SELECT id from literature WHERE bibtexkey='3789'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3789-7440-01-9-ABC',
    '3789', 'The data from Lannung (1930) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;40.04033 +1266.80589/T +4.12574&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3789-7440-01-9-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;6</sup>',
    '-990',
    'M',
    (SELECT id from species WHERE iupac='neon'),
    (SELECT id from literature WHERE bibtexkey='3714'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;6</sup>',
    '510',
    'V',
    (SELECT id from species WHERE iupac='neon'),
    (SELECT id from literature WHERE bibtexkey='2375'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;6</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='neon'),
    (SELECT id from literature WHERE bibtexkey='766'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='neon'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;6</sup>',
    '250',
    'Q',
    (SELECT id from species WHERE iupac='neon'),
    (SELECT id from literature WHERE bibtexkey='3517'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HTdep_r2_lessthan_0.9'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;6</sup>',
    '470',
    'Q',
    (SELECT id from species WHERE iupac='neon'),
    (SELECT id from literature WHERE bibtexkey='3517'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HTdep_r2_lessthan_0.9'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3517-Warr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='neon'),
    (SELECT id from literature WHERE bibtexkey='3550'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;6</sup>',
    '470',
    '?',
    (SELECT id from species WHERE iupac='neon'),
    (SELECT id from literature WHERE bibtexkey='3811'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='neon'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;6</sup>',
    '550',
    '?',
    (SELECT id from species WHERE iupac='neon'),
    (SELECT id from literature WHERE bibtexkey='379'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0379-7440-01-9-ABC',
    '379', 'The data from Dean and Lange (1999) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;150.94728 +6639.96438/T +20.42365&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0379-7440-01-9-ABC'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='379'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='neon'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'argon',
    'Ar',
    '',
    '7440-37-1',
    'XKRFYHLGVUSROY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Rare gases (He, Ne, Ar, Kr, Xe, Rn)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '1700',
    'L',
    (SELECT id from species WHERE iupac='argon'),
    (SELECT id from literature WHERE bibtexkey='2828'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '1400',
    'L',
    (SELECT id from species WHERE iupac='argon'),
    (SELECT id from literature WHERE bibtexkey='2105'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2105'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '1500',
    'L',
    (SELECT id from species WHERE iupac='argon'),
    (SELECT id from literature WHERE bibtexkey='1498'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '1500',
    'L',
    (SELECT id from species WHERE iupac='argon'),
    (SELECT id from literature WHERE bibtexkey='3851'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '1500',
    'L',
    (SELECT id from species WHERE iupac='argon'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '1400',
    'M',
    (SELECT id from species WHERE iupac='argon'),
    (SELECT id from literature WHERE bibtexkey='2435'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2435-7440-37-1-ABC',
    '2435', 'The data from Rettich et&nbsp;al. (1992) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;178.55165 +8674.63293/T +24.26764&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2435-7440-37-1-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '1400',
    'M',
    (SELECT id from species WHERE iupac='argon'),
    (SELECT id from literature WHERE bibtexkey='2436'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='argon'),
    (SELECT id from literature WHERE bibtexkey='2486'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '1500',
    'M',
    (SELECT id from species WHERE iupac='argon'),
    (SELECT id from literature WHERE bibtexkey='2557'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '1200',
    'M',
    (SELECT id from species WHERE iupac='argon'),
    (SELECT id from literature WHERE bibtexkey='3601'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '1300',
    'M',
    (SELECT id from species WHERE iupac='argon'),
    (SELECT id from literature WHERE bibtexkey='3547'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '1500',
    'M',
    (SELECT id from species WHERE iupac='argon'),
    (SELECT id from literature WHERE bibtexkey='3567'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3567-7440-37-1-ABC',
    '3567', 'The data from Murray and Riley (1970) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;151.84230 +7548.13106/T +20.24085&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3567-7440-37-1-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '1600',
    'M',
    (SELECT id from species WHERE iupac='argon'),
    (SELECT id from literature WHERE bibtexkey='3785'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3785-7440-37-1-ABC',
    '3785', 'The data from Shoor et&nbsp;al. (1969) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;177.19900 +8740.49327/T +23.99118&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3785-7440-37-1-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '1500',
    'M',
    (SELECT id from species WHERE iupac='argon'),
    (SELECT id from literature WHERE bibtexkey='2831'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2831-7440-37-1-ABC',
    '2831', 'The data from Ashton et&nbsp;al. (1968) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;160.52023 +7898.05096/T +21.56102&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2831-7440-37-1-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '1500',
    'M',
    (SELECT id from species WHERE iupac='argon'),
    (SELECT id from literature WHERE bibtexkey='764'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0764-7440-37-1-ABC',
    '764', 'The data from Morrison and Johnstone (1954) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;159.49603 +7859.86242/T +21.39868&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0764-7440-37-1-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '1800',
    'M',
    (SELECT id from species WHERE iupac='argon'),
    (SELECT id from literature WHERE bibtexkey='3801'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '1400',
    'M',
    (SELECT id from species WHERE iupac='argon'),
    (SELECT id from literature WHERE bibtexkey='3789'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3789-7440-37-1-ABC',
    '3789', 'The data from Lannung (1930) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;183.19260 +8856.79081/T +24.97248&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3789-7440-37-1-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '1300',
    'M',
    (SELECT id from species WHERE iupac='argon'),
    (SELECT id from literature WHERE bibtexkey='3714'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '1400',
    'M',
    (SELECT id from species WHERE iupac='argon'),
    (SELECT id from literature WHERE bibtexkey='862'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '1400',
    'V',
    (SELECT id from species WHERE iupac='argon'),
    (SELECT id from literature WHERE bibtexkey='2375'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '1400',
    'V',
    (SELECT id from species WHERE iupac='argon'),
    (SELECT id from literature WHERE bibtexkey='2375'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;5</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='argon'),
    (SELECT id from literature WHERE bibtexkey='766'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='argon'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;6</sup>',
    '1200',
    'Q',
    (SELECT id from species WHERE iupac='argon'),
    (SELECT id from literature WHERE bibtexkey='3517'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3517-Warr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '1100',
    'Q',
    (SELECT id from species WHERE iupac='argon'),
    (SELECT id from literature WHERE bibtexkey='3517'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3517-Vrabec',
    '3551', 'Calculated employing molecular force field models for the solutes from Vrabec et&nbsp;al. (2001).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3517-Vrabec'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='argon'),
    (SELECT id from literature WHERE bibtexkey='3550'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '1500',
    '?',
    (SELECT id from species WHERE iupac='argon'),
    (SELECT id from literature WHERE bibtexkey='3811'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='argon'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '1500',
    '?',
    (SELECT id from species WHERE iupac='argon'),
    (SELECT id from literature WHERE bibtexkey='379'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0379-7440-37-1-ABC',
    '379', 'The data from Dean and Lange (1999) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;143.77232 +7158.59719/T +19.05403&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0379-7440-37-1-ABC'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='379'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='argon'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'krypton',
    'Kr',
    '',
    '7439-90-9',
    'DNNSSWSSYDEUBZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Rare gases (He, Ne, Ar, Kr, Xe, Rn)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '1700',
    'L',
    (SELECT id from species WHERE iupac='krypton'),
    (SELECT id from literature WHERE bibtexkey='2105'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2105'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '1900',
    'L',
    (SELECT id from species WHERE iupac='krypton'),
    (SELECT id from literature WHERE bibtexkey='1498'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '1900',
    'L',
    (SELECT id from species WHERE iupac='krypton'),
    (SELECT id from literature WHERE bibtexkey='3850'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '1900',
    'L',
    (SELECT id from species WHERE iupac='krypton'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='krypton'),
    (SELECT id from literature WHERE bibtexkey='2441'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '2000',
    'L',
    (SELECT id from species WHERE iupac='krypton'),
    (SELECT id from literature WHERE bibtexkey='3696'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '1800',
    'M',
    (SELECT id from species WHERE iupac='krypton'),
    (SELECT id from literature WHERE bibtexkey='2436'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '1900',
    'M',
    (SELECT id from species WHERE iupac='krypton'),
    (SELECT id from literature WHERE bibtexkey='2557'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;5</sup>',
    '1800',
    'M',
    (SELECT id from species WHERE iupac='krypton'),
    (SELECT id from literature WHERE bibtexkey='3601'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;5</sup>',
    '1700',
    'M',
    (SELECT id from species WHERE iupac='krypton'),
    (SELECT id from literature WHERE bibtexkey='764'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0764-7439-90-9-ABC',
    '764', 'The data from Morrison and Johnstone (1954) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;153.87925 +7855.39037/T +20.51280&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0764-7439-90-9-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;5</sup>',
    '1400',
    'M',
    (SELECT id from species WHERE iupac='krypton'),
    (SELECT id from literature WHERE bibtexkey='3714'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3714_krypton',
    '3714', 'Two series of measurements with considerably different results are presented by von Antropoff (1910) for krypton.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3714_krypton'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;5</sup>',
    '1900',
    'M',
    (SELECT id from species WHERE iupac='krypton'),
    (SELECT id from literature WHERE bibtexkey='3714'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3714_krypton'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;5</sup>',
    '1800',
    'V',
    (SELECT id from species WHERE iupac='krypton'),
    (SELECT id from literature WHERE bibtexkey='2375'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;5</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='krypton'),
    (SELECT id from literature WHERE bibtexkey='766'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='krypton'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '1600',
    'Q',
    (SELECT id from species WHERE iupac='krypton'),
    (SELECT id from literature WHERE bibtexkey='3517'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3517-Warr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '1400',
    'Q',
    (SELECT id from species WHERE iupac='krypton'),
    (SELECT id from literature WHERE bibtexkey='3517'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3517-Vrabec'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='krypton'),
    (SELECT id from literature WHERE bibtexkey='3550'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '1900',
    '?',
    (SELECT id from species WHERE iupac='krypton'),
    (SELECT id from literature WHERE bibtexkey='3811'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='krypton'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '1800',
    '?',
    (SELECT id from species WHERE iupac='krypton'),
    (SELECT id from literature WHERE bibtexkey='379'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0379-7439-90-9-ABC',
    '379', 'The data from Dean and Lange (1999) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;220.92114 +10903.79433/T +30.49407&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0379-7439-90-9-ABC'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='379'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='krypton'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'xenon',
    'Xe',
    '',
    '7440-63-3',
    'FHNFHKCVQCLJFQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Rare gases (He, Ne, Ar, Kr, Xe, Rn)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;5</sup>',
    '2200',
    'L',
    (SELECT id from species WHERE iupac='xenon'),
    (SELECT id from literature WHERE bibtexkey='2105'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2105'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;5</sup>',
    '2300',
    'L',
    (SELECT id from species WHERE iupac='xenon'),
    (SELECT id from literature WHERE bibtexkey='1498'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;5</sup>',
    '2300',
    'L',
    (SELECT id from species WHERE iupac='xenon'),
    (SELECT id from literature WHERE bibtexkey='3850'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;5</sup>',
    '2200',
    'L',
    (SELECT id from species WHERE iupac='xenon'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='xenon'),
    (SELECT id from literature WHERE bibtexkey='2441'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;5</sup>',
    '2400',
    'L',
    (SELECT id from species WHERE iupac='xenon'),
    (SELECT id from literature WHERE bibtexkey='3696'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;5</sup>',
    '2400',
    'L',
    (SELECT id from species WHERE iupac='xenon'),
    (SELECT id from literature WHERE bibtexkey='3431'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3431',
    '3431', 'The value b for Xe given by Himmelblau (1960) in their Table&nbsp;III is incorrect. Most likely, only a minus sign is missing.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3431'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;5</sup>',
    '2300',
    'M',
    (SELECT id from species WHERE iupac='xenon'),
    (SELECT id from literature WHERE bibtexkey='2436'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;5</sup>',
    '2400',
    'M',
    (SELECT id from species WHERE iupac='xenon'),
    (SELECT id from literature WHERE bibtexkey='2557'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;5</sup>',
    '2200',
    'M',
    (SELECT id from species WHERE iupac='xenon'),
    (SELECT id from literature WHERE bibtexkey='764'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0764-7440-63-3-ABC',
    '764', 'The data from Morrison and Johnstone (1954) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;165.83721 +8808.62019/T +22.15186&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0764-7440-63-3-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;5</sup>',
    '2500',
    'M',
    (SELECT id from species WHERE iupac='xenon'),
    (SELECT id from literature WHERE bibtexkey='3714'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;5</sup>',
    '2200',
    'V',
    (SELECT id from species WHERE iupac='xenon'),
    (SELECT id from literature WHERE bibtexkey='2375'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;5</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='xenon'),
    (SELECT id from literature WHERE bibtexkey='766'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='xenon'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;5</sup>',
    '2300',
    'Q',
    (SELECT id from species WHERE iupac='xenon'),
    (SELECT id from literature WHERE bibtexkey='3517'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3517-Warr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;5</sup>',
    '1800',
    'Q',
    (SELECT id from species WHERE iupac='xenon'),
    (SELECT id from literature WHERE bibtexkey='3517'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3517-Vrabec'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='xenon'),
    (SELECT id from literature WHERE bibtexkey='3550'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;5</sup>',
    '2300',
    '?',
    (SELECT id from species WHERE iupac='xenon'),
    (SELECT id from literature WHERE bibtexkey='3811'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='xenon'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;5</sup>',
    '2200',
    '?',
    (SELECT id from species WHERE iupac='xenon'),
    (SELECT id from literature WHERE bibtexkey='379'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0379-7440-63-3-ABC',
    '379', 'The data from Dean and Lange (1999) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;199.40126 +10306.10786/T +27.18844&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0379-7440-63-3-ABC'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='379'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='xenon'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'xenon-133',
    '<sup>133</sup>Xe',
    '',
    '14932-42-4',
    'FHNFHKCVQCLJFQ-NJFSPNSNSA-N',
    (SELECT id from subcategories WHERE subcatname='Rare gases (He, Ne, Ar, Kr, Xe, Rn)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;5</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='xenon-133'),
    (SELECT id from literature WHERE bibtexkey='3700'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'radon',
    'Rn',
    '',
    '10043-92-2',
    'SYUHGPGVQRZVTB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Rare gases (He, Ne, Ar, Kr, Xe, Rn)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;5</sup>',
    '2900',
    'L',
    (SELECT id from species WHERE iupac='radon'),
    (SELECT id from literature WHERE bibtexkey='1498'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;5</sup>',
    '2600',
    'L',
    (SELECT id from species WHERE iupac='radon'),
    (SELECT id from literature WHERE bibtexkey='3850'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;5</sup>',
    '2600',
    'L',
    (SELECT id from species WHERE iupac='radon'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;5</sup>',
    '2600',
    'M',
    (SELECT id from species WHERE iupac='radon'),
    (SELECT id from literature WHERE bibtexkey='3545'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3545-10043-92-2-ABC',
    '3545', 'The data from Lewis et&nbsp;al. (1987) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( 5.03587 +1555.37916/T &#8722;3.42648&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3545-10043-92-2-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;4</sup>',
    '2700',
    'M',
    (SELECT id from species WHERE iupac='radon'),
    (SELECT id from literature WHERE bibtexkey='3546'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='radon'),
    (SELECT id from literature WHERE bibtexkey='766'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='radon'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;5</sup>',
    '2400',
    'Q',
    (SELECT id from species WHERE iupac='radon'),
    (SELECT id from literature WHERE bibtexkey='3517'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3517-Mick',
    '3552', 'Calculated employing molecular force field models for the solutes from Mick et&nbsp;al. (2016).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3517-Mick'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;5</sup>',
    '2600',
    '?',
    (SELECT id from species WHERE iupac='radon'),
    (SELECT id from literature WHERE bibtexkey='3811'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;5</sup>',
    '2800',
    '?',
    (SELECT id from species WHERE iupac='radon'),
    (SELECT id from literature WHERE bibtexkey='379'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0379-10043-92-2-ABC',
    '379', 'The data from Dean and Lange (1999) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;240.66156 +12686.97685/T +33.12171&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0379-10043-92-2-ABC'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='379'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='radon'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Other elements (B, Se, P, As, Hg)',
    (SELECT id from categories WHERE catname='Inorganic species'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'boric acid',
    'H<sub>3</sub>BO<sub>3</sub>',
    '',
    '10043-35-3',
    'KGBXLFKZBHKPEV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Other elements (B, Se, P, As, Hg)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='boric acid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'selenium hydride',
    'H<sub>2</sub>Se',
    '',
    '7783-07-5',
    'BUGBHKTXTAQXES-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Other elements (B, Se, P, As, Hg)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;4</sup>',
    '1700',
    'L',
    (SELECT id from species WHERE iupac='selenium hydride'),
    (SELECT id from literature WHERE bibtexkey='3863'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;4</sup>',
    '1900',
    'L',
    (SELECT id from species WHERE iupac='selenium hydride'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;4</sup>',
    '1900',
    'M',
    (SELECT id from species WHERE iupac='selenium hydride'),
    (SELECT id from literature WHERE bibtexkey='3808'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3808-7783-07-5-ABC',
    '3808', 'The data from Sisi et&nbsp;al. (1971) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;81.82525 +4954.57763/T +10.19950&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3808-7783-07-5-ABC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phosphorus trihydride',
    'PH<sub>3</sub>',
    'phosphine',
    '7803-51-2',
    'XYFCBTPGUUZFHI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Other elements (B, Se, P, As, Hg)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;5</sup>',
    '2000',
    'L',
    (SELECT id from species WHERE iupac='phosphorus trihydride'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;5</sup>',
    '3000',
    'M',
    (SELECT id from species WHERE iupac='phosphorus trihydride'),
    (SELECT id from literature WHERE bibtexkey='3033'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3033seawater',
    '', 'Solubility in natural sea water. Measurements at different salinities were also performed but only at a fixed temperature of 296.15&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3033seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;5</sup>',
    '2000',
    '?',
    (SELECT id from species WHERE iupac='phosphorus trihydride'),
    (SELECT id from literature WHERE bibtexkey='3811'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'arsenic hydride',
    'AsH<sub>3</sub>',
    'arsine',
    '7784-42-1',
    'RQNWIZPPADIBDY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Other elements (B, Se, P, As, Hg)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;5</sup>',
    '2100',
    'L',
    (SELECT id from species WHERE iupac='arsenic hydride'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'mercury',
    'Hg',
    '',
    '7439-97-6',
    'QSHDDOUJBYECFT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Other elements (B, Se, P, As, Hg)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '2600',
    'L',
    (SELECT id from species WHERE iupac='mercury'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '2600',
    'L',
    (SELECT id from species WHERE iupac='mercury'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '5400',
    'L',
    (SELECT id from species WHERE iupac='mercury'),
    (SELECT id from literature WHERE bibtexkey='3862'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '4800',
    'L',
    (SELECT id from species WHERE iupac='mercury'),
    (SELECT id from literature WHERE bibtexkey='2279'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '2600',
    'M',
    (SELECT id from species WHERE iupac='mercury'),
    (SELECT id from literature WHERE bibtexkey='2820'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '2500',
    'M',
    (SELECT id from species WHERE iupac='mercury'),
    (SELECT id from literature WHERE bibtexkey='2280'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='mercury'),
    (SELECT id from literature WHERE bibtexkey='2471'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '5700',
    'V',
    (SELECT id from species WHERE iupac='mercury'),
    (SELECT id from literature WHERE bibtexkey='2578'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='mercury'),
    (SELECT id from literature WHERE bibtexkey='2285'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='mercury'),
    (SELECT id from literature WHERE bibtexkey='3070'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2300',
    'Q',
    (SELECT id from species WHERE iupac='mercury'),
    (SELECT id from literature WHERE bibtexkey='2577'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2577-LFER',
    '', 'Temperature dependence calculated using linear free energy relationships (LFERs).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2577-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='mercury'),
    (SELECT id from literature WHERE bibtexkey='2171'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '2700',
    '?',
    (SELECT id from species WHERE iupac='mercury'),
    (SELECT id from literature WHERE bibtexkey='2171'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='mercury'),
    (SELECT id from literature WHERE bibtexkey='2286'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2286',
    '2286', 'Petersen et&nbsp;al. (1998) give the invalid unit "mol&nbsp;L<sup>&#8722;1</sup>&nbsp;ppm<sup>&#8722;1</sup>". Here, it is assumed that "ppm" is used as a synonym for "10<sup>&#8722;6</sup>&nbsp;atm".');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2286'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='mercury'),
    (SELECT id from literature WHERE bibtexkey='695'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'mercury(II) oxide',
    'HgO',
    '',
    '21908-53-2',
    'UKWHYYKOEPRTIC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Other elements (B, Se, P, As, Hg)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='mercury(II) oxide'),
    (SELECT id from literature WHERE bibtexkey='2285'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2285wrongrefHgO',
    '2285,2286', 'Shon et&nbsp;al. (2005) refer to Petersen et&nbsp;al. (1998) as the source, but a different value is listed there.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2285wrongrefHgO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>10</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='mercury(II) oxide'),
    (SELECT id from literature WHERE bibtexkey='2171'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='mercury(II) oxide'),
    (SELECT id from literature WHERE bibtexkey='2286'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2286'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'mercury dihydroxide',
    'Hg(OH)<sub>2</sub>',
    '',
    '12135-13-6',
    'VLKKXDVIWIBHHS-UHFFFAOYSA-L',
    (SELECT id from subcategories WHERE subcatname='Other elements (B, Se, P, As, Hg)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '4200',
    'C',
    (SELECT id from species WHERE iupac='mercury dihydroxide'),
    (SELECT id from literature WHERE bibtexkey='3070'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '4200',
    'C',
    (SELECT id from species WHERE iupac='mercury dihydroxide'),
    (SELECT id from literature WHERE bibtexkey='2290'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'mercury dichloride',
    'HgCl<sub>2</sub>',
    '',
    '7487-94-7',
    'LWJROJCJINYWOX-UHFFFAOYSA-L',
    (SELECT id from subcategories WHERE subcatname='Other elements (B, Se, P, As, Hg)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='mercury dichloride'),
    (SELECT id from literature WHERE bibtexkey='2572'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'at333K',
    '', 'Value at T = 333&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at333K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='mercury dichloride'),
    (SELECT id from literature WHERE bibtexkey='2577'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='mercury dichloride'),
    (SELECT id from literature WHERE bibtexkey='2577'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '7400',
    'R',
    (SELECT id from species WHERE iupac='mercury dichloride'),
    (SELECT id from literature WHERE bibtexkey='2571'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>5</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='mercury dichloride'),
    (SELECT id from literature WHERE bibtexkey='2285'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '5300',
    'C',
    (SELECT id from species WHERE iupac='mercury dichloride'),
    (SELECT id from literature WHERE bibtexkey='3070'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '5300',
    'C',
    (SELECT id from species WHERE iupac='mercury dichloride'),
    (SELECT id from literature WHERE bibtexkey='2290'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>4</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='mercury dichloride'),
    (SELECT id from literature WHERE bibtexkey='2577'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2577',
    '', 'Calculated using linear free energy relationships (LFERs).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2577'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='mercury dichloride'),
    (SELECT id from literature WHERE bibtexkey='2171'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '9500',
    '?',
    (SELECT id from species WHERE iupac='mercury dichloride'),
    (SELECT id from literature WHERE bibtexkey='2570'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='mercury dichloride'),
    (SELECT id from literature WHERE bibtexkey='2576'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'morethanoneref',
    '', 'More than one reference is given as the source of this value.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='morethanoneref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'mercury dibromide',
    'HgBr<sub>2</sub>',
    '',
    '7789-47-1',
    'NGYIMTKLQULBOO-UHFFFAOYSA-L',
    (SELECT id from subcategories WHERE subcatname='Other elements (B, Se, P, As, Hg)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='mercury dibromide'),
    (SELECT id from literature WHERE bibtexkey='2577'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>2</sup>',
    '7400',
    'C',
    (SELECT id from species WHERE iupac='mercury dibromide'),
    (SELECT id from literature WHERE bibtexkey='2571'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>3</sup>',
    '7100',
    'Q',
    (SELECT id from species WHERE iupac='mercury dibromide'),
    (SELECT id from literature WHERE bibtexkey='2577'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2577'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='mercury dibromide'),
    (SELECT id from literature WHERE bibtexkey='2169'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2169wrongrefHgBr2',
    '2169,2255', 'Hedgecock et&nbsp;al. (2005) refer to Hedgecock and Pirrone (2004) as the source, but this value cannot be found there.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2169wrongrefHgBr2'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='mercury dibromide'),
    (SELECT id from literature WHERE bibtexkey='2576'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='morethanoneref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'mercury diiodide',
    'HgI<sub>2</sub>',
    '',
    '7774-29-0',
    'YFDLHELOZYVNJE-UHFFFAOYSA-L',
    (SELECT id from subcategories WHERE subcatname='Other elements (B, Se, P, As, Hg)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='mercury diiodide'),
    (SELECT id from literature WHERE bibtexkey='2577'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '6700',
    'Q',
    (SELECT id from species WHERE iupac='mercury diiodide'),
    (SELECT id from literature WHERE bibtexkey='2577'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2577'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    '?',
    (SELECT id from species WHERE iupac='mercury diiodide'),
    (SELECT id from literature WHERE bibtexkey='2576'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='morethanoneref'));
INSERT INTO categories (catname) VALUES (
    'Hydrocarbons (C, H)');
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Alkanes',
    (SELECT id from categories WHERE catname='Hydrocarbons (C, H)'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methane',
    'CH<sub>4</sub>',
    '',
    '74-82-8',
    'VNWKTOKETHGBQD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '1600',
    'L',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '1100',
    'L',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '1600',
    'L',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '1100',
    'L',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '1900',
    'L',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='2828'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '1600',
    'L',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '1600',
    'L',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '1500',
    'L',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='2105'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2105'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '1600',
    'L',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '1600',
    'L',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='1498'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'L',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='3861'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3861',
    '3861,491', 'Clever and Young (1987) recommend the data from Rettich et&nbsp;al. (1981).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3861'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '1700',
    'L',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '1500',
    'L',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='3431'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='3695'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '1800',
    'M',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='3690'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '2400',
    'M',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='3126'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '1400',
    'M',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='2013'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2013-74-82-8-ABC',
    '2013', 'The data from Reichl (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;133.87728 +6629.97157/T +17.62624&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2013-74-82-8-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '1600',
    'M',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='3569'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3569-74-82-8-ABC',
    '3569', 'The data from Scharlin and Battino (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;206.41168 +10058.77208/T +28.34417&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3569-74-82-8-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='2924'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '1800',
    'M',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='3734'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '1600',
    'M',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='2557'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '1600',
    'M',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='491'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '1600',
    'M',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='3601'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '1700',
    'M',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='3785'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3785-74-82-8-ABC',
    '3785', 'The data from Shoor et&nbsp;al. (1969) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;201.05778 +9920.37989/T +27.48020&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3785-74-82-8-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='3924'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3924_also_3923',
    '3923', 'The same value was also published in McAuliffe (1963).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3924_also_3923'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '1600',
    'M',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='3799'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='3923'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3923_also_3924',
    '3924', 'The same value was also published in McAuliffe (1966).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3923_also_3924'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '1600',
    'M',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='3783'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3783-74-82-8-ABC',
    '3783', 'The data from Morrison and Billett (1952) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;195.92072 +9624.37184/T +26.74976&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3783-74-82-8-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '1700',
    'M',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='2834'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2834-74-82-8-ABC',
    '2834', 'The data from Winkler (1901) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;203.15902 +9951.75251/T +27.82679&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2834-74-82-8-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '1600',
    'V',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='2375'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='713'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='714'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='766'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;6</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='529'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2300',
    'Q',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3731_RBFN',
    '3731,2440', 'Yao et&nbsp;al. (2002) compared two QSPR methods and found that radial basis function networks (RBFNs) are better than multiple linear regression. In their paper, they provide neither a definition nor the unit of their Henry''s law constants. Comparing the values with those that they cite from Yaws (1999), it is assumed that they use the variant H<sub>v</sub><sup>px</sup> and the unit atm.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2543',
    '2543', 'English and Carroll (2001) provide several calculations. Here, the preferred value with explicit inclusion of hydrogen bonding parameters from a neural network is shown.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2543-T',
    '', 'Value from the training dataset.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '1162PCR',
    '1162', 'Calculated with a principal component analysis (PCA); see Suzuki et&nbsp;al. (1992) for details.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '1700',
    '?',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '1600',
    '?',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='3811'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '1700',
    '?',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='379'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0379-74-82-8-ABC',
    '379', 'The data from Dean and Lange (1999) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;185.72813 +9197.97387/T +25.21142&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0379-74-82-8-ABC'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='379'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethane',
    'C<sub>2</sub>H<sub>6</sub>',
    '',
    '74-84-0',
    'OTMSDBZUPAUEDD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '2400',
    'L',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '2400',
    'L',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '2400',
    'L',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '2400',
    'L',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '2400',
    'L',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='2105'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2105'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '2300',
    'L',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '2300',
    'L',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='1498'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '2300',
    'L',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='3855'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;5</sup>',
    '2400',
    'L',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '2300',
    'M',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='2013'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2013-74-84-0-ABC',
    '2013', 'The data from Reichl (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;109.51433 +6313.03876/T +13.60483&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2013-74-84-0-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='2924'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;5</sup>',
    '2700',
    'M',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='3734'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '2300',
    'M',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='491'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;5</sup>',
    '2700',
    'M',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='3601'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='3924'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3924_also_3923'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '2400',
    'M',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='3799'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='3923'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3923_also_3924'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;5</sup>',
    '2100',
    'M',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='3783'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3783-74-84-0-ABC',
    '3783', 'The data from Morrison and Billett (1952) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;215.51394 +10861.98666/T +29.50128&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3783-74-84-0-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;5</sup>',
    '2400',
    'M',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='2834'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2834-74-84-0-ABC',
    '2834', 'The data from Winkler (1901) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;277.60377 +13887.90452/T +38.63046&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2834-74-84-0-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;5</sup>',
    '2000',
    'V',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='2375'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='713'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;5</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='766'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'from3579',
    '3579', 'Value given here as quoted by Gharagheizi et&nbsp;al. (2010).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;5</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='529'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3409-LFER',
    '', 'Calculated using linear free energy relationships (LFERs).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3409-SPARC',
    '', 'Calculated using SPARC Performs Automated Reasoning in Chemistry (SPARC).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3409-COSMO',
    '', 'Calculated using COSMOtherm.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'unknownT',
    '', 'Temperature is not specified.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2546-T',
    '', 'Value from the training dataset.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2546-GROMHE',
    '', 'Calculated using the GROMHE model.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2546-SPARC',
    '', 'Calculated using the SPARC approach.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2546-HENRYWIN',
    '', 'Calculated using the HENRYWIN method.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3579-NN-GC',
    '', 'Calculated using a combination of a group contribution method and neural networks.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2600',
    'Q',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3512',
    '3512', 'Modarresi et&nbsp;al. (2005) use different descriptors for the QSPR models. They conclude that their "COSA" method and the artificial neural network (ANN) are best. However, as COSA is not ideal for hydrocarbons with low solubility, only results obtained with ANN are shown here.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2535',
    '2535', 'Yaffe et&nbsp;al. (2003) present QSPR results calculated with the fuzzy ARTMAP (FAM) and with the back-propagation (BK-Pr) method. They conclude that FAM is better. Only the FAM results are shown here.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2535-Tr',
    '', 'Value from the training set.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2500',
    '?',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '2300',
    '?',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='3811'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;5</sup>',
    '2400',
    '?',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='379'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0379-74-84-0-ABC',
    '379', 'The data from Dean and Lange (1999) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;249.13770 +12672.58357/T +34.34947&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0379-74-84-0-ABC'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='379'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propane',
    'C<sub>3</sub>H<sub>8</sub>',
    '',
    '74-98-6',
    'ATUOYWHBWRKTHZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '2700',
    'L',
    (SELECT id from species WHERE iupac='propane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '2700',
    'L',
    (SELECT id from species WHERE iupac='propane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '2700',
    'L',
    (SELECT id from species WHERE iupac='propane'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '2700',
    'L',
    (SELECT id from species WHERE iupac='propane'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '2800',
    'L',
    (SELECT id from species WHERE iupac='propane'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '2800',
    'L',
    (SELECT id from species WHERE iupac='propane'),
    (SELECT id from literature WHERE bibtexkey='1498'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '2700',
    'L',
    (SELECT id from species WHERE iupac='propane'),
    (SELECT id from literature WHERE bibtexkey='3860'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='propane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '2700',
    'L',
    (SELECT id from species WHERE iupac='propane'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '2700',
    'M',
    (SELECT id from species WHERE iupac='propane'),
    (SELECT id from literature WHERE bibtexkey='3129'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '2700',
    'M',
    (SELECT id from species WHERE iupac='propane'),
    (SELECT id from literature WHERE bibtexkey='2013'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2013-74-98-6-ABC',
    '2013', 'The data from Reichl (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;275.67877 +14048.75446/T +38.16041&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2013-74-98-6-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;6</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='propane'),
    (SELECT id from literature WHERE bibtexkey='2924'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '3000',
    'M',
    (SELECT id from species WHERE iupac='propane'),
    (SELECT id from literature WHERE bibtexkey='3734'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='propane'),
    (SELECT id from literature WHERE bibtexkey='3924'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3924_also_3923'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '2700',
    'M',
    (SELECT id from species WHERE iupac='propane'),
    (SELECT id from literature WHERE bibtexkey='3799'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='propane'),
    (SELECT id from literature WHERE bibtexkey='3923'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3923_also_3924'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '2600',
    'M',
    (SELECT id from species WHERE iupac='propane'),
    (SELECT id from literature WHERE bibtexkey='3783'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3783-74-98-6-ABC',
    '3783', 'The data from Morrison and Billett (1952) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;257.69118 +13189.22089/T +35.51019&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3783-74-98-6-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '2600',
    'V',
    (SELECT id from species WHERE iupac='propane'),
    (SELECT id from literature WHERE bibtexkey='2375'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '2700',
    'V',
    (SELECT id from species WHERE iupac='propane'),
    (SELECT id from literature WHERE bibtexkey='2375'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propane'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='propane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='propane'),
    (SELECT id from literature WHERE bibtexkey='529'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propane'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2900',
    'Q',
    (SELECT id from species WHERE iupac='propane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propane'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propane'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2800',
    '?',
    (SELECT id from species WHERE iupac='propane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '4500',
    '?',
    (SELECT id from species WHERE iupac='propane'),
    (SELECT id from literature WHERE bibtexkey='3811'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'butane',
    'C<sub>4</sub>H<sub>10</sub>',
    '',
    '106-97-8',
    'IJDNQMDRQITEOD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '3100',
    'L',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3500-106-97-8-consicheck',
    '3500', 'The H298 and A, B, C data listed in Table&nbsp;5-4 of Burkholder et&nbsp;al. (2019) are inconsistent, with 14&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3500-106-97-8-consicheck'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '3100',
    'L',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3245-106-97-8-consicheck',
    '3245', 'The H298 and A, B, C data listed in Table&nbsp;5-4 of Burkholder et&nbsp;al. (2015) are inconsistent, with 14&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3245-106-97-8-consicheck'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '3100',
    'L',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2626-106-97-8-consicheck',
    '2626', 'The H298 and A, B, C data listed in Table&nbsp;5.4 of Sander et&nbsp;al. (2011) are inconsistent, with 14&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2626-106-97-8-consicheck'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '3100',
    'L',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '1945-106-97-8-consicheck',
    '1945', 'The H298 and A, B, C data listed in Table&nbsp;5.4 of Sander et&nbsp;al. (2006) are inconsistent, with 14&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1945-106-97-8-consicheck'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '3100',
    'L',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '3100',
    'L',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='1498'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '3000',
    'L',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='3860'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '3100',
    'L',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '2300',
    'M',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='3124'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;6</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='2924'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '3200',
    'M',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='3734'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='3924'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3924_also_3923'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '3200',
    'M',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='3799'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='3923'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3923_also_3924'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '2900',
    'M',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='3783'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3783-106-97-8-ABC',
    '3783', 'The data from Morrison and Billett (1952) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;257.40529 +13425.82235/T +35.27658&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3783-106-97-8-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '2900',
    'V',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='2375'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '3100',
    'V',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='2375'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='713'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'from3682',
    '3682', 'Value given here as quoted by Dupeux et&nbsp;al. (2022).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='529'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3682-COSMO',
    '', 'Calculated using the COSMO-RS method.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3300',
    'Q',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2543-V',
    '', 'Value from the validation dataset.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3300',
    '?',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '3000',
    '?',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='3811'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='butane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methylpropane',
    'HC(CH<sub>3</sub>)<sub>3</sub>',
    'isobutane',
    '75-28-5',
    'NNPPMTNAJDCUHE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;6</sup>',
    '2700',
    'L',
    (SELECT id from species WHERE iupac='2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3500-75-28-5-consicheck',
    '3500', 'The H298 and A, B, C data listed in Table&nbsp;5-4 of Burkholder et&nbsp;al. (2019) are inconsistent, with 6&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3500-75-28-5-consicheck'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;6</sup>',
    '2700',
    'L',
    (SELECT id from species WHERE iupac='2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3245-75-28-5-consicheck',
    '3245', 'The H298 and A, B, C data listed in Table&nbsp;5-4 of Burkholder et&nbsp;al. (2015) are inconsistent, with 6&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3245-75-28-5-consicheck'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;6</sup>',
    '2700',
    'L',
    (SELECT id from species WHERE iupac='2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2626-75-28-5-consicheck',
    '2626', 'The H298 and A, B, C data listed in Table&nbsp;5.4 of Sander et&nbsp;al. (2011) are inconsistent, with 6&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2626-75-28-5-consicheck'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;6</sup>',
    '2700',
    'L',
    (SELECT id from species WHERE iupac='2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '1945-75-28-5-consicheck',
    '1945', 'The H298 and A, B, C data listed in Table&nbsp;5.4 of Sander et&nbsp;al. (2006) are inconsistent, with 6&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1945-75-28-5-consicheck'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'L',
    (SELECT id from species WHERE iupac='2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '1943-75-28-5',
    '1943,3860', 'Fogg and Sangster (2003) cite an incorrect fitting function from Hayduk (1986).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1943-75-28-5'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;6</sup>',
    '2900',
    'L',
    (SELECT id from species WHERE iupac='2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;6</sup>',
    '2700',
    'L',
    (SELECT id from species WHERE iupac='2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='3860'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3860-75-28-5',
    '3860,3799', 'The fitting function and the data in the table on page 34 of Hayduk (1986) are inconsistent by a factor of about 3. A comparison with the original measurements by Wetlaufer et&nbsp;al. (1964) shows that the data in the table are correct. Refitting the data suggests that the third fitting parameter should be 52.4651, not 53.4651.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3860-75-28-5'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;6</sup>',
    '2700',
    'L',
    (SELECT id from species WHERE iupac='2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '5100',
    'M',
    (SELECT id from species WHERE iupac='2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='3117'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;6</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='3924'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3924_also_3923'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;6</sup>',
    '2700',
    'M',
    (SELECT id from species WHERE iupac='2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='3799'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;6</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='3923'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3923_also_3924'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3300',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3731_test',
    '', 'Value from the test set.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2900',
    '?',
    (SELECT id from species WHERE iupac='2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;6</sup>',
    '2700',
    '?',
    (SELECT id from species WHERE iupac='2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='3811'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='2226'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pentane',
    'C<sub>5</sub>H<sub>12</sub>',
    '',
    '109-66-0',
    'OFBQJSOFQDEBGM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;6</sup>',
    '3900',
    'L',
    (SELECT id from species WHERE iupac='pentane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3518-109-66-0-consicheck',
    '3518', 'Values at 298&nbsp;K in Tables&nbsp;C2 and C5 of Brockbank (2013) are inconsistent, with 15&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3518-109-66-0-consicheck'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;6</sup>',
    '3500',
    'L',
    (SELECT id from species WHERE iupac='pentane'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;6</sup>',
    '3400',
    'L',
    (SELECT id from species WHERE iupac='pentane'),
    (SELECT id from literature WHERE bibtexkey='1498'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='pentane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;6</sup>',
    '3400',
    'M',
    (SELECT id from species WHERE iupac='pentane'),
    (SELECT id from literature WHERE bibtexkey='2910'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2910-109-66-0-ABC',
    '2910', 'The data from Jou and Mather (2000) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;400.38105 +20169.61328/T +56.35286&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2910-109-66-0-ABC'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2910',
    '2910', 'The paper by Jou and Mather (2000) also contains high-temperature data. However, only data up to 373.2&nbsp;K were used here to calculate the temperature dependence.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2910'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;6</sup>',
    '3600',
    'M',
    (SELECT id from species WHERE iupac='pentane'),
    (SELECT id from literature WHERE bibtexkey='2909'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;6</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='pentane'),
    (SELECT id from literature WHERE bibtexkey='2218'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pentane'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pentane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pentane'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pentane'),
    (SELECT id from literature WHERE bibtexkey='2388'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pentane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pentane'),
    (SELECT id from literature WHERE bibtexkey='3924'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3924_also_3923'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pentane'),
    (SELECT id from literature WHERE bibtexkey='3923'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3923_also_3924'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3000',
    'T',
    (SELECT id from species WHERE iupac='pentane'),
    (SELECT id from literature WHERE bibtexkey='2224'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='pentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='pentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentane'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3600',
    'Q',
    (SELECT id from species WHERE iupac='pentane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentane'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pentane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4200',
    '?',
    (SELECT id from species WHERE iupac='pentane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pentane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pentane'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pentane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pentane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methylbutane',
    'C<sub>5</sub>H<sub>12</sub>',
    'isopentane',
    '78-78-4',
    'QWTDNUCVQCZILF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;6</sup>',
    '3000',
    'L',
    (SELECT id from species WHERE iupac='2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='1910'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='3924'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3924_also_3923'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='3923'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3923_also_3924'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2546-V',
    '', 'Value from the validation dataset.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2535-Ts',
    '', 'Value from the test set.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimethylpropane',
    'C(CH<sub>3</sub>)<sub>4</sub>',
    'neopentane',
    '463-82-1',
    'CRSOQBOWXPBRES-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;6</sup>',
    '3000',
    'L',
    (SELECT id from species WHERE iupac='dimethylpropane'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='dimethylpropane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;6</sup>',
    '3300',
    'L',
    (SELECT id from species WHERE iupac='dimethylpropane'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;6</sup>',
    '2800',
    'M',
    (SELECT id from species WHERE iupac='dimethylpropane'),
    (SELECT id from literature WHERE bibtexkey='3785'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3785-463-82-1-ABC',
    '3785', 'The data from Shoor et&nbsp;al. (1969) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;311.59148 +15699.27148/T +43.32183&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3785-463-82-1-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;6</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dimethylpropane'),
    (SELECT id from literature WHERE bibtexkey='3924'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;6</sup>',
    '3200',
    'M',
    (SELECT id from species WHERE iupac='dimethylpropane'),
    (SELECT id from literature WHERE bibtexkey='3799'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dimethylpropane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dimethylpropane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dimethylpropane'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dimethylpropane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dimethylpropane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dimethylpropane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylpropane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylpropane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylpropane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylpropane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylpropane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylpropane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylpropane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylpropane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylpropane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylpropane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylpropane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3600',
    'Q',
    (SELECT id from species WHERE iupac='dimethylpropane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylpropane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylpropane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylpropane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylpropane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2543-Test',
    '', 'Value from the test dataset.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-Test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylpropane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylpropane'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylpropane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3100',
    '?',
    (SELECT id from species WHERE iupac='dimethylpropane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dimethylpropane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dimethylpropane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dimethylpropane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dimethylpropane'),
    (SELECT id from literature WHERE bibtexkey='2226'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hexane',
    'C<sub>6</sub>H<sub>14</sub>',
    '',
    '110-54-3',
    'VLKZOEOYAKHREP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;6</sup>',
    '4400',
    'L',
    (SELECT id from species WHERE iupac='hexane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3518-110-54-3-consicheck',
    '3518', 'Values at 298&nbsp;K in Tables&nbsp;C2 and C5 of Brockbank (2013) are inconsistent, with 6&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3518-110-54-3-consicheck'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;6</sup>',
    '3800',
    'L',
    (SELECT id from species WHERE iupac='hexane'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;6</sup>',
    '3800',
    'L',
    (SELECT id from species WHERE iupac='hexane'),
    (SELECT id from literature WHERE bibtexkey='1498'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='hexane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;6</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='hexane'),
    (SELECT id from literature WHERE bibtexkey='2935'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;6</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='hexane'),
    (SELECT id from literature WHERE bibtexkey='2905'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2905',
    '2905', 'Apparently, the values in Table&nbsp;2 of Park et&nbsp;al. (1997) show log<sub>10</sub>(K<sub><span class="roman">aw</span></sub>) and not K<sub><span class="roman">aw</span></sub> as their figure caption states.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2905'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;4</sup>',
    '8700',
    'M',
    (SELECT id from species WHERE iupac='hexane'),
    (SELECT id from literature WHERE bibtexkey='857'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '857',
    '', 'Extrapolated from data measured between 40&nbsp;<sup>&#176;</sup>C and 80&nbsp;<sup>&#176;</sup>C.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='857'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;6</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='hexane'),
    (SELECT id from literature WHERE bibtexkey='2924'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;6</sup>',
    '7500',
    'M',
    (SELECT id from species WHERE iupac='hexane'),
    (SELECT id from literature WHERE bibtexkey='1156'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '1156',
    '2894', 'Data are taken from the report by Howe et&nbsp;al. (1987).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1156'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;6</sup>',
    '4200',
    'M',
    (SELECT id from species WHERE iupac='hexane'),
    (SELECT id from literature WHERE bibtexkey='2911'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;6</sup>',
    '4000',
    'M',
    (SELECT id from species WHERE iupac='hexane'),
    (SELECT id from literature WHERE bibtexkey='2909'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;6</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='hexane'),
    (SELECT id from literature WHERE bibtexkey='2218'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexane'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexane'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexane'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexane'),
    (SELECT id from literature WHERE bibtexkey='1910'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexane'),
    (SELECT id from literature WHERE bibtexkey='3924'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3924_also_3923'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexane'),
    (SELECT id from literature WHERE bibtexkey='3923'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3923_also_3924'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;6</sup>',
    '3800',
    'T',
    (SELECT id from species WHERE iupac='hexane'),
    (SELECT id from literature WHERE bibtexkey='3674'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3800',
    'T',
    (SELECT id from species WHERE iupac='hexane'),
    (SELECT id from literature WHERE bibtexkey='2224'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='hexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='hexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexane'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexane'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexane'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4000',
    'Q',
    (SELECT id from species WHERE iupac='hexane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexane'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '731-T',
    '', 'Value from the training set.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexane'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4100',
    '?',
    (SELECT id from species WHERE iupac='hexane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='hexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='hexane'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='hexane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='hexane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methylpentane',
    'C<sub>6</sub>H<sub>14</sub>',
    'isohexane',
    '107-83-5',
    'AFABGHUZZDYHJO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;6</sup>',
    '4500',
    'L',
    (SELECT id from species WHERE iupac='2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;6</sup>',
    '3900',
    'L',
    (SELECT id from species WHERE iupac='2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '960',
    'M',
    (SELECT id from species WHERE iupac='2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='1156'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HTdep_r2_lessthan_0.5'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1156'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='3924'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3924_also_3923'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='3923'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3923_also_3924'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'R',
    (SELECT id from species WHERE iupac='2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='747'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '747Mepentane',
    '747,1156', 'In their Table&nbsp;8, Staudinger and Roberts (1996) incorrectly cite a value given by Ashworth et&nbsp;al. (1988).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='747Mepentane'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;6</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4000',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4000',
    '?',
    (SELECT id from species WHERE iupac='2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methylpentane',
    'C<sub>6</sub>H<sub>14</sub>',
    '',
    '96-14-0',
    'PFEOZHBOMNWTJB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='3-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='3-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='3-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='3924'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4000',
    'Q',
    (SELECT id from species WHERE iupac='3-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4700',
    '?',
    (SELECT id from species WHERE iupac='3-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dimethylbutane',
    'C<sub>6</sub>H<sub>14</sub>',
    '',
    '75-83-2',
    'HNRMPXKDFBEGFZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2,2-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;6</sup>',
    '3500',
    'L',
    (SELECT id from species WHERE iupac='2,2-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2,2-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='3924'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3924_also_3923'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='3923'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3923_also_3924'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethylbutane',
    'C<sub>6</sub>H<sub>14</sub>',
    '',
    '79-29-8',
    'ZFFMLCVRJBZUDZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;6</sup>',
    '4400',
    'L',
    (SELECT id from species WHERE iupac='2,3-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2,3-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2,3-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4000',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-Test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4200',
    '?',
    (SELECT id from species WHERE iupac='2,3-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'heptane',
    'C<sub>7</sub>H<sub>16</sub>',
    '',
    '142-82-5',
    'IMNFDUFMRHMDMM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;6</sup>',
    '4500',
    'L',
    (SELECT id from species WHERE iupac='heptane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;6</sup>',
    '4200',
    'L',
    (SELECT id from species WHERE iupac='heptane'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;6</sup>',
    '4100',
    'L',
    (SELECT id from species WHERE iupac='heptane'),
    (SELECT id from literature WHERE bibtexkey='1498'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='heptane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;6</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='heptane'),
    (SELECT id from literature WHERE bibtexkey='2935'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;6</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='heptane'),
    (SELECT id from literature WHERE bibtexkey='2905'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2905'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '3700',
    'M',
    (SELECT id from species WHERE iupac='heptane'),
    (SELECT id from literature WHERE bibtexkey='903'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '903',
    '618', 'The same data were also published in Hansen et&nbsp;al. (1995).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='903'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;6</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='heptane'),
    (SELECT id from literature WHERE bibtexkey='2924'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;6</sup>',
    '4700',
    'M',
    (SELECT id from species WHERE iupac='heptane'),
    (SELECT id from literature WHERE bibtexkey='2909'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;6</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='heptane'),
    (SELECT id from literature WHERE bibtexkey='2218'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='heptane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='heptane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='heptane'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='heptane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='heptane'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='heptane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='heptane'),
    (SELECT id from literature WHERE bibtexkey='3924'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3924_also_3923'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='heptane'),
    (SELECT id from literature WHERE bibtexkey='3923'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3923_also_3924'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='heptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='heptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptane'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptane'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4300',
    'Q',
    (SELECT id from species WHERE iupac='heptane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptane'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptane'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4900',
    '?',
    (SELECT id from species WHERE iupac='heptane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='heptane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='heptane'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='heptane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='heptane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methylhexane',
    'C<sub>7</sub>H<sub>16</sub>',
    'isoheptane',
    '591-76-4',
    'GXDHCNNESPLIKD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '-3600',
    'M',
    (SELECT id from species WHERE iupac='2-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='903'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='903'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '903mehex',
    '903', 'Hansen et&nbsp;al. (1993) found that the solubility of 2-methylhexane increases with temperature.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='903mehex'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methylhexane',
    'C<sub>7</sub>H<sub>16</sub>',
    '',
    '589-34-4',
    'VLJXXKKOSFGPHI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='3-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='3-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='3-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dimethylpentane',
    'C<sub>7</sub>H<sub>16</sub>',
    '',
    '590-35-2',
    'CXOWYJMDMMMMJO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2,2-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2,2-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethylpentane',
    'C<sub>7</sub>H<sub>16</sub>',
    '',
    '565-59-3',
    'WGECXQBGLLYSFP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2,3-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2,3-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dimethylpentane',
    'C<sub>7</sub>H<sub>16</sub>',
    '',
    '108-08-7',
    'BZHMBWZPUJHVEE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2,4-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2,4-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2,4-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3924'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-Test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,4-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,4-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3-dimethylpentane',
    'C<sub>7</sub>H<sub>16</sub>',
    '',
    '562-49-2',
    'AEXMKKGTQYQZCS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;6</sup>',
    '3000',
    'L',
    (SELECT id from species WHERE iupac='3,3-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3518-562-49-2-consicheck',
    '3518', 'Values at 298&nbsp;K in Tables&nbsp;C2 and C5 of Brockbank (2013) are inconsistent, with 5&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3518-562-49-2-consicheck'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='3,3-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='3,3-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,3-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,3-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,3-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,3-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4300',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3000',
    '?',
    (SELECT id from species WHERE iupac='3,3-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,3-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,3-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethylpentane',
    'C<sub>7</sub>H<sub>16</sub>',
    '',
    '617-78-7',
    'AORMDLNPRGXHHL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethylpentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-ethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-ethylpentane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3-trimethylbutane',
    'C<sub>7</sub>H<sub>16</sub>',
    '',
    '464-06-2',
    'ZISSAWUMDACLOM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2,3-trimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2,3-trimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3-trimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3-trimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3-trimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3-trimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3-trimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3-trimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3-trimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3-trimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2,3-trimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2,3-trimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'octane',
    'C<sub>8</sub>H<sub>18</sub>',
    '',
    '111-65-9',
    'TVMXDCGIABBOFY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;6</sup>',
    '5300',
    'L',
    (SELECT id from species WHERE iupac='octane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;6</sup>',
    '4600',
    'L',
    (SELECT id from species WHERE iupac='octane'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;6</sup>',
    '4300',
    'L',
    (SELECT id from species WHERE iupac='octane'),
    (SELECT id from literature WHERE bibtexkey='1498'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='octane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;6</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='octane'),
    (SELECT id from literature WHERE bibtexkey='2935'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;6</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='octane'),
    (SELECT id from literature WHERE bibtexkey='2905'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2905'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;5</sup>',
    '8000',
    'M',
    (SELECT id from species WHERE iupac='octane'),
    (SELECT id from literature WHERE bibtexkey='903'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='903'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;6</sup>',
    '4100',
    'M',
    (SELECT id from species WHERE iupac='octane'),
    (SELECT id from literature WHERE bibtexkey='2912'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;6</sup>',
    '5400',
    'M',
    (SELECT id from species WHERE iupac='octane'),
    (SELECT id from literature WHERE bibtexkey='2909'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;6</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='octane'),
    (SELECT id from literature WHERE bibtexkey='2218'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='octane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='octane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;7</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='octane'),
    (SELECT id from literature WHERE bibtexkey='2580'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='octane'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;6</sup>',
    '4800',
    'V',
    (SELECT id from species WHERE iupac='octane'),
    (SELECT id from literature WHERE bibtexkey='2554'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='octane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='octane'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='octane'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='octane'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='octane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='octane'),
    (SELECT id from literature WHERE bibtexkey='2471'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='octane'),
    (SELECT id from literature WHERE bibtexkey='3924'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3924_also_3923'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='octane'),
    (SELECT id from literature WHERE bibtexkey='3923'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3923_also_3924'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='octane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='octane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octane'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octane'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octane'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4700',
    'Q',
    (SELECT id from species WHERE iupac='octane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octane'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octane'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octane'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5400',
    '?',
    (SELECT id from species WHERE iupac='octane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='octane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='octane'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='octane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='octane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methylheptane',
    'C<sub>8</sub>H<sub>18</sub>',
    '',
    '592-27-8',
    'JVSWJIKNEAIKJW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='637'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methylheptane',
    'C<sub>8</sub>H<sub>18</sub>',
    '',
    '589-81-1',
    'LAIUFBWHERIJIH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='3-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='3-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='3-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methylheptane',
    'C<sub>8</sub>H<sub>18</sub>',
    '',
    '589-53-7',
    'CHBAWFGIXDBEBT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='4-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dimethylhexane',
    'C<sub>8</sub>H<sub>18</sub>',
    '',
    '590-73-8',
    'FLTJDUOFAQWHDF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;6</sup>',
    '4600',
    'L',
    (SELECT id from species WHERE iupac='2,2-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;6</sup>',
    '4600',
    'M',
    (SELECT id from species WHERE iupac='2,2-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2936'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2936-590-73-8-ABC',
    '2936', 'The data from Dohányosová et&nbsp;al. (2004) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;670.94997 +33188.34075/T +95.95541&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2936-590-73-8-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;7</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4700',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5100',
    '?',
    (SELECT id from species WHERE iupac='2,2-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethylhexane',
    'C<sub>8</sub>H<sub>18</sub>',
    '',
    '584-94-1',
    'JXPOLSKBTUYKJB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dimethylhexane',
    'C<sub>8</sub>H<sub>18</sub>',
    '',
    '589-43-5',
    'HDGQICNBXPAKLR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,4-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,4-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5-dimethylhexane',
    'C<sub>8</sub>H<sub>18</sub>',
    '',
    '592-13-2',
    'UWNADWZGEHDQAB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;6</sup>',
    '4000',
    'L',
    (SELECT id from species WHERE iupac='2,5-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3518-592-13-2-consicheck',
    '3518', 'Values at 298&nbsp;K in Tables&nbsp;C2 and C5 of Brockbank (2013) are inconsistent, with 21&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3518-592-13-2-consicheck'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;6</sup>',
    '4000',
    'M',
    (SELECT id from species WHERE iupac='2,5-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2936'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2936-592-13-2-ABC',
    '2936', 'The data from Dohányosová et&nbsp;al. (2004) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;792.29258 +38089.35992/T +114.36667&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2936-592-13-2-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,5-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4700',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4700',
    '?',
    (SELECT id from species WHERE iupac='2,5-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,5-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,5-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3-dimethylhexane',
    'C<sub>8</sub>H<sub>18</sub>',
    '',
    '563-16-6',
    'KUMXLFIBWFCMOJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,3-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,3-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4-dimethylhexane',
    'C<sub>8</sub>H<sub>18</sub>',
    '',
    '583-48-2',
    'RNTWWGNZUXGTAX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,4-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,4-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethylhexane',
    'C<sub>8</sub>H<sub>18</sub>',
    '',
    '619-99-8',
    'SFRKSDZMZHIISH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3-trimethylpentane',
    'C<sub>8</sub>H<sub>18</sub>',
    '',
    '564-02-3',
    'XTDQDBVBDLYELW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2,3-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2,3-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,4-trimethylpentane',
    'C<sub>8</sub>H<sub>18</sub>',
    'isooctane',
    '540-84-1',
    'NHTMVDHEPJAVLT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2,2,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2,2,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;6</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2924'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2471'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3924'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3924_also_3923'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3923'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3923_also_3924'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'supplement',
    '', 'Data taken from the supplement.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2995EPI',
    '', 'Calculated using the EPI Suite (v4.0) method.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2995SPARC',
    '', 'Calculated using the SPARC (v4.2) method.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2995COSMO',
    '', 'Calculated using the COSMOtherm (v2.1) method.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2995ABSOLV',
    '', 'Calculated using the ABSOLV (ADMEBoxes v4.1) method.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4700',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-Test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4000',
    '?',
    (SELECT id from species WHERE iupac='2,2,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3-trimethylpentane',
    'C<sub>8</sub>H<sub>18</sub>',
    '',
    '560-21-4',
    'OKVWYBALHQFVFP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,3-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3,3-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3,3-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4-trimethylpentane',
    'C<sub>8</sub>H<sub>18</sub>',
    '',
    '565-75-3',
    'RLPGDEORIPLBNF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2,3,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2,3,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2,3,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2611_pc_problem',
    '2611', 'Mackay et&nbsp;al. (2006a) list a vapor pressure p, a solubility c, and a Henry''s law constant calculated as p/c. However, the data are internally inconsistent and deviate by more than 10&nbsp;%.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2611_pc_problem'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4700',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4900',
    '?',
    (SELECT id from species WHERE iupac='2,3,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-2-methylpentane',
    'C<sub>8</sub>H<sub>18</sub>',
    '',
    '609-26-7',
    'DUPUVYJQZSLSJB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-ethyl-2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-ethyl-2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-3-methylpentane',
    'C<sub>8</sub>H<sub>18</sub>',
    '',
    '1067-08-9',
    'GIEZWIDCIFCQPS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-3-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-3-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-3-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-3-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-3-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-3-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-ethyl-3-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-ethyl-3-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,3-tetramethylbutane',
    'C<sub>8</sub>H<sub>18</sub>',
    '',
    '594-82-1',
    'OMMLUKLXGSRPHK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3,3-tetramethylbutane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3-tetramethylbutane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3-tetramethylbutane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3-tetramethylbutane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2,3,3-tetramethylbutane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nonane',
    'C<sub>9</sub>H<sub>20</sub>',
    '',
    '111-84-2',
    'BKIMMITUMNQMOS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;6</sup>',
    '6600',
    'L',
    (SELECT id from species WHERE iupac='nonane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3518-111-84-2-consicheck',
    '3518', 'Values at 298&nbsp;K in Tables&nbsp;C2 and C5 of Brockbank (2013) are inconsistent, with 23&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3518-111-84-2-consicheck'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='nonane'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='nonane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;6</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='nonane'),
    (SELECT id from literature WHERE bibtexkey='2935'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;6</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='nonane'),
    (SELECT id from literature WHERE bibtexkey='2905'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2905'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;5</sup>',
    '190',
    'M',
    (SELECT id from species WHERE iupac='nonane'),
    (SELECT id from literature WHERE bibtexkey='1156'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HTdep_r2_lessthan_0.5'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1156'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;6</sup>',
    '7300',
    'M',
    (SELECT id from species WHERE iupac='nonane'),
    (SELECT id from literature WHERE bibtexkey='2909'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='nonane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='nonane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='nonane'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='nonane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='nonane'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='nonane'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='nonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5000',
    'Q',
    (SELECT id from species WHERE iupac='nonane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonane'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4100',
    '?',
    (SELECT id from species WHERE iupac='nonane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='nonane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='nonane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyloctane',
    'C<sub>9</sub>H<sub>20</sub>',
    '',
    '3221-61-2',
    'ZUBZATZOEPUUQF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyloctane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyloctane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyloctane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methyloctane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methyloctane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyloctane',
    'C<sub>9</sub>H<sub>20</sub>',
    '',
    '2216-33-3',
    'SEEOMASXHIJCDV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyloctane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyloctane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyloctane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-methyloctane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-methyloctane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyloctane',
    'C<sub>9</sub>H<sub>20</sub>',
    '',
    '2216-34-4',
    'DOGIHOCMZJUJNR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;7</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='4-methyloctane'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='4-methyloctane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;7</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-methyloctane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;7</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-methyloctane'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyloctane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyloctane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyloctane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyloctane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyloctane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyloctane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyloctane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyloctane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-methyloctane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-methyloctane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethylheptane',
    'C<sub>9</sub>H<sub>20</sub>',
    '',
    '3074-71-3',
    'WBRFDUJXCLCKPX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dimethylheptane',
    'C<sub>9</sub>H<sub>20</sub>',
    '',
    '1071-26-7',
    'PSABUFWDVWCFDP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dimethylheptane',
    'C<sub>9</sub>H<sub>20</sub>',
    '',
    '2213-23-2',
    'AUKVIBNBLXQNIZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,4-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,4-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5-dimethylheptane',
    'C<sub>9</sub>H<sub>20</sub>',
    '',
    '2216-30-0',
    'HQZHQNKZOYIKQC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,5-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,5-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,5-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6-dimethylheptane',
    'C<sub>9</sub>H<sub>20</sub>',
    '',
    '1072-05-5',
    'KBPCCVWUMVGXGF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,6-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,6-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,6-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3-dimethylheptane',
    'C<sub>9</sub>H<sub>20</sub>',
    '',
    '4032-86-4',
    'BVAKDOXCVSMKHE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,3-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4-dimethylheptane',
    'C<sub>9</sub>H<sub>20</sub>',
    '',
    '922-28-1',
    'MAKRYGRRIKSDES-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,4-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,4-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,5-dimethylheptane',
    'C<sub>9</sub>H<sub>20</sub>',
    '',
    '926-82-9',
    'DZJTZGHZAWTWGA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,5-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,5-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,5-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,4-dimethylheptane',
    'C<sub>9</sub>H<sub>20</sub>',
    '',
    '1068-19-5',
    'WSOKFYJGNBQDPW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,4-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4,4-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4,4-dimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethylheptane',
    'C<sub>9</sub>H<sub>20</sub>',
    '',
    '15869-80-4',
    'PSVQKOKKLWHNRP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-ethylheptane',
    'C<sub>9</sub>H<sub>20</sub>',
    '',
    '2216-32-2',
    'XMROPFQWHHUFFS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3-trimethylhexane',
    'C<sub>9</sub>H<sub>20</sub>',
    '',
    '16747-25-4',
    'CBVFSZDQEHBJEQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2,3-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2,3-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,4-trimethylhexane',
    'C<sub>9</sub>H<sub>20</sub>',
    '',
    '16747-26-5',
    'AFTPEBDOGXRMNQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,4-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2,4-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2,4-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,5-trimethylhexane',
    'C<sub>9</sub>H<sub>20</sub>',
    '',
    '3522-94-9',
    'HHOSMYBYIHNXNO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;6</sup>',
    '6200',
    'L',
    (SELECT id from species WHERE iupac='2,2,5-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2,2,5-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2,2,5-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2,5-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2,5-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2,5-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='1910'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2,5-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3924'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,5-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,5-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,5-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,5-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,5-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,5-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,5-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,5-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2,5-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2,5-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3-trimethylhexane',
    'C<sub>9</sub>H<sub>20</sub>',
    '',
    '16747-28-7',
    'DJYSEQMMCZAKGT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,3-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3,3-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3,3-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4-trimethylhexane',
    'C<sub>9</sub>H<sub>20</sub>',
    '',
    '921-47-1',
    'RUTNOQHQISEBGT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,4-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3,4-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3,4-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,5-trimethylhexane',
    'C<sub>9</sub>H<sub>20</sub>',
    '',
    '1069-53-0',
    'ODGLTLJZCVNPBU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,5-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3,5-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3,5-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,4-trimethylhexane',
    'C<sub>9</sub>H<sub>20</sub>',
    '',
    '16747-30-1',
    'SVEMKBCPZYWEPH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4,4-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,4,4-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,4,4-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3,4-trimethylhexane',
    'C<sub>9</sub>H<sub>20</sub>',
    '',
    '16747-31-2',
    'ARWOOWBJJKVYOV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3,4-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,3,4-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,3,4-trimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-2-methylhexane',
    'C<sub>9</sub>H<sub>20</sub>',
    '',
    '16789-46-1',
    'MVLOWDRGPHBNNF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-2-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-ethyl-2-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-ethyl-2-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-ethyl-2-methylhexane',
    'C<sub>9</sub>H<sub>20</sub>',
    '',
    '3074-75-7',
    'KYCZJIBOPKRSOV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-ethyl-2-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-2-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-2-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-2-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-2-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-2-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-ethyl-2-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-ethyl-2-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-3-methylhexane',
    'C<sub>9</sub>H<sub>20</sub>',
    '',
    '3074-76-8',
    'CYWROHZCELEGSE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-3-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-3-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-3-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-3-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-3-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-3-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-ethyl-3-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-ethyl-3-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-4-methylhexane',
    'C<sub>9</sub>H<sub>20</sub>',
    '',
    '3074-77-9',
    'OKCRKWVABWILDR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-4-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-4-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-4-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-4-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-4-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-4-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-ethyl-4-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-ethyl-4-methylhexane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,3-tetramethylpentane',
    'C<sub>9</sub>H<sub>20</sub>',
    '',
    '7154-79-2',
    'QUKOJKFJIHSBKV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3,3-tetramethylpentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3-tetramethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3-tetramethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3-tetramethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3-tetramethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3-tetramethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2,3,3-tetramethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2,3,3-tetramethylpentane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,4-tetramethylpentane',
    'C<sub>9</sub>H<sub>20</sub>',
    '',
    '1186-53-4',
    'VZFMYOCAEQDWDY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3,4-tetramethylpentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,4-tetramethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,4-tetramethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,4-tetramethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,4-tetramethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,4-tetramethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2,3,4-tetramethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2,3,4-tetramethylpentane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,4,4-tetramethylpentane',
    'C<sub>9</sub>H<sub>20</sub>',
    '',
    '1070-87-7',
    'GUMULFRCHLJNDY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,4,4-tetramethylpentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,4-tetramethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,4-tetramethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,4-tetramethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,4-tetramethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,4-tetramethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2,4,4-tetramethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2,4,4-tetramethylpentane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3,4-tetramethylpentane',
    'C<sub>9</sub>H<sub>20</sub>',
    '',
    '16747-38-9',
    'JLCYYQOQSAMWTA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,3,4-tetramethylpentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3,4-tetramethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3,4-tetramethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3,4-tetramethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3,4-tetramethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3,4-tetramethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3,3,4-tetramethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3,3,4-tetramethylpentane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-2,2-dimethylpentane',
    'C<sub>9</sub>H<sub>20</sub>',
    '',
    '16747-32-3',
    'CLZCPQKGOAXOJT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-2,2-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,2-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,2-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,2-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,2-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,2-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-ethyl-2,2-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-ethyl-2,2-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-2,3-dimethylpentane',
    'C<sub>9</sub>H<sub>20</sub>',
    '',
    '16747-33-4',
    'MMASVVOQIKCFJZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-2,3-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,3-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,3-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,3-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,3-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,3-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-ethyl-2,3-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-ethyl-2,3-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-2,4-dimethylpentane',
    'C<sub>9</sub>H<sub>20</sub>',
    '',
    '1068-87-7',
    'VLHAGZNBWKUMRW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-2,4-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,4-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,4-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,4-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,4-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,4-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-ethyl-2,4-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-ethyl-2,4-dimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3-diethylpentane',
    'C<sub>9</sub>H<sub>20</sub>',
    '',
    '1067-20-5',
    'BGXXXYLRPIRDHJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4900',
    'R',
    (SELECT id from species WHERE iupac='3,3-diethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2225'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3-diethylpentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-diethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-diethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-diethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-diethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-diethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,3-diethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,3-diethylpentane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,3-diethylpentane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,3-diethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2226'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'decane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '124-18-5',
    'DIOQZVSQGTUSAI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='decane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='decane'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='decane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='decane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='decane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='decane'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='decane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='decane'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='decane'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='decane'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='decane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='decane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decane'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decane'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='decane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='decane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methylnonane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '871-83-0',
    'SGVYKUFIHHTIFL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylnonane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylnonane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylnonane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methylnonane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methylnonane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methylnonane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '5911-04-6',
    'PLZDDPSCZHRBOY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylnonane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylnonane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylnonane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-methylnonane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-methylnonane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methylnonane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '17301-94-9',
    'IALRSQMWHFKJJA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylnonane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylnonane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylnonane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-methylnonane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-methylnonane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-methylnonane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '15869-85-9',
    'TYSIILFJZXHVPU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='5-methylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methylnonane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methylnonane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methylnonane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='5-methylnonane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='5-methylnonane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dimethyloctane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '15869-87-1',
    'GPBUTTSWJNPYJL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethyloctane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '7146-60-3',
    'YPMNDMUOGQJCLW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dimethyloctane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '4032-94-4',
    'IXAVTTRPEXFVSX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,4-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,4-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5-dimethyloctane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '15869-89-3',
    'HOAAQUNESXYFDT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,5-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,5-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,5-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6-dimethyloctane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '2051-30-1',
    'ZALHPSXXQIPKTQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,6-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,6-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,6-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,7-dimethyloctane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '1072-16-8',
    'KEVMYFLMMDUPJE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,7-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,7-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,7-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,7-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,7-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,7-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,7-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,7-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3-dimethyloctane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '4110-44-5',
    'DBULLUBYDONGLT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,3-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,3-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4-dimethyloctane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '15869-92-8',
    'QQCWGAMGBCGAQJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,4-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,4-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,5-dimethyloctane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '15869-93-9',
    'VRHRGVJOUHJULC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,5-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,5-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,5-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,6-dimethyloctane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '15869-94-0',
    'JEEQUUSFXYRPRK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,6-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,6-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,6-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,6-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,6-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,6-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,6-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,6-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,4-dimethyloctane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '15869-95-1',
    'ZMEDGZAGMLTROM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,4-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4,4-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4,4-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,5-dimethyloctane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '15869-96-2',
    'DOYJTLUPPPUSMD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,5-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,5-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,5-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,5-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,5-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,5-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4,5-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4,5-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyloctane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '5881-17-4',
    'OEYGTUAKNZFCDJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-ethyloctane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '15869-86-0',
    'NRJUFUBKIFIKFI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3-trimethylheptane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '52896-92-1',
    'ACYHSTUWOQNWCX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2,3-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2,3-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,4-trimethylheptane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '14720-74-2',
    'IIYGOARYARWJBO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,4-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2,4-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2,4-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,5-trimethylheptane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '20291-95-6',
    'GZJFAWOTMWATOS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,5-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,5-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,5-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,5-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,5-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2,5-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2,5-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,6-trimethylheptane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '1190-83-6',
    'FHJCGIUZJXWNET-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,6-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,6-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,6-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,6-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,6-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2,6-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2,6-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3-trimethylheptane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '52896-93-2',
    'QACXEXNKLFWKLK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,3-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3,3-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3,3-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4-trimethylheptane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '52896-95-4',
    'UVVYAKOLFKEZEE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,4-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3,4-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3,4-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,5-trimethylheptane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '20278-85-7',
    'YKPNYFKOKKKGNM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,5-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3,5-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3,5-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,6-trimethylheptane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '4032-93-3',
    'IHPXJGBVRWFEJB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,6-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,6-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,6-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,6-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,6-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,6-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3,6-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3,6-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,4-trimethylheptane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '4032-92-2',
    'QALGVLROELGEEM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4,4-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,4,4-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,4,4-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,5-trimethylheptane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '20278-84-6',
    'YMBNRMDSLJNNPF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4,5-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,4,5-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,4,5-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,6-trimethylheptane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '2613-61-8',
    'YNLBBDHDNIXQNL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4,6-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,4,6-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,4,6-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5,5-trimethylheptane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '1189-99-7',
    'SOYLPZSOEXZMLE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,5,5-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5,5-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5,5-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5,5-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5,5-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5,5-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,5,5-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,5,5-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3,4-trimethylheptane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '20278-87-9',
    'WRBHKVWLEIYLDZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3,4-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,3,4-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,3,4-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3,5-trimethylheptane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '7154-80-5',
    'VRVRZZWPKABUOE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3,5-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,5-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,5-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,5-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,5-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,5-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,3,5-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,3,5-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4,4-trimethylheptane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '20278-88-0',
    'BLNBSBLKPFFJKQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4,4-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,4-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,4-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,4-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,4-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,4-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,4,4-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,4,4-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4,5-trimethylheptane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '20278-89-1',
    'LJIIBBYARMPSMT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4,5-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,5-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,5-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,5-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,5-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,5-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,4,5-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,4,5-trimethylheptane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-2-methylheptane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '14676-29-0',
    'NKMJCVVUYDKHAV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-2-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-ethyl-2-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-ethyl-2-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-ethyl-2-methylheptane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '52896-88-5',
    'OJDKRASKNKPYDH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-ethyl-2-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-2-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-2-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-2-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-2-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-2-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-ethyl-2-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-ethyl-2-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-ethyl-2-methylheptane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '13475-78-0',
    'DGEMPTLPTFNEHJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='5-ethyl-2-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-ethyl-2-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-ethyl-2-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-ethyl-2-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-ethyl-2-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-ethyl-2-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='5-ethyl-2-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='5-ethyl-2-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-3-methylheptane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '17302-01-1',
    'HSOMNBKXPGCNBH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-3-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-3-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-3-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-3-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-3-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-3-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-ethyl-3-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-ethyl-3-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-ethyl-3-methylheptane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '52896-89-6',
    'BTGGSWBKRYMHQK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-ethyl-3-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-3-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-3-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-3-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-3-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-3-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-ethyl-3-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-ethyl-3-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-5-methylheptane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '52896-90-9',
    'VXARVYMIZCGZGG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-5-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-5-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-5-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-5-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-5-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-5-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-ethyl-5-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-ethyl-5-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-4-methylheptane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '52896-91-0',
    'JZBKRUIGSVOOIC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-4-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-4-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-4-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-4-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-4-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-4-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-ethyl-4-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-ethyl-4-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-ethyl-4-methylheptane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '17302-04-4',
    'MPYQJQDSICRCJJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-ethyl-4-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-4-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-4-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-4-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-4-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-4-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-ethyl-4-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-ethyl-4-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-propylheptane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '3178-29-8',
    'ABYGSZMCWVXFCQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-propylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-propylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-propylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-propylheptane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-propylheptane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-propylheptane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-propylheptane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-propylheptane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-(1-methylethyl)-heptane',
    'C<sub>10</sub>H<sub>22</sub>',
    '4-isopropylheptane',
    '52896-87-4',
    'AZLAWGCUDHUQDB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-(1-methylethyl)-heptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-(1-methylethyl)-heptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-(1-methylethyl)-heptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-(1-methylethyl)-heptane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-(1-methylethyl)-heptane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-(1-methylethyl)-heptane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-(1-methylethyl)-heptane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-(1-methylethyl)-heptane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,3-tetramethylhexane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '13475-81-5',
    'RMQHJMMCLSJULX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3,3-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2,3,3-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2,3,3-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,4-tetramethylhexane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '52897-08-2',
    'MHPSPNGWFAGBNH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3,4-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,4-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,4-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,4-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,4-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,4-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2,3,4-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2,3,4-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,5-tetramethylhexane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '52897-09-3',
    'GCFKTDRTZYDRBI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3,5-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,5-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,5-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,5-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,5-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,5-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2,3,5-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2,3,5-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,4,4-tetramethylhexane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '51750-65-3',
    'PXHNHTBJHHSVPT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,4,4-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,4-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,4-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,4-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,4-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,4-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2,4,4-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2,4,4-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,4,5-tetramethylhexane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '16747-42-5',
    'KDRZICOOQNIJDN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,4,5-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,5-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,5-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,5-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,5-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,5-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2,4,5-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2,4,5-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,5,5-tetramethylhexane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '1071-81-4',
    'HXQDUXXBVMMIKL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,5,5-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,5,5-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,5,5-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,5,5-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,5,5-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,5,5-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2,5,5-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2,5,5-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3,4-tetramethylhexane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '52897-10-6',
    'HIHSOGFAVTVMCY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,3,4-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3,4-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3,4-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3,4-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3,4-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3,4-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3,3,4-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3,3,4-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3,5-tetramethylhexane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '52897-11-7',
    'GCGFXFIPOBRMQT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,3,5-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3,5-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3,5-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3,5-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3,5-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3,5-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3,3,5-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3,3,5-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,4-tetramethylhexane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '52897-12-8',
    'XDRDDPSGUQMOBO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,4,4-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,4-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,4-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,4-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,4-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,4-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3,4,4-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3,4,4-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,5-tetramethylhexane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '52897-15-1',
    'BHGNYYIOYPFWKC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,4,5-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,5-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,5-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,5-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,5-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,5-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3,4,5-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3,4,5-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3,4,4-tetramethylhexane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '5171-84-6',
    'MCEYLFHKATVXLN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3,4,4-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,3,4,4-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,3,4,4-tetramethylhexane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-2,2-dimethylhexane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '20291-91-2',
    'XYDYODCWVCBIOQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-2,2-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,2-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,2-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,2-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,2-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,2-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,2-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-ethyl-2,2-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-ethyl-2,2-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-ethyl-2,2-dimethylhexane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '52896-99-8',
    'QHLDBFLIDFTHQI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-ethyl-2,2-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-2,2-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-2,2-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-2,2-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-2,2-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-2,2-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-ethyl-2,2-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-ethyl-2,2-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-2,3-dimethylhexane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '52897-00-4',
    'PJIFKODHGMUPFH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-2,3-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,3-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,3-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,3-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,3-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,3-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-ethyl-2,3-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-ethyl-2,3-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-ethyl-2,3-dimethylhexane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '52897-01-5',
    'RHMRCCBCYFAZIK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-ethyl-2,3-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-2,3-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-2,3-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-2,3-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-2,3-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-2,3-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-ethyl-2,3-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-ethyl-2,3-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-2,4-dimethylhexane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '7220-26-0',
    'OSKIMJMPFNLVOU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-2,4-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,4-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,4-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,4-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,4-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,4-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-ethyl-2,4-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-ethyl-2,4-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-ethyl-2,4-dimethylhexane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '52897-03-7',
    'SIKFMUYSQCEQOO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-ethyl-2,4-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-2,4-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-2,4-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-2,4-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-2,4-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-2,4-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-ethyl-2,4-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-ethyl-2,4-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-2,5-dimethylhexane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '52897-04-8',
    'UJEUVDLASLOZIV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-2,5-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,5-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,5-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,5-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,5-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,5-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-ethyl-2,5-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-ethyl-2,5-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-ethyl-3,3-dimethylhexane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '52897-05-9',
    'ZRTXVJYJVBTXHE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-ethyl-3,3-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-3,3-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-3,3-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-3,3-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-3,3-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-3,3-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-ethyl-3,3-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-ethyl-3,3-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-3,4-dimethylhexane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '52897-06-0',
    'ZGJCTUKRTSBTIQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-3,4-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-3,4-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-3,4-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-3,4-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-3,4-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-3,4-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-ethyl-3,4-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-ethyl-3,4-dimethylhexane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3-diethylhexane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '17302-02-2',
    'WWNGLKDLYKNGGT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,3-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,3-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4-diethylhexane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '19398-77-7',
    'VBZCRMTUDYIWIH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,4-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,4-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-3-(1-methylethyl)-hexane',
    'C<sub>10</sub>H<sub>22</sub>',
    '3-isopropyl-2-methylhexane',
    '62016-13-1',
    'YBOXGRMAQIYMGV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-3-(1-methylethyl)-hexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-(1-methylethyl)-hexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-(1-methylethyl)-hexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-(1-methylethyl)-hexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-(1-methylethyl)-hexane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-(1-methylethyl)-hexane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methyl-3-(1-methylethyl)-hexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methyl-3-(1-methylethyl)-hexane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,3,4-pentamethylpentane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '16747-44-7',
    'WKQBIIUOSATALN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3,3,4-pentamethylpentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3,4-pentamethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3,4-pentamethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3,4-pentamethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3,4-pentamethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3,4-pentamethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2,3,3,4-pentamethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2,3,3,4-pentamethylpentane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,4,4-pentamethylpentane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '16747-45-8',
    'OWFKEHICSVOVAC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3,4,4-pentamethylpentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,4,4-pentamethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,4,4-pentamethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,4,4-pentamethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,4,4-pentamethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,4,4-pentamethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2,3,4,4-pentamethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2,3,4,4-pentamethylpentane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-2,2,3-trimethylpentane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '52897-17-3',
    'AJDIFHIHSYVDGP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-2,2,3-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,2,3-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,2,3-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,2,3-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,2,3-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,2,3-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-ethyl-2,2,3-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-ethyl-2,2,3-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-2,2,4-trimethylpentane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '52897-18-4',
    'VLIZIVHXZXQRDE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-2,2,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,2,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,2,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,2,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,2,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,2,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-ethyl-2,2,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-ethyl-2,2,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-2,3,4-trimethylpentane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '52897-19-5',
    'OHZNMGSGEFVFTI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-2,3,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,3,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,3,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,3,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,3,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,3,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-ethyl-2,3,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-ethyl-2,3,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3-diethyl-2-methylpentane',
    'C<sub>10</sub>H<sub>22</sub>',
    '',
    '52897-16-2',
    'DSSAZLXYIQIXGW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3-diethyl-2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-diethyl-2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-diethyl-2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-diethyl-2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-diethyl-2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-diethyl-2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,3-diethyl-2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,3-diethyl-2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dimethyl-3-(1-methylethyl)-pentane',
    'C<sub>10</sub>H<sub>22</sub>',
    '2,4-dimethyl-3-isopropylpentane',
    '13475-79-1',
    'YVYHOOYMDHZALB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-(1-methylethyl)-pentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-(1-methylethyl)-pentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-(1-methylethyl)-pentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-(1-methylethyl)-pentane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-(1-methylethyl)-pentane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-(1-methylethyl)-pentane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-(1-methylethyl)-pentane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-(1-methylethyl)-pentane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'undecane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '1120-21-4',
    'RSJKGSCJYJTIGS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;7</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='undecane'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;7</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='undecane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='undecane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='undecane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;7</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='undecane'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='undecane'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;7</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='undecane'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='undecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='undecane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='undecane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='undecane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='undecane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='undecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='undecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='undecane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='undecane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='undecane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='undecane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='undecane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='undecane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyldecane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '6975-98-0',
    'CNPVJWYWYZMPDS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyldecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyldecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyldecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyldecane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '13151-34-3',
    'JJRUZTXRDDMYGM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyldecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyldecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyldecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyldecane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '2847-72-5',
    'DVWZNKLWPILULD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyldecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyldecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyldecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-methyldecane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '13151-35-4',
    'QUYFPNWYGLFQQU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='5-methyldecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyldecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyldecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dimethylnonane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '17302-14-6',
    'WDSBVMLUILIJOW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2-dimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethylnonane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '2884-06-2',
    'IGJRNTLDWLTHCQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3-dimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dimethylnonane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '17302-24-8',
    'JZUUOAUSQCXSTN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4-dimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5-dimethylnonane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '17302-27-1',
    'NQUMJENPNGXAIH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,5-dimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6-dimethylnonane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '17302-28-2',
    'MGNGOEWESNDQAN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,6-dimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,7-dimethylnonane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '17302-29-3',
    'QYQSPINNJUXEDY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,7-dimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,7-dimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,7-dimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,8-dimethylnonane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '17302-30-6',
    'FZFRYQHIQUEAAV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,8-dimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,8-dimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,8-dimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3-dimethylnonane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '17302-15-7',
    'HTRYNYZYFGHKDV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3-dimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4-dimethylnonane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '17302-22-6',
    'PAXLEVPLFYBSQJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4-dimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,5-dimethylnonane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '17302-25-9',
    'BAFVBVRBYKSWCE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,5-dimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,6-dimethylnonane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '17302-31-7',
    'YHLBUWVGPXILSW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,6-dimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,6-dimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,6-dimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,7-dimethylnonane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '17302-32-8',
    'YGPVLXJHRFZYJJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,7-dimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,7-dimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,7-dimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,4-dimethylnonane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '17302-18-0',
    'HARRKRKVTQABSF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,4-dimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,5-dimethylnonane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '17302-23-7',
    'JDNGDDOTBYZAGS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,5-dimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,5-dimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,5-dimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,6-dimethylnonane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '17302-26-0',
    'JZKWOUUZMBTBDO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,6-dimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,6-dimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,6-dimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5,5-dimethylnonane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '6414-96-6',
    'BEPKYSJVUZWKMP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='5,5-dimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5,5-dimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5,5-dimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethylnonane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '17302-11-3',
    'FKJSIWPQZCKMIL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-ethylnonane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '5911-05-7',
    'UGCQDCMVAKKTQG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-ethylnonane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '17302-12-4',
    'QPOVZYGNFWRMJE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='5-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3-trimethyloctane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '62016-26-6',
    'XZPXMWMVWDSEMY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,4-trimethyloctane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '18932-14-4',
    'IKMGZPRUMVFYBK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,4-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,5-trimethyloctane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '62016-27-7',
    'CSVNISDVBYGXME-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,5-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,5-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,5-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,6-trimethyloctane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '62016-28-8',
    'NBIHFQKVSFKHGH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,6-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,6-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,6-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,7-trimethyloctane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '62016-29-9',
    'QGQAHVJOBYNMFN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,7-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,7-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,7-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3-trimethyloctane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '62016-30-2',
    'KFYWDCDWVPXXCA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,3-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4-trimethyloctane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '62016-31-3',
    'SJQAEXCGOLTHPG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,4-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,5-trimethyloctane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '62016-32-4',
    'CEOHXVQAHFSSEG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,5-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,6-trimethyloctane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '62016-33-5',
    'MNFBUNLEXRMWOY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,6-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,6-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,6-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,7-trimethyloctane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '62016-34-6',
    'XJKKSYAVEVAGFX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,7-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,7-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,7-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,4-trimethyloctane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '62016-35-7',
    'CJXXTMYWNCYKHU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4,4-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,5-trimethyloctane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '62016-36-8',
    'UJYGOBMOHSFJQP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4,5-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,6-trimethyloctane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '62016-37-9',
    'XHNIFDXYGLPJLP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4,6-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,7-trimethyloctane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '62016-38-0',
    'DUHKHXHIPOGMOW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4,7-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,7-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,7-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5,5-trimethyloctane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '62016-39-1',
    'DZKJZWAIBSEZKB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,5,5-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5,5-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5,5-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5,6-trimethyloctane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '62016-14-2',
    'VHBZECSWMWWTMQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,5,6-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5,6-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5,6-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6,6-trimethyloctane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '54166-32-4',
    'RUPXAIGHLDMSOL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,6,6-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6,6-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6,6-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3,4-trimethyloctane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '62016-40-4',
    'IJVIFYHTPQSPSW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3,4-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3,5-trimethyloctane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '62016-41-5',
    'BEFCOJKHEMBPSK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3,5-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,5-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,5-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3,6-trimethyloctane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '62016-42-6',
    'CFESHXNQRRYSED-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3,6-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,6-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,6-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4,4-trimethyloctane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '62016-43-7',
    'WWCBWKZBTINVDE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4,4-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,4-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,4-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4,5-trimethyloctane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '62016-44-8',
    'BPFOUTQNEVQSFR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4,5-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,5-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,5-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4,6-trimethyloctane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '62016-45-9',
    'RMGAENUTYIFEJO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4,6-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,6-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,6-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,5,5-trimethyloctane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-94-8',
    'FVYNWISHVUNIOZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,5,5-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5,5-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5,5-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,4,5-trimethyloctane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-95-9',
    'QGCXVKCDWOOWTQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,4,5-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4,5-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4,5-trimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-3-ethyloctane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '62016-16-4',
    'ITDXDXCBDQBZEB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-3-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-4-ethyloctane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '62016-17-5',
    'ZYEQSLLHBOITAM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-4-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-4-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-4-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-5-ethyloctane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '62016-18-6',
    'CQCKNPUKBOITAX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-5-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-5-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-5-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-6-ethyloctane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '62016-19-7',
    'AZXGABNJUBNOHW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-6-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-6-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-6-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-3-ethyloctane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '17302-16-8',
    'DQNINFLTCGTQGU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-3-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-3-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-3-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-4-ethyloctane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '62016-20-0',
    'BTRAURWAFYPYMW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-4-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-4-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-4-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-5-ethyloctane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '62016-21-1',
    'LZFCEXJTLLKGPW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-5-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-5-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-5-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-6-ethyloctane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '62016-22-2',
    'FTQLPWORENXYAZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-6-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-6-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-6-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-3-ethyloctane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '62016-23-3',
    'LXRSBMFQRZTMNK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-3-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-3-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-3-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-4-ethyloctane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '17302-19-1',
    'IXZULXYHNRHENR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-4-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-4-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-4-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-5-ethyloctane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '62016-24-4',
    'DTSHQAHKLUTGAR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-5-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-5-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-5-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-6-ethyloctane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '62016-25-5',
    'NXUUVZOGBPCPDV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-6-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-6-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-6-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-propyloctane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '17302-13-5',
    'VFAMBAFLNKONTN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-propyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-propyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-propyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-isopropyloctane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '62016-15-3',
    'VSJAVEFYQMREHJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-isopropyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-isopropyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-isopropyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,3-tetramethylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-40-4',
    'YPGGGWSLWOECQF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3,3-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,4-tetramethylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-41-5',
    'HPKDRGPKZGWSND-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3,4-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,4-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,4-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,5-tetramethylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-42-6',
    'KXNFNEAZTWCHIL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3,5-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,5-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,5-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,6-tetramethylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-43-7',
    'AQHGQPHAJYTMDJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3,6-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,6-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,6-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,4,4-tetramethylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-44-8',
    'JMRHVFQTDSCACD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,4,4-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,4-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,4-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,4,5-tetramethylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-45-9',
    'MPDBIZNQOUSUIN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,4,5-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,5-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,5-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,4,6-tetramethylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-46-0',
    'XSMHBEAIQLABAO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,4,6-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,6-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,6-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,5,5-tetramethylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-47-1',
    'VQJNSRPWQMPDDO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,5,5-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,5,5-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,5,5-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,5,6-tetramethylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-48-2',
    'ZYJXKOJVCNGFSL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,5,6-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,5,6-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,5,6-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,6,6-tetramethylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '40117-45-1',
    'GKNMBVVJQTWDRT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,6,6-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,6,6-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,6,6-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3,4-tetramethylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-49-3',
    'OHIUILFTBGSFAG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,3,4-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3,4-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3,4-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3,5-tetramethylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-50-6',
    'XGCFPCZVDOZHLT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,3,5-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3,5-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3,5-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3,6-tetramethylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-51-7',
    'ZVRALCAHDAJURU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,3,6-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3,6-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3,6-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,4-tetramethylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-52-8',
    'SXHQWTUVNZIMTP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,4,4-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,4-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,4-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,5-tetramethylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-53-9',
    'LGUFKOOYNDNVNP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,4,5-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,5-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,5-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,6-tetramethylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-54-0',
    'WOHJQOFSYZPITE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,4,6-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,6-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,6-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,5,5-tetramethylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-55-1',
    'QSBIXVGCKCYBBL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,5,5-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5,5-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5,5-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,5,6-tetramethylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '52670-32-3',
    'RAHGVMDMAJFLTP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,5,6-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5,6-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5,6-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,4,5-tetramethylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-56-2',
    'QALMSCCHYDFGLF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4,4,5-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4,5-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4,5-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,4,6-tetramethylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-57-3',
    'DTMSZIVVBLZFEV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4,4,6-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4,6-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4,6-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,5,5-tetramethylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-58-4',
    'JVYVKEOAYQAABU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4,5,5-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5,5-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5,5-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3,4,4-tetramethylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-59-5',
    'CFNIIBCZVLNKPV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3,4,4-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3,4,5-tetramethylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-60-8',
    'QVCSKDHUHWRVTA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3,4,5-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,5-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,5-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3,5,5-tetramethylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-61-9',
    'GALDMESQGNRJGE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3,5,5-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,5,5-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,5,5-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4,4,5-tetramethylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-62-0',
    'CXIAIMLBUJNNJR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4,4,5-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,4,5-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,4,5-tetramethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dimethyl-3-ethylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61869-03-2',
    'SBWMIVQVGGUMCE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2-dimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dimethyl-4-ethylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '62016-46-0',
    'BJOUMNMMNSZESV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2-dimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dimethyl-5-ethylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '62016-47-1',
    'HVVFIKMZXFNXKA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2-dimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethyl-3-ethylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-21-1',
    'KQUHXOYVQZYOOF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3-dimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethyl-4-ethylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-22-2',
    'CNEPAGDSOHLVRW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3-dimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethyl-5-ethylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-23-3',
    'BFCKNSGKYWMUNP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3-dimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dimethyl-3-ethylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-24-4',
    'OBCGEYFMJYXFJV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dimethyl-4-ethylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-25-5',
    'OETKSNKIFXLJDO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4-dimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dimethyl-5-ethylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-26-6',
    'RZHNOEUMKYRHIX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4-dimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5-dimethyl-3-ethylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-27-7',
    'DEZOXTLNRYCKNK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,5-dimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5-dimethyl-4-ethylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-28-8',
    'CUHCBWKQRDWQMN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,5-dimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5-dimethyl-5-ethylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-29-9',
    'GPZDEXDVXFJVLH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,5-dimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6-dimethyl-3-ethylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-30-2',
    'BFXHSWDHLPKFSH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,6-dimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6-dimethyl-4-ethylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-31-3',
    'GBSGJLJGXHBTQQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,6-dimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3-dimethyl-4-ethylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-32-4',
    'QXJXAHFNWHEQEU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3-dimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3-dimethyl-5-ethylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-33-5',
    'FLLHBJKGZIOYAA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3-dimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4-dimethyl-3-ethylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-34-6',
    'HKSCZRRMBTUZLO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4-dimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4-dimethyl-4-ethylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-35-7',
    'RMVWUAZCGGWZKA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4-dimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4-dimethyl-5-ethylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-36-8',
    'PCRCVFLPWIQGNJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4-dimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,5-dimethyl-3-ethylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-37-9',
    'FQOCKNRDCVODKW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,5-dimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,5-dimethyl-4-ethylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-38-0',
    'IKVNPWSSYMJDKE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,5-dimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,4-dimethyl-3-ethylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-39-1',
    'YMWPSGKMCMMFSS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,4-dimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-4-propylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-96-0',
    'AXOUMHTUGUFOKF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-4-propylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-4-propylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-4-propylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-4-propylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-97-1',
    'WAMROSASDOIVDE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-4-propylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-4-propylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-4-propylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-4-propylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '17302-20-4',
    'RDZFGBZTNOYNAH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-4-propylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-4-propylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-4-propylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-3-isopropylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '6876-18-2',
    'GECZBVJYUAPYFD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-3-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-4-isopropylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-98-2',
    'ADLZFTVQXMDTCY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-4-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-4-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-4-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-4-isopropylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-99-3',
    'SRECVVXQFXRBNI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-4-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-4-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-4-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-4-isopropylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61869-00-9',
    'LSJZMBVEVGYTAG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-4-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-4-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-4-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3-diethylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '17302-17-9',
    'XATIZWAWQAIMQJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3-diethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-diethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-diethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4-diethylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61869-01-0',
    'UWOPVDFSBGDRJR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4-diethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-diethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-diethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,5-diethylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61869-02-1',
    'OBHTWTQZINRNAB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,5-diethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-diethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-diethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,4-diethylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '17302-21-5',
    'WDTMGYSKSAMSPF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,4-diethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-diethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-diethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-<i>tert</i>-butylheptane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '60302-21-8',
    'MDOHZJRFNISIIH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-<i>tert</i>-butylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-<i>tert</i>-butylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-<i>tert</i>-butylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,3,4-pentamethylhexane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-85-7',
    'RSEBTOONCGVAKN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3,3,4-pentamethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3,4-pentamethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3,4-pentamethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,3,5-pentamethylhexane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-86-8',
    'QGVXFIIZUSICQO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3,3,5-pentamethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3,5-pentamethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3,5-pentamethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,4,4-pentamethylhexane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-87-9',
    'HBVQLCKOFAUQGY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3,4,4-pentamethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,4,4-pentamethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,4,4-pentamethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,4,5-pentamethylhexane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-88-0',
    'LDUJDGROUWHEKU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3,4,5-pentamethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,4,5-pentamethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,4,5-pentamethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,5,5-pentamethylhexane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '14739-73-2',
    'UKYAYXXQXKPIBL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3,5,5-pentamethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,5,5-pentamethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,5,5-pentamethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,4,4,5-pentamethylhexane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '60302-23-0',
    'JQFZWBZEZYOCQL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,4,4,5-pentamethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,4,5-pentamethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,4,5-pentamethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3,4,4-pentamethylhexane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-89-1',
    'GHRPCKCGHFDDOH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,3,4,4-pentamethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3,4,4-pentamethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3,4,4-pentamethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3,4,5-pentamethylhexane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '52670-33-4',
    'STMIMOZUYGUOQZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,3,4,5-pentamethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3,4,5-pentamethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3,4,5-pentamethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3-trimethyl-3-ethylhexane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-72-2',
    'HUAYVWMWWLHZAB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3-trimethyl-3-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3-trimethyl-3-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3-trimethyl-3-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3-trimethyl-4-ethylhexane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-73-3',
    'ZSUMTZIXJNZKBI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3-trimethyl-4-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3-trimethyl-4-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3-trimethyl-4-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,4-trimethyl-3-ethylhexane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-74-4',
    'UDUTWNYTAVENNO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,4-trimethyl-3-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethyl-3-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethyl-3-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,4-trimethyl-4-ethylhexane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-75-5',
    'YFQDCXGMLYJDSG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,4-trimethyl-4-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethyl-4-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethyl-4-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,5-trimethyl-3-ethylhexane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-76-6',
    'GJVFOLLEVKEKMU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,5-trimethyl-3-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,5-trimethyl-3-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,5-trimethyl-3-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,5-trimethyl-4-ethylhexane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-77-7',
    'UKTBERWYLDSZDQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,5-trimethyl-4-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,5-trimethyl-4-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,5-trimethyl-4-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3-trimethyl-4-ethylhexane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-78-8',
    'DNDCULLMOLSZER-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,3-trimethyl-4-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3-trimethyl-4-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3-trimethyl-4-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4-trimethyl-3-ethylhexane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-79-9',
    'XCNOKZUAQAZTAJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,4-trimethyl-3-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethyl-3-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethyl-3-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4-trimethyl-4-ethylhexane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-80-2',
    'HNNSQDJQJRTMMW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,4-trimethyl-4-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethyl-4-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethyl-4-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,5-trimethyl-3-ethylhexane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-81-3',
    'VYVPEEFLIYVOTH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,5-trimethyl-3-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5-trimethyl-3-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5-trimethyl-3-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,5-trimethyl-4-ethylhexane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-82-4',
    'LDKMZLRIVWGQRW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,5-trimethyl-4-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5-trimethyl-4-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5-trimethyl-4-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,4-trimethyl-3-ethylhexane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-83-5',
    'MTYPKDRKJRWXKB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4,4-trimethyl-3-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4-trimethyl-3-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4-trimethyl-3-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3,4-trimethyl-4-ethylhexane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-84-6',
    'ADDYWUNUHVKQGT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3,4-trimethyl-4-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4-trimethyl-4-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4-trimethyl-4-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dimethyl-3-isopropylhexane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-63-1',
    'VKABOTNMFKIVDN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2-dimethyl-3-isopropylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-3-isopropylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-3-isopropylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethyl-3-isopropylhexane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-64-2',
    'XVWGUCNHEXRNJU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3-dimethyl-3-isopropylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-3-isopropylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-3-isopropylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dimethyl-3-isopropylhexane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-65-3',
    'QRNSQXWPYPLHTL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-isopropylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-isopropylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-isopropylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5-dimethyl-3-isopropylhexane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-66-4',
    'QKICRGDGSLQROM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,5-dimethyl-3-isopropylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyl-3-isopropylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyl-3-isopropylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-3,3-diethylhexane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-67-5',
    'QNRHKXCWHYUEKP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-3,3-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3,3-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3,3-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-3,4-diethylhexane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-68-6',
    'MWHIPTVSAPEYPC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-3,4-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3,4-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3,4-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-4,4-diethylhexane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-69-7',
    'UNPXTJSCIHOMKB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-4,4-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-4,4-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-4,4-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-3,4-diethylhexane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-70-0',
    'ZFMWIWWLOKHXHC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-3,4-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-3,4-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-3,4-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-4,4-diethylhexane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-71-1',
    'CUHCCZRBXHOAMW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-4,4-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-4,4-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-4,4-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,3,4,4-hexamethylpentane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '60302-27-4',
    'JKJQSSSRSKPVEM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3,3,4,4-hexamethylpentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3,4,4-hexamethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3,4,4-hexamethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,4-tetramethyl-3-ethylpentane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-93-7',
    'HBSINJYUKWVYBC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3,4-tetramethyl-3-ethylpentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,4-tetramethyl-3-ethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,4-tetramethyl-3-ethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,4,4-tetramethyl-3-ethylpentane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '3178-30-1',
    'FNWCWFQEEKFGHB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,4,4-tetramethyl-3-ethylpentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,4-tetramethyl-3-ethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,4-tetramethyl-3-ethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,4-trimethyl-3-isopropylpentane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-90-4',
    'SZPCILWZDHUKLW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,4-trimethyl-3-isopropylpentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethyl-3-isopropylpentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethyl-3-isopropylpentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4-trimethyl-3-isopropylpentane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-91-5',
    'FHBFVPOXLRZZPP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,4-trimethyl-3-isopropylpentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethyl-3-isopropylpentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethyl-3-isopropylpentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dimethyl-3,3-diethylpentane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '60302-28-5',
    'KCQSYGZVYTYSLG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2-dimethyl-3,3-diethylpentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-3,3-diethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-3,3-diethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dimethyl-3,3-diethylpentane',
    'C<sub>11</sub>H<sub>24</sub>',
    '',
    '61868-92-6',
    'VVQOQVXGUMJNET-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3,3-diethylpentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3,3-diethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3,3-diethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dodecane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '112-40-3',
    'SNRUBQQJIBEYMU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='dodecane'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='dodecane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dodecane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dodecane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dodecane'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dodecane'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dodecane'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dodecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dodecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dodecane'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dodecane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dodecane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dodecane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dodecane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dodecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dodecane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dodecane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dodecane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dodecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dodecane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dodecane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dodecane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dodecane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methylundecane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '31807-55-3',
    'GTJOHISYCKPIMT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methylundecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylundecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylundecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methylundecane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '1002-43-3',
    'HTZWVZNRDDOFEI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methylundecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylundecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylundecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methylundecane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '2980-69-0',
    'KNMXZGDUJVOTOC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methylundecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylundecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylundecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-methylundecane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '1632-70-8',
    'QULNVKABFWNUCW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='5-methylundecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methylundecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methylundecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '6-methylundecane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '17302-33-9',
    'VPYZCUCKYWHJGX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='6-methylundecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-methylundecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-methylundecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dimethyldecane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '17302-37-3',
    'WBWYXWILSHQILH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethyldecane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '17312-44-6',
    'ZCTGYLNFWOQVHV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dimethyldecane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '2801-84-5',
    'OJAFXEXESSNPMH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5-dimethyldecane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '17312-50-4',
    'DQHKBYZSYRJBMD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,5-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6-dimethyldecane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '13150-81-7',
    'DHJGXZWEQBKLNV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,6-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,7-dimethyldecane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '17312-51-5',
    'RVQIXUWWPOTVNP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,7-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,7-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,7-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,8-dimethyldecane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '17312-52-6',
    'KSRGGHUVCVWVDW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,8-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,8-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,8-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,9-dimethyldecane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '1002-17-1',
    'HWISDPDDDUZJAW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,9-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,9-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,9-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3-dimethyldecane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '17302-38-4',
    'URERYYDSQOIHQK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4-dimethyldecane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '17312-45-7',
    'NRBMEEDORZDRIT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,5-dimethyldecane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '17312-48-0',
    'XXSUEVGKGOUJMD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,5-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,6-dimethyldecane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '17312-53-7',
    'NQWFSCYWTXQNGG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,6-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,6-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,6-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,7-dimethyldecane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '17312-54-8',
    'VDAVEASVPZDNQB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,7-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,7-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,7-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,8-dimethyldecane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '17312-55-9',
    'KMAHIPNGGSOJSM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,8-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,8-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,8-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,4-dimethyldecane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '17312-39-9',
    'WZCACTKWHXCWFZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,4-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,5-dimethyldecane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '17312-46-8',
    'QZFIIEYSHODCSV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,5-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,5-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,5-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,6-dimethyldecane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '17312-49-1',
    'TVGNRLXIJXKVGD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,6-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,6-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,6-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,7-dimethyldecane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '17312-56-0',
    'GCKWUFQALHAZDH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,7-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,7-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,7-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5,5-dimethyldecane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '17453-92-8',
    'RNXSOUOIPAWOAC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='5,5-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5,5-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5,5-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5,6-dimethyldecane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '1636-43-7',
    'NCJIZIYQFWXMFZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='5,6-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5,6-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5,6-dimethyldecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyldecane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '17085-96-0',
    'ZBDDVSBBCGZQDV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyldecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyldecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyldecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-ethyldecane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '1636-44-8',
    'IGTKVLJTIZALGL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-ethyldecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyldecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyldecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-ethyldecane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '17302-36-2',
    'BCQLAHKMMOGIIS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='5-ethyldecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-ethyldecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-ethyldecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3-trimethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '55499-04-2',
    'XXNUJUNKYOZLAJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,4-trimethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-50-3',
    'YYYAICGYFLHBIN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,4-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,5-trimethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-51-4',
    'ZIXRFABUOOUIMA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,5-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,5-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,5-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,6-trimethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-52-5',
    'BUTMZMIZSWINDK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,6-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,6-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,6-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,7-trimethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-53-6',
    'PXOURNMYVAOUML-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,7-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,7-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,7-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,8-trimethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-54-7',
    'WXUAVABOZJOELJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,8-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,8-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,8-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3-trimethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-55-8',
    'RSUFJUIYLXRYFG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,3-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4-trimethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-56-9',
    'RRZRZLRUYPZYEH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,4-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,5-trimethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-57-0',
    'IESSJVKAXJWJFD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,5-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,6-trimethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-58-1',
    'AUXUELQPRQTQBE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,6-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,6-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,6-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,7-trimethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-59-2',
    'GGUGBCMHEULHJS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,7-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,7-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,7-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,8-trimethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-60-5',
    'GQHCJRDJABETBJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,8-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,8-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,8-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,4-trimethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-61-6',
    'RRLKOZCPQXMIIJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4,4-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,5-trimethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-62-7',
    'NZAPYIGNIYRJNJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4,5-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,6-trimethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-10-5',
    'QCQMRLDBNMVKOZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4,6-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,7-trimethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-11-6',
    'OHBDIVOYUFLOTO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4,7-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,7-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,7-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,8-trimethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '49542-74-7',
    'PZXMOJBYRFSNJH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4,8-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,8-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,8-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5,5-trimethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-12-7',
    'ZRRKWMYBHUMSTG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,5,5-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5,5-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5,5-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5,6-trimethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-13-8',
    'KXHDWXIQHWSOHI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,5,6-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5,6-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5,6-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5,7-trimethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-14-9',
    'KMBPYTMBXFKXON-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,5,7-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5,7-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5,7-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5,8-trimethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '49557-09-7',
    'YYZRNFMGAQMLJJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,5,8-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5,8-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5,8-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6,6-trimethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-15-0',
    'MTPVPWZHWOHMQT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,6,6-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6,6-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6,6-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6,7-trimethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-16-1',
    'PGLYQCHTCUBASV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,6,7-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6,7-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6,7-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,7,7-trimethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-17-2',
    'RCTMUTWYOMEASD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,7,7-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,7,7-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,7,7-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3,4-trimethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-18-3',
    'RNCRKMFELJSFRA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3,4-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3,5-trimethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-19-4',
    'KRWQPUYFIGHZNF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3,5-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,5-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,5-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3,6-trimethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-20-7',
    'GPSMOBMYMZBKGT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3,6-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,6-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,6-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3,7-trimethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-21-8',
    'NZYGFHSHEQXPFT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3,7-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,7-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,7-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4,4-trimethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-22-9',
    'UYNWXBDPBKCTRS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4,4-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,4-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,4-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4,5-trimethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-23-0',
    'PFVDUOFPBLPHEQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4,5-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,5-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,5-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4,6-trimethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-24-1',
    'VSRUKIVBXBGRDU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4,6-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,6-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,6-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4,7-trimethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '27802-85-3',
    'HQIBDLHPQGDJEW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4,7-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,7-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,7-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,5,5-trimethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-25-2',
    'MUVSDRJGHVLJQX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,5,5-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5,5-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5,5-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,5,6-trimethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-26-3',
    'HMCPPWBQUPZETF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,5,6-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5,6-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5,6-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,5,7-trimethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-27-4',
    'LLVWEFHXQBAEJX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,5,7-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5,7-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5,7-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,6,6-trimethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-28-5',
    'CBDYLMAJISNHBH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,6,6-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,6,6-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,6,6-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,4,5-trimethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-29-6',
    'QLJZSYCAASGFGU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,4,5-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4,5-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4,5-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,4,6-trimethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-30-9',
    'KBTTWWLCACXOSV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,4,6-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4,6-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4,6-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,5,5-trimethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-31-0',
    'QVDLUCCOJXIINS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,5,5-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,5,5-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,5,5-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,5,6-trimethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62211-85-2',
    'BBEKERHGCOZOIX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,5,6-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,5,6-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,5,6-trimethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-3-ethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-73-0',
    'NVCDNLWOUSWNRQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-3-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-4-ethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-37-6',
    'GRYPXYDXCQOVAY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-4-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-4-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-4-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-5-ethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-38-7',
    'WZWWJMDOQQIPJZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-5-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-5-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-5-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-6-ethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-39-8',
    'GBMUYXDAAUUNLY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-6-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-6-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-6-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-7-ethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-40-1',
    'PHPGTUZXJVCCKP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-7-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-7-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-7-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-3-ethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '17302-39-5',
    'MJZXPSBAAXOUJF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-3-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-3-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-3-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-4-ethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-41-2',
    'ZELDGOVWPZHVJS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-4-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-4-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-4-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-5-ethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-42-3',
    'GDUZVOIDJDZQBC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-5-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-5-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-5-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-6-ethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-43-4',
    'WSMCXXNPFLZSMY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-6-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-6-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-6-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-7-ethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-44-5',
    'FSGFZSLYTXQNCW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-7-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-7-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-7-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-3-ethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-45-6',
    'AUMKRFNJSTUECA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-3-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-3-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-3-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-4-ethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '17312-40-2',
    'LXQCGRFCISXKCQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-4-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-4-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-4-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-5-ethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-46-7',
    'BDJIXOFXGLDYLN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-5-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-5-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-5-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-6-ethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-47-8',
    'SULZKBWLMOBACQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-6-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-6-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-6-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-7-ethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-48-9',
    'HYIBWPIYSSTZLB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-7-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-7-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-7-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-methyl-3-ethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-49-0',
    'ZBALIHDUORTBQR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='5-methyl-3-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-3-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-3-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-methyl-4-ethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '1632-71-9',
    'HKUUNAOHRKAJIY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='5-methyl-4-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-4-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-4-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-methyl-5-ethylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '14531-16-9',
    'DZSBQMNPPIKBNF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='5-methyl-5-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-5-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-5-ethylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-propylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '6165-37-3',
    'QLKPGWNXMMBQMG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-propylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-propylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-propylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-propylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '998-35-6',
    'ISHSSTRAYNPQFX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='5-propylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-propylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-propylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-isopropylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-71-8',
    'BXYKZQOGHMLDIE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-isopropylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-isopropylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-isopropylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-isopropylnonane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-72-9',
    'ALZCRHWYCQKCQK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='5-isopropylnonane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-isopropylnonane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-isopropylnonane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,3-tetramethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62183-74-8',
    'UXQAEOWCSOPBLF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3,3-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,4-tetramethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62183-75-9',
    'HEJULKHHKGYPNT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3,4-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,4-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,4-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,5-tetramethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62183-76-0',
    'MRBTZFDZTJYCAO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3,5-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,5-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,5-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,6-tetramethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62183-77-1',
    'YRSBZJIBIXVOME-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3,6-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,6-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,6-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,7-tetramethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62183-78-2',
    'CPEHPCZXBBEYOL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3,7-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,7-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,7-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,4,4-tetramethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62183-79-3',
    'TYUFTNSABIBNRY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,4,4-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,4-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,4-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,4,5-tetramethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62183-80-6',
    'SNJCVPBJFQJMFW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,4,5-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,5-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,5-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,4,6-tetramethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62183-81-7',
    'ODZRFEPMTHWMBK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,4,6-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,6-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,6-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,4,7-tetramethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62183-82-8',
    'QHDQKPZLRKHEHV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,4,7-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,7-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,7-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,5,5-tetramethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62183-83-9',
    'RJJMZKVKQLGGDK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,5,5-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,5,5-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,5,5-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,5,6-tetramethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62183-84-0',
    'BQUVPJLOJUCQGM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,5,6-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,5,6-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,5,6-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,5,7-tetramethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-19-3',
    'ISTINYWNHRBEDQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,5,7-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,5,7-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,5,7-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,6,6-tetramethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-20-6',
    'BANZIZHQGFRTMI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,6,6-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,6,6-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,6,6-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,6,7-tetramethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-21-7',
    'ZSXJNQURTCJFGP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,6,7-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,6,7-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,6,7-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,7,7-tetramethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '1071-31-4',
    'QZUFNKONEPLWBC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,7,7-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,7,7-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,7,7-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3,4-tetramethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-22-8',
    'ITTRGXLKGDMYDX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,3,4-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3,4-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3,4-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3,5-tetramethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-23-9',
    'RVOIBAZQSHFKMM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,3,5-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3,5-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3,5-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3,6-tetramethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-24-0',
    'MBJHOSHYIFXEPL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,3,6-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3,6-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3,6-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3,7-tetramethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-25-1',
    'WWQBXZREQWIXFF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,3,7-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3,7-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3,7-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,4-tetramethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-26-2',
    'MELCVUZPHQRNTK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,4,4-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,4-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,4-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,5-tetramethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-27-3',
    'AMIZVDCCXDQOHL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,4,5-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,5-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,5-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,6-tetramethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-28-4',
    'OYZWSGWTBSWCLN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,4,6-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,6-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,6-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,7-tetramethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-29-5',
    'YUCNZDFGMLKYFT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,4,7-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,7-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,7-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,5,5-tetramethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-30-8',
    'RQOLUXQWYAKKTG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,5,5-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5,5-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5,5-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,5,6-tetramethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-31-9',
    'IPYLOMHOPWIUFA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,5,6-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5,6-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5,6-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,5,7-tetramethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-32-0',
    'AIUMUUQTYGQPMV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,5,7-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5,7-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5,7-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,6,6-tetramethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-33-1',
    'CVRMZIOMFWYAPV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,6,6-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,6,6-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,6,6-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,6,7-tetramethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '52670-34-5',
    'FZCGYGCYZRXLDY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,6,7-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,6,7-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,6,7-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,4,5-tetramethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-34-2',
    'OBWRJGVWBWXXAO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4,4,5-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4,5-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4,5-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,4,6-tetramethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-35-3',
    'UQCGTRPILZWACX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4,4,6-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4,6-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4,6-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,4,7-tetramethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '35866-96-7',
    'QYUWMFZODNLLRJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4,4,7-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4,7-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4,7-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,5,5-tetramethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-36-4',
    'OMFWIGPPTXTQHH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4,5,5-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5,5-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5,5-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,5,6-tetramethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-37-5',
    'YJMGKHXCSVEVKG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4,5,6-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5,6-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5,6-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,5,7-tetramethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '2217-17-6',
    'PWYLDJLMYGOPSR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4,5,7-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5,7-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5,7-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,6,6-tetramethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-38-6',
    'VVEPRQWGSASPPP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4,6,6-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6,6-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6,6-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5,5,6-tetramethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-39-7',
    'DLCPMTDXNVOOLU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,5,5,6-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5,5,6-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5,5,6-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5,6,6-tetramethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-40-0',
    'SQOVOQLOSFZJGI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,5,6,6-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5,6,6-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5,6,6-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3,4,4-tetramethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-41-1',
    'VXEUNQVVVNDDTL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3,4,4-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3,4,5-tetramethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-42-2',
    'FATMBSLXTUXZBP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3,4,5-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,5-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,5-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3,4,6-tetramethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-43-3',
    'VCXMKRQQDPQALS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3,4,6-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,6-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,6-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3,5,5-tetramethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-44-4',
    'UJLDJWNVZROTLS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3,5,5-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,5,5-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,5,5-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3,5,6-tetramethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-45-5',
    'AQPSWWWUVHSZJK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3,5,6-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,5,6-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,5,6-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3,6,6-tetramethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-46-6',
    'PAEUGKMMSQUAGH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3,6,6-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,6,6-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,6,6-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4,4,5-tetramethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-47-7',
    'HWNTXBYEGXKWKG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4,4,5-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,4,5-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,4,5-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4,4,6-tetramethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62185-19-7',
    'LNRFUGUGPGLBLV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4,4,6-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,4,6-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,4,6-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4,5,5-tetramethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62185-20-0',
    'NCNZUEBQNGRARF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4,5,5-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,5,5-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,5,5-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4,5,6-tetramethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62185-21-1',
    'NADJQGPTQSFIHB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4,5,6-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,5,6-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,5,6-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,4,5,5-tetramethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62185-22-2',
    'INTYEXUWOYUVGJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,4,5,5-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4,5,5-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4,5,5-tetramethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dimethyl-3-ethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62183-95-3',
    'LIZQPVRBTUZZCL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2-dimethyl-3-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-3-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-3-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dimethyl-4-ethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62183-96-4',
    'PEGJIJFSOTZJFH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2-dimethyl-4-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-4-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-4-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dimethyl-5-ethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62183-97-5',
    'ACWGGQUVVQOZPJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2-dimethyl-5-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-5-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-5-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dimethyl-6-ethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62183-98-6',
    'SHNILIMSRTWRKG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2-dimethyl-6-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-6-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-6-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethyl-3-ethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62183-99-7',
    'NDFHPGVSCVJNFR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3-dimethyl-3-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-3-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-3-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethyl-4-ethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-00-3',
    'DCBIYDZULXWXTQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3-dimethyl-4-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-4-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-4-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethyl-5-ethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-01-4',
    'NPUNZBBVZZNRNS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3-dimethyl-5-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-5-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-5-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethyl-6-ethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-02-5',
    'BWSXPPUMTZVKPA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3-dimethyl-6-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-6-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-6-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dimethyl-3-ethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-03-6',
    'QYHDQDAUJCPVFJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dimethyl-4-ethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-04-7',
    'XAKSPVTVTMAMDT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4-dimethyl-4-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-4-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-4-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dimethyl-5-ethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-05-8',
    'JHDZOLPKXSWZKD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4-dimethyl-5-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-5-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-5-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dimethyl-6-ethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-06-9',
    'VGDSKYYXZZCASQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4-dimethyl-6-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-6-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-6-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5-dimethyl-3-ethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-07-0',
    'BCQWMBQACXNHGP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,5-dimethyl-3-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyl-3-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyl-3-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5-dimethyl-4-ethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-08-1',
    'IMMDGMKEESKIQT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,5-dimethyl-4-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyl-4-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyl-4-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5-dimethyl-5-ethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-09-2',
    'BVAIFAWSJOPLJD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,5-dimethyl-5-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyl-5-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyl-5-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5-dimethyl-6-ethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62183-50-0',
    'CYTDZGRTFHXLQS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,5-dimethyl-6-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyl-6-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyl-6-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6-dimethyl-3-ethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62183-51-1',
    'WAFCPUFGSNTFSP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,6-dimethyl-3-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethyl-3-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethyl-3-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6-dimethyl-4-ethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62183-52-2',
    'JIOQMQLJPQDNFA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,6-dimethyl-4-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethyl-4-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethyl-4-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6-dimethyl-5-ethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62183-53-3',
    'ZBMWKURVBLDBAH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,6-dimethyl-5-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethyl-5-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethyl-5-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6-dimethyl-6-ethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62183-54-4',
    'DGFWFJRTTJTVEQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,6-dimethyl-6-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethyl-6-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethyl-6-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,7-dimethyl-3-ethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62183-55-5',
    'XEMFRSYZKNPRTA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,7-dimethyl-3-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,7-dimethyl-3-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,7-dimethyl-3-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,7-dimethyl-4-ethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62183-56-6',
    'KSVMIUVYLYZDMT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,7-dimethyl-4-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,7-dimethyl-4-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,7-dimethyl-4-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3-dimethyl-4-ethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62183-57-7',
    'BKNJDUXGYCILJT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3-dimethyl-4-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-4-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-4-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3-dimethyl-5-ethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62183-58-8',
    'GQTCKTISADWVNV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3-dimethyl-5-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-5-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-5-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3-dimethyl-6-ethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62183-59-9',
    'DDRNTRVXHMVVLA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3-dimethyl-6-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-6-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-6-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4-dimethyl-3-ethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62212-28-6',
    'AOQVLRSMPNHJPF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4-dimethyl-3-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyl-3-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyl-3-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4-dimethyl-4-ethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62183-60-2',
    'WBKPODGAYHVUMM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4-dimethyl-4-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyl-4-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyl-4-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4-dimethyl-5-ethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62183-61-3',
    'LEPWFUNEXVKPDO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4-dimethyl-5-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyl-5-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyl-5-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4-dimethyl-6-ethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62183-62-4',
    'DPDGQUDZYGOBAM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4-dimethyl-6-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyl-6-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyl-6-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,5-dimethyl-3-ethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62183-63-5',
    'QYJKERUDQYOWRC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,5-dimethyl-3-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethyl-3-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethyl-3-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,5-dimethyl-4-ethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62183-64-6',
    'OMAJEXDENFMCIN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,5-dimethyl-4-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethyl-4-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethyl-4-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,5-dimethyl-5-ethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62183-65-7',
    'OLBJDMSGRVKJMF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,5-dimethyl-5-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethyl-5-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethyl-5-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,5-dimethyl-6-ethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62183-66-8',
    'LLHGAWREVJAITE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,5-dimethyl-6-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethyl-6-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethyl-6-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,6-dimethyl-3-ethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62183-67-9',
    'MNXPIOFJFYQCKE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,6-dimethyl-3-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,6-dimethyl-3-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,6-dimethyl-3-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,6-dimethyl-4-ethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62183-68-0',
    'RTVRGBUFZDOPIH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,6-dimethyl-4-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,6-dimethyl-4-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,6-dimethyl-4-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,4-dimethyl-3-ethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62183-69-1',
    'RHSANRLUOZFJDW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,4-dimethyl-3-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethyl-3-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethyl-3-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,4-dimethyl-5-ethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62183-70-4',
    'BETVNWPSZXTJLK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,4-dimethyl-5-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethyl-5-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethyl-5-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,4-dimethyl-6-ethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62183-71-5',
    'UGEWSKWSWHZABT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,4-dimethyl-6-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethyl-6-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethyl-6-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,5-dimethyl-3-ethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62183-72-6',
    'MNDPOEACQSQPCJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,5-dimethyl-3-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,5-dimethyl-3-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,5-dimethyl-3-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,5-dimethyl-4-ethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62183-73-7',
    'MOEUNMMPAYEJOZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,5-dimethyl-4-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,5-dimethyl-4-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,5-dimethyl-4-ethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3-diethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '17302-40-8',
    'DGJISSKLLWWXTG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3-diethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-diethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-diethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4-diethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62183-92-0',
    'HILZBOWVGZXYGQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4-diethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-diethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-diethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,5-diethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62183-93-1',
    'DSYIMNMBWBEOHY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,5-diethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-diethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-diethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,6-diethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62183-94-2',
    'UTCTYSTYZOAAOS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,6-diethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,6-diethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,6-diethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,4-diethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '17312-42-4',
    'FTEQKVNFZNDQJG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,4-diethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-diethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-diethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,5-diethyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '1636-41-5',
    'XRVCHXCONYJHLU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,5-diethyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,5-diethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,5-diethyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-4-propyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-33-2',
    'FJPVBTBEYVNWCA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-4-propyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-4-propyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-4-propyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-5-propyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-34-3',
    'NYBDGQCIJCAIJL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-5-propyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-5-propyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-5-propyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-4-propyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-35-4',
    'CTXPEFTVFFFIBQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-4-propyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-4-propyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-4-propyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-5-propyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-36-5',
    'VOSHMCRSZWNTLJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-5-propyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-5-propyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-5-propyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-4-propyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '17312-41-3',
    'RNKCZSBPRRHTOZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-4-propyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-4-propyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-4-propyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-5-propyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62183-85-1',
    'MVUWSCFPURGAJF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-5-propyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-5-propyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-5-propyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-3-isopropyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '13287-19-9',
    'KBIUKRVYBYJVSS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-3-isopropyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-isopropyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-isopropyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-4-isopropyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62183-86-2',
    'NRRICFUUPCDSKW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-4-isopropyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-4-isopropyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-4-isopropyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-5-isopropyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62183-87-3',
    'OPKVPKXVSDEXOZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-5-isopropyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-5-isopropyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-5-isopropyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-4-isopropyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62183-88-4',
    'UXTHXSNAZBLVOD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-4-isopropyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-4-isopropyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-4-isopropyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-5-isopropyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62183-89-5',
    'VEJPAYNPRZYJNN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-5-isopropyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-5-isopropyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-5-isopropyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-4-isopropyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62183-90-8',
    'KCNISWXEVSJYRS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-4-isopropyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-4-isopropyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-4-isopropyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-5-isopropyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62183-91-9',
    'HEFVKUUZAXCMQX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-5-isopropyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-5-isopropyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-5-isopropyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-<i>tert</i>-butyloctane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-32-1',
    'RWILNGDOCMDMJW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-<i>tert</i>-butyloctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-<i>tert</i>-butyloctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-<i>tert</i>-butyloctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,4,6,6-pentamethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '13475-82-6',
    'VKPSKYDESGTTFR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,4,6,6-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,6,6-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,6,6-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,6,6-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,6,6-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,6,6-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,6,6-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,3,4-pentamethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62198-80-5',
    'NTDYBHYVUCYILC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3,3,4-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3,4-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3,4-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,3,5-pentamethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62198-81-6',
    'ZLCPPJIFAFIYPV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3,3,5-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3,5-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3,5-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,3,6-pentamethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62198-82-7',
    'LYTFNNQFUUFUDH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3,3,6-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3,6-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3,6-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,4,4-pentamethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62198-83-8',
    'SUFPUVGFEWPIFA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3,4,4-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,4,4-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,4,4-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,4,5-pentamethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62198-84-9',
    'XYDYIKVIGCXDLV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3,4,5-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,4,5-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,4,5-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,4,6-pentamethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62198-85-0',
    'XRJGBYMRUIWAJP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3,4,6-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,4,6-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,4,6-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,5,5-pentamethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62198-86-1',
    'OSZLORKBJVWZNT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3,5,5-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,5,5-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,5,5-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,5,6-pentamethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62198-87-2',
    'MHJUEZDXDYXCPA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3,5,6-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,5,6-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,5,6-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,6,6-pentamethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62198-88-3',
    'SLGYOGBODYIQGW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3,6,6-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,6,6-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,6,6-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,4,4,5-pentamethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-61-5',
    'XRGPEBQZXVFCRE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,4,4,5-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,4,5-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,4,5-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,4,4,6-pentamethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-62-6',
    'NOFQKTWPZFUCOO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,4,4,6-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,4,6-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,4,6-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,4,5,5-pentamethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-63-7',
    'JGOKXUSMFJOVQT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,4,5,5-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,5,5-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,5,5-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,4,5,6-pentamethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-64-8',
    'JVESFBBBMJIZLO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,4,5,6-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,5,6-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,5,6-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,5,5,6-pentamethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-65-9',
    'FMJMMNPKKCFHTH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,5,5,6-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,5,5,6-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,5,5,6-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3,4,4-pentamethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-66-0',
    'VBOBCKMZHQJDQA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,3,4,4-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3,4,4-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3,4,4-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3,4,5-pentamethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-67-1',
    'OLZJEASBDLLWCY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,3,4,5-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3,4,5-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3,4,5-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3,4,6-pentamethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-68-2',
    'YENAHMOHMFYKPC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,3,4,6-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3,4,6-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3,4,6-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3,5,5-pentamethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-69-3',
    'DTLBRJVRUQMSQN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,3,5,5-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3,5,5-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3,5,5-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3,5,6-pentamethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '52670-35-6',
    'SZQDOCSTKXRXAR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,3,5,6-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3,5,6-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3,5,6-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,4,5-pentamethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-70-6',
    'CHHJLGDSEYTKKE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,4,4,5-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,4,5-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,4,5-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,4,6-pentamethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-71-7',
    'DHXWMADSONSWTL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,4,4,6-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,4,6-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,4,6-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,5,5-pentamethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-72-8',
    'BDFJISGXUJUYCX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,4,5,5-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,5,5-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,5,5-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,5,6-pentamethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '27574-98-7',
    'YIKFFSNUOIJPSI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,4,5,6-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,5,6-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,5,6-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,4,5,5-pentamethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-73-9',
    'TXGUYEKSMHZHSB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4,4,5,5-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4,5,5-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4,5,5-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3,4,4,5-pentamethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-74-0',
    'YFXNIDIHYOGTEN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3,4,4,5-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4,5-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4,5-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3,4,5,5-pentamethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-75-1',
    'NZIFKVSORPBQSX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3,4,5,5-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,5,5-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,5,5-pentamethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3-trimethyl-3-ethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-04-6',
    'CVXGCQXACVZXQR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3-trimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3-trimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3-trimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3-trimethyl-4-ethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-05-7',
    'COHRBFNOOUABCT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3-trimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3-trimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3-trimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3-trimethyl-5-ethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-06-8',
    'OOIGDPTZPWRGHN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3-trimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3-trimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3-trimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,4-trimethyl-3-ethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-07-9',
    'TYGUUZVWCBYDKW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,4-trimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,4-trimethyl-4-ethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-08-0',
    'XMUXASPVOBQLPC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,4-trimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,4-trimethyl-5-ethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-09-1',
    'QADOHJKDWMLCQT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,4-trimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,5-trimethyl-3-ethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-10-4',
    'SUDWTPMZYLBGKW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,5-trimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,5-trimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,5-trimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,5-trimethyl-4-ethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-11-5',
    'GDPLKYYKURLRKJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,5-trimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,5-trimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,5-trimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,5-trimethyl-5-ethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-12-6',
    'KJWMMFYTYSUWMH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,5-trimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,5-trimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,5-trimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,6-trimethyl-3-ethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-13-7',
    'RIIDJOQRWGTQEN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,6-trimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,6-trimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,6-trimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,6-trimethyl-4-ethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-14-8',
    'QGYSVVWKEDKPTP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,6-trimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,6-trimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,6-trimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,6-trimethyl-5-ethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-15-9',
    'LYZRWXZZVRWJHX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,6-trimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,6-trimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,6-trimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3-trimethyl-4-ethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-16-0',
    'VIIXOXRHJWHIBP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,3-trimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3-trimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3-trimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3-trimethyl-5-ethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-17-1',
    'JHGOLBUJAIJLCX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,3-trimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3-trimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3-trimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4-trimethyl-3-ethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-18-2',
    'YZXMDESZKHUODO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,4-trimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4-trimethyl-4-ethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62198-55-4',
    'QDWZIZQKVLESDK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,4-trimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4-trimethyl-5-ethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62198-56-5',
    'URFFXJPJMCMXFR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,4-trimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,5-trimethyl-3-ethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62198-57-6',
    'QHACFORXSGHTJG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,5-trimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5-trimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5-trimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,5-trimethyl-4-ethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62198-58-7',
    'UEZAASCWBAVHRO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,5-trimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5-trimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5-trimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,5-trimethyl-5-ethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62198-59-8',
    'LTSLSBVPXXAMBM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,5-trimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5-trimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5-trimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,6-trimethyl-3-ethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62198-60-1',
    'KOVQAKVRXODFNL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,6-trimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,6-trimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,6-trimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,6-trimethyl-4-ethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62198-61-2',
    'RBVKVRIWSQSXPO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,6-trimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,6-trimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,6-trimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,6-trimethyl-5-ethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62198-62-3',
    'JXCQTSFHNKTOLJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,6-trimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,6-trimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,6-trimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,4-trimethyl-3-ethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62198-63-4',
    'BNFUBMCCIACHFX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4,4-trimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4-trimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4-trimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,4-trimethyl-5-ethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62198-64-5',
    'YSCJXRHNKUXHLH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4,4-trimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4-trimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4-trimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,5-trimethyl-3-ethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62198-65-6',
    'JFKSTTDMBQAPCT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4,5-trimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5-trimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5-trimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,5-trimethyl-4-ethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62198-66-7',
    'HSVLOEWHJNAWLC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4,5-trimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5-trimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5-trimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,5-trimethyl-5-ethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62198-67-8',
    'JAUBFUIZENVVAG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4,5-trimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5-trimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5-trimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,6-trimethyl-3-ethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62198-68-9',
    'KQBJYFJWQOUHCI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4,6-trimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,6-trimethyl-4-ethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62198-69-0',
    'LPNPQCHEMXFBSW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4,6-trimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5,5-trimethyl-3-ethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62198-70-3',
    'MARFNXCIPCRAJU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,5,5-trimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5,5-trimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5,5-trimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5,5-trimethyl-4-ethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62198-71-4',
    'HGYOEMXZYDBOKQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,5,5-trimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5,5-trimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5,5-trimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3,4-trimethyl-4-ethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62198-72-5',
    'QLOXTBGCIUOWIG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3,4-trimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4-trimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4-trimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3,4-trimethyl-5-ethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62198-73-6',
    'CUWOOQVXUDOHOC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3,4-trimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4-trimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4-trimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3,5-trimethyl-4-ethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62198-74-7',
    'QXCHZKHHIUTBOU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3,5-trimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,5-trimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,5-trimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3,5-trimethyl-5-ethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62198-75-8',
    'GCWLDOMARVHVOZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3,5-trimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,5-trimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,5-trimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4,4-trimethyl-3-ethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62198-76-9',
    'SIIFYRMARKBLER-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4,4-trimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,4-trimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,4-trimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4,4-trimethyl-5-ethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62198-77-0',
    'XSLWCLUAFIVTLD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4,4-trimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,4-trimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,4-trimethyl-5-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4,5-trimethyl-3-ethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62198-78-1',
    'ZHILUIHUWKDTTM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4,5-trimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,5-trimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,5-trimethyl-3-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4,5-trimethyl-4-ethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62198-79-2',
    'SZOKDASFURUJDF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4,5-trimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,5-trimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,5-trimethyl-4-ethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dimethyl-4-propylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '',
    'DWEXNJRCPKKJBQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2-dimethyl-4-propylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-4-propylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-4-propylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethyl-4-propylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62185-30-2',
    'AZUDVOIXPNEOLR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3-dimethyl-4-propylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-4-propylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-4-propylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dimethyl-4-propylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62185-31-3',
    'FDVJFPZZPSPQAO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4-dimethyl-4-propylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-4-propylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-4-propylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5-dimethyl-4-propylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62185-32-4',
    'PJXVVWKRCASATD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,5-dimethyl-4-propylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyl-4-propylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyl-4-propylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6-dimethyl-4-propylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62185-33-5',
    'UFJZYHSURMZROL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,6-dimethyl-4-propylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethyl-4-propylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethyl-4-propylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3-dimethyl-4-propylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62185-34-6',
    'XVWBLUKOUJTCDO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3-dimethyl-4-propylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-4-propylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-4-propylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4-dimethyl-4-propylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62185-35-7',
    'UGSAJWKYCFFZRD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4-dimethyl-4-propylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyl-4-propylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyl-4-propylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,5-dimethyl-4-propylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62185-36-8',
    'GKVRDSIZILZQJE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,5-dimethyl-4-propylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethyl-4-propylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethyl-4-propylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dimethyl-3-isopropylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62185-37-9',
    'XPOSVKCTMHOWTN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2-dimethyl-3-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-3-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-3-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dimethyl-4-isopropylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62185-38-0',
    'HFRVMJCEWUXCMP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2-dimethyl-4-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-4-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-4-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethyl-3-isopropylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62185-39-1',
    'IAWDNHPMOJTEEN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3-dimethyl-3-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-3-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-3-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethyl-4-isopropylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62185-40-4',
    'GEQDAUMUCVOARW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3-dimethyl-4-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-4-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-4-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dimethyl-3-isopropylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62185-41-5',
    'MWVRZCOXSIAHLW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dimethyl-4-isopropylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62185-42-6',
    'MTPOSRQPOBWFQC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4-dimethyl-4-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-4-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-4-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5-dimethyl-3-isopropylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62185-43-7',
    'XSKMFUBSJXETFW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,5-dimethyl-3-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyl-3-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyl-3-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5-dimethyl-4-isopropylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62185-44-8',
    'OOYWQZAQFKOCKA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,5-dimethyl-4-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyl-4-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyl-4-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6-dimethyl-3-isopropylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62185-45-9',
    'NOAGKIODSFDOTA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,6-dimethyl-3-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethyl-3-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethyl-3-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6-dimethyl-4-isopropylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '35866-89-8',
    'BIBHNAJLMRUJLS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,6-dimethyl-4-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethyl-4-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethyl-4-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3-dimethyl-4-isopropylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62185-46-0',
    'MACIOLXBYDNTTI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3-dimethyl-4-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-4-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-4-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4-dimethyl-4-isopropylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62185-47-1',
    'QFKXRROMVRXZIF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4-dimethyl-4-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyl-4-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyl-4-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,5-dimethyl-4-isopropylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62198-89-4',
    'XJRRTENBDSNHQB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,5-dimethyl-4-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethyl-4-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethyl-4-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-3,3-diethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62198-90-7',
    'VBKOVPDJLQIMSZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-3,3-diethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3,3-diethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3,3-diethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-3,4-diethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62198-91-8',
    'PRSHREOBBOOUSO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-3,4-diethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3,4-diethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3,4-diethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-3,5-diethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62198-92-9',
    'KZTGLPPJUZINLQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-3,5-diethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3,5-diethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3,5-diethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-4,4-diethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62198-93-0',
    'VJTVFYMTOXDIID-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-4,4-diethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-4,4-diethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-4,4-diethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-4,5-diethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62198-94-1',
    'SRLQJPCYGKMUSM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-4,5-diethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-4,5-diethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-4,5-diethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-5,5-diethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62198-95-2',
    'XPAWKGLXSPHNAN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-5,5-diethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-5,5-diethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-5,5-diethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-3,4-diethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62198-96-3',
    'VRVVWJIPKQWWJB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-3,4-diethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-3,4-diethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-3,4-diethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-3,5-diethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62198-97-4',
    'RGRSPNWZJFXFAN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-3,5-diethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-3,5-diethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-3,5-diethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-4,4-diethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62198-98-5',
    'WSBKWCXGZHVUHW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-4,4-diethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-4,4-diethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-4,4-diethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-4,5-diethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62198-99-6',
    'NVBVLQDXCRDBBU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-4,5-diethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-4,5-diethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-4,5-diethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-5,5-diethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-00-2',
    'JOJSCBROPYJHJX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-5,5-diethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-5,5-diethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-5,5-diethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-3,3-diethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-01-3',
    'KGSWPEXUAXYDMO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-3,3-diethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-3,3-diethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-3,3-diethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-3,4-diethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-02-4',
    'RAFABRWSQNCWEY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-3,4-diethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-3,4-diethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-3,4-diethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-3,5-diethylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-03-5',
    'XUVBJZPYCGZQDK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-3,5-diethylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-3,5-diethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-3,5-diethylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-4-<i>tert</i>-butylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62185-23-3',
    'HIHQJZLWJQHTEJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-4-<i>tert</i>-butylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-4-<i>tert</i>-butylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-4-<i>tert</i>-butylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-4-<i>tert</i>-butylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62185-24-4',
    'IKKVFRPBQQTTKP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-4-<i>tert</i>-butylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-4-<i>tert</i>-butylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-4-<i>tert</i>-butylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-4-<i>tert</i>-butylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62185-25-5',
    'JABLMQZBFVBNBS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-4-<i>tert</i>-butylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-4-<i>tert</i>-butylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-4-<i>tert</i>-butylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-4-propylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62185-26-6',
    'FPODIYZXVCXXQE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-4-propylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-4-propylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-4-propylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-ethyl-4-propylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '17312-43-5',
    'JTZJHTZCYBYCSZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-ethyl-4-propylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-4-propylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-4-propylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-4-isopropylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62185-27-7',
    'VENQCMDSFBOTMS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-4-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-4-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-4-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-ethyl-4-isopropylheptane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62185-28-8',
    'IKRHMKIYGHBTGZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-ethyl-4-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-4-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-4-isopropylheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,3,4,4-hexamethylhexane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62185-11-9',
    'ACZDZCRQHVWGEF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3,3,4,4-hexamethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3,4,4-hexamethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3,4,4-hexamethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,3,4,5-hexamethylhexane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62185-12-0',
    'IFHVEHXJQMYGHH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3,3,4,5-hexamethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3,4,5-hexamethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3,4,5-hexamethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,3,5,5-hexamethylhexane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '60302-24-1',
    'YFGLJPQISFJQSO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3,3,5,5-hexamethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3,5,5-hexamethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3,5,5-hexamethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,4,4,5-hexamethylhexane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62185-13-1',
    'QJVUKMHIEDVCDT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3,4,4,5-hexamethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,4,4,5-hexamethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,4,4,5-hexamethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,4,5,5-hexamethylhexane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62185-14-2',
    'NXZMBOYMQLHOPD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3,4,5,5-hexamethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,4,5,5-hexamethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,4,5,5-hexamethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3,4,4,5-hexamethylhexane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '52670-36-7',
    'GRVNDHRZJGSRDC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,3,4,4,5-hexamethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3,4,4,5-hexamethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3,4,4,5-hexamethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,3-tetramethyl-4-ethylhexane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-98-9',
    'CRTTYRRLFPCOTC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3,3-tetramethyl-4-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3-tetramethyl-4-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3-tetramethyl-4-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,4-tetramethyl-3-ethylhexane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-99-0',
    'SYWRGACXWPDDMM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3,4-tetramethyl-3-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,4-tetramethyl-3-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,4-tetramethyl-3-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,4-tetramethyl-4-ethylhexane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62185-00-6',
    'WVLMCSYUMSZJQJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3,4-tetramethyl-4-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,4-tetramethyl-4-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,4-tetramethyl-4-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,5-tetramethyl-3-ethylhexane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62185-01-7',
    'CHURHVBNTYCJDL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3,5-tetramethyl-3-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,5-tetramethyl-3-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,5-tetramethyl-3-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,5-tetramethyl-4-ethylhexane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62185-02-8',
    'GYAMSLKQDQYJGT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3,5-tetramethyl-4-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,5-tetramethyl-4-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,5-tetramethyl-4-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,4,4-tetramethyl-3-ethylhexane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62185-03-9',
    'HWHADLCAKCOTRI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,4,4-tetramethyl-3-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,4-tetramethyl-3-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,4-tetramethyl-3-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,4,5-tetramethyl-3-ethylhexane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62185-04-0',
    'KZHIDSBQFJFWDV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,4,5-tetramethyl-3-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,5-tetramethyl-3-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,5-tetramethyl-3-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,4,5-tetramethyl-4-ethylhexane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62185-05-1',
    'HAVVVIZEMKFOFL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,4,5-tetramethyl-4-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,5-tetramethyl-4-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,5-tetramethyl-4-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,5,5-tetramethyl-3-ethylhexane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62185-06-2',
    'GJJUHGLRQQDIFN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,5,5-tetramethyl-3-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,5,5-tetramethyl-3-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,5,5-tetramethyl-3-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3,4-tetramethyl-4-ethylhexane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62185-07-3',
    'YVKQGHGRZXUTNK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,3,4-tetramethyl-4-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3,4-tetramethyl-4-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3,4-tetramethyl-4-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3,5-tetramethyl-4-ethylhexane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62185-08-4',
    'AMMSTTMNZHWREI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,3,5-tetramethyl-4-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3,5-tetramethyl-4-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3,5-tetramethyl-4-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,4-tetramethyl-3-ethylhexane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62185-09-5',
    'VYCKEOSFJUAFGK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,4,4-tetramethyl-3-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,4-tetramethyl-3-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,4-tetramethyl-3-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,5-tetramethyl-3-ethylhexane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62185-10-8',
    'IBPLCPRMAQRHHK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,4,5-tetramethyl-3-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,5-tetramethyl-3-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,5-tetramethyl-3-ethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3-trimethyl-3-isopropylhexane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-79-5',
    'UTCSLOLKGOKPGW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3-trimethyl-3-isopropylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3-trimethyl-3-isopropylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3-trimethyl-3-isopropylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,4-trimethyl-3-isopropylhexane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-80-8',
    'VEMACPZMOMAUAN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,4-trimethyl-3-isopropylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethyl-3-isopropylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethyl-3-isopropylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,5-trimethyl-3-isopropylhexane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-81-9',
    'GZFAXOCUKPGWEA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,5-trimethyl-3-isopropylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,5-trimethyl-3-isopropylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,5-trimethyl-3-isopropylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,5-trimethyl-4-isopropylhexane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-82-0',
    'QFLYTOVYLBZBJC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,5-trimethyl-4-isopropylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,5-trimethyl-4-isopropylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,5-trimethyl-4-isopropylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4-trimethyl-3-isopropylhexane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-83-1',
    'SXELEUFFBZGXIC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,4-trimethyl-3-isopropylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethyl-3-isopropylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethyl-3-isopropylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,5-trimethyl-3-isopropylhexane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-84-2',
    'GUMUKRVQSSIBJO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,5-trimethyl-3-isopropylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5-trimethyl-3-isopropylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5-trimethyl-3-isopropylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,5-trimethyl-4-isopropylhexane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-85-3',
    'VBRDSJSWPGXVIR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,5-trimethyl-4-isopropylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5-trimethyl-4-isopropylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5-trimethyl-4-isopropylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,4-trimethyl-3-isopropylhexane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-86-4',
    'UGPHXQWIHGYHOH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4,4-trimethyl-3-isopropylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4-trimethyl-3-isopropylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4-trimethyl-3-isopropylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dimethyl-3,4-diethylhexane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-89-7',
    'ZAKPEOVUOZWBNO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2-dimethyl-3,4-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-3,4-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-3,4-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dimethyl-4,4-diethylhexane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-89-8',
    'CYPRMBGQWCLJBN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2-dimethyl-4,4-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-4,4-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-4,4-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethyl-3,4-diethylhexane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-90-1',
    'BUUBMKJJLVCTKU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3-dimethyl-3,4-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-3,4-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-3,4-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethyl-4,4-diethylhexane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-91-2',
    'YNHBDJNMYMZVLM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3-dimethyl-4,4-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-4,4-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-4,4-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dimethyl-3,3-diethylhexane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-92-3',
    'OXAROVXPKXMTIV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3,3-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3,3-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3,3-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dimethyl-3,4-diethylhexane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-93-4',
    'AUVJTUXGNKLTIN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3,4-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3,4-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3,4-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5-dimethyl-3,3-diethylhexane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-94-5',
    'XHDPVTDRZGCNFV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,5-dimethyl-3,3-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyl-3,3-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyl-3,3-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5-dimethyl-3,4-diethylhexane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-95-6',
    'WCPAKUFSQFCWTQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,5-dimethyl-3,4-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyl-3,4-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyl-3,4-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3-dimethyl-4,4-diethylhexane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-96-7',
    'XFUAJHJJXMVZCQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3-dimethyl-4,4-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-4,4-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-4,4-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4-dimethyl-3,4-diethylhexane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62184-97-8',
    'NTQKWVJMJSYRDX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4-dimethyl-3,4-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyl-3,4-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyl-3,4-diethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dimethyl-3-<i>tert</i>-butylhexane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-76-2',
    'VZAYJUSYQVNGBC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2-dimethyl-3-<i>tert</i>-butylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-3-<i>tert</i>-butylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-3-<i>tert</i>-butylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-3-ethyl-3-isopropylhexane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-77-3',
    'TXYYDQJNRQJTOW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-3-ethyl-3-isopropylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-ethyl-3-isopropylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-ethyl-3-isopropylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-4-ethyl-3-isopropylhexane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-78-4',
    'JXHSGKIMXDNKIS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-4-ethyl-3-isopropylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-4-ethyl-3-isopropylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-4-ethyl-3-isopropylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3,4-triethylhexane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62199-87-5',
    'YGNQREHYYJPYLX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3,4-triethylhexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4-triethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4-triethylhexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,4,4-pentamethyl-3-ethylpentane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '66576-21-4',
    'IZNAUALMSCRPBS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3,4,4-pentamethyl-3-ethylpentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,4,4-pentamethyl-3-ethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,4,4-pentamethyl-3-ethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,4-tetramethyl-3-isopropylpentane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62185-17-5',
    'OKGFCJOAXUYCBG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3,4-tetramethyl-3-isopropylpentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,4-tetramethyl-3-isopropylpentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,4-tetramethyl-3-isopropylpentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,4,4-tetramethyl-3-isopropylpentane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62185-18-6',
    'BYIFHEDQKBAFSW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,4,4-tetramethyl-3-isopropylpentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,4-tetramethyl-3-isopropylpentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,4-tetramethyl-3-isopropylpentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,4-trimethyl-3,3-diethylpentane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62185-15-3',
    'GIKXQMPMOJVRDN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,4-trimethyl-3,3-diethylpentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethyl-3,3-diethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethyl-3,3-diethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dimethyl-3-ethyl-3-isopropylpentane',
    'C<sub>12</sub>H<sub>26</sub>',
    '',
    '62185-16-4',
    'ASDDXPPGGPFNIL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-ethyl-3-isopropylpentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-ethyl-3-isopropylpentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-ethyl-3-isopropylpentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tridecane',
    'C<sub>13</sub>H<sub>28</sub>',
    '',
    '629-50-5',
    'IIYFAKIEWZDVMP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tridecane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='tridecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tridecane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tridecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tridecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tridecane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tridecane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tridecane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyldodecane',
    'C<sub>13</sub>H<sub>28</sub>',
    '',
    '1560-97-0',
    'HGEMCUOAMCILCP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyldodecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyldodecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyldodecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyldodecane',
    'C<sub>13</sub>H<sub>28</sub>',
    '',
    '17312-57-1',
    'GRJUENNHVNYCHD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyldodecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyldodecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyldodecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dimethylundecane',
    'C<sub>13</sub>H<sub>28</sub>',
    '',
    '17312-64-0',
    'QDKSGHXRHXVMPF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2-dimethylundecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylundecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylundecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethylundecane',
    'C<sub>13</sub>H<sub>28</sub>',
    '',
    '17312-77-5',
    'QSSUTSOGIQHRIU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3-dimethylundecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylundecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylundecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dimethylundecane',
    'C<sub>13</sub>H<sub>28</sub>',
    '',
    '17312-80-0',
    'WMZNFELFMFOGCC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4-dimethylundecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethylundecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethylundecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tetradecane',
    'C<sub>14</sub>H<sub>30</sub>',
    '',
    '629-59-4',
    'BGHCVCJVXZWKCC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;7</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='tetradecane'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tetradecane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tetradecane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tetradecane'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tetradecane'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='tetradecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetradecane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetradecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetradecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetradecane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetradecane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetradecane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tetradecane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tetradecane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyltridecane',
    'C<sub>14</sub>H<sub>30</sub>',
    '',
    '1560-96-9',
    'CJBFZKZYIPBBTO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyltridecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyltridecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyltridecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyltridecane',
    'C<sub>14</sub>H<sub>30</sub>',
    '',
    '6418-41-3',
    'NLHRRMKILFRDGV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyltridecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyltridecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyltridecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dimethyldodecane',
    'C<sub>14</sub>H<sub>30</sub>',
    '',
    '49598-54-1',
    'ATWISEHEXAEGKB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2-dimethyldodecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyldodecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyldodecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethyldodecane',
    'C<sub>14</sub>H<sub>30</sub>',
    '',
    '6117-98-2',
    'QBIXLGJCVGNDBJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3-dimethyldodecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyldodecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyldodecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dimethyldodecane',
    'C<sub>14</sub>H<sub>30</sub>',
    '',
    '6117-99-3',
    'AFELDWXNIFIYOC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4-dimethyldodecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyldodecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyldodecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pentadecane',
    'C<sub>15</sub>H<sub>32</sub>',
    '',
    '629-62-9',
    'YCOZIPAWZNQLMR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;7</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pentadecane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;7</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pentadecane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='pentadecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentadecane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentadecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentadecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentadecane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pentadecane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pentadecane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyltetradecane',
    'C<sub>15</sub>H<sub>32</sub>',
    '',
    '1560-95-8',
    'KUVMKLCGXIYSNH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyltetradecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyltetradecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyltetradecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyltetradecane',
    'C<sub>15</sub>H<sub>32</sub>',
    '',
    '18435-22-8',
    'HXUYUZCPGPKNGS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyltetradecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyltetradecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyltetradecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dimethyltridecane',
    'C<sub>15</sub>H<sub>32</sub>',
    '',
    '61869-04-3',
    'NVEUWWMNWPNXOC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2-dimethyltridecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyltridecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyltridecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethyltridecane',
    'C<sub>15</sub>H<sub>32</sub>',
    '',
    '18435-20-6',
    'SWUJSLXRUPXTQB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3-dimethyltridecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyltridecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyltridecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dimethyltridecane',
    'C<sub>15</sub>H<sub>32</sub>',
    '',
    '61868-05-1',
    'JDFJCABQSZLDMZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4-dimethyltridecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyltridecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyltridecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hexadecane',
    'C<sub>16</sub>H<sub>34</sub>',
    '',
    '544-76-3',
    'DCAYPVUWAIABOU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexadecane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexadecane'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexadecane'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='hexadecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexadecane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexadecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexadecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexadecane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='hexadecane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='hexadecane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methylpentadecane',
    'C<sub>16</sub>H<sub>34</sub>',
    '',
    '1560-93-6',
    'BANXPJUEBPWEOT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methylpentadecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpentadecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpentadecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methylpentadecane',
    'C<sub>16</sub>H<sub>34</sub>',
    '',
    '2882-96-4',
    'FWXKCXJPHSAYMK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methylpentadecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylpentadecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylpentadecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dimethyltetradecane',
    'C<sub>16</sub>H<sub>34</sub>',
    '',
    '59222-86-5',
    'VCAMXEBNASZVEZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2-dimethyltetradecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyltetradecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyltetradecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethyltetradecane',
    'C<sub>16</sub>H<sub>34</sub>',
    '',
    '18435-23-9',
    'ZQRVEWIJXCRTFW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3-dimethyltetradecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyltetradecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyltetradecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dimethyltetradecane',
    'C<sub>16</sub>H<sub>34</sub>',
    '',
    '61868-06-2',
    'NWTLFDYNCLTSAR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4-dimethyltetradecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyltetradecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyltetradecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'heptadecane',
    'C<sub>17</sub>H<sub>36</sub>',
    '',
    '629-78-7',
    'NDJKXXJCMXVBJW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptadecane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='heptadecane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='heptadecane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'octadecane',
    'C<sub>18</sub>H<sub>38</sub>',
    '',
    '593-45-3',
    'RZJRJXONCZWCBN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='octadecane'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='octadecane'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octadecane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octadecane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='octadecane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='octadecane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nonadecane',
    'C<sub>19</sub>H<sub>40</sub>',
    '',
    '629-92-5',
    'LQERIDTXQFOHKA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonadecane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='nonadecane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='nonadecane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'eicosane',
    'C<sub>20</sub>H<sub>42</sub>',
    '',
    '112-95-8',
    'CBFCDTFDPHXCNY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='eicosane'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='eicosane'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='eicosane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='eicosane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='eicosane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'heneicosane',
    'C<sub>21</sub>H<sub>44</sub>',
    '',
    '629-94-7',
    'FNAZRRHPUDJQCJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heneicosane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'docosane',
    'C<sub>22</sub>H<sub>46</sub>',
    '',
    '629-97-0',
    'HOWGUJZVBDQJKV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='docosane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tricosane',
    'C<sub>23</sub>H<sub>48</sub>',
    '',
    '638-67-5',
    'FIGVVZUWCLSUEI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tricosane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tetracosane',
    'C<sub>24</sub>H<sub>50</sub>',
    '',
    '646-31-1',
    'POOSGDOYLQNASK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetracosane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pentacosane',
    'C<sub>25</sub>H<sub>52</sub>',
    '',
    '629-99-2',
    'YKNWIILGEFFOPE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentacosane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hexacosane',
    'C<sub>26</sub>H<sub>54</sub>',
    '',
    '630-01-3',
    'HMSWAIKSFDFLKN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexacosane'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexacosane'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexacosane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'heptacosane',
    'C<sub>27</sub>H<sub>56</sub>',
    '',
    '593-49-7',
    'BJQWYEJQWHSSCJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptacosane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'octacosane',
    'C<sub>28</sub>H<sub>58</sub>',
    '',
    '630-02-4',
    'ZYURHZPYMFLWSH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octacosane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nonacosane',
    'C<sub>29</sub>H<sub>60</sub>',
    '',
    '630-03-5',
    'IGGUPRCHHJZPBS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonacosane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'triacontane',
    'C<sub>30</sub>H<sub>62</sub>',
    '',
    '638-68-6',
    'JXTPJDDICSTXJX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triacontane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dotriacontane',
    'C<sub>32</sub>H<sub>66</sub>',
    '',
    '544-85-4',
    'QHMGJGNTMQDRQA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dotriacontane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pentatriacontane',
    'C<sub>35</sub>H<sub>72</sub>',
    '',
    '630-07-9',
    'VHQQPFLOGSTQPC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentatriacontane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hexatriacontane',
    'C<sub>36</sub>H<sub>74</sub>',
    '',
    '630-06-8',
    'YDLYQMBWCWFRAI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>8</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexatriacontane'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'octatriacontane',
    'C<sub>38</sub>H<sub>78</sub>',
    '',
    '7194-85-6',
    'BVKCQBBZBGYNOP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octatriacontane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Cycloalkanes',
    (SELECT id from categories WHERE catname='Hydrocarbons (C, H)'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cyclopropane',
    'C<sub>3</sub>H<sub>6</sub>',
    '',
    '75-19-4',
    'LVZWSLJZHVFIQJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '2800',
    'L',
    (SELECT id from species WHERE iupac='cyclopropane'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '1600',
    'L',
    (SELECT id from species WHERE iupac='cyclopropane'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='cyclopropane'),
    (SELECT id from literature WHERE bibtexkey='2441'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '2300',
    'L',
    (SELECT id from species WHERE iupac='cyclopropane'),
    (SELECT id from literature WHERE bibtexkey='3696'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;5</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='cyclopropane'),
    (SELECT id from literature WHERE bibtexkey='2924'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '2000',
    'M',
    (SELECT id from species WHERE iupac='cyclopropane'),
    (SELECT id from literature WHERE bibtexkey='3710'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cyclopropane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cyclopropane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cyclopropane'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='cyclopropane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'at294K',
    '', 'Value at T = 294&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at294K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopropane'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopropane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopropane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopropane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopropane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopropane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopropane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopropane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopropane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2500',
    'Q',
    (SELECT id from species WHERE iupac='cyclopropane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopropane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopropane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopropane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopropane'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2200',
    '?',
    (SELECT id from species WHERE iupac='cyclopropane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cyclopropane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at294K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '1600',
    '?',
    (SELECT id from species WHERE iupac='cyclopropane'),
    (SELECT id from literature WHERE bibtexkey='3811'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cyclopropane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at294K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cyclopropane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cyclobutane',
    'C<sub>4</sub>H<sub>8</sub>',
    '',
    '287-23-0',
    'PMPVIKIVABFJJI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclobutane'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclobutane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cyclopentane',
    'C<sub>5</sub>H<sub>10</sub>',
    '',
    '287-92-3',
    'RGSFGYAAUTVSQA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;5</sup>',
    '3500',
    'L',
    (SELECT id from species WHERE iupac='cyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;5</sup>',
    '3200',
    'L',
    (SELECT id from species WHERE iupac='cyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='cyclopentane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;5</sup>',
    '3400',
    'M',
    (SELECT id from species WHERE iupac='cyclopentane'),
    (SELECT id from literature WHERE bibtexkey='903'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='903'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cyclopentane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cyclopentane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3923'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='cyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='cyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3200',
    'Q',
    (SELECT id from species WHERE iupac='cyclopentane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopentane'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4300',
    '?',
    (SELECT id from species WHERE iupac='cyclopentane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cyclopentane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cyclopentane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2226'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cyclohexane',
    'C<sub>6</sub>H<sub>12</sub>',
    '',
    '110-82-7',
    'XDTMQSROBMDMFD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;5</sup>',
    '3900',
    'L',
    (SELECT id from species WHERE iupac='cyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3518-110-82-7-consicheck',
    '3518', 'Values at 298&nbsp;K in Tables&nbsp;C2 and C5 of Brockbank (2013) are inconsistent, with 13&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3518-110-82-7-consicheck'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;5</sup>',
    '4000',
    'L',
    (SELECT id from species WHERE iupac='cyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='cyclohexane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;4</sup>',
    '5400',
    'M',
    (SELECT id from species WHERE iupac='cyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;5</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='cyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2955'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;5</sup>',
    '4500',
    'M',
    (SELECT id from species WHERE iupac='cyclohexane'),
    (SELECT id from literature WHERE bibtexkey='1107'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '1107-110-82-7-consicheck',
    '1107', 'The data listed in Tables&nbsp;2 and 3 of Dewulf et&nbsp;al. (1999) are inconsistent, with 5&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1107-110-82-7-consicheck'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;5</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='cyclohexane'),
    (SELECT id from literature WHERE bibtexkey='903'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'at301K',
    '', 'Value at T = 301&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at301K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;5</sup>',
    '3800',
    'M',
    (SELECT id from species WHERE iupac='cyclohexane'),
    (SELECT id from literature WHERE bibtexkey='857'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='857'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;5</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='cyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2924'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;5</sup>',
    '3200',
    'M',
    (SELECT id from species WHERE iupac='cyclohexane'),
    (SELECT id from literature WHERE bibtexkey='1156'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1156'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;5</sup>',
    '3400',
    'M',
    (SELECT id from species WHERE iupac='cyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2911'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;5</sup>',
    '3800',
    'M',
    (SELECT id from species WHERE iupac='cyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2980'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cyclohexane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cyclohexane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3923'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;5</sup>',
    '4000',
    'T',
    (SELECT id from species WHERE iupac='cyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3674'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4000',
    'T',
    (SELECT id from species WHERE iupac='cyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2224'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='cyclohexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='cyclohexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;5</sup>',
    '710',
    'X',
    (SELECT id from species WHERE iupac='cyclohexane'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'from747',
    '747', 'Value given here as quoted by Staudinger and Roberts (1996).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3586_test',
    '', 'Value from the test set for true external validation.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3600',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-Test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexane'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3900',
    '?',
    (SELECT id from species WHERE iupac='cyclohexane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cyclohexane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cyclohexane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2226'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methylcyclopentane',
    'C<sub>5</sub>H<sub>9</sub>CH<sub>3</sub>',
    '',
    '96-37-7',
    'GDOPTJXRTPNYNR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='methylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;5</sup>',
    '5500',
    'L',
    (SELECT id from species WHERE iupac='methylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='methylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3923'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cycloheptane',
    'C<sub>7</sub>H<sub>14</sub>',
    '',
    '291-64-5',
    'DMEGYFMYUHOHGS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='cycloheptane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;4</sup>',
    '3100',
    'L',
    (SELECT id from species WHERE iupac='cycloheptane'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cycloheptane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cycloheptane'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cycloheptane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cycloheptane'),
    (SELECT id from literature WHERE bibtexkey='1910'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='cycloheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='cycloheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cycloheptane'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cycloheptane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cycloheptane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cycloheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cycloheptane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cycloheptane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cycloheptane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cycloheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cycloheptane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cycloheptane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cycloheptane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cycloheptane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cycloheptane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cycloheptane'),
    (SELECT id from literature WHERE bibtexkey='637'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cycloheptane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methylcyclohexane',
    'C<sub>6</sub>H<sub>11</sub>CH<sub>3</sub>',
    '',
    '108-87-2',
    'UAEPNZWRGJTJPN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;5</sup>',
    '4500',
    'L',
    (SELECT id from species WHERE iupac='methylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='methylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='methylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;4</sup>',
    '5300',
    'M',
    (SELECT id from species WHERE iupac='methylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2930'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;5</sup>',
    '9400',
    'M',
    (SELECT id from species WHERE iupac='methylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='903'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='903'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2580'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3923'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3900',
    'Q',
    (SELECT id from species WHERE iupac='methylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3100',
    '?',
    (SELECT id from species WHERE iupac='methylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methylcyclohexane-d14',
    'C<sub>6</sub>D<sub>11</sub>CD<sub>3</sub>',
    '',
    '10120-28-2',
    'UAEPNZWRGJTJPN-OBYKGMMLSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;4</sup>',
    '5600',
    'M',
    (SELECT id from species WHERE iupac='methylcyclohexane-d14'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethylcyclopentane',
    'C<sub>7</sub>H<sub>14</sub>',
    '',
    '1640-89-7',
    'IFTRQJLVEBNKJK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1-dimethylcyclopentane',
    'C<sub>7</sub>H<sub>14</sub>',
    '',
    '1638-26-2',
    'QWHNJUXXYKPLQM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,1-dimethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dimethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dimethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dimethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1-dimethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>cis</i>-1,2-dimethylcyclopentane',
    'C<sub>7</sub>H<sub>14</sub>',
    '',
    '1192-18-3',
    'RIRARCHMRDHZAR-KNVOCYPGSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,2-dimethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,2-dimethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,2-dimethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,2-dimethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>cis</i>-1,3-dimethylcyclopentane',
    'C<sub>7</sub>H<sub>14</sub>',
    '',
    '2532-58-3',
    'XAZKFISIRYLAEE-KNVOCYPGSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,3-dimethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,3-dimethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,3-dimethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,3-dimethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>trans</i>-1,2-dimethylcyclopentane',
    'C<sub>7</sub>H<sub>14</sub>',
    '',
    '822-50-4',
    'RIRARCHMRDHZAR-RNFRBKRXSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,2-dimethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,2-dimethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,2-dimethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,2-dimethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>trans</i>-1,3-dimethylcyclopentane',
    'C<sub>7</sub>H<sub>14</sub>',
    '',
    '1759-58-6',
    'XAZKFISIRYLAEE-RNFRBKRXSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,3-dimethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,3-dimethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,3-dimethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,3-dimethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cyclooctane',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '292-64-8',
    'WJTCGQSWYFHTAC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;5</sup>',
    '4800',
    'L',
    (SELECT id from species WHERE iupac='cyclooctane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;5</sup>',
    '3800',
    'L',
    (SELECT id from species WHERE iupac='cyclooctane'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;5</sup>',
    '4700',
    'M',
    (SELECT id from species WHERE iupac='cyclooctane'),
    (SELECT id from literature WHERE bibtexkey='2936'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2936-292-64-8-ABC',
    '2936', 'The data from Dohányosová et&nbsp;al. (2004) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;365.40645 +19821.40051/T +50.78223&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2936-292-64-8-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cyclooctane'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cyclooctane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cyclooctane'),
    (SELECT id from literature WHERE bibtexkey='1910'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='cyclooctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclooctane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclooctane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclooctane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclooctane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4300',
    'Q',
    (SELECT id from species WHERE iupac='cyclooctane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5000',
    '?',
    (SELECT id from species WHERE iupac='cyclooctane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cyclooctane'),
    (SELECT id from literature WHERE bibtexkey='637'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cyclooctane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methylcycloheptane',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '4126-78-7',
    'GYNNXHKOJHMOHS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylcycloheptane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1-dimethylcyclohexane',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '590-66-9',
    'QEGNUYASOUJEHD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,1-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-dimethylcyclohexane',
    'C<sub>6</sub>H<sub>10</sub>(CH<sub>3</sub>)<sub>2</sub>',
    '',
    '583-57-3',
    'KVZJLSYJROEPSQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>cis</i>-1,2-dimethylcyclohexane',
    'C<sub>6</sub>H<sub>10</sub>(CH<sub>3</sub>)<sub>2</sub>',
    '',
    '2207-01-4',
    'KVZJLSYJROEPSQ-OCAPTIKFSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;5</sup>',
    '4600',
    'L',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,2-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,2-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,2-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;5</sup>',
    '4600',
    'M',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,2-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2936'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2936-2207-01-4-ABC',
    '2936', 'The data from Dohányosová et&nbsp;al. (2004) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;383.72514 +20514.87228/T +53.42859&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2936-2207-01-4-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,2-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,2-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2580'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,2-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,2-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,2-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,2-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,2-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,2-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,2-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,2-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,2-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4300',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,2-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,2-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,2-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,2-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,2-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4900',
    '?',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,2-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,2-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,2-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>trans</i>-1,2-dimethylcyclohexane',
    'C<sub>6</sub>H<sub>10</sub>(CH<sub>3</sub>)<sub>2</sub>',
    '',
    '6876-23-9',
    'KVZJLSYJROEPSQ-HTQZYQBOSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '4000',
    'L',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,2-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '4300',
    'M',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,2-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2936'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2936-6876-23-9-ABC',
    '2936', 'The data from Dohányosová et&nbsp;al. (2004) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;369.42853 +19642.40603/T +51.34116&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2936-6876-23-9-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,2-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,2-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2580'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,2-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,2-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,2-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,2-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,2-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4300',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,2-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4600',
    '?',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,2-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,2-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,2-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,2-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3034'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'CRCwrong2',
    '3034,479', 'Haynes (2014) refers to Mackay and Shiu (1981), but that article lists this value for 1,4-dimethylcyclohexane, not for 1,2-dimethylcyclohexane.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='CRCwrong2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>cis</i>-1,3-dimethylcyclohexane',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '638-04-0',
    'SGVUHPSBDNVHKL-OCAPTIKFSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,3-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,3-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,3-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,3-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>trans</i>-1,3-dimethylcyclohexane',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '2207-03-6',
    'SGVUHPSBDNVHKL-HTQZYQBOSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,3-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,3-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,3-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,3-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4-dimethylcyclohexane',
    'C<sub>6</sub>H<sub>10</sub>(CH<sub>3</sub>)<sub>2</sub>',
    '',
    '589-90-2',
    'QRMPKOFEUHIBNM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>cis</i>-1,4-dimethylcyclohexane',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '624-29-3',
    'QRMPKOFEUHIBNM-OCAPTIKFSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,4-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,4-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,4-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,4-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>trans</i>-1,4-dimethylcyclohexane',
    'C<sub>6</sub>H<sub>10</sub>(CH<sub>3</sub>)<sub>2</sub>',
    '',
    '2207-04-7',
    'QRMPKOFEUHIBNM-ZKCHVHJHSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,4-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,4-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,4-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,4-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,4-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,4-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,4-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,4-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,4-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,4-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,4-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,4-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,4-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,4-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,4-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,4-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,4-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,4-dimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethylcyclohexane',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '1678-91-7',
    'IIEWJVIFRVWJOD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;5</sup>',
    '4100',
    'L',
    (SELECT id from species WHERE iupac='ethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3518-1678-91-7-consicheck',
    '3518', 'Values at 298&nbsp;K in Tables&nbsp;C2 and C5 of Brockbank (2013) are inconsistent, with 6&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3518-1678-91-7-consicheck'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '4400',
    'M',
    (SELECT id from species WHERE iupac='ethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2936'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2936-1678-91-7-ABC',
    '2936', 'The data from Dohányosová et&nbsp;al. (2004) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;346.32561 +18710.63122/T +47.87398&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2936-1678-91-7-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;5</sup>',
    '4600',
    'M',
    (SELECT id from species WHERE iupac='ethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2912'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2580'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4300',
    'Q',
    (SELECT id from species WHERE iupac='ethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4700',
    '?',
    (SELECT id from species WHERE iupac='ethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,2-trimethylcyclopentane',
    'C<sub>5</sub>H<sub>7</sub>(CH<sub>3</sub>)<sub>3</sub>',
    '',
    '4259-00-1',
    'WINCSBAYCULVDU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,1,2-trimethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2-trimethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2-trimethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2-trimethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,3-trimethylcyclopentane',
    'C<sub>5</sub>H<sub>7</sub>(CH<sub>3</sub>)<sub>3</sub>',
    '',
    '4516-69-2',
    'OBKHYUIZSOIEPG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,1,3-trimethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,1,3-trimethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1,3-trimethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1,3-trimethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1,3-trimethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,1,3-trimethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,3-trimethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,3-trimethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,3-trimethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,3-trimethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,3-trimethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,3-trimethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,<i>cis</i>-2,<i>cis</i>-3-trimethylcyclopentane',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '2613-69-6',
    'VCWNHOPGKQCXIQ-RNLVFQAGSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-2,<i>cis</i>-3-trimethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-2,<i>cis</i>-3-trimethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-2,<i>cis</i>-3-trimethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,<i>cis</i>-2,<i>trans</i>-3-trimethylcyclopentane',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '15890-40-1',
    'VCWNHOPGKQCXIQ-JIGDXULJSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-2,<i>trans</i>-3-trimethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-2,<i>trans</i>-3-trimethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-2,<i>trans</i>-3-trimethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,<i>trans</i>-2,<i>cis</i>-3-trimethylcyclopentane',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '19374-46-0',
    'VCWNHOPGKQCXIQ-RNFRBKRXSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,<i>trans</i>-2,<i>cis</i>-3-trimethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>trans</i>-2,<i>cis</i>-3-trimethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>trans</i>-2,<i>cis</i>-3-trimethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,<i>cis</i>-2,<i>cis</i>-4-trimethylcyclopentane',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '2613-72-1',
    'PNUFYSGVPVMNRN-RNLVFQAGSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-2,<i>cis</i>-4-trimethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-2,<i>cis</i>-4-trimethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-2,<i>cis</i>-4-trimethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,<i>cis</i>-2,<i>trans</i>-4-trimethylcyclopentane',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '4850-28-6',
    'PNUFYSGVPVMNRN-WHUPJOBBSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-2,<i>trans</i>-4-trimethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-2,<i>trans</i>-4-trimethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-2,<i>trans</i>-4-trimethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,<i>trans</i>-2,<i>cis</i>-4-trimethylcyclopentane',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '16883-48-0',
    'PNUFYSGVPVMNRN-HTQZYQBOSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,<i>trans</i>-2,<i>cis</i>-4-trimethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>trans</i>-2,<i>cis</i>-4-trimethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>trans</i>-2,<i>cis</i>-4-trimethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-1-ethylcyclopentane',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '16747-50-5',
    'LETYIFNDQBJGPJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-methyl-1-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-1-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-1-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-1-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-methyl-1-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-<i>cis</i>-2-ethylcyclopentane',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '930-89-2',
    'BSKOLJVTLRLTHE-SFYZADRCSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-methyl-<i>cis</i>-2-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-<i>cis</i>-2-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-<i>cis</i>-2-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-<i>trans</i>-2-ethylcyclopentane',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '930-90-5',
    'BSKOLJVTLRLTHE-HTQZYQBOSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-methyl-<i>trans</i>-2-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-<i>trans</i>-2-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-<i>trans</i>-2-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-<i>cis</i>-3-ethylcyclopentane',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '2613-66-3',
    'PQXAPVOKLYINEI-SFYZADRCSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-methyl-<i>cis</i>-3-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-<i>cis</i>-3-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-<i>cis</i>-3-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-<i>trans</i>-3-ethylcyclopentane',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '2613-65-2',
    'PQXAPVOKLYINEI-HTQZYQBOSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-methyl-<i>trans</i>-3-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-<i>trans</i>-3-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-<i>trans</i>-3-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propylcyclopentane',
    'C<sub>5</sub>H<sub>9</sub>C<sub>3</sub>H<sub>7</sub>',
    '',
    '2040-96-2',
    'KDIAMAVWIJYWHN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='propylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='propylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='propylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'isopropylcyclopentane',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '3875-51-2',
    'TVSBRLGQVHJIKT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='isopropylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isopropylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isopropylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5,5-dimethylbicyclo[2.1.1]hexane',
    'C<sub>8</sub>H<sub>14</sub>',
    'MCM:C8BC',
    '',
    'WZXMVFMYGAOEAT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5,5-dimethylbicyclo[2.1.1]hexane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5,5-dimethylbicyclo[2.1.1]hexane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5,5-dimethylbicyclo[2.1.1]hexane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,2-trimethylcyclohexane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '7094-26-0',
    'MEBONNVPKOBPEA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,1,2-trimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2-trimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2-trimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,3-trimethylcyclohexane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '3073-66-3',
    'PYOLJOJPIPCRDP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,1,3-trimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1,3-trimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1,3-trimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,1,3-trimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,3-trimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,3-trimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,4-trimethylcyclohexane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '7094-27-1',
    'UIWORXHEVNIOJG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,1,4-trimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,4-trimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,4-trimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,<i>cis</i>-2,<i>cis</i>-3-trimethylcyclohexane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '1839-88-9',
    'DQTVJLHNWPRPPH-AYMMMOKOSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-2,<i>cis</i>-3-trimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-2,<i>cis</i>-3-trimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-2,<i>cis</i>-3-trimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,<i>cis</i>-2,<i>trans</i>-3-trimethylcyclohexane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '7667-55-2',
    'DQTVJLHNWPRPPH-BRPSZJMVSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-2,<i>trans</i>-3-trimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-2,<i>trans</i>-3-trimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-2,<i>trans</i>-3-trimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,<i>cis</i>-2,<i>cis</i>-4-trimethylcyclohexane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '1678-80-4',
    'VCJPCEVERINRSG-YIZRAAEISA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-2,<i>cis</i>-4-trimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-2,<i>cis</i>-4-trimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-2,<i>cis</i>-4-trimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,<i>cis</i>-2,<i>trans</i>-4-trimethylcyclohexane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '7667-58-5',
    'VCJPCEVERINRSG-HLTSFMKQSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-2,<i>trans</i>-4-trimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-2,<i>trans</i>-4-trimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-2,<i>trans</i>-4-trimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>cis</i>,<i>cis</i>-1,3,5-trimethylcyclohexane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '1795-27-3',
    'ODNRTOSCFYDTKF-AYMMMOKOSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>cis</i>,<i>cis</i>-1,3,5-trimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>,<i>cis</i>-1,3,5-trimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>,<i>cis</i>-1,3,5-trimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>cis</i>,<i>trans</i>-1,3,5-trimethylcyclohexane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '1795-26-2',
    'ODNRTOSCFYDTKF-FBJIGQNJSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>cis</i>,<i>trans</i>-1,3,5-trimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>,<i>trans</i>-1,3,5-trimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>,<i>trans</i>-1,3,5-trimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>,<i>trans</i>-1,3,5-trimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,<i>trans</i>-2,<i>cis</i>-3-trimethylcyclohexane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '1678-81-5',
    'DQTVJLHNWPRPPH-HTQZYQBOSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,<i>trans</i>-2,<i>cis</i>-3-trimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>trans</i>-2,<i>cis</i>-3-trimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>trans</i>-2,<i>cis</i>-3-trimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,<i>trans</i>-2,<i>cis</i>-4-trimethylcyclohexane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '7667-59-6',
    'VCJPCEVERINRSG-DJLDLDEBSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,<i>trans</i>-2,<i>cis</i>-4-trimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>trans</i>-2,<i>cis</i>-4-trimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>trans</i>-2,<i>cis</i>-4-trimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,<i>trans</i>-2,<i>trans</i>-4-trimethylcyclohexane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '7667-60-9',
    'VCJPCEVERINRSG-IWSPIJDZSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,<i>trans</i>-2,<i>trans</i>-4-trimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>trans</i>-2,<i>trans</i>-4-trimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>trans</i>-2,<i>trans</i>-4-trimethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-1-ethylcyclohexane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '4926-90-3',
    'YPJRYQGOKHKNKZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-methyl-1-ethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-1-ethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-1-ethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-<i>cis</i>-2-ethylcyclohexane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '4923-77-7',
    'XARGIVYWQPXRTC-BDAKNGLRSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-methyl-<i>cis</i>-2-ethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-<i>cis</i>-2-ethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-<i>cis</i>-2-ethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-<i>cis</i>-3-ethylcyclohexane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '19489-10-2',
    'UDDVMPHNQKRNNS-BDAKNGLRSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-methyl-<i>cis</i>-3-ethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-<i>cis</i>-3-ethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-<i>cis</i>-3-ethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-<i>cis</i>-4-ethylcyclohexane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '4926-78-7',
    'CYISMTMRBPPERU-DTORHVGOSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-methyl-<i>cis</i>-4-ethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-<i>cis</i>-4-ethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-<i>cis</i>-4-ethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-<i>trans</i>-2-ethylcyclohexane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '4923-78-8',
    'XARGIVYWQPXRTC-RKDXNWHRSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-methyl-<i>trans</i>-2-ethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-<i>trans</i>-2-ethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-<i>trans</i>-2-ethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-<i>trans</i>-3-ethylcyclohexane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '4926-76-5',
    'UDDVMPHNQKRNNS-RKDXNWHRSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-methyl-<i>trans</i>-3-ethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-<i>trans</i>-3-ethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-<i>trans</i>-3-ethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-<i>trans</i>-4-ethylcyclohexane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '6236-88-0',
    'CYISMTMRBPPERU-KYZUINATSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-methyl-<i>trans</i>-4-ethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-<i>trans</i>-4-ethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-<i>trans</i>-4-ethylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propylcyclohexane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '1678-92-8',
    'DEDZSLCZHWTGOR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='propylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'isopropylcyclohexane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '696-29-7',
    'GWESVXSMPKAFAS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='isopropylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isopropylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isopropylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isopropylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='isopropylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,2,2-tetramethylcyclopentane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '52688-89-8',
    'YXDMSFJDVHXFCV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,1,2,2-tetramethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetramethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetramethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>cis</i>-1,1,2,3-tetramethylcyclopentane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '',
    'CXCBKSYSKZEEJB-YUMQZZPRSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,1,2,3-tetramethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,1,2,3-tetramethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,1,2,3-tetramethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>trans</i>-1,1,2,3-tetramethylcyclopentane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '62016-70-0',
    'CXCBKSYSKZEEJB-SFYZADRCSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,1,2,3-tetramethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,1,2,3-tetramethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,1,2,3-tetramethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>cis</i>-1,1,2,4-tetramethylcyclopentane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '62016-71-1',
    'AVBGIJNNMIBMQG-SFYZADRCSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,1,2,4-tetramethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,1,2,4-tetramethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,1,2,4-tetramethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>trans</i>-1,1,2,4-tetramethylcyclopentane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '',
    'AVBGIJNNMIBMQG-YUMQZZPRSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,1,2,4-tetramethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,1,2,4-tetramethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,1,2,4-tetramethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,3,3-tetramethylcyclopentane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '50876-33-0',
    'YWYCGTZNHWYQBD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,1,3,3-tetramethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,3,3-tetramethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,3,3-tetramethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>cis</i>-1,1,3,4-tetramethylcyclopentane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '53907-60-1',
    'OWHFMVURUNNXMJ-OCAPTIKFSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,1,3,4-tetramethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,1,3,4-tetramethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,1,3,4-tetramethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>trans</i>-1,1,3,4-tetramethylcyclopentane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '20309-77-7',
    'OWHFMVURUNNXMJ-HTQZYQBOSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,1,3,4-tetramethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,1,3,4-tetramethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,1,3,4-tetramethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>cis</i>-1,2,2,3-tetramethylcyclopentane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '18938-68-6',
    'DHLYDHNCPUAVHP-OCAPTIKFSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,2,2,3-tetramethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,2,2,3-tetramethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,2,2,3-tetramethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>trans</i>-1,2,2,3-tetramethylcyclopentane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '',
    'DHLYDHNCPUAVHP-YUMQZZPRSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,2,2,3-tetramethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,2,2,3-tetramethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,2,2,3-tetramethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,<i>cis</i>-2,<i>cis</i>-3,<i>cis</i>-4-tetramethylcyclopentane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '2532-65-2',
    'INYXDKODFMWKER-FNCVBFRFSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-2,<i>cis</i>-3,<i>cis</i>-4-tetramethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-2,<i>cis</i>-3,<i>cis</i>-4-tetramethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-2,<i>cis</i>-3,<i>cis</i>-4-tetramethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,<i>cis</i>-2,<i>cis</i>-3,<i>trans</i>-4-tetramethylcyclopentane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '2532-69-6',
    'INYXDKODFMWKER-BGZDPUMWSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-2,<i>cis</i>-3,<i>trans</i>-4-tetramethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-2,<i>cis</i>-3,<i>trans</i>-4-tetramethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,<i>cis</i>-2,<i>trans</i>-3,<i>cis</i>-4-tetramethylcyclopentane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '2532-68-5',
    'INYXDKODFMWKER-BZNPZCIMSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-2,<i>trans</i>-3,<i>cis</i>-4-tetramethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-2,<i>trans</i>-3,<i>cis</i>-4-tetramethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-2,<i>trans</i>-3,<i>cis</i>-4-tetramethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,<i>trans</i>-2,<i>cis</i>-3,<i>trans</i>-4-tetramethylcyclopentane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '2532-67-4',
    'INYXDKODFMWKER-HXFLIBJXSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,<i>trans</i>-2,<i>cis</i>-3,<i>trans</i>-4-tetramethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>trans</i>-2,<i>cis</i>-3,<i>trans</i>-4-tetramethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>trans</i>-2,<i>cis</i>-3,<i>trans</i>-4-tetramethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,<i>trans</i>-2,<i>trans</i>-3,<i>cis</i>-4-tetramethylcyclopentane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '19907-40-5',
    'INYXDKODFMWKER-OJOKCITNSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,<i>trans</i>-2,<i>trans</i>-3,<i>cis</i>-4-tetramethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>trans</i>-2,<i>trans</i>-3,<i>cis</i>-4-tetramethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>trans</i>-2,<i>trans</i>-3,<i>cis</i>-4-tetramethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1-dimethyl-2-ethylcyclopentane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '54549-80-3',
    'RXPIHZJWAFCHEJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,1-dimethyl-2-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dimethyl-2-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dimethyl-2-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1-dimethyl-3-ethylcyclopentane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '62016-61-9',
    'WXHYOGXBESCULU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,1-dimethyl-3-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dimethyl-3-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dimethyl-3-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,<i>cis</i>-2-dimethyl-1-ethylcyclopentane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '62016-63-1',
    'DRWDWIMYUGHJBR-DTWKUNHWSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-2-dimethyl-1-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-2-dimethyl-1-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-2-dimethyl-1-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,<i>trans</i>-2-dimethyl-1-ethylcyclopentane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '62016-62-0',
    'DRWDWIMYUGHJBR-RKDXNWHRSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,<i>trans</i>-2-dimethyl-1-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>trans</i>-2-dimethyl-1-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>trans</i>-2-dimethyl-1-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,<i>cis</i>-2-dimethyl-<i>cis</i>-3-ethylcyclopentane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '',
    'UMUGNPFWQJAOJI-HLTSFMKQSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-2-dimethyl-<i>cis</i>-3-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-2-dimethyl-<i>cis</i>-3-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-2-dimethyl-<i>cis</i>-3-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,<i>trans</i>-2-dimethyl-<i>trans</i>-3-ethylcyclopentane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '',
    'UMUGNPFWQJAOJI-HRDYMLBCSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,<i>trans</i>-2-dimethyl-<i>trans</i>-3-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>trans</i>-2-dimethyl-<i>trans</i>-3-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>trans</i>-2-dimethyl-<i>trans</i>-3-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,<i>cis</i>-2-dimethyl-<i>trans</i>-3-ethylcyclopentane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '',
    'UMUGNPFWQJAOJI-IWSPIJDZSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-2-dimethyl-<i>trans</i>-3-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-2-dimethyl-<i>trans</i>-3-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-2-dimethyl-<i>trans</i>-3-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,<i>trans</i>-2-dimethyl-<i>cis</i>-3-ethylcyclopentane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '',
    'UMUGNPFWQJAOJI-VGMNWLOBSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,<i>trans</i>-2-dimethyl-<i>cis</i>-3-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>trans</i>-2-dimethyl-<i>cis</i>-3-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>trans</i>-2-dimethyl-<i>cis</i>-3-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,<i>cis</i>-2-dimethyl-<i>cis</i>-4-ethylcyclopentane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '62016-64-2',
    'QKXQNQVXTYSGKS-BRPSZJMVSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-2-dimethyl-<i>cis</i>-4-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-2-dimethyl-<i>cis</i>-4-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-2-dimethyl-<i>cis</i>-4-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,<i>cis</i>-2-dimethyl-<i>trans</i>-4-ethylcyclopentane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '62016-65-3',
    'QKXQNQVXTYSGKS-AYMMMOKOSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-2-dimethyl-<i>trans</i>-4-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-2-dimethyl-<i>trans</i>-4-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-2-dimethyl-<i>trans</i>-4-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,<i>trans</i>-2-dimethyl-<i>cis</i>-4-ethylcyclopentane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '62016-66-4',
    'QKXQNQVXTYSGKS-HTQZYQBOSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,<i>trans</i>-2-dimethyl-<i>cis</i>-4-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>trans</i>-2-dimethyl-<i>cis</i>-4-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>trans</i>-2-dimethyl-<i>cis</i>-4-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,<i>cis</i>-3-dimethyl-1-ethylcyclopentane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '62016-68-6',
    'OAWOMHRJVJMDLZ-DTWKUNHWSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-3-dimethyl-1-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-3-dimethyl-1-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-3-dimethyl-1-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,<i>trans</i>-3-dimethyl-1-ethylcyclopentane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '62016-67-5',
    'OAWOMHRJVJMDLZ-RKDXNWHRSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,<i>trans</i>-3-dimethyl-1-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>trans</i>-3-dimethyl-1-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>trans</i>-3-dimethyl-1-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,<i>cis</i>-3-dimethyl-<i>cis</i>-2-ethylcyclopentane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '19903-00-5',
    'JREISGVVJTVFBL-AYMMMOKOSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-3-dimethyl-<i>cis</i>-2-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-3-dimethyl-<i>cis</i>-2-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-3-dimethyl-<i>cis</i>-2-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,<i>cis</i>-3-dimethyl-<i>trans</i>-2-ethylcyclopentane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '19902-98-8',
    'JREISGVVJTVFBL-BRPSZJMVSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-3-dimethyl-<i>trans</i>-2-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-3-dimethyl-<i>trans</i>-2-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-3-dimethyl-<i>trans</i>-2-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,<i>trans</i>-3-dimethyl-<i>cis</i>-2-ethylcyclopentane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '19902-99-9',
    'JREISGVVJTVFBL-HTQZYQBOSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,<i>trans</i>-3-dimethyl-<i>cis</i>-2-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>trans</i>-3-dimethyl-<i>cis</i>-2-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>trans</i>-3-dimethyl-<i>cis</i>-2-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,<i>cis</i>-3-dimethyl-<i>cis</i>-4-ethylcyclopentane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '',
    'VMCXXGFUCWAIIN-YIZRAAEISA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-3-dimethyl-<i>cis</i>-4-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-3-dimethyl-<i>cis</i>-4-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-3-dimethyl-<i>cis</i>-4-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,<i>cis</i>-3-dimethyl-<i>trans</i>-4-ethylcyclopentane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '',
    'VMCXXGFUCWAIIN-DJLDLDEBSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-3-dimethyl-<i>trans</i>-4-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-3-dimethyl-<i>trans</i>-4-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-3-dimethyl-<i>trans</i>-4-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,<i>trans</i>-3-dimethyl-<i>cis</i>-4-ethylcyclopentane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '',
    'VMCXXGFUCWAIIN-CIUDSAMLSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,<i>trans</i>-3-dimethyl-<i>cis</i>-4-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>trans</i>-3-dimethyl-<i>cis</i>-4-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>trans</i>-3-dimethyl-<i>cis</i>-4-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,<i>trans</i>-3-dimethyl-<i>trans</i>-4-ethylcyclopentane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '',
    'VMCXXGFUCWAIIN-XHNCKOQMSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,<i>trans</i>-3-dimethyl-<i>trans</i>-4-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>trans</i>-3-dimethyl-<i>trans</i>-4-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>trans</i>-3-dimethyl-<i>trans</i>-4-ethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-1-propylcyclopentane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '16631-63-3',
    'HICYLMKNNFKEMK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-methyl-1-propylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-1-propylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-1-propylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-<i>cis</i>-2-propylcyclopentane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '932-43-4',
    'ADQJFBQXLAAVQA-BDAKNGLRSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-methyl-<i>cis</i>-2-propylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-<i>cis</i>-2-propylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-<i>cis</i>-2-propylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-<i>trans</i>-2-propylcyclopentane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '932-44-5',
    'ADQJFBQXLAAVQA-RKDXNWHRSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-methyl-<i>trans</i>-2-propylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-<i>trans</i>-2-propylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-<i>trans</i>-2-propylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-<i>cis</i>-3-propylcyclopentane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '2443-04-1',
    'HRSBIYASWAILIF-BDAKNGLRSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-methyl-<i>cis</i>-3-propylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-<i>cis</i>-3-propylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-<i>cis</i>-3-propylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-<i>trans</i>-3-propylcyclopentane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '2443-03-0',
    'HRSBIYASWAILIF-RKDXNWHRSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-methyl-<i>trans</i>-3-propylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-<i>trans</i>-3-propylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-<i>trans</i>-3-propylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-1-isopropylcyclopentane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '61828-00-0',
    'XFMQGDWBNOQLEG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-methyl-1-isopropylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-1-isopropylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-1-isopropylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-<i>cis</i>-2-isopropylcyclopentane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '61868-01-7',
    'CGWXYEIWDQDFIU-RKDXNWHRSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-methyl-<i>cis</i>-2-isopropylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-<i>cis</i>-2-isopropylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-<i>cis</i>-2-isopropylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-<i>trans</i>-2-isopropylcyclopentane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '61828-01-1',
    'CGWXYEIWDQDFIU-BDAKNGLRSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-methyl-<i>trans</i>-2-isopropylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-<i>trans</i>-2-isopropylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-<i>trans</i>-2-isopropylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-<i>cis</i>-3-isopropylcyclopentane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '61828-02-2',
    'CDTDMKCVKCGRPD-BDAKNGLRSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-methyl-<i>cis</i>-3-isopropylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-<i>cis</i>-3-isopropylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-<i>cis</i>-3-isopropylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-<i>trans</i>-3-isopropylcyclopentane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '61828-03-3',
    'CDTDMKCVKCGRPD-RKDXNWHRSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-methyl-<i>trans</i>-3-isopropylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-<i>trans</i>-3-isopropylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-<i>trans</i>-3-isopropylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1-diethylcyclopentane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '2721-38-2',
    'DPGQSDLGKGLNHC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,1-diethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-diethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-diethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,<i>cis</i>-2-diethylcyclopentane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '932-39-8',
    'JKMYLSLBFNMSFP-DTORHVGOSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-2-diethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-2-diethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-2-diethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,<i>trans</i>-2-diethylcyclopentane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '932-40-1',
    'JKMYLSLBFNMSFP-RKDXNWHRSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,<i>trans</i>-2-diethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>trans</i>-2-diethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>trans</i>-2-diethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,<i>cis</i>-3-diethylcyclopentane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '62016-59-5',
    'RUUVWUNHERVOAY-DTORHVGOSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-3-diethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-3-diethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>cis</i>-3-diethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,<i>trans</i>-3-diethylcyclopentane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '62016-60-8',
    'RUUVWUNHERVOAY-RKDXNWHRSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,<i>trans</i>-3-diethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>trans</i>-3-diethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,<i>trans</i>-3-diethylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'butylcyclopentane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '2040-95-1',
    'ZAGHKONXGGSVDV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='butylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='butylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'isobutylcyclopentane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '3788-32-7',
    'DPUYDFJBHDYVQM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='isobutylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isobutylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isobutylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>sec</i>-butylcyclopentane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '4850-32-2',
    'DCEHVBLXWODXCW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>sec</i>-butylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>sec</i>-butylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>sec</i>-butylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>tert</i>-butylcyclopentane',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '3875-52-3',
    'BFWVYBVSRYIDHI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>tert</i>-butylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>tert</i>-butylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>tert</i>-butylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'octahydro-1H-indene',
    'C<sub>9</sub>H<sub>16</sub>',
    '',
    '496-10-6',
    'BNRNAKTVFSZAFA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octahydro-1H-indene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'butylcyclohexane',
    'C<sub>10</sub>H<sub>20</sub>',
    '',
    '1678-93-9',
    'GGBJHURWWWLEQH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='butylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='butylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pentylcyclopentane',
    'C<sub>10</sub>H<sub>20</sub>',
    '',
    '3741-00-2',
    'HPQURZRDYMUHJI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='pentylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='pentylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pentylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pentylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pentylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='pentylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pentylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'decahydronaphthalene',
    'C<sub>10</sub>H<sub>18</sub>',
    'decalin',
    '91-17-8',
    'NNBZCPXTIHJBJL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;5</sup>',
    '4100',
    'M',
    (SELECT id from species WHERE iupac='decahydronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='1156'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1156'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='decahydronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='decahydronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decahydronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decahydronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4500',
    'Q',
    (SELECT id from species WHERE iupac='decahydronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decahydronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decahydronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4100',
    '?',
    (SELECT id from species WHERE iupac='decahydronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(Z)-bicyclo[4.4.0]decane',
    'C<sub>10</sub>H<sub>18</sub>',
    '<i>cis</i>-decahydronaphthalene; <i>cis</i>-decalin',
    '493-01-6',
    'NNBZCPXTIHJBJL-AOOOYVTPSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(Z)-bicyclo[4.4.0]decane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='(Z)-bicyclo[4.4.0]decane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(Z)-bicyclo[4.4.0]decane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(Z)-bicyclo[4.4.0]decane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(Z)-bicyclo[4.4.0]decane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(E)-bicyclo[4.4.0]decane',
    'C<sub>10</sub>H<sub>18</sub>',
    '<i>trans</i>-decahydronaphthalene; <i>trans</i>-decalin',
    '493-02-7',
    'NNBZCPXTIHJBJL-MGCOHNPYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(E)-bicyclo[4.4.0]decane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='(E)-bicyclo[4.4.0]decane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(E)-bicyclo[4.4.0]decane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(E)-bicyclo[4.4.0]decane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(E)-bicyclo[4.4.0]decane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6,6-trimethylbicyclo[3.1.1]heptane',
    'C<sub>10</sub>H<sub>18</sub>',
    'dihydropinene',
    '473-55-2',
    'XOKSLPVRUOBDEW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6,6-trimethylbicyclo[3.1.1]heptane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tricyclene',
    'C<sub>10</sub>H<sub>16</sub>',
    '',
    '508-32-7',
    'RRBYUSWBLVXTQN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='tricyclene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hexylcyclopentane',
    'C<sub>11</sub>H<sub>22</sub>',
    '',
    '4457-00-5',
    'LKHGKBBAJAFMSQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='hexylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pentylcyclohexane',
    'C<sub>11</sub>H<sub>22</sub>',
    '',
    '4292-92-6',
    'HLTMUYBTNSVOFY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='pentylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cyclododecane',
    'C<sub>12</sub>H<sub>24</sub>',
    '',
    '294-62-2',
    'DDTBPAQBQHZRDW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclododecane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'heptylcyclopentane',
    'C<sub>12</sub>H<sub>24</sub>',
    '',
    '5617-42-5',
    'BOFNAOHMSHEKQL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='heptylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hexylcyclohexane',
    'C<sub>12</sub>H<sub>24</sub>',
    '',
    '4292-75-5',
    'QHWAQXOSHHKCFK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='hexylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1''-bicyclohexyl',
    'C<sub>12</sub>H<sub>22</sub>',
    '',
    '92-51-3',
    'WVIIMZNLDWSIRH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1''-bicyclohexyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'heptylcyclohexane',
    'C<sub>13</sub>H<sub>26</sub>',
    '',
    '5617-41-4',
    'MSTLSCNJAHAQNU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='heptylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'octylcyclopentane',
    'C<sub>13</sub>H<sub>26</sub>',
    '',
    '1795-20-6',
    'HARXDULSBROLME-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='octylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'octylcyclohexane',
    'C<sub>14</sub>H<sub>28</sub>',
    '',
    '1795-15-9',
    'FBXWCEKQCVOOLT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='octylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nonylcyclopentane',
    'C<sub>14</sub>H<sub>28</sub>',
    '',
    '2882-98-6',
    'GDCYEUOAZVKNHT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='nonylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'octahydro-1,1,2,3,3-pentamethyl-1H-indene',
    'C<sub>14</sub>H<sub>26</sub>',
    '',
    '33704-60-8',
    'TUALLFJCLUYJEN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octahydro-1,1,2,3,3-pentamethyl-1H-indene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octahydro-1,1,2,3,3-pentamethyl-1H-indene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octahydro-1,1,2,3,3-pentamethyl-1H-indene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octahydro-1,1,2,3,3-pentamethyl-1H-indene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nonylcyclohexane',
    'C<sub>15</sub>H<sub>30</sub>',
    '',
    '2883-02-5',
    'CLMFECCMAVQYQA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='nonylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'decylcyclopentane',
    'C<sub>15</sub>H<sub>30</sub>',
    '',
    '1795-21-7',
    'WOUVLFFZQCUYOL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='decylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decylcyclopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'decylcyclohexane',
    'C<sub>16</sub>H<sub>32</sub>',
    '',
    '1795-16-0',
    'STWFZICHPLEOIC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='decylcyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1''-(2-methylpentane-2,4-diyl)dicyclohexane',
    'C<sub>18</sub>H<sub>34</sub>',
    '',
    '38970-72-8',
    'XUVKLBIJXLIPDZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1''-(2-methylpentane-2,4-diyl)dicyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1''-(2-methylpentane-2,4-diyl)dicyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1''-(2-methylpentane-2,4-diyl)dicyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1''-(2-methylpentane-2,4-diyl)dicyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1'':3'',1"-tercyclohexane',
    'C<sub>18</sub>H<sub>32</sub>',
    '',
    '1706-50-9',
    'JBQRJHVXZMSLNH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Cycloalkanes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1'':3'',1"-tercyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1'':3'',1"-tercyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1'':3'',1"-tercyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1'':3'',1"-tercyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Aliphatic alkenes and cycloalkenes',
    (SELECT id from categories WHERE catname='Hydrocarbons (C, H)'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethene',
    'C<sub>2</sub>H<sub>4</sub>',
    'ethylene',
    '74-85-1',
    'VGGSQFUCUMXWEO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;5</sup>',
    '2200',
    'L',
    (SELECT id from species WHERE iupac='ethene'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;5</sup>',
    '2200',
    'L',
    (SELECT id from species WHERE iupac='ethene'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;5</sup>',
    '2200',
    'L',
    (SELECT id from species WHERE iupac='ethene'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;5</sup>',
    '2200',
    'L',
    (SELECT id from species WHERE iupac='ethene'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;5</sup>',
    '2000',
    'L',
    (SELECT id from species WHERE iupac='ethene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;5</sup>',
    '2000',
    'L',
    (SELECT id from species WHERE iupac='ethene'),
    (SELECT id from literature WHERE bibtexkey='3869'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='ethene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;5</sup>',
    '1800',
    'L',
    (SELECT id from species WHERE iupac='ethene'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='ethene'),
    (SELECT id from literature WHERE bibtexkey='2441'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;5</sup>',
    '2200',
    'L',
    (SELECT id from species WHERE iupac='ethene'),
    (SELECT id from literature WHERE bibtexkey='3696'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;5</sup>',
    '2000',
    'M',
    (SELECT id from species WHERE iupac='ethene'),
    (SELECT id from literature WHERE bibtexkey='923'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0923-74-85-1-ABC',
    '923', 'The data from Maaßen (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;187.57836 +9639.75245/T +25.50544&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0923-74-85-1-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;5</sup>',
    '1900',
    'M',
    (SELECT id from species WHERE iupac='ethene'),
    (SELECT id from literature WHERE bibtexkey='2013'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2013-74-85-1-ABC',
    '2013', 'The data from Reichl (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;166.44394 +8613.39266/T +22.39721&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2013-74-85-1-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;5</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethene'),
    (SELECT id from literature WHERE bibtexkey='3924'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;5</sup>',
    '2000',
    'M',
    (SELECT id from species WHERE iupac='ethene'),
    (SELECT id from literature WHERE bibtexkey='3783'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3783-74-85-1-ABC',
    '3783', 'The data from Morrison and Billett (1952) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;175.14997 +9028.26949/T +23.67675&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3783-74-85-1-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;5</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethene'),
    (SELECT id from literature WHERE bibtexkey='3702'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;5</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethene'),
    (SELECT id from literature WHERE bibtexkey='3715'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at311K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;5</sup>',
    '2300',
    'M',
    (SELECT id from species WHERE iupac='ethene'),
    (SELECT id from literature WHERE bibtexkey='862'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;5</sup>',
    '1900',
    'V',
    (SELECT id from species WHERE iupac='ethene'),
    (SELECT id from literature WHERE bibtexkey='2375'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;5</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='ethene'),
    (SELECT id from literature WHERE bibtexkey='766'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;5</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='ethene'),
    (SELECT id from literature WHERE bibtexkey='529'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethene'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethene'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2700',
    'Q',
    (SELECT id from species WHERE iupac='ethene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethene'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '1900',
    '?',
    (SELECT id from species WHERE iupac='ethene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;5</sup>',
    '2400',
    '?',
    (SELECT id from species WHERE iupac='ethene'),
    (SELECT id from literature WHERE bibtexkey='3811'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethene'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;5</sup>',
    '2000',
    '?',
    (SELECT id from species WHERE iupac='ethene'),
    (SELECT id from literature WHERE bibtexkey='379'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0379-74-85-1-ABC',
    '379', 'The data from Dean and Lange (1999) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;221.00286 +11107.47493/T +30.50401&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0379-74-85-1-ABC'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='379'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethene'),
    (SELECT id from literature WHERE bibtexkey='523'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propene',
    'C<sub>3</sub>H<sub>6</sub>',
    'propylene',
    '115-07-1',
    'QQONPFPTGQHPMA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;5</sup>',
    '2600',
    'L',
    (SELECT id from species WHERE iupac='propene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='propene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;5</sup>',
    '3400',
    'L',
    (SELECT id from species WHERE iupac='propene'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;5</sup>',
    '2700',
    'M',
    (SELECT id from species WHERE iupac='propene'),
    (SELECT id from literature WHERE bibtexkey='923'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0923-115-07-1-ABC',
    '923', 'The data from Maaßen (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;168.51157 +9378.22622/T +22.33127&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0923-115-07-1-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;5</sup>',
    '2800',
    'M',
    (SELECT id from species WHERE iupac='propene'),
    (SELECT id from literature WHERE bibtexkey='2013'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2013-115-07-1-ABC',
    '2013', 'The data from Reichl (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;241.54655 +12718.75981/T +33.18333&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2013-115-07-1-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;5</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='propene'),
    (SELECT id from literature WHERE bibtexkey='3924'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propene'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='propene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;5</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='propene'),
    (SELECT id from literature WHERE bibtexkey='529'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propene'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3100',
    'Q',
    (SELECT id from species WHERE iupac='propene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propene'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propene'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3800',
    '?',
    (SELECT id from species WHERE iupac='propene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;5</sup>',
    '2800',
    '?',
    (SELECT id from species WHERE iupac='propene'),
    (SELECT id from literature WHERE bibtexkey='3811'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-butene',
    'C<sub>4</sub>H<sub>8</sub>',
    '',
    '106-98-9',
    'VXNZUUAINFGPBY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;5</sup>',
    '3000',
    'L',
    (SELECT id from species WHERE iupac='1-butene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '6400',
    'L',
    (SELECT id from species WHERE iupac='1-butene'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;5</sup>',
    '3000',
    'M',
    (SELECT id from species WHERE iupac='1-butene'),
    (SELECT id from literature WHERE bibtexkey='3612'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3612-106-98-9-ABC',
    '3612', 'The data from Serra and Palavra (2003) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;261.78355 +13728.91505/T +36.10688&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3612-106-98-9-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;5</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-butene'),
    (SELECT id from literature WHERE bibtexkey='3924'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-butene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-butene'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-butene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-butene'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-butene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butene'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butene'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butene'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butene'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butene'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-butene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-butene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-butene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-butene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='1-butene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '479wrong',
    '1337', 'According to Donahue and Prinn (1993), the value is incorrect.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='479wrong'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-butene',
    'C<sub>4</sub>H<sub>8</sub>',
    '',
    '107-01-7',
    'IAQRGUVFOMOMEM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>cis</i>-2-butene',
    'C<sub>4</sub>H<sub>8</sub>',
    '',
    '590-18-1',
    'IAQRGUVFOMOMEM-ARJAWSKDSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='<i>cis</i>-2-butene'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>cis</i>-2-butene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-2-butene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-2-butene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-2-butene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3409-cis-trans',
    '3409', 'Wang et&nbsp;al. (2017) provide separate data for <i>cis</i> and <i>trans</i>. However, since both isomers are identified by the same SMILES string in their study, it is unclear how the stereochemistry has been taken into account.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-cis-trans'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-2-butene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-cis-trans'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-2-butene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-cis-trans'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-2-butene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-2-butene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-2-butene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-2-butene'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-2-butene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-2-butene'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='<i>cis</i>-2-butene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='<i>cis</i>-2-butene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>trans</i>-2-butene',
    'C<sub>4</sub>H<sub>8</sub>',
    '',
    '624-64-6',
    'IAQRGUVFOMOMEM-ONEGZZNKSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-butene'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-butene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-butene'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-butene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-butene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-butene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-cis-trans'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-butene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-cis-trans'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-butene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-cis-trans'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-butene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-butene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-butene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-butene'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-butene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-butene'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-butene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-butene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methylpropene',
    'C<sub>4</sub>H<sub>8</sub>',
    'isobutene',
    '115-11-7',
    'VQTUBCCKSQIDNK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;5</sup>',
    '3000',
    'L',
    (SELECT id from species WHERE iupac='2-methylpropene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;5</sup>',
    '3000',
    'L',
    (SELECT id from species WHERE iupac='2-methylpropene'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;5</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methylpropene'),
    (SELECT id from literature WHERE bibtexkey='3924'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylpropene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylpropene'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylpropene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methylpropene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropene'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3400',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropene'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropene'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methylpropene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3000',
    '?',
    (SELECT id from species WHERE iupac='2-methylpropene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methylpropene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;5</sup>',
    '3000',
    '?',
    (SELECT id from species WHERE iupac='2-methylpropene'),
    (SELECT id from literature WHERE bibtexkey='3811'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methylpropene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='2-methylpropene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='479wrong'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-pentene',
    'C<sub>5</sub>H<sub>10</sub>',
    '',
    '109-67-1',
    'YWAKXRMUMFPDSH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-pentene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-pentene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-pentene'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-pentene'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-pentene'),
    (SELECT id from literature WHERE bibtexkey='2388'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-pentene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3924'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-pentene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentene'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-pentene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-pentene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-pentene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-pentene',
    'C<sub>5</sub>H<sub>10</sub>',
    '',
    '109-68-2',
    'QMMOXUPEWRXHJS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-pentene'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>cis</i>-2-pentene',
    'C<sub>5</sub>H<sub>10</sub>',
    '',
    '627-20-3',
    'QMMOXUPEWRXHJS-HYXAFXHYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='<i>cis</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='<i>cis</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='<i>cis</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>cis</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-cis-trans'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-cis-trans'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-cis-trans'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='<i>cis</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='<i>cis</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>trans</i>-2-pentene',
    'C<sub>5</sub>H<sub>10</sub>',
    '',
    '646-04-8',
    'QMMOXUPEWRXHJS-HWKANZROSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-cis-trans'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-cis-trans'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-cis-trans'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-1-butene',
    'C<sub>5</sub>H<sub>10</sub>',
    '',
    '563-46-2',
    'MHNNAWXXUZQSNM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-2-butene',
    'C<sub>5</sub>H<sub>10</sub>',
    '',
    '513-35-9',
    'BKOOMYPCSUNDGP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;5</sup>',
    '3500',
    'L',
    (SELECT id from species WHERE iupac='2-methyl-2-butene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;5</sup>',
    '3600',
    'L',
    (SELECT id from species WHERE iupac='2-methyl-2-butene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-2-butene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-2-butene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-2-butene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-2-butene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-butene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-butene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-butene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-butene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-butene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-butene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-butene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-butene'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-butene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-butene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-butene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-Test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-butene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-butene'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-butene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methyl-2-butene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-1-butene',
    'C<sub>5</sub>H<sub>10</sub>',
    '',
    '563-45-1',
    'YHQXBTXEYZIYOV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='3-methyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='3-methyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3-methyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='3924'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-methyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-methyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-methyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-methyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-methyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-methyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-hexene',
    'C<sub>6</sub>H<sub>12</sub>',
    '',
    '592-41-6',
    'LIKMAJRDDDTEIG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-hexene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;5</sup>',
    '3900',
    'L',
    (SELECT id from species WHERE iupac='1-hexene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-hexene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hexene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hexene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hexene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hexene'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hexene'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hexene'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hexene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hexene'),
    (SELECT id from literature WHERE bibtexkey='3924'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4100',
    'Q',
    (SELECT id from species WHERE iupac='1-hexene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexene'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexene'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4000',
    '?',
    (SELECT id from species WHERE iupac='1-hexene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-hexene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-hexene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-hexene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>cis</i>-2-hexene',
    'C<sub>6</sub>H<sub>12</sub>',
    '',
    '7688-21-3',
    'RYPKRALMXUUNKS-HYXAFXHYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>cis</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-cis-trans'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-cis-trans'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-cis-trans'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='<i>cis</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>trans</i>-2-hexene',
    'C<sub>6</sub>H<sub>12</sub>',
    '',
    '4050-45-7',
    'RYPKRALMXUUNKS-HWKANZROSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-cis-trans'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-cis-trans'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-cis-trans'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>cis</i>-3-hexene',
    'C<sub>6</sub>H<sub>12</sub>',
    '',
    '7642-09-3',
    'ZQDPJFUHLCOCRG-WAYWQWQTSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>cis</i>-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='<i>cis</i>-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>trans</i>-3-hexene',
    'C<sub>6</sub>H<sub>12</sub>',
    '',
    '13269-52-8',
    'ZQDPJFUHLCOCRG-AATRIKPKSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>trans</i>-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='<i>trans</i>-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-1-pentene',
    'C<sub>6</sub>H<sub>12</sub>',
    '',
    '763-29-1',
    'WWUVJRULCWHUSA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2-methyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2-methyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='1910'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-1-pentene',
    'C<sub>6</sub>H<sub>12</sub>',
    '',
    '760-20-3',
    'LDTAOIUHUHHCMU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-methyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-1-pentene',
    'C<sub>6</sub>H<sub>12</sub>',
    '',
    '691-37-2',
    'WSSSPWUEQFSQQG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='4-methyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='4-methyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-methyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-methyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-methyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-methyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-methyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-methyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-methyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-2-pentene',
    'C<sub>6</sub>H<sub>12</sub>',
    '',
    '625-27-4',
    'JMMZCWZIJXAGKW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methyl-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>cis</i>-3-methyl-2-pentene',
    'C<sub>6</sub>H<sub>12</sub>',
    '',
    '922-62-3',
    'BEQGRRJLJLVQAQ-XQRVVYSFSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>cis</i>-3-methyl-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-3-methyl-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-3-methyl-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='<i>cis</i>-3-methyl-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>trans</i>-3-methyl-2-pentene',
    'C<sub>6</sub>H<sub>12</sub>',
    '',
    '616-12-6',
    'BEQGRRJLJLVQAQ-GQCTYLIASA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>trans</i>-3-methyl-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-3-methyl-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-3-methyl-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-3-methyl-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-3-methyl-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='<i>trans</i>-3-methyl-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>cis</i>-4-methyl-2-pentene',
    'C<sub>6</sub>H<sub>12</sub>',
    '',
    '691-38-3',
    'LGAQJENWWYGFSN-PLNGDYQASA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>cis</i>-4-methyl-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-4-methyl-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-4-methyl-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-4-methyl-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-4-methyl-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='<i>cis</i>-4-methyl-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>trans</i>-4-methyl-2-pentene',
    'C<sub>6</sub>H<sub>12</sub>',
    '',
    '674-76-0',
    'LGAQJENWWYGFSN-SNAWJCMRSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>trans</i>-4-methyl-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-4-methyl-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-4-methyl-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-4-methyl-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-4-methyl-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='<i>trans</i>-4-methyl-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methylenepentane',
    'C<sub>6</sub>H<sub>12</sub>',
    '2-ethyl-1-butene',
    '760-21-4',
    'RYKZRKKEYSRDNF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methylenepentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylenepentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylenepentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylenepentane'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylenepentane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-methylenepentane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethyl-1-butene',
    'C<sub>6</sub>H<sub>12</sub>',
    '',
    '563-78-0',
    'OWWIWYDDISJUMY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3-dimethyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3-dimethyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3-dimethyl-1-butene',
    'C<sub>6</sub>H<sub>12</sub>',
    '',
    '558-37-2',
    'PKXHXOTZMFCXSH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3-dimethyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,3-dimethyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethyl-2-butene',
    'C<sub>6</sub>H<sub>12</sub>',
    '',
    '563-79-1',
    'WGLLSSPDPJPLOR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3-dimethyl-2-butene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-2-butene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-2-butene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-2-butene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-2-butene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-2-butene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-2-butene'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-2-butene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3-dimethyl-2-butene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-heptene',
    'C<sub>7</sub>H<sub>14</sub>',
    '',
    '592-76-7',
    'ZGEGCLOFRBLKSE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-heptene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-heptene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-heptene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-heptene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-heptene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-heptene'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-heptene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-heptene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-heptene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-heptene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-heptene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-heptene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-heptene'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-heptene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-heptene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-heptene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-heptene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-heptene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-heptene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-heptene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-heptene',
    'C<sub>7</sub>H<sub>14</sub>',
    '',
    '592-77-8',
    'OTTZHAVKAVGASB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2-heptene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-heptene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-heptene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-heptene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-heptene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-heptene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-heptene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-heptene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-heptene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-Test'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>cis</i>-2-heptene',
    'C<sub>7</sub>H<sub>14</sub>',
    '',
    '6443-92-1',
    'OTTZHAVKAVGASB-HYXAFXHYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='<i>cis</i>-2-heptene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>cis</i>-2-heptene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-2-heptene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-2-heptene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-2-heptene'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-2-heptene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='<i>cis</i>-2-heptene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>trans</i>-2-heptene',
    'C<sub>7</sub>H<sub>14</sub>',
    '',
    '14686-13-6',
    'OTTZHAVKAVGASB-HWKANZROSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-heptene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-heptene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-heptene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-heptene'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-heptene'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-heptene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-heptene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-heptene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-heptene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-heptene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-heptene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-heptene'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-heptene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-heptene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-heptene'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-heptene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>cis</i>-3-heptene',
    'C<sub>7</sub>H<sub>14</sub>',
    '',
    '7642-10-6',
    'WZHKDGJSXCTSCK-ALCCZGGFSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>cis</i>-3-heptene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-3-heptene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-3-heptene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-3-heptene'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-3-heptene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='<i>cis</i>-3-heptene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>trans</i>-3-heptene',
    'C<sub>7</sub>H<sub>14</sub>',
    '',
    '14686-14-7',
    'WZHKDGJSXCTSCK-FNORWQNLSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>trans</i>-3-heptene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-3-heptene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-3-heptene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-3-heptene'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-3-heptene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='<i>trans</i>-3-heptene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-1-hexene',
    'C<sub>7</sub>H<sub>14</sub>',
    '',
    '6094-02-6',
    'IRUDSQHLKGNCGF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-2-hexene',
    'C<sub>7</sub>H<sub>14</sub>',
    '',
    '2738-19-4',
    'BWEKDYGHDCHWEN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-<i>cis</i>-3-hexene',
    'C<sub>7</sub>H<sub>14</sub>',
    '',
    '15840-60-5',
    'IQANHWBWTVLDTP-WAYWQWQTSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-<i>cis</i>-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-<i>cis</i>-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-<i>cis</i>-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-<i>trans</i>-3-hexene',
    'C<sub>7</sub>H<sub>14</sub>',
    '',
    '692-24-0',
    'IQANHWBWTVLDTP-AATRIKPKSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-<i>trans</i>-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-<i>trans</i>-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-<i>trans</i>-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-1-hexene',
    'C<sub>7</sub>H<sub>14</sub>',
    '',
    '3404-61-3',
    'RITONZMLZWYPHW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-methyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-<i>cis</i>-2-hexene',
    'C<sub>7</sub>H<sub>14</sub>',
    '',
    '10574-36-4',
    'JZMUUSXQSKCZNO-ALCCZGGFSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-<i>cis</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-<i>cis</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-<i>cis</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-<i>trans</i>-2-hexene',
    'C<sub>7</sub>H<sub>14</sub>',
    '',
    '20710-38-7',
    'JZMUUSXQSKCZNO-FNORWQNLSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-<i>trans</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-<i>trans</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-<i>trans</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-<i>cis</i>-3-hexene',
    'C<sub>7</sub>H<sub>14</sub>',
    '',
    '4914-89-0',
    'FHHSSXNRVNXTBG-SREVYHEPSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-<i>cis</i>-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-<i>cis</i>-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-<i>cis</i>-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-<i>trans</i>-3-hexene',
    'C<sub>7</sub>H<sub>14</sub>',
    '',
    '3899-36-3',
    'FHHSSXNRVNXTBG-VOTSOKGWSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-<i>trans</i>-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-<i>trans</i>-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-<i>trans</i>-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-1-hexene',
    'C<sub>7</sub>H<sub>14</sub>',
    '',
    '3769-23-1',
    'SUWJESCICIOQHO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-methyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-<i>cis</i>-2-hexene',
    'C<sub>7</sub>H<sub>14</sub>',
    '',
    '3683-19-0',
    'MBNDKEPQUVZHCM-XQRVVYSFSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-<i>cis</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-<i>cis</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-<i>cis</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-<i>trans</i>-2-hexene',
    'C<sub>7</sub>H<sub>14</sub>',
    '',
    '3683-22-5',
    'MBNDKEPQUVZHCM-GQCTYLIASA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-<i>trans</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-<i>trans</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-<i>trans</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-methyl-1-hexene',
    'C<sub>7</sub>H<sub>14</sub>',
    '',
    '3524-73-0',
    'JIUFYGIESXPUPL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='5-methyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-methyl-<i>cis</i>-2-hexene',
    'C<sub>7</sub>H<sub>14</sub>',
    '',
    '13151-17-2',
    'GHBKCPRDHLITSE-PLNGDYQASA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='5-methyl-<i>cis</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-<i>cis</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-<i>cis</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-methyl-<i>trans</i>-2-hexene',
    'C<sub>7</sub>H<sub>14</sub>',
    '',
    '7385-82-2',
    'GHBKCPRDHLITSE-SNAWJCMRSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='5-methyl-<i>trans</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-<i>trans</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-<i>trans</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethyl-1-pentene',
    'C<sub>7</sub>H<sub>14</sub>',
    '',
    '3404-72-6',
    'LIMAEKMEXJTSNI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3-dimethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethyl-2-pentene',
    'C<sub>7</sub>H<sub>14</sub>',
    '',
    '10574-37-5',
    'WFHALSLYRWWUGH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3-dimethyl-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dimethyl-1-pentene',
    'C<sub>7</sub>H<sub>14</sub>',
    '',
    '2213-32-3',
    'LXQPBCHJNIOMQU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4-dimethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dimethyl-2-pentene',
    'C<sub>7</sub>H<sub>14</sub>',
    '',
    '625-65-0',
    'VVCFYASOGFVJFN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4-dimethyl-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3-dimethyl-1-pentene',
    'C<sub>7</sub>H<sub>14</sub>',
    '',
    '3404-73-7',
    'TXBZITDWMURSEF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3-dimethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4-dimethyl-1-pentene',
    'C<sub>7</sub>H<sub>14</sub>',
    '',
    '7385-78-6',
    'WFHXQNMTMDKVJG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4-dimethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4-dimethyl-<i>cis</i>-2-pentene',
    'C<sub>7</sub>H<sub>14</sub>',
    '',
    '4914-91-4',
    'PPBWEVVDSRKEIK-ALCCZGGFSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4-dimethyl-<i>cis</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyl-<i>cis</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyl-<i>cis</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4-dimethyl-<i>trans</i>-2-pentene',
    'C<sub>7</sub>H<sub>14</sub>',
    '',
    '4914-92-5',
    'PPBWEVVDSRKEIK-FNORWQNLSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4-dimethyl-<i>trans</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyl-<i>trans</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyl-<i>trans</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,4-dimethyl-1-pentene',
    'C<sub>7</sub>H<sub>14</sub>',
    '',
    '762-62-9',
    'KLCNJIQZXOQYTE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,4-dimethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,4-dimethyl-<i>cis</i>-2-pentene',
    'C<sub>7</sub>H<sub>14</sub>',
    '',
    '762-63-0',
    'BIDIHFPLDRSAMB-WAYWQWQTSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,4-dimethyl-<i>cis</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethyl-<i>cis</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethyl-<i>cis</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,4-dimethyl-<i>trans</i>-2-pentene',
    'C<sub>7</sub>H<sub>14</sub>',
    '',
    '690-08-4',
    'BIDIHFPLDRSAMB-AATRIKPKSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,4-dimethyl-<i>trans</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethyl-<i>trans</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethyl-<i>trans</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-ethyl-1-pentene',
    'C<sub>7</sub>H<sub>14</sub>',
    '',
    '3404-71-5',
    'TWCRBBJSQAZZQB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-ethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-ethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-1-pentene',
    'C<sub>7</sub>H<sub>14</sub>',
    '',
    '4038-04-4',
    'YPVPQMCSLFDIKA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-ethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-2-pentene',
    'C<sub>7</sub>H<sub>14</sub>',
    '',
    '816-79-5',
    'XMYFZAWUNVHVGI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-2-ethyl-1-butene',
    'C<sub>7</sub>H<sub>14</sub>',
    '',
    '7357-93-9',
    'ADHCYQWFCLQBFG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-2-ethyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-ethyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-ethyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3-trimethyl-1-butene',
    'C<sub>7</sub>H<sub>14</sub>',
    '',
    '594-56-9',
    'AUYRUAVCWOAHQN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,3-trimethyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3-trimethyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3-trimethyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3-trimethyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3-trimethyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3,3-trimethyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-octene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '111-66-0',
    'KWKAKUADMBZCLK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-octene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '4400',
    'L',
    (SELECT id from species WHERE iupac='1-octene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-octene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-octene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-octene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-octene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-octene'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-octene'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-octene'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-octene'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-octene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-octene'),
    (SELECT id from literature WHERE bibtexkey='3924'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-octene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octene'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octene'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octene'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octene'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-octene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-octene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-octene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>cis</i>-2-octene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '7642-04-8',
    'ILPBINAXDRFYPL-HYXAFXHYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>cis</i>-2-octene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-2-octene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-2-octene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>trans</i>-2-octene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '13389-42-9',
    'ILPBINAXDRFYPL-HWKANZROSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-octene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-octene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-octene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='<i>trans</i>-2-octene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>cis</i>-3-octene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '14850-22-7',
    'YCTDZYMMFQCTEO-ALCCZGGFSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>cis</i>-3-octene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-3-octene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-3-octene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>trans</i>-3-octene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '14919-01-8',
    'YCTDZYMMFQCTEO-FNORWQNLSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>trans</i>-3-octene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-3-octene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-3-octene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='<i>trans</i>-3-octene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>cis</i>-4-octene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '7642-15-1',
    'IRUCBBFNLDIMIK-FPLPWBNLSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>cis</i>-4-octene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-4-octene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-4-octene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>trans</i>-4-octene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '14850-23-8',
    'IRUCBBFNLDIMIK-BQYQJAHWSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>trans</i>-4-octene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-4-octene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-4-octene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='<i>trans</i>-4-octene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-1-heptene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '15870-10-7',
    'RCBGGJURENJHKV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-1-heptene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-heptene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-heptene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-2-heptene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '627-97-4',
    'WEPNJTDVIIKRIK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-2-heptene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-heptene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-heptene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-<i>cis</i>-3-heptene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '20488-34-0',
    'CYEZJYAMLNTSKN-SREVYHEPSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-<i>cis</i>-3-heptene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-<i>cis</i>-3-heptene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-<i>cis</i>-3-heptene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-<i>trans</i>-3-heptene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '692-96-6',
    'CYEZJYAMLNTSKN-VOTSOKGWSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-<i>trans</i>-3-heptene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-<i>trans</i>-3-heptene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-<i>trans</i>-3-heptene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-1-heptene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '4810-09-7',
    'QDMFTFWKTYXBIW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-1-heptene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-heptene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-heptene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-<i>cis</i>-2-heptene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '22768-19-0',
    'OFKLSPUVNMOIJB-YVMONPNESA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-<i>cis</i>-2-heptene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-<i>cis</i>-2-heptene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-<i>cis</i>-2-heptene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-<i>trans</i>-2-heptene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '22768-20-3',
    'OFKLSPUVNMOIJB-VMPITWQZSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-<i>trans</i>-2-heptene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-<i>trans</i>-2-heptene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-<i>trans</i>-2-heptene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-<i>cis</i>-3-heptene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '22768-17-8',
    'AAUHUDBDDBJONC-FPLPWBNLSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-<i>cis</i>-3-heptene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-<i>cis</i>-3-heptene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-<i>cis</i>-3-heptene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-<i>trans</i>-3-heptene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '22768-18-9',
    'AAUHUDBDDBJONC-BQYQJAHWSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-<i>trans</i>-3-heptene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-<i>trans</i>-3-heptene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-<i>trans</i>-3-heptene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-1-heptene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '13151-05-8',
    'BFGOGLKYJXQPJZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-1-heptene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1-heptene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1-heptene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-<i>cis</i>-2-heptene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '66225-16-9',
    'SVGLFIBXFVQUQY-XQRVVYSFSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-<i>cis</i>-2-heptene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-<i>cis</i>-2-heptene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-<i>cis</i>-2-heptene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-<i>trans</i>-2-heptene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '66225-17-0',
    'SVGLFIBXFVQUQY-GQCTYLIASA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-<i>trans</i>-2-heptene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-<i>trans</i>-2-heptene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-<i>trans</i>-2-heptene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-<i>cis</i>-3-heptene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '14255-24-4',
    'KKVVJQGDNYIIMN-VURMDHGXSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-<i>cis</i>-3-heptene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-<i>cis</i>-3-heptene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-<i>cis</i>-3-heptene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-<i>trans</i>-3-heptene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '13714-85-7',
    'KKVVJQGDNYIIMN-SOFGYWHQSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-<i>trans</i>-3-heptene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-<i>trans</i>-3-heptene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-<i>trans</i>-3-heptene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-methyl-1-heptene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '13151-04-7',
    'WNEYWVBECXCQRT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='5-methyl-1-heptene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-1-heptene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-1-heptene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-methyl-<i>cis</i>-2-heptene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '24608-84-2',
    'VIHUHUGDEZCPDK-XQRVVYSFSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='5-methyl-<i>cis</i>-2-heptene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-<i>cis</i>-2-heptene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-<i>cis</i>-2-heptene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-methyl-<i>trans</i>-2-heptene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '24608-85-3',
    'VIHUHUGDEZCPDK-GQCTYLIASA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='5-methyl-<i>trans</i>-2-heptene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-<i>trans</i>-2-heptene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-<i>trans</i>-2-heptene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-methyl-<i>cis</i>-3-heptene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '50422-80-5',
    'YMNTZRCUPAYGLG-SREVYHEPSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='5-methyl-<i>cis</i>-3-heptene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-<i>cis</i>-3-heptene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-<i>cis</i>-3-heptene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-methyl-<i>trans</i>-3-heptene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '53510-18-2',
    'YMNTZRCUPAYGLG-VOTSOKGWSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='5-methyl-<i>trans</i>-3-heptene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-<i>trans</i>-3-heptene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-<i>trans</i>-3-heptene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '6-methyl-1-heptene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '5026-76-6',
    'DFVOXRAAHOJJBN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='6-methyl-1-heptene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-methyl-1-heptene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-methyl-1-heptene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '6-methyl-<i>cis</i>-2-heptene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '66225-18-1',
    'LXBJRNXXTAWCKU-PLNGDYQASA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='6-methyl-<i>cis</i>-2-heptene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-methyl-<i>cis</i>-2-heptene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-methyl-<i>cis</i>-2-heptene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '6-methyl-<i>trans</i>-2-heptene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '51065-65-7',
    'LXBJRNXXTAWCKU-SNAWJCMRSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='6-methyl-<i>trans</i>-2-heptene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-methyl-<i>trans</i>-2-heptene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-methyl-<i>trans</i>-2-heptene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '6-methyl-<i>cis</i>-3-heptene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '66225-19-2',
    'PMPISKBGRHSPEE-WAYWQWQTSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='6-methyl-<i>cis</i>-3-heptene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-methyl-<i>cis</i>-3-heptene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-methyl-<i>cis</i>-3-heptene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '6-methyl-<i>trans</i>-3-heptene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '66225-20-5',
    'PMPISKBGRHSPEE-AATRIKPKSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='6-methyl-<i>trans</i>-3-heptene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-methyl-<i>trans</i>-3-heptene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-methyl-<i>trans</i>-3-heptene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dimethyl-<i>cis</i>-3-hexene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '690-92-6',
    'JPLZSSHKQZJYTJ-SREVYHEPSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2-dimethyl-<i>cis</i>-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-<i>cis</i>-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-<i>cis</i>-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dimethyl-<i>trans</i>-3-hexene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '690-93-7',
    'JPLZSSHKQZJYTJ-VOTSOKGWSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2-dimethyl-<i>trans</i>-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-<i>trans</i>-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-<i>trans</i>-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethyl-1-hexene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '16746-86-4',
    'LVLXQRZPKUFJJQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3-dimethyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethyl-2-hexene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '7145-20-2',
    'RGYAVZGBAJFMIZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3-dimethyl-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethyl-<i>cis</i>-3-hexene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '59643-75-3',
    'PRTXQHCLTIKAAJ-VURMDHGXSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3-dimethyl-<i>cis</i>-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-<i>cis</i>-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-<i>cis</i>-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethyl-<i>trans</i>-3-hexene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '66225-30-7',
    'PRTXQHCLTIKAAJ-SOFGYWHQSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3-dimethyl-<i>trans</i>-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-<i>trans</i>-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-<i>trans</i>-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dimethyl-1-hexene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '16746-87-5',
    'PKVDGQHNRICJLA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4-dimethyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dimethyl-2-hexene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '14255-23-3',
    'IZSBIPQYBGDXJZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4-dimethyl-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dimethyl-<i>cis</i>-3-hexene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '37549-89-6',
    'VFCHHMABGOYOQI-VURMDHGXSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4-dimethyl-<i>cis</i>-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-<i>cis</i>-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-<i>cis</i>-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dimethyl-<i>trans</i>-3-hexene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '61847-78-7',
    'VFCHHMABGOYOQI-SOFGYWHQSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4-dimethyl-<i>trans</i>-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-<i>trans</i>-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-<i>trans</i>-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5-dimethyl-1-hexene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '6975-92-4',
    'ISZWTVCVSJVEOL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,5-dimethyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5-dimethyl-2-hexene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '3404-78-2',
    'VFZIUYUUQFYZBR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,5-dimethyl-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyl-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyl-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5-dimethyl-<i>cis</i>-3-hexene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '10557-44-5',
    'KNCMKWVOMRUHKZ-WAYWQWQTSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,5-dimethyl-<i>cis</i>-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyl-<i>cis</i>-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyl-<i>cis</i>-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5-dimethyl-<i>trans</i>-3-hexene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '692-70-6',
    'KNCMKWVOMRUHKZ-AATRIKPKSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,5-dimethyl-<i>trans</i>-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyl-<i>trans</i>-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyl-<i>trans</i>-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3-dimethyl-1-hexene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '3404-77-1',
    'RXYYKIMRVXDSFR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3-dimethyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4-dimethyl-1-hexene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '16745-94-1',
    'OWWRMMIWAOBBFK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4-dimethyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4-dimethyl-<i>cis</i>-2-hexene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '19550-81-3',
    'FMNLVKMLDPGPRY-ALCCZGGFSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4-dimethyl-<i>cis</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyl-<i>cis</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyl-<i>cis</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4-dimethyl-<i>trans</i>-2-hexene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '19550-82-4',
    'FMNLVKMLDPGPRY-FNORWQNLSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4-dimethyl-<i>trans</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyl-<i>trans</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyl-<i>trans</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4-dimethyl-<i>cis</i>-3-hexene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '19550-87-9',
    'XTUXVDJHGIEBAA-FPLPWBNLSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4-dimethyl-<i>cis</i>-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyl-<i>cis</i>-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyl-<i>cis</i>-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4-dimethyl-<i>trans</i>-3-hexene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '19550-88-0',
    'XTUXVDJHGIEBAA-BQYQJAHWSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4-dimethyl-<i>trans</i>-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyl-<i>trans</i>-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyl-<i>trans</i>-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,5-dimethyl-1-hexene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '7423-69-0',
    'FEZKAPRRVNNJTK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,5-dimethyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,5-dimethyl-<i>cis</i>-2-hexene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '66225-31-8',
    'BQAZYKYBFAMHPG-YVMONPNESA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,5-dimethyl-<i>cis</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethyl-<i>cis</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethyl-<i>cis</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,5-dimethyl-<i>trans</i>-2-hexene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '66225-12-5',
    'BQAZYKYBFAMHPG-VMPITWQZSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,5-dimethyl-<i>trans</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethyl-<i>trans</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethyl-<i>trans</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,4-dimethyl-1-hexene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '1647-08-1',
    'SUJVAMIXNUAJEY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,4-dimethyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,4-dimethyl-<i>cis</i>-2-hexene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '',
    'OQEVAISXHCRQGF-ALCCZGGFSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,4-dimethyl-<i>cis</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethyl-<i>cis</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethyl-<i>cis</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,4-dimethyl-<i>trans</i>-2-hexene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '19550-83-5',
    'OQEVAISXHCRQGF-FNORWQNLSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,4-dimethyl-<i>trans</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethyl-<i>trans</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethyl-<i>trans</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,5-dimethyl-1-hexene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '16106-59-5',
    'UFWIBUBEFUNVNI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,5-dimethyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,5-dimethyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,5-dimethyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,5-dimethyl-<i>cis</i>-2-hexene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '65036-71-7',
    'OAVNNZUEVHDCKP-WAYWQWQTSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,5-dimethyl-<i>cis</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,5-dimethyl-<i>cis</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,5-dimethyl-<i>cis</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,5-dimethyl-<i>trans</i>-2-hexene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '66225-14-7',
    'OAVNNZUEVHDCKP-AATRIKPKSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,5-dimethyl-<i>trans</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,5-dimethyl-<i>trans</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,5-dimethyl-<i>trans</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5,5-dimethyl-1-hexene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '7116-86-1',
    'KZJIOVQKSAOPOP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='5,5-dimethyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5,5-dimethyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5,5-dimethyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5,5-dimethyl-<i>cis</i>-2-hexene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '39761-61-0',
    'NWZJLSKAFZXSQH-WAYWQWQTSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='5,5-dimethyl-<i>cis</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5,5-dimethyl-<i>cis</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5,5-dimethyl-<i>cis</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5,5-dimethyl-<i>trans</i>-2-hexene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '39782-43-9',
    'NWZJLSKAFZXSQH-AATRIKPKSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='5,5-dimethyl-<i>trans</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5,5-dimethyl-<i>trans</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5,5-dimethyl-<i>trans</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-ethyl-1-hexene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '1632-16-2',
    'XTVRLCUJHGUXCP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-ethyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-ethyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-1-hexene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '3404-58-8',
    'OLGHJTHQWQKJQQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-3-hexene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '16789-51-8',
    'AUJLDZJNMXNESO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-3-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-<i>cis</i>-2-hexene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '36880-72-5',
    'QEMJIDSLEPYRLM-YVMONPNESA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-<i>cis</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-<i>cis</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-<i>cis</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-<i>trans</i>-2-hexene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '66225-15-8',
    'QEMJIDSLEPYRLM-VMPITWQZSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-<i>trans</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-<i>trans</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-<i>trans</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-ethyl-1-hexene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '16746-85-3',
    'OPMUAJRVOWSBTP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-ethyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-1-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-ethyl-<i>cis</i>-2-hexene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '54616-49-8',
    'STHONQMAWQLWLX-DAXSKMNVSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-ethyl-<i>cis</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-<i>cis</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-<i>cis</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-ethyl-<i>trans</i>-2-hexene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '19781-63-6',
    'STHONQMAWQLWLX-QPJJXVBHSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-ethyl-<i>trans</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-<i>trans</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-<i>trans</i>-2-hexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3-trimethyl-1-pentene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '560-23-6',
    'TUSBCMPNIOJUBX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,3-trimethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3-trimethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3-trimethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4-trimethyl-1-pentene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '565-76-4',
    'FAWUHEYSSPPNSH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,4-trimethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4-trimethyl-2-pentene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '565-77-5',
    'SZFRZEBLZFTODC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,4-trimethyl-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethyl-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethyl-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,4-trimethyl-1-pentene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '107-39-1',
    'FXNDIJDIPNCZQJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4,4-trimethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4-trimethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4-trimethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4-trimethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4-trimethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4-trimethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,4,4-trimethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,4-trimethyl-2-pentene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '107-40-4',
    'LAAVYEUJEMRIGF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4,4-trimethyl-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4-trimethyl-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4-trimethyl-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4-trimethyl-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4-trimethyl-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4-trimethyl-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,4,4-trimethyl-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3,4-trimethyl-1-pentene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '560-22-5',
    'LLFHCOGPDCJMKY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3,4-trimethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4-trimethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4-trimethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4,4-trimethyl-1-pentene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '564-03-4',
    'BOPVNOMJIDZBQB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4,4-trimethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,4-trimethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,4-trimethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4,4-trimethyl-2-pentene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '598-96-9',
    'FZQMZRXKWHQJAG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,4-trimethyl-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4,4-trimethyl-<i>cis</i>-2-pentene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '39761-64-3',
    'FZQMZRXKWHQJAG-SREVYHEPSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4,4-trimethyl-<i>cis</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,4-trimethyl-<i>cis</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,4-trimethyl-<i>cis</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4,4-trimethyl-<i>trans</i>-2-pentene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '39761-57-4',
    'FZQMZRXKWHQJAG-VOTSOKGWSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4,4-trimethyl-<i>trans</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,4-trimethyl-<i>trans</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,4-trimethyl-<i>trans</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-3-ethyl-1-pentene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '19780-66-6',
    'HPHHYSWOBXEIRG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-3-ethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-ethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-ethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-3-ethyl-2-pentene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '19780-67-7',
    'FQYUGAXHZSQHMU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-3-ethyl-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-ethyl-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-ethyl-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-2-ethyl-1-pentene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '3404-67-9',
    'YXLCVBVDFKWWRW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-2-ethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-ethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-ethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-3-ethyl-1-pentene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '6196-60-7',
    'PHHHEKOJKDYRIN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-3-ethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-3-ethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-3-ethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-2-ethyl-1-pentene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '3404-80-6',
    'TVBQWTDYXVGWJL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-2-ethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-ethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-ethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-3-ethyl-1-pentene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '61847-80-1',
    'DTNALCAUPPLROB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-3-ethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-3-ethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-3-ethyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-3-ethyl-<i>cis</i>-2-pentene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '42067-48-1',
    'DSTFDBMUTNIZGD-YVMONPNESA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-3-ethyl-<i>cis</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-3-ethyl-<i>cis</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-3-ethyl-<i>cis</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-3-ethyl-<i>trans</i>-2-pentene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '42067-49-2',
    'DSTFDBMUTNIZGD-VMPITWQZSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-3-ethyl-<i>trans</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-3-ethyl-<i>trans</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-3-ethyl-<i>trans</i>-2-pentene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-propyl-1-pentene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '15918-08-8',
    'FYUUBXZYRPRIHC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-propyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-isopropyl-1-pentene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '16746-02-4',
    'QOUCFWFZPKWYRE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-isopropyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-isopropyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-isopropyl-1-pentene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3-dimethyl-2-ethyl-1-butene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '18231-53-3',
    'KQRPZENSXZIOQO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3-dimethyl-2-ethyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-2-ethyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-2-ethyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-2-isopropyl-1-butene',
    'C<sub>8</sub>H<sub>16</sub>',
    '',
    '111823-35-9',
    'GIBPFTYFAOOKOV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-2-isopropyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-isopropyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-isopropyl-1-butene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-nonene',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '124-11-8',
    'JRZJOMJEPLMPRA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-nonene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-nonene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-nonene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-nonene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-nonene'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-nonene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nonene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nonene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nonene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nonene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nonene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nonene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nonene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nonene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-nonene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-nonene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-nonene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-1-octene',
    'C<sub>9</sub>H<sub>18</sub>',
    '',
    '4588-18-5',
    'FBEDQPGLIKZGIN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-1-octene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-octene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-octene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-decene',
    'C<sub>10</sub>H<sub>20</sub>',
    '',
    '872-05-9',
    'AFFLGGQVNFXPEV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-decene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-decene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-decene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-decene'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-decene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-decene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-decene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-decene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-decene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-decene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-1-nonene',
    'C<sub>10</sub>H<sub>20</sub>',
    '',
    '2980-71-4',
    'YLZQHQUVNZVGOK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-1-nonene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-nonene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-nonene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-undecene',
    'C<sub>11</sub>H<sub>22</sub>',
    '',
    '821-95-4',
    'DCTOHCCUXLBQMS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-undecene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-undecene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-undecene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-undecene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-undecene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-undecene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-undecene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-1-decene',
    'C<sub>11</sub>H<sub>22</sub>',
    '',
    '13151-27-4',
    'HLMACKQLXSEXIY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-1-decene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-decene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-decene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-dodecene',
    'C<sub>12</sub>H<sub>24</sub>',
    '',
    '112-41-4',
    'CRSBERNSMYQZNG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-dodecene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-dodecene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-dodecene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-dodecene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-dodecene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-dodecene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-dodecene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-1-undecene',
    'C<sub>12</sub>H<sub>24</sub>',
    '',
    '18516-37-5',
    'SJVKHZYVCVKEGM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-1-undecene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-undecene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,4,6,6-pentamethyl-3-heptene',
    'C<sub>12</sub>H<sub>24</sub>',
    '',
    '123-48-8',
    'NBUMCEJRJRRLCA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,6,6-pentamethyl-3-heptene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,6,6-pentamethyl-3-heptene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,6,6-pentamethyl-3-heptene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,6,6-pentamethyl-3-heptene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-tridecene',
    'C<sub>13</sub>H<sub>26</sub>',
    '',
    '2437-56-1',
    'VQOXUMQBYILCKR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-tridecene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-tridecene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-tridecene'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-tridecene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-tridecene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-tridecene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-tridecene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-tridecene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-1-dodecene',
    'C<sub>13</sub>H<sub>26</sub>',
    '',
    '16435-49-7',
    'PWRBDKMPAZFCSV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-1-dodecene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-dodecene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-dodecene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-tetradecene',
    'C<sub>14</sub>H<sub>28</sub>',
    '',
    '1120-36-1',
    'HFDVRLIODXPAHB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-tetradecene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-tetradecene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-tetradecene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-tetradecene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-tetradecene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-tetradecene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-tetradecene',
    'C<sub>14</sub>H<sub>28</sub>',
    '',
    '638-60-8',
    'OBDUMNZXAIUUTH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-tetradecene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-tetradecene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-tetradecene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-1-tridecene',
    'C<sub>14</sub>H<sub>28</sub>',
    '',
    '18094-01-4',
    'VNBHQOHLCULRDN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-1-tridecene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-tridecene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-tridecene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-pentadecene',
    'C<sub>15</sub>H<sub>30</sub>',
    '',
    '13360-61-7',
    'PJLHTVIBELQURV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-pentadecene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-pentadecene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentadecene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentadecene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentadecene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-pentadecene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-1-tetradecene',
    'C<sub>15</sub>H<sub>30</sub>',
    '',
    '52254-38-3',
    'WSNMNSLVXDWAFZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-1-tetradecene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-tetradecene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-tetradecene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-hexadecene',
    'C<sub>16</sub>H<sub>32</sub>',
    '',
    '629-73-2',
    'GQEZCXVZFLOKMC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-hexadecene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexadecene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexadecene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-hexadecene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-1-pentadecene',
    'C<sub>16</sub>H<sub>32</sub>',
    '',
    '29833-69-0',
    'FWQJRKLMXMTXDY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-1-pentadecene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-pentadecene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-pentadecene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dimethylpentadecane',
    'C<sub>17</sub>H<sub>36</sub>',
    '',
    '61868-07-3',
    'TXGHMPJBDYZJLF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4-dimethylpentadecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethylpentadecane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethylpentadecane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-butadiene',
    'C<sub>4</sub>H<sub>6</sub>',
    '',
    '590-19-2',
    'QNRMTGGDHLBXQZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,2-butadiene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-butadiene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-butadiene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-butadiene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-butadiene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-butadiene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3-butadiene',
    'C<sub>4</sub>H<sub>6</sub>',
    '',
    '106-99-0',
    'KAKZBPTYRLMSJV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;4</sup>',
    '3200',
    'L',
    (SELECT id from species WHERE iupac='1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;4</sup>',
    '4500',
    'L',
    (SELECT id from species WHERE iupac='1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='3066'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;4</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3600',
    'Q',
    (SELECT id from species WHERE iupac='1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-Test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4100',
    '?',
    (SELECT id from species WHERE iupac='1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-1,2-butadiene',
    'C<sub>5</sub>H<sub>8</sub>',
    '2-methyl-2,3-butadiene',
    '598-25-4',
    'PAKGDPSCXSUALC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-1,2-butadiene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1,2-butadiene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1,2-butadiene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1,2-butadiene'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-methyl-1,2-butadiene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-1,3-butadiene',
    'C<sub>5</sub>H<sub>8</sub>',
    'isoprene',
    '78-79-5',
    'RRHGJUQNOFWUDK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '2700',
    'L',
    (SELECT id from species WHERE iupac='2-methyl-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2-methyl-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methyl-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='3423'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '4400',
    'M',
    (SELECT id from species WHERE iupac='2-methyl-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='3008'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '4400',
    'M',
    (SELECT id from species WHERE iupac='2-methyl-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='3564'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methyl-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='1922'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at291K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='3678'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3678',
    '3678', 'Values for the Henry''s law constants shown in Fig.&nbsp;3 of Martins et&nbsp;al. (2017) were obtained from Sim&#227;o Pinho (personal communication, 2022).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3678'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='2124'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methyl-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methyl-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methyl-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-pentadiene',
    'C<sub>5</sub>H<sub>8</sub>',
    '',
    '591-95-7',
    'LVMTVPFRTKXRPH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,2-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3-pentadiene',
    'C<sub>5</sub>H<sub>8</sub>',
    '',
    '504-60-9',
    'PMJHHCWVYXUKFD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>trans</i>-1,3-pentadiene',
    'C<sub>5</sub>H<sub>8</sub>',
    '',
    '2004-70-8',
    'PMJHHCWVYXUKFD-SNAWJCMRSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,3-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,3-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,3-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,3-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,3-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>cis</i>-1,3-pentadiene',
    'C<sub>5</sub>H<sub>8</sub>',
    '',
    '1574-41-0',
    'PMJHHCWVYXUKFD-PLNGDYQASA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,3-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,3-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,3-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,3-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4-pentadiene',
    'C<sub>5</sub>H<sub>8</sub>',
    '',
    '591-93-5',
    'QYZLKGVUSQXAMU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,4-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,4-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,4-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,4-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,4-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-pentadiene',
    'C<sub>5</sub>H<sub>8</sub>',
    '',
    '591-96-8',
    'PODAMDNJNMAKAZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-hexadiene',
    'C<sub>6</sub>H<sub>10</sub>',
    '',
    '592-44-9',
    'XIAJQOBRHVKGSP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,2-hexadiene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-hexadiene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-hexadiene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>cis</i>-1,3-hexadiene',
    'C<sub>6</sub>H<sub>10</sub>',
    '',
    '14596-92-0',
    'AHAREKHAZNPPMI-WAYWQWQTSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,3-hexadiene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,3-hexadiene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,3-hexadiene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>trans</i>-1,3-hexadiene',
    'C<sub>6</sub>H<sub>10</sub>',
    '',
    '20237-34-7',
    'AHAREKHAZNPPMI-AATRIKPKSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,3-hexadiene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,3-hexadiene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,3-hexadiene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4-hexadiene',
    'C<sub>6</sub>H<sub>10</sub>',
    '',
    '592-45-0',
    'PRBHEGAFLDMLAL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-hexadiene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>cis</i>-1,4-hexadiene',
    'C<sub>6</sub>H<sub>10</sub>',
    '',
    '7318-67-4',
    'PRBHEGAFLDMLAL-XQRVVYSFSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,4-hexadiene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,4-hexadiene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,4-hexadiene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>trans</i>-1,4-hexadiene',
    'C<sub>6</sub>H<sub>10</sub>',
    '',
    '7319-00-8',
    'PRBHEGAFLDMLAL-GQCTYLIASA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,4-hexadiene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,4-hexadiene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,4-hexadiene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,5-hexadiene',
    'C<sub>6</sub>H<sub>10</sub>',
    '',
    '592-42-7',
    'PYGSKMBEVAICCR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,5-hexadiene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,5-hexadiene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,5-hexadiene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,5-hexadiene'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,5-hexadiene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,5-hexadiene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,5-hexadiene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,5-hexadiene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,5-hexadiene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,5-hexadiene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,5-hexadiene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,5-hexadiene'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,5-hexadiene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,5-hexadiene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,5-hexadiene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,5-hexadiene'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,5-hexadiene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,5-hexadiene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-hexadiene',
    'C<sub>6</sub>H<sub>10</sub>',
    '',
    '592-49-4',
    'DPUXQWOMYBMHRN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3-hexadiene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-hexadiene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-hexadiene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>cis</i>-2,<i>cis</i>-4-hexadiene',
    'C<sub>6</sub>H<sub>10</sub>',
    '',
    '6108-61-8',
    'APPOKADJQUIAHP-GLIMQPGKSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>cis</i>-2,<i>cis</i>-4-hexadiene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-2,<i>cis</i>-4-hexadiene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-2,<i>cis</i>-4-hexadiene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>cis</i>-2,<i>trans</i>-4-hexadiene',
    'C<sub>6</sub>H<sub>10</sub>',
    '',
    '5194-50-3',
    'APPOKADJQUIAHP-CIIODKQPSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>cis</i>-2,<i>trans</i>-4-hexadiene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-2,<i>trans</i>-4-hexadiene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-2,<i>trans</i>-4-hexadiene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='<i>cis</i>-2,<i>trans</i>-4-hexadiene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>trans</i>-2,<i>trans</i>-4-hexadiene',
    'C<sub>6</sub>H<sub>10</sub>',
    '',
    '5194-51-4',
    'APPOKADJQUIAHP-GGWOSOGESA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>trans</i>-2,<i>trans</i>-4-hexadiene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-2,<i>trans</i>-4-hexadiene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-2,<i>trans</i>-4-hexadiene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='<i>trans</i>-2,<i>trans</i>-4-hexadiene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-1,4-pentadiene',
    'C<sub>6</sub>H<sub>10</sub>',
    '',
    '763-30-4',
    'DRWYRROCDFQZQF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-1,4-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1,4-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1,4-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-1,<i>cis</i>-3-pentadiene',
    'C<sub>6</sub>H<sub>10</sub>',
    '',
    '1501-60-6',
    'RCJMVGJKROQDCB-PLNGDYQASA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-1,<i>cis</i>-3-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1,<i>cis</i>-3-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1,<i>cis</i>-3-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-1,<i>trans</i>-3-pentadiene',
    'C<sub>6</sub>H<sub>10</sub>',
    '',
    '926-54-5',
    'RCJMVGJKROQDCB-SNAWJCMRSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-1,<i>trans</i>-3-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1,<i>trans</i>-3-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1,<i>trans</i>-3-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-2,3-pentadiene',
    'C<sub>6</sub>H<sub>10</sub>',
    '',
    '3043-33-2',
    'JWMDOGMKTRMFDS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-2,3-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2,3-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2,3-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-1,2-pentadiene',
    'C<sub>6</sub>H<sub>10</sub>',
    '',
    '7417-48-3',
    'INFFCVIZNSUFGK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-1,2-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1,2-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1,2-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-1,<i>cis</i>-3-pentadiene',
    'C<sub>6</sub>H<sub>10</sub>',
    '',
    '2787-45-3',
    'BOGRNZQRTNVZCZ-WAYWQWQTSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-1,<i>cis</i>-3-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1,<i>cis</i>-3-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1,<i>cis</i>-3-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-1,<i>trans</i>-3-pentadiene',
    'C<sub>6</sub>H<sub>10</sub>',
    '',
    '2787-43-1',
    'BOGRNZQRTNVZCZ-AATRIKPKSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-1,<i>trans</i>-3-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1,<i>trans</i>-3-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1,<i>trans</i>-3-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-1,4-pentadiene',
    'C<sub>6</sub>H<sub>10</sub>',
    '',
    '1115-08-8',
    'IKQUUYYDRTYXAP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-1,4-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1,4-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1,4-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-1,2-pentadiene',
    'C<sub>6</sub>H<sub>10</sub>',
    '',
    '13643-05-5',
    'CAAAXQFHDYHTTC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-1,2-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1,2-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1,2-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-1,3-pentadiene',
    'C<sub>6</sub>H<sub>10</sub>',
    '',
    '926-56-7',
    'CJSBUWDGPXGFGA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-1,3-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1,3-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1,3-pentadiene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-ethyl-1,3-butadiene',
    'C<sub>6</sub>H<sub>10</sub>',
    '',
    '3404-63-5',
    'IGLWCQMNTGCUBB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-ethyl-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethyl-1,3-butadiene',
    'C<sub>6</sub>H<sub>10</sub>',
    '',
    '513-81-5',
    'SDJHPPZKZZWAKF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3-dimethyl-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3-dimethyl-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3-dimethyl-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3-dimethyl-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3-dimethyl-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3-dimethyl-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3-dimethyl-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,6-heptadiene',
    'C<sub>7</sub>H<sub>12</sub>',
    '',
    '3070-53-9',
    'GEAWFZNTIFJMHR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,6-heptadiene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,6-heptadiene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,6-heptadiene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5-dimethyl-2,4-hexadiene',
    'C<sub>8</sub>H<sub>14</sub>',
    '',
    '764-13-6',
    'DZPCYXCBXGQBRN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,5-dimethyl-2,4-hexadiene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3766_M2',
    '3766', 'Ebert et&nbsp;al. (2023) present "curated experimental" Henry''s law constants from the literature but do not provide any references. It is only mentioned that the value is from multiple sources and obtained from experimental vapor pressure and water solubility.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methylcyclopropene',
    'C<sub>4</sub>H<sub>6</sub>',
    '',
    '3100-04-7',
    'SHDPRTQPPWIEJG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methylcyclopropene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cyclopentene',
    'C<sub>5</sub>H<sub>8</sub>',
    '',
    '142-29-0',
    'LPIQUOYDBNQMRZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;4</sup>',
    '3300',
    'L',
    (SELECT id from species WHERE iupac='cyclopentene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='cyclopentene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;4</sup>',
    '2200',
    'M',
    (SELECT id from species WHERE iupac='cyclopentene'),
    (SELECT id from literature WHERE bibtexkey='2923'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cyclopentene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cyclopentene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cyclopentene'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cyclopentene'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cyclopentene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='cyclopentene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopentene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopentene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopentene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopentene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopentene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopentene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopentene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3400',
    'Q',
    (SELECT id from species WHERE iupac='cyclopentene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopentene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopentene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopentene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopentene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopentene'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopentene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2200',
    '?',
    (SELECT id from species WHERE iupac='cyclopentene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cyclopentene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cyclopentene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cyclohexene',
    'C<sub>6</sub>H<sub>10</sub>',
    '',
    '110-83-8',
    'HGCIXCUEYOPUTN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;4</sup>',
    '3600',
    'L',
    (SELECT id from species WHERE iupac='cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;4</sup>',
    '2000',
    'M',
    (SELECT id from species WHERE iupac='cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='2923'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='622'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3700',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3600',
    '?',
    (SELECT id from species WHERE iupac='cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methylcyclopentene',
    'C<sub>6</sub>H<sub>10</sub>',
    '',
    '693-89-0',
    'ATQUFXWBVZUTKO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methylcyclopentene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cycloheptene',
    'C<sub>7</sub>H<sub>12</sub>',
    '',
    '628-92-2',
    'ZXIJMRYMVAMXQP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='cycloheptene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='cycloheptene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cycloheptene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cycloheptene'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cycloheptene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methylcyclohexene',
    'C<sub>6</sub>H<sub>9</sub>CH<sub>3</sub>',
    '',
    '591-49-1',
    'CTMHWPIWNRWQEG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-methylcyclohexene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-methylcyclohexene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-methylcyclohexene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-methylcyclohexene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methylcyclohexene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methylcyclohexene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methylcyclohexene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methylcyclohexene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methylcyclohexene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methylcyclohexene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methylcyclohexene'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cyclooctene',
    'C<sub>8</sub>H<sub>14</sub>',
    '',
    '931-88-4',
    'URYYVOIYTNXXBN-UPHRSURJSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;4</sup>',
    '4300',
    'L',
    (SELECT id from species WHERE iupac='cyclooctene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;4</sup>',
    '4300',
    'M',
    (SELECT id from species WHERE iupac='cyclooctene'),
    (SELECT id from literature WHERE bibtexkey='2936'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2936-931-88-4-ABC',
    '2936', 'The data from Dohányosová et&nbsp;al. (2004) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;169.70973 +10843.51763/T +21.91320&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2936-931-88-4-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cyclooctene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4400',
    'Q',
    (SELECT id from species WHERE iupac='cyclooctene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4400',
    '?',
    (SELECT id from species WHERE iupac='cyclooctene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,2,3,3-pentamethyl-2,3,4,5,6,7-hexahydro-1H-indene',
    'C<sub>14</sub>H<sub>24</sub>',
    '',
    '33704-59-5',
    'CDEGOUYLXTUDAU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,3,3-pentamethyl-2,3,4,5,6,7-hexahydro-1H-indene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,3,3-pentamethyl-2,3,4,5,6,7-hexahydro-1H-indene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,3,3-pentamethyl-2,3,4,5,6,7-hexahydro-1H-indene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,3,3-pentamethyl-2,3,4,5,6,7-hexahydro-1H-indene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3-cyclopentadiene',
    'C<sub>5</sub>H<sub>6</sub>',
    '',
    '542-92-7',
    'ZSWFCLXCOIISFI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,3-cyclopentadiene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3-cyclopentadiene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3-cyclopentadiene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-cyclopentadiene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-cyclopentadiene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3-cyclohexadiene',
    'C<sub>6</sub>H<sub>8</sub>',
    '',
    '592-57-4',
    'MGNZXYYWBUKAII-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,3-cyclohexadiene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-cyclohexadiene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-cyclohexadiene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-cyclohexadiene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,3-cyclohexadiene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4-cyclohexadiene',
    'C<sub>6</sub>H<sub>8</sub>',
    '1,4-dihydrobenzene',
    '628-41-1',
    'UVJHQYIOXKWHFD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '4000',
    'L',
    (SELECT id from species WHERE iupac='1,4-cyclohexadiene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '3800',
    'L',
    (SELECT id from species WHERE iupac='1,4-cyclohexadiene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-cyclohexadiene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-cyclohexadiene'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1,4-cyclohexadiene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-cyclohexadiene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-cyclohexadiene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-cyclohexadiene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-cyclohexadiene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-cyclohexadiene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3-cycloheptadiene',
    'C<sub>7</sub>H<sub>10</sub>',
    '',
    '4054-38-0',
    'GWYPDXLJACEENP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-cycloheptadiene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3,5-cycloheptatriene',
    'C<sub>7</sub>H<sub>8</sub>',
    '',
    '544-25-2',
    'CHVJITGCYZJHLR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '3900',
    'L',
    (SELECT id from species WHERE iupac='1,3,5-cycloheptatriene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3,5-cycloheptatriene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3,5-cycloheptatriene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2611_pc_problem'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3,5-cycloheptatriene'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3,5-cycloheptatriene'),
    (SELECT id from literature WHERE bibtexkey='1910'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,3,5-cycloheptatriene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-cycloheptatriene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-cycloheptatriene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-cycloheptatriene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-cycloheptatriene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-cycloheptatriene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-cycloheptatriene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-cycloheptatriene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,3,5-cycloheptatriene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,3,5-cycloheptatriene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,5-cyclooctadiene',
    'C<sub>8</sub>H<sub>12</sub>',
    '',
    '111-78-4',
    'VYXHVRARDIDEHS-QGTKBVGQSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,5-cyclooctadiene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-ethenylcyclohexene',
    'C<sub>8</sub>H<sub>12</sub>',
    '',
    '2622-21-1',
    'SDRZFSPCVYEJTP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethenylcyclohexene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-ethenylcyclohexene',
    'C<sub>8</sub>H<sub>12</sub>',
    '4-vinylcyclohexene',
    '100-40-3',
    'BBDKZWKEPDTENS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='4-ethenylcyclohexene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-ethenylcyclohexene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-ethenylcyclohexene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethenylcyclohexene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethenylcyclohexene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethenylcyclohexene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethenylcyclohexene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethenylcyclohexene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethenylcyclohexene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethenylcyclohexene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethenylcyclohexene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-ethenylcyclohexene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3,5,7-cyclooctatetraene',
    'C<sub>8</sub>H<sub>8</sub>',
    '',
    '629-20-9',
    'KDUIUFJBNGTBMD-DLMDZQPMSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5,7-cyclooctatetraene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3a,4,7,7a-tetrahydro-4,7-methano-1H-indene',
    'C<sub>10</sub>H<sub>12</sub>',
    'dicyclopentadiene',
    '77-73-6',
    'HECLRDQVFMWTQS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3a,4,7,7a-tetrahydro-4,7-methano-1H-indene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3a,4,7,7a-tetrahydro-4,7-methano-1H-indene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,5,9-cyclododecatriene',
    'C<sub>12</sub>H<sub>18</sub>',
    '',
    '4904-61-4',
    'ZOLLIQAKMYWTBR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,5,9-cyclododecatriene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(E,E,Z)-1,5,9-cyclododecatriene',
    'C<sub>12</sub>H<sub>18</sub>',
    '',
    '706-31-0',
    'ZOLLIQAKMYWTBR-RYMQXAEESA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkenes and cycloalkenes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(E,E,Z)-1,5,9-cyclododecatriene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3766_D2',
    '3766', 'Ebert et&nbsp;al. (2023) present "curated experimental" Henry''s law constants from the literature but do not provide any references. It is only mentioned that the value is from a single database or data collection and obtained from experimental vapor pressure and water solubility.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Aliphatic alkynes',
    (SELECT id from categories WHERE catname='Hydrocarbons (C, H)'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyne',
    'C<sub>2</sub>H<sub>2</sub>',
    'acetylene',
    '74-86-2',
    'HSFWRNGVRCDJHI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;4</sup>',
    '1800',
    'L',
    (SELECT id from species WHERE iupac='ethyne'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;4</sup>',
    '1800',
    'L',
    (SELECT id from species WHERE iupac='ethyne'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;4</sup>',
    '1700',
    'L',
    (SELECT id from species WHERE iupac='ethyne'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;4</sup>',
    '1800',
    'L',
    (SELECT id from species WHERE iupac='ethyne'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;4</sup>',
    '1700',
    'L',
    (SELECT id from species WHERE iupac='ethyne'),
    (SELECT id from literature WHERE bibtexkey='3528'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;4</sup>',
    '1800',
    'L',
    (SELECT id from species WHERE iupac='ethyne'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;4</sup>',
    '1800',
    'L',
    (SELECT id from species WHERE iupac='ethyne'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;4</sup>',
    '2500',
    'M',
    (SELECT id from species WHERE iupac='ethyne'),
    (SELECT id from literature WHERE bibtexkey='3751'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethyne'),
    (SELECT id from literature WHERE bibtexkey='3750'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3750',
    '3750', 'Approximate value extracted from Fig.&nbsp;1 of Maillard and Rosenthal (1952).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3750'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethyne'),
    (SELECT id from literature WHERE bibtexkey='3715'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at311K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;4</sup>',
    '1900',
    'M',
    (SELECT id from species WHERE iupac='ethyne'),
    (SELECT id from literature WHERE bibtexkey='3748'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethyne'),
    (SELECT id from literature WHERE bibtexkey='3749'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;4</sup>',
    '2000',
    'M',
    (SELECT id from species WHERE iupac='ethyne'),
    (SELECT id from literature WHERE bibtexkey='862'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethyne'),
    (SELECT id from literature WHERE bibtexkey='3747'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3747',
    '', 'The same article was also published in <i>Monatshefte f&#252;r Chemie</i> 23, 489-501 (1902).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyne'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyne'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyne'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyne'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;5</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='ethyne'),
    (SELECT id from literature WHERE bibtexkey='766'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethyne'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;4</sup>',
    '1800',
    'X',
    (SELECT id from species WHERE iupac='ethyne'),
    (SELECT id from literature WHERE bibtexkey='schoen23'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'from3528',
    '3528', 'Value given here as quoted by Fogg et&nbsp;al. (2002).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3528'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethyne'),
    (SELECT id from literature WHERE bibtexkey='vitovec68'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3528'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;4</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='ethyne'),
    (SELECT id from literature WHERE bibtexkey='529'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyne'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyne'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyne'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyne'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyne'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyne'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyne'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyne'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '1800',
    'Q',
    (SELECT id from species WHERE iupac='ethyne'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyne'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyne'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyne'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '1800',
    '?',
    (SELECT id from species WHERE iupac='ethyne'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethyne'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;4</sup>',
    '1800',
    '?',
    (SELECT id from species WHERE iupac='ethyne'),
    (SELECT id from literature WHERE bibtexkey='3811'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;4</sup>',
    '1800',
    '?',
    (SELECT id from species WHERE iupac='ethyne'),
    (SELECT id from literature WHERE bibtexkey='379'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0379-74-86-2-ABC',
    '379', 'The data from Dean and Lange (1999) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;143.25283 +7542.89338/T +19.33269&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0379-74-86-2-ABC'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='379'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethyne'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethyne'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propyne',
    'CH<sub>3</sub>CCH',
    '',
    '74-99-7',
    'MWWATHDPGQKSAR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;4</sup>',
    '2400',
    'L',
    (SELECT id from species WHERE iupac='propyne'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='propyne'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='propyne'),
    (SELECT id from literature WHERE bibtexkey='3924'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;4</sup>',
    '2500',
    'M',
    (SELECT id from species WHERE iupac='propyne'),
    (SELECT id from literature WHERE bibtexkey='2551'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '2000',
    'M',
    (SELECT id from species WHERE iupac='propyne'),
    (SELECT id from literature WHERE bibtexkey='3100'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propyne'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propyne'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propyne'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propyne'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='propyne'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyne'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyne'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyne'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyne'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyne'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyne'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2100',
    'Q',
    (SELECT id from species WHERE iupac='propyne'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyne'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyne'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyne'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyne'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2400',
    '?',
    (SELECT id from species WHERE iupac='propyne'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propyne'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propyne'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propyne'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='propyne'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='190'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-butyne',
    'C<sub>2</sub>H<sub>5</sub>CCH',
    'ethylacetylene',
    '107-00-6',
    'KDKYADYSIPSCCQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-butyne'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '1900',
    'L',
    (SELECT id from species WHERE iupac='1-butyne'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-butyne'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;4</sup>',
    '1900',
    'L',
    (SELECT id from species WHERE iupac='1-butyne'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-butyne'),
    (SELECT id from literature WHERE bibtexkey='3924'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;4</sup>',
    '1900',
    'M',
    (SELECT id from species WHERE iupac='1-butyne'),
    (SELECT id from literature WHERE bibtexkey='2551'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-butyne'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-butyne'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-butyne'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-butyne'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butyne'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butyne'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butyne'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butyne'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2500',
    'Q',
    (SELECT id from species WHERE iupac='1-butyne'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butyne'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butyne'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butyne'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butyne'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '1900',
    '?',
    (SELECT id from species WHERE iupac='1-butyne'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-butyne'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-butyne'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-butyne'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='1-butyne'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3500-107-00-6',
    '3500', 'Incorrect data are given by Burkholder et&nbsp;al. (2019) for 1-butyne. The number in their table should probably be 0.0569, not 0.569.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3500-107-00-6'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-butyne',
    'C<sub>4</sub>H<sub>6</sub>',
    'dimethylacetylene',
    '503-17-3',
    'XNMQEEKYCVKGBD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-butyne'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butyne'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butyne'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butyne'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-butyne'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-pentyne',
    'C<sub>3</sub>H<sub>7</sub>CCH',
    '',
    '627-19-0',
    'IBXNCJKFFQIKKY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-pentyne'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-pentyne'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-pentyne'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-pentyne'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-pentyne'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-pentyne'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-pentyne'),
    (SELECT id from literature WHERE bibtexkey='2388'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-pentyne'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-pentyne'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentyne'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentyne'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentyne'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentyne'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentyne'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentyne'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentyne'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentyne'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentyne'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentyne'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentyne'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentyne'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-pentyne'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-pentyne'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-pentyne'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-pentyne',
    'C<sub>5</sub>H<sub>8</sub>',
    '',
    '627-21-4',
    'NKTDTMONXHODTI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-pentyne'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentyne'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentyne'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentyne'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentyne'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentyne'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-pentyne'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-1-butyne',
    'C<sub>5</sub>H<sub>8</sub>',
    '',
    '598-23-2',
    'USCSRAJGJYMJFZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-1-butyne'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-butyne'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-butyne'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-methyl-1-butyne'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-hexyne',
    'C<sub>4</sub>H<sub>9</sub>CCH',
    '',
    '693-02-7',
    'CGHIBGNXEGJPQZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-hexyne'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-hexyne'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hexyne'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hexyne'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hexyne'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hexyne'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hexyne'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-hexyne'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexyne'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexyne'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexyne'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexyne'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexyne'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexyne'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexyne'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexyne'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexyne'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexyne'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-Test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexyne'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexyne'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-hexyne'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-hexyne'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-hexyne'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-hexyne',
    'C<sub>6</sub>H<sub>10</sub>',
    '',
    '764-35-2',
    'MELUCTCJOARQQG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-hexyne'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hexyne'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hexyne'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hexyne'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hexyne'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hexyne'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-hexyne'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-hexyne',
    'C<sub>6</sub>H<sub>10</sub>',
    '',
    '928-49-4',
    'DQQNMIPXXNPGCV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='3-hexyne'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-hexyne'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hexyne'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hexyne'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hexyne'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hexyne'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hexyne'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-hexyne'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-1-pentyne',
    'C<sub>6</sub>H<sub>10</sub>',
    '',
    '922-59-8',
    'PLHJCCHSCFNKCC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-1-pentyne'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-pentyne'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-pentyne'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-1-pentyne',
    'C<sub>6</sub>H<sub>10</sub>',
    '',
    '7154-75-8',
    'OXRWICUICBZVAE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-1-pentyne'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1-pentyne'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1-pentyne'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-2-pentyne',
    'C<sub>6</sub>H<sub>10</sub>',
    '',
    '21020-27-9',
    'SLMFWJQZLPEDDU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-2-pentyne'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-pentyne'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-pentyne'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3-dimethyl-1-butyne',
    'C<sub>6</sub>H<sub>10</sub>',
    '',
    '917-92-0',
    'PPWNCLVNXGCGAF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3-dimethyl-1-butyne'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-1-butyne'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-1-butyne'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-heptyne',
    'C<sub>5</sub>H<sub>11</sub>CCH',
    '',
    '628-71-7',
    'YVXHZKKCZYLQOP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-heptyne'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-heptyne'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-heptyne'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-heptyne'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-heptyne'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-heptyne'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-heptyne'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-heptyne'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-heptyne'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-heptyne'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-heptyne'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-heptyne'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-heptyne'),
    (SELECT id from literature WHERE bibtexkey='3512'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-heptyne'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-heptyne'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-heptyne'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-heptyne'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-heptyne'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-heptyne'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-heptyne'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-heptyne'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-heptyne',
    'C<sub>7</sub>H<sub>12</sub>',
    '',
    '1119-65-9',
    'AMSFEMSYKQQCHL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2-heptyne'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-heptyne'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-heptyne'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-heptyne'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-heptyne',
    'C<sub>7</sub>H<sub>12</sub>',
    '',
    '2586-89-2',
    'KLYHSJRCIZOUHE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-heptyne'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-heptyne'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-heptyne'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-3-hexyne',
    'C<sub>7</sub>H<sub>12</sub>',
    '',
    '36566-80-0',
    'POBOUPFSQKXZFZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2-methyl-3-hexyne'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-3-hexyne'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-hexyne'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-hexyne'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-1-hexyne',
    'C<sub>7</sub>H<sub>12</sub>',
    '',
    '40276-93-5',
    'OPZULQHRFNTFFZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-1-hexyne'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-hexyne'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-hexyne'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-1-hexyne',
    'C<sub>7</sub>H<sub>12</sub>',
    '',
    '52713-81-2',
    'YFZSGTDENCTWGW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-1-hexyne'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1-hexyne'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1-hexyne'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-2-hexyne',
    'C<sub>7</sub>H<sub>12</sub>',
    '',
    '20198-49-6',
    'ABEXZFRJQJSEBW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-2-hexyne'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-hexyne'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-methyl-1-hexyne',
    'C<sub>7</sub>H<sub>12</sub>',
    '',
    '2203-80-7',
    'HKNANEMUCJGPMS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='5-methyl-1-hexyne'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-1-hexyne'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-1-hexyne'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-methyl-2-hexyne',
    'C<sub>7</sub>H<sub>12</sub>',
    '',
    '53566-37-3',
    'SVGAHRUSRQTQES-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='5-methyl-2-hexyne'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-2-hexyne'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-2-hexyne'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3-dimethyl-1-pentyne',
    'C<sub>7</sub>H<sub>12</sub>',
    '',
    '918-82-1',
    'KQIIKSQUHGGYCU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3-dimethyl-1-pentyne'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-1-pentyne'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-1-pentyne'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4-dimethyl-1-pentyne',
    'C<sub>7</sub>H<sub>12</sub>',
    '',
    '61064-08-2',
    'JDQKSTIAVKXRSK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4-dimethyl-1-pentyne'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyl-1-pentyne'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyl-1-pentyne'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,4-dimethyl-1-pentyne',
    'C<sub>7</sub>H<sub>12</sub>',
    '',
    '13361-63-2',
    'KHBYKPSFBHWBJQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,4-dimethyl-1-pentyne'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethyl-1-pentyne'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethyl-1-pentyne'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,4-dimethyl-2-pentyne',
    'C<sub>7</sub>H<sub>12</sub>',
    '',
    '999-78-0',
    'FOALCTWKQSWRST-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,4-dimethyl-2-pentyne'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethyl-2-pentyne'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethyl-2-pentyne'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-1-pentyne',
    'C<sub>7</sub>H<sub>12</sub>',
    '',
    '21020-26-8',
    'WGWGXWSBPXLXTA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-1-pentyne'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-1-pentyne'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-1-pentyne'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-octyne',
    'C<sub>6</sub>H<sub>13</sub>CCH',
    '',
    '629-05-0',
    'UMIPWJGWASORKV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-octyne'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-octyne'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-octyne'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-octyne'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-octyne'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-octyne'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-octyne'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octyne'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octyne'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octyne'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octyne'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octyne'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octyne'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octyne'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octyne'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octyne'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-octyne'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-octyne'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-octyne',
    'C<sub>8</sub>H<sub>14</sub>',
    '',
    '2809-67-8',
    'QCQALVMFTWRCFI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-octyne'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-octyne'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-octyne'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-octyne'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-octyne',
    'C<sub>8</sub>H<sub>14</sub>',
    '',
    '15232-76-5',
    'UDEISTCPVNLKRJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-octyne'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-octyne'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-octyne'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dimethyl-3-hexyne',
    'C<sub>8</sub>H<sub>14</sub>',
    '',
    '4911-60-8',
    'XYBFBXTUWDPXLK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2,2-dimethyl-3-hexyne'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-nonyne',
    'C<sub>7</sub>H<sub>15</sub>CCH',
    '',
    '3452-09-3',
    'OSSQSXOTMIGBCF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-nonyne'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-nonyne'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-nonyne'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-nonyne'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-nonyne'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-nonyne'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nonyne'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nonyne'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nonyne'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nonyne'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nonyne'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nonyne'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nonyne'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nonyne'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nonyne'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nonyne'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-nonyne'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-nonyne'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-nonyne',
    'C<sub>9</sub>H<sub>16</sub>',
    '',
    '19447-29-1',
    'LXKRETAGISZJAD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-nonyne'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nonyne'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nonyne'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-nonyne',
    'C<sub>9</sub>H<sub>16</sub>',
    '',
    '20184-89-8',
    'SRRDSRCWRHKEKU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-nonyne'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-nonyne'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-nonyne'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,5-trimethyl-3-hexyne',
    'C<sub>9</sub>H<sub>16</sub>',
    '',
    '17530-23-3',
    'DKFPMSNUJIRAMR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2,2,5-trimethyl-3-hexyne'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,5,5-tetramethyl-3-hexyne',
    'C<sub>10</sub>H<sub>18</sub>',
    '',
    '17530-24-4',
    'FXVDWKZNFZMSOU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2,2,5,5-tetramethyl-3-hexyne'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-decyne',
    'C<sub>10</sub>H<sub>18</sub>',
    '',
    '764-93-2',
    'ILLHQJIJCRNRCJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-decyne'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-decyne'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-decyne'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-decyne',
    'C<sub>10</sub>H<sub>18</sub>',
    '',
    '2384-70-5',
    'RWDDSTHSVISBEA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-decyne'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-decyne'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-decyne'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-decyne',
    'C<sub>10</sub>H<sub>18</sub>',
    '',
    '2384-85-2',
    'JUWXVJKQNKKRLD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-decyne'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-decyne'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-decyne'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-undecyne',
    'C<sub>11</sub>H<sub>20</sub>',
    '',
    '2243-98-3',
    'YVSFLVNWJIEJRV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-undecyne'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-undecyne'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-undecyne',
    'C<sub>11</sub>H<sub>20</sub>',
    '',
    '60212-29-5',
    'XZSXEDPHMIFYOS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-undecyne'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-undecyne'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-undecyne'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-undecyne',
    'C<sub>11</sub>H<sub>20</sub>',
    '',
    '60212-30-8',
    'DPWGJNPCPLQVKQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-undecyne'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-undecyne'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-undecyne'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-dodecyne',
    'C<sub>12</sub>H<sub>22</sub>',
    '',
    '765-03-7',
    'ZVDBUOGYYYNMQI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-dodecyne'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-dodecyne'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-dodecyne'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-dodecyne',
    'C<sub>12</sub>H<sub>22</sub>',
    '',
    '629-49-2',
    'NDIJGAGRSOPRNJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-dodecyne'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-dodecyne'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-dodecyne'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-dodecyne',
    'C<sub>12</sub>H<sub>22</sub>',
    '',
    '6790-27-8',
    'ZFAGQZXKTQFQLE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-dodecyne'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-dodecyne'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-dodecyne'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-tridecyne',
    'C<sub>13</sub>H<sub>24</sub>',
    '',
    '26186-02-7',
    'GZEDKDBFUBPZNG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-tridecyne'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-tridecyne'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-tridecyne'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-tridecyne',
    'C<sub>13</sub>H<sub>24</sub>',
    '',
    '28467-75-6',
    'ZGKKGWBQPYIOBH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-tridecyne'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-tridecyne'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-tridecyne'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-tridecyne',
    'C<sub>13</sub>H<sub>24</sub>',
    '',
    '60186-78-9',
    'HDLJOUCNTFYRPD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-tridecyne'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-tridecyne'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-tridecyne'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-tetradecyne',
    'C<sub>14</sub>H<sub>26</sub>',
    '',
    '765-10-6',
    'DZEFNRWGWQDGTR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-tetradecyne'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-tetradecyne'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-tetradecyne'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-tetradecyne',
    'C<sub>14</sub>H<sub>26</sub>',
    '',
    '60212-32-0',
    'DWWMJIDVLGUCDE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-tetradecyne'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-tetradecyne'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-tetradecyne'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-pentadecyne',
    'C<sub>15</sub>H<sub>28</sub>',
    '',
    '765-13-9',
    'DONJGKADZJEXRJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-pentadecyne'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentadecyne'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentadecyne'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-pentadecyne',
    'C<sub>15</sub>H<sub>28</sub>',
    '',
    '52112-25-1',
    'VWWAVTXUUYIIEE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-pentadecyne'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentadecyne'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentadecyne'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-pentadecyne',
    'C<sub>15</sub>H<sub>28</sub>',
    '',
    '61886-61-1',
    'RUHQUJVXUGQUNY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-pentadecyne'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-pentadecyne'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-pentadecyne'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-hexadecyne',
    'C<sub>16</sub>H<sub>30</sub>',
    '',
    '629-74-3',
    'UCIDYSLOTJMRAM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-hexadecyne'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexadecyne'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-hexadecyne',
    'C<sub>16</sub>H<sub>30</sub>',
    '',
    '61886-62-2',
    'HRFPRVYNMNOAQO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-hexadecyne'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hexadecyne'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hexadecyne'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-buten-1-yne',
    'CH<sub>2</sub>CHCCH',
    'vinylacetylene',
    '689-97-4',
    'WFYPICNXBKQZGB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;4</sup>',
    '1700',
    'L',
    (SELECT id from species WHERE iupac='3-buten-1-yne'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;4</sup>',
    '1700',
    'L',
    (SELECT id from species WHERE iupac='3-buten-1-yne'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;4</sup>',
    '1800',
    'M',
    (SELECT id from species WHERE iupac='3-buten-1-yne'),
    (SELECT id from literature WHERE bibtexkey='2551'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2551-107-00-6-consicheck',
    '2551', 'Regression and individual data points of Simpson and Lovell (1962) are inconsistent, with 5&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2551-107-00-6-consicheck'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-buten-1-yne'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-buten-1-yne'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-buten-1-yne'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-buten-1-yne'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2600',
    'Q',
    (SELECT id from species WHERE iupac='3-buten-1-yne'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2100',
    '?',
    (SELECT id from species WHERE iupac='3-buten-1-yne'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-buten-1-yne'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at303K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'butadiyne',
    'C<sub>4</sub>H<sub>2</sub>',
    'biacetylene',
    '460-12-8',
    'LLCSWKVOHICRDD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='butadiyne'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butadiyne'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butadiyne'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='butadiyne'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='butadiyne'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,6-heptadiyne',
    'C<sub>7</sub>H<sub>8</sub>',
    '',
    '2396-63-6',
    'RSPZSDWVQWRAEF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,6-heptadiyne'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,8-nonadiyne',
    'C<sub>9</sub>H<sub>12</sub>',
    '',
    '2396-65-8',
    'DMOVPHYFYSASTC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aliphatic alkynes'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,8-nonadiyne'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Mononuclear aromatics',
    (SELECT id from categories WHERE catname='Hydrocarbons (C, H)'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benzene',
    'C<sub>6</sub>H<sub>6</sub>',
    '',
    '71-43-2',
    'UHOVQNZJYSORNB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '3800',
    'L',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='3681'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '3700',
    'L',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '4200',
    'L',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '3800',
    'L',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '4100',
    'L',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='3032'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '3800',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '1400',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2921'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2921H0',
    '2921', 'Using the theoretical initial concentration (H<sub>0</sub>); see Zhang et&nbsp;al. (2013) for details.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2921H0'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2921'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2921H1',
    '2921', 'Average of all duplicates (H<sub>1</sub>); see Zhang et&nbsp;al. (2013) for details.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2921H1'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '2400',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2982'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '4200',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2645'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2645',
    '2645', 'Sieg et&nbsp;al. (2009) also provide data for supercooled water. Here, only data above 0&nbsp;<sup>&#176;</sup>C were used to calculate the temperature dependence.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2645'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2970'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2954'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '2200',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2996'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2996',
    '', 'Extrapolated from data above 298&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2996'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='1856'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'cdep',
    '', 'It was found that H<sub>s</sub> changes with the concentration of the solution.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='cdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='1922'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '4200',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2923'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '3800',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2953'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2953-71-43-2-ABC',
    '2953', 'The data from Görgényi et&nbsp;al. (2002) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;346.88030 +18421.52810/T +48.91393&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2953-71-43-2-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '3200',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2522'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='3081'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at301K'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3081VEL',
    '3081', 'Value obtained by applying a modified batch air-stripping method, otherwise called the vapor entry loop (VEL) method; see Kochetkov et&nbsp;al. (2001) for details.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3081VEL'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='3081'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at301K'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3081HS',
    '3081', 'Value obtained by applying the static head space (HS) method; see Kochetkov et&nbsp;al. (2001) for details.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3081HS'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='1928'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at296K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2935'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2938'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='985'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='1114'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '3300',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='1114'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2950'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='3646'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '3200',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='837'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '2700',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2904'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '3300',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2905'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '4200',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='1597'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '4300',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2463'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '3900',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='584'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='622'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '4100',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2931'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2931-71-43-2-ABC',
    '2931', 'The data from Khalfaoui and Newsham (1994b) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;129.36095 +8999.48627/T +16.29087&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2931-71-43-2-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '3400',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='599'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0599-71-43-2-ABC',
    '599', 'The data from Robbins et&nbsp;al. (1993) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( 189.41389 &#8722;5855.10843/T &#8722;30.90289&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0599-71-43-2-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='637'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '2300',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='858'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='903'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'at302K',
    '', 'Value at T = 302&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at302K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '4000',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='1229'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2457'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2493'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2937'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '4300',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='1148'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref1148-71-43-2-ABC',
    '1148', 'The data from Cooling et&nbsp;al. (1992) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;231.38331 +13640.47358/T +31.46504&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref1148-71-43-2-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2983'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at296K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='3675'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '4300',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2270'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2924'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '3200',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='1156'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1156'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2906'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2448'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2479'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '3600',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2911'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '3900',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2453'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '4000',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='1150'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '3500',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '5300',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2271'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='490'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2917'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '3800',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2922'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '4200',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2942'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='1492'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '4400',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2981'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '4500',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='640'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '4500',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='791'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2491'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at303K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2580'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='3081'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2338'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2339'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2905'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '3800',
    'V',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '3600',
    'V',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2219'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '4100',
    'V',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2471'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '3800',
    'V',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2375'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '3800',
    'V',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2375'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='3924'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '3800',
    'V',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='719'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '719',
    '719', 'Calculated using G<sub>h</sub> and H<sub>h</sub> from Table&nbsp;2 in Andon et&nbsp;al. (1954). Note that the thermodynamic functions in that table are not based on their &#945; in Table&nbsp;1. Instead, the expression exp(&#8722;G<sub>h</sub>/(RT)) yields the Henry''s law constant H<sub>s</sub><sup>xp</sup> in the unit 1/atm.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='719'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='790'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '3800',
    'T',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='3674'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='490'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3800',
    'T',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2224'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='766'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '2200',
    'X',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='3135'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2165'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='3071'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='3083'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4000',
    'Q',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2481'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3700',
    '?',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='benzene'),
    (SELECT id from literature WHERE bibtexkey='2233'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benzene-d6',
    'C<sub>6</sub>D<sub>6</sub>',
    '',
    '1076-43-3',
    'UHOVQNZJYSORNB-MZWXYZOWSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '4000',
    'M',
    (SELECT id from species WHERE iupac='benzene-d6'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '4500',
    'M',
    (SELECT id from species WHERE iupac='benzene-d6'),
    (SELECT id from literature WHERE bibtexkey='791'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3800',
    'T',
    (SELECT id from species WHERE iupac='benzene-d6'),
    (SELECT id from literature WHERE bibtexkey='2224'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methylbenzene',
    'C<sub>6</sub>H<sub>5</sub>CH<sub>3</sub>',
    'toluene',
    '108-88-3',
    'YXFVVABEGXRONW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '4100',
    'L',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3681'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '4000',
    'L',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3518-108-88-3-consicheck',
    '3518', 'Values at 298&nbsp;K in Tables&nbsp;C2 and C5 of Brockbank (2013) are inconsistent, with 11&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3518-108-88-3-consicheck'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '4300',
    'L',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '4400',
    'L',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '4000',
    'L',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '4600',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3507'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3032'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '4400',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2921'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2921H1'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '4200',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2987'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3007'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '2700',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2982'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '4300',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2645'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2645'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2955'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2970'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '2100',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3116'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'alsosalt',
    '', 'Values for salt solutions are also available from this reference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='alsosalt'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2954'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '3900',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3694'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2483'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='cdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '2200',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2996'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2996'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1856'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='cdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1922'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2899'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '4300',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2923'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '4200',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2953'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2953-108-88-3-ABC',
    '2953', 'The data from Görgényi et&nbsp;al. (2002) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;468.28203 +24099.39947/T +66.85565&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2953-108-88-3-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '3600',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2522'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2969'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2969epics',
    '2969', 'Value obtained by applying the EPICS method; see Ayuttaya et&nbsp;al. (2001) for details.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2969epics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2969'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2969linear',
    '2969', 'Value obtained by applying the static cell (linear form) method; see Ayuttaya et&nbsp;al. (2001) for details.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2969linear'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2969'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2969direct',
    '2969', 'Value obtained by applying the direct phase concentration ratio method; see Ayuttaya et&nbsp;al. (2001) for details.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2969direct'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2969'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2969nonlin',
    '2969', 'Value obtained by applying the static cell (nonlinear form) method; see Ayuttaya et&nbsp;al. (2001) for details.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2969nonlin'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1573'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at296K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1928'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at296K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '4000',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2896'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3672'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '4700',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1107'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2935'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2938'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='985'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1114'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '3600',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1114'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2950'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3646'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '3700',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='837'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '2800',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2904'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '3900',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2905'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '4100',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2463'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2930'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '4400',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='584'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='622'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '4400',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='599'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0599-108-88-3-ABC',
    '599', 'The data from Robbins et&nbsp;al. (1993) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;573.76928 +28956.65188/T +82.51911&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0599-108-88-3-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='637'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '2500',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='858'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='903'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at302K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '4500',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1229'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2457'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2493'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2937'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '2500',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='857'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='857'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2983'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at296K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3675'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '5000',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2270'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '6500',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2901'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2901',
    '2901', 'The temperature dependence is recalculated using the data in Table&nbsp;4 of Lamarche and Droste (1989) and not taken from their Table&nbsp;5.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2901'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '3000',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1156'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1156'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2906'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2479'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '5400',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1331'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2902'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '4200',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2453'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '3800',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1150'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '4100',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '4900',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2271'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='490'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2917'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '4700',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2922'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '5000',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2981'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '4900',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='640'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '5900',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='791'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3678'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3678'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '4300',
    'V',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '1943-108-88-3',
    '', 'Apparently, the vapor pressure of toluene was used to calculate its Henry''s law constant. However, no source is provided.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1943-108-88-3'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2338'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2905'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '4400',
    'V',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '4200',
    'V',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2219'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2471'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '4400',
    'V',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2375'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3924'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '4300',
    'V',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='719'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='719'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='790'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '4400',
    'T',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3674'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='490'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4400',
    'T',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2224'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '1900',
    'X',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='mcauliffe71'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'from584',
    '584', 'Value given here as quoted by Dewulf et&nbsp;al. (1995).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from584'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3135'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2165'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3071'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3083'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4300',
    'Q',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2481'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4200',
    '?',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2233'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methylbenzene-d8',
    'C<sub>6</sub>D<sub>5</sub>CD<sub>3</sub>',
    'toluene-d8',
    '2037-26-5',
    'YXFVVABEGXRONW-JGUCLWPXSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '4300',
    'M',
    (SELECT id from species WHERE iupac='methylbenzene-d8'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-dimethylbenzene',
    'C<sub>6</sub>H<sub>4</sub>(CH<sub>3</sub>)<sub>2</sub>',
    'o-xylene',
    '95-47-6',
    'CTQNGGLPUBDAKN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '4600',
    'L',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3681'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '4700',
    'L',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '4200',
    'L',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '4300',
    'L',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '4400',
    'L',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '4000',
    'L',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3032'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;3</sup>',
    '4500',
    'M',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '8500',
    'M',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2921'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2921H0'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2921'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2921H1'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '4300',
    'M',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2645'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2645'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2970'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '2500',
    'M',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3116'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='alsosalt'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3672'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2938'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3646'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '3400',
    'M',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2904'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2463'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '4500',
    'M',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='584'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '5800',
    'M',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='599'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0599-95-47-6-ABC',
    '599', 'The data from Robbins et&nbsp;al. (1993) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;1350.74178 +64760.28328/T +197.85937&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0599-95-47-6-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2457'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2493'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2937'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '3000',
    'M',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='857'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='857'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2983'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at296K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '5600',
    'M',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2270'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '3200',
    'M',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1156'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1156'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2479'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '4500',
    'M',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2453'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2917'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '5400',
    'M',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='791'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2338'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2471'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3924'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3135'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4100',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-Test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4100',
    '?',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-dimethylbenzene-d10',
    'C<sub>6</sub>D<sub>4</sub>(CD<sub>3</sub>)<sub>2</sub>',
    'o-xylene-d10',
    '56004-61-6',
    'CTQNGGLPUBDAKN-ZGYYUIRESA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '4700',
    'M',
    (SELECT id from species WHERE iupac='1,2-dimethylbenzene-d10'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3-dimethylbenzene',
    'C<sub>6</sub>H<sub>4</sub>(CH<sub>3</sub>)<sub>2</sub>',
    'm-xylene',
    '108-38-3',
    'IVSZLXZYQVIEFR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '4100',
    'L',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3681'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '4300',
    'L',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '4200',
    'L',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '4600',
    'L',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '4200',
    'L',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3032'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2970'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1922'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3672'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2938'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '2900',
    'M',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2904'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '4300',
    'M',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='584'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2457'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2493'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '6000',
    'M',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2270'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '3300',
    'M',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1156'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1156'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '4700',
    'M',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2453'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2917'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '4500',
    'M',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2922'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '4300',
    'V',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2338'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '4800',
    'V',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2375'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '5000',
    'V',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='719'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='719'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='790'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3135'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4700',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4900',
    '?',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4-dimethylbenzene',
    'C<sub>6</sub>H<sub>4</sub>(CH<sub>3</sub>)<sub>2</sub>',
    'p-xylene',
    '106-42-3',
    'URLKBWYHVLBVBO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '5000',
    'L',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3681'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '5000',
    'L',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '4200',
    'L',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '4000',
    'L',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '4600',
    'L',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '3800',
    'L',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '2600',
    'M',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3681'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3681-106-42-3-ABC',
    '3681', 'The data from Schwardt et&nbsp;al. (2021) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( 100.47045 &#8722;2603.76722/T &#8722;17.31043&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3681-106-42-3-ABC'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3032'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2970'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '4800',
    'M',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3694'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2899'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3672'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2935'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2938'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '2900',
    'M',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2904'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;4</sup>',
    '3200',
    'M',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2905'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '4800',
    'M',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='584'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '3100',
    'M',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='903'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='903'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2457'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2493'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2937'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '5300',
    'M',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2270'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '3500',
    'M',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1156'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1156'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '4800',
    'M',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2453'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2917'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '5400',
    'M',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='791'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3678'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3678'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2580'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2338'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2905'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '4800',
    'V',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2375'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '4900',
    'V',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='719'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='719'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='790'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='foster94'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'from3088',
    '3088', 'Value given here as quoted by HSDB (2015).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3135'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2165'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4700',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4500',
    '?',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3-trimethylbenzene',
    'C<sub>6</sub>H<sub>3</sub>(CH<sub>3</sub>)<sub>3</sub>',
    '',
    '526-73-8',
    'FYGHSUNMUKGBRK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '4600',
    'L',
    (SELECT id from species WHERE iupac='1,2,3-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '4800',
    'L',
    (SELECT id from species WHERE iupac='1,2,3-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '4500',
    'L',
    (SELECT id from species WHERE iupac='1,2,3-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,2,3-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2,3-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3664'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '4500',
    'M',
    (SELECT id from species WHERE iupac='1,2,3-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2453'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2338'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,2,3-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3900',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-Test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2,3-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4400',
    '?',
    (SELECT id from species WHERE iupac='1,2,3-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2,3-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2,3-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2,3-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4-trimethylbenzene',
    'C<sub>6</sub>H<sub>3</sub>(CH<sub>3</sub>)<sub>3</sub>',
    '',
    '95-63-6',
    'GWHJZXXIDMPWGX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '4700',
    'L',
    (SELECT id from species WHERE iupac='1,2,4-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '3100',
    'L',
    (SELECT id from species WHERE iupac='1,2,4-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '4800',
    'L',
    (SELECT id from species WHERE iupac='1,2,4-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,2,4-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;3</sup>',
    '5200',
    'M',
    (SELECT id from species WHERE iupac='1,2,4-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2,4-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2970'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '3600',
    'M',
    (SELECT id from species WHERE iupac='1,2,4-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2904'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2,4-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3664'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '4300',
    'M',
    (SELECT id from species WHERE iupac='1,2,4-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='903'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='903'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2,4-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2479'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '4800',
    'M',
    (SELECT id from species WHERE iupac='1,2,4-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2453'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,4-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,4-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2338'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,4-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,4-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,4-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,4-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,2,4-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4500',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2481'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2,4-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4700',
    '?',
    (SELECT id from species WHERE iupac='1,2,4-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2,4-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2,4-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2,4-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3,5-trimethylbenzene',
    'C<sub>6</sub>H<sub>3</sub>(CH<sub>3</sub>)<sub>3</sub>',
    'mesitylene',
    '108-67-8',
    'AUHZEENZYGFFBQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '4400',
    'L',
    (SELECT id from species WHERE iupac='1,3,5-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '4900',
    'L',
    (SELECT id from species WHERE iupac='1,3,5-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,3,5-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '5100',
    'M',
    (SELECT id from species WHERE iupac='1,3,5-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,3,5-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1922'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '3000',
    'M',
    (SELECT id from species WHERE iupac='1,3,5-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2904'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,3,5-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3664'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,3,5-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2457'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,3,5-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2493'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '3600',
    'M',
    (SELECT id from species WHERE iupac='1,3,5-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1156'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1156'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '4700',
    'M',
    (SELECT id from species WHERE iupac='1,3,5-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2453'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '4600',
    'M',
    (SELECT id from species WHERE iupac='1,3,5-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3,5-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2580'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3,5-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3,5-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2338'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3,5-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3,5-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3,5-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,3,5-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5000',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,3,5-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4400',
    '?',
    (SELECT id from species WHERE iupac='1,3,5-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,3,5-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,3,5-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,3,5-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,4-tetramethylbenzene',
    'C<sub>10</sub>H<sub>14</sub>',
    '',
    '488-23-3',
    'UOHMMEJUHBCKEE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '5900',
    'L',
    (SELECT id from species WHERE iupac='1,2,3,4-tetramethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,5-tetramethylbenzene',
    'C<sub>10</sub>H<sub>14</sub>',
    '',
    '527-53-7',
    'BFIMMTCNYPIMRN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,5-tetramethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,5-tetramethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,5-tetramethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,5-tetramethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2,3,5-tetramethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4,5-tetramethylbenzene',
    'C<sub>10</sub>H<sub>14</sub>',
    '',
    '95-93-2',
    'SQNZJJAZBFDUTD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,2,4,5-tetramethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,2,4,5-tetramethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,2,4,5-tetramethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,4,5-tetramethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,4,5-tetramethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,4,5-tetramethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,2,4,5-tetramethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,5-tetramethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,5-tetramethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,5-tetramethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,5-tetramethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,5-tetramethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,5-tetramethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,5-tetramethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,5-tetramethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,5-tetramethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,5-tetramethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2,4,5-tetramethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethylbenzene',
    'C<sub>6</sub>H<sub>5</sub>C<sub>2</sub>H<sub>5</sub>',
    '',
    '100-41-4',
    'YNQLUTRBYVCPMQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '4500',
    'L',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3681'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3681ethylbenzene',
    '3681,3722', 'The regression parameters for ethylbenzene in Table&nbsp;1 of Schwardt et&nbsp;al. (2021) are wrong. Corrected values from Schwardt et&nbsp;al. (2022) are used here.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3681ethylbenzene'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '5000',
    'L',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '4800',
    'L',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '5100',
    'L',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '4800',
    'L',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '5100',
    'L',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '4400',
    'M',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3681'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3681-100-41-4-ABC',
    '3681', 'The data from Schwardt et&nbsp;al. (2021) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;176.88587 +11290.74921/T +23.22869&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3681-100-41-4-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '4100',
    'M',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '4200',
    'M',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2921'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2921H0'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2921'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2921H1'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '5100',
    'M',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2645'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2645'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2970'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '2700',
    'M',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3116'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='alsosalt'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2954'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1856'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='cdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1928'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at296K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2935'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2935-100-41-4-consicheck',
    '2935', 'Different types of Henry''s law constants of Ryu and Park (1999) are inconsistent, with 14&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2935-100-41-4-consicheck'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='985'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '2800',
    'M',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2904'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2463'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '4900',
    'M',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='584'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '5000',
    'M',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='599'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0599-100-41-4-ABC',
    '599', 'The data from Robbins et&nbsp;al. (1993) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;371.46947 +20514.07888/T +51.95086&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0599-100-41-4-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '5300',
    'M',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1229'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2457'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2493'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2937'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '5500',
    'M',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2270'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '5000',
    'M',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1156'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1156'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '4400',
    'M',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2912'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '4600',
    'M',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2453'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '4500',
    'M',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '5500',
    'M',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2271'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='490'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2917'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '5600',
    'M',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2981'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '6400',
    'M',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='640'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2580'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2338'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '4800',
    'V',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '4900',
    'V',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2219'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '4800',
    'V',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2375'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3924'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '4900',
    'V',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='719'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='719'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='790'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '4900',
    'T',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='490'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4800',
    'T',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2224'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '1700',
    'X',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3135'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3083'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4700',
    'Q',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2481'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5000',
    '?',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='637'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethylbenzene-d10',
    'C<sub>6</sub>D<sub>5</sub>C<sub>2</sub>D<sub>5</sub>',
    '',
    '25837-05-2',
    'YNQLUTRBYVCPMQ-CFTAVCBPSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '4200',
    'M',
    (SELECT id from species WHERE iupac='ethylbenzene-d10'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-diethylbenzene',
    'C<sub>10</sub>H<sub>14</sub>',
    'o-diethylbenzene',
    '135-01-3',
    'KVNYFPKFSJIPBJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,2-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1,2-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4800',
    'Q',
    (SELECT id from species WHERE iupac='1,2-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5100',
    '?',
    (SELECT id from species WHERE iupac='1,2-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3-diethylbenzene',
    'C<sub>10</sub>H<sub>14</sub>',
    'm-diethylbenzene',
    '141-93-5',
    'AFZZYIJIWUTJFO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,3-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1,3-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5300',
    'Q',
    (SELECT id from species WHERE iupac='1,3-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5300',
    '?',
    (SELECT id from species WHERE iupac='1,3-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,3-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4-diethylbenzene',
    'C<sub>10</sub>H<sub>14</sub>',
    'p-diethylbenzene',
    '105-05-5',
    'DSNHSQKRULAAEI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,4-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5300',
    'Q',
    (SELECT id from species WHERE iupac='1,4-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5900',
    '?',
    (SELECT id from species WHERE iupac='1,4-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,4-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='1,4-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3518-105-05-5',
    '', 'The value listed as A for diethylbenzene is probably not A but the Henry''s law volatility constant H<sub>v</sub><sup>px</sup> at 298&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3518-105-05-5'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propylbenzene',
    'C<sub>6</sub>H<sub>5</sub>C<sub>3</sub>H<sub>7</sub>',
    '',
    '103-65-1',
    'ODLMAHJVESYWTB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;4</sup>',
    '3800',
    'L',
    (SELECT id from species WHERE iupac='propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3681'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;4</sup>',
    '4700',
    'L',
    (SELECT id from species WHERE iupac='propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;4</sup>',
    '5300',
    'L',
    (SELECT id from species WHERE iupac='propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '4500',
    'M',
    (SELECT id from species WHERE iupac='propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1922'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '2600',
    'M',
    (SELECT id from species WHERE iupac='propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2904'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;4</sup>',
    '5400',
    'M',
    (SELECT id from species WHERE iupac='propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1229'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2457'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2493'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;4</sup>',
    '3700',
    'M',
    (SELECT id from species WHERE iupac='propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1156'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1156'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;4</sup>',
    '4700',
    'M',
    (SELECT id from species WHERE iupac='propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2453'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2917'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2338'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;4</sup>',
    '5300',
    'V',
    (SELECT id from species WHERE iupac='propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '5500',
    'V',
    (SELECT id from species WHERE iupac='propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2219'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;4</sup>',
    '5100',
    'T',
    (SELECT id from species WHERE iupac='propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5300',
    'T',
    (SELECT id from species WHERE iupac='propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2224'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5000',
    'Q',
    (SELECT id from species WHERE iupac='propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4700',
    '?',
    (SELECT id from species WHERE iupac='propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(2-propyl)-benzene',
    'C<sub>6</sub>H<sub>5</sub>C<sub>3</sub>H<sub>7</sub>',
    'isopropylbenzene; cumene',
    '98-82-8',
    'RWGFKTVRMDUZSP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;4</sup>',
    '4800',
    'L',
    (SELECT id from species WHERE iupac='(2-propyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '3200',
    'L',
    (SELECT id from species WHERE iupac='(2-propyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;4</sup>',
    '4800',
    'L',
    (SELECT id from species WHERE iupac='(2-propyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='(2-propyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '4900',
    'M',
    (SELECT id from species WHERE iupac='(2-propyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '2500',
    'M',
    (SELECT id from species WHERE iupac='(2-propyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2904'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;4</sup>',
    '3300',
    'M',
    (SELECT id from species WHERE iupac='(2-propyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='903'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='903'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='(2-propyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2457'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='(2-propyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2493'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '3200',
    'M',
    (SELECT id from species WHERE iupac='(2-propyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='1156'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1156'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;4</sup>',
    '4700',
    'M',
    (SELECT id from species WHERE iupac='(2-propyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2453'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='(2-propyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2917'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(2-propyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(2-propyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2338'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(2-propyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(2-propyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(2-propyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(2-propyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(2-propyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2471'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '5000',
    'V',
    (SELECT id from species WHERE iupac='(2-propyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2375'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(2-propyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3924'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='(2-propyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2-propyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2-propyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2-propyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2-propyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2-propyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2-propyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3025'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2-propyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2-propyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2-propyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2-propyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2-propyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2-propyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2-propyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5000',
    'Q',
    (SELECT id from species WHERE iupac='(2-propyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2-propyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2535dupl',
    '2535', 'Yaffe et&nbsp;al. (2003) list this species twice in their table, with different values. As it is unclear which is correct, the data are not reproduced here.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535dupl'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2-propyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2-propyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2-propyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2-propyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2-propyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2-propyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(2-propyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4400',
    '?',
    (SELECT id from species WHERE iupac='(2-propyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(2-propyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(2-propyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(2-propyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='637'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(2-propyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(2-propyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='(2-propyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '1943-98-82-8-erratum',
    '1943,2904', 'Erratum for page 365 of Fogg and Sangster (2003): data from Kondoh and Nakajima (1997) are cited incorrectly, giving the same values at 308.2&nbsp;K and 318.2&nbsp;K, respectively.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1943-98-82-8-erratum'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-ethyl-2-methylbenzene',
    'C<sub>6</sub>H<sub>4</sub>CH<sub>3</sub>C<sub>2</sub>H<sub>5</sub>',
    'o-ethyltoluene',
    '611-14-3',
    'HYFLWBNQFMXCPA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-ethyl-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-ethyl-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-ethyl-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-ethyl-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-ethyl-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-ethyl-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-ethyl-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethyl-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethyl-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethyl-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethyl-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethyl-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethyl-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethyl-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethyl-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethyl-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethyl-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4500',
    'Q',
    (SELECT id from species WHERE iupac='1-ethyl-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethyl-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethyl-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethyl-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3200',
    '?',
    (SELECT id from species WHERE iupac='1-ethyl-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-ethyl-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-ethyl-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-ethyl-3-methylbenzene',
    'C<sub>6</sub>H<sub>4</sub>CH<sub>3</sub>C<sub>2</sub>H<sub>5</sub>',
    'm-ethyltoluene',
    '620-14-4',
    'ZLCSFXXPPANWQY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-ethyl-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethyl-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethyl-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethyl-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethyl-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethyl-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-ethyl-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-ethyl-4-methylbenzene',
    'C<sub>6</sub>H<sub>4</sub>CH<sub>3</sub>C<sub>2</sub>H<sub>5</sub>',
    'p-ethyltoluene',
    '622-96-8',
    'JRLPEMVDPFPYPJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-ethyl-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-ethyl-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-ethyl-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-ethyl-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-ethyl-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-ethyl-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-ethyl-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethyl-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethyl-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethyl-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethyl-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethyl-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethyl-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethyl-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethyl-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethyl-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethyl-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethyl-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethyl-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-ethyl-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-ethyl-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'butylbenzene',
    'C<sub>6</sub>H<sub>5</sub>C<sub>4</sub>H<sub>9</sub>',
    '',
    '104-51-8',
    'OCKPCBLVNKHBMX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;4</sup>',
    '5100',
    'L',
    (SELECT id from species WHERE iupac='butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;4</sup>',
    '5500',
    'L',
    (SELECT id from species WHERE iupac='butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '4500',
    'M',
    (SELECT id from species WHERE iupac='butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2935'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;4</sup>',
    '2700',
    'M',
    (SELECT id from species WHERE iupac='butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2904'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '6000',
    'M',
    (SELECT id from species WHERE iupac='butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1229'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2457'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2493'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2580'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2338'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '6500',
    'V',
    (SELECT id from species WHERE iupac='butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2219'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;4</sup>',
    '5300',
    'T',
    (SELECT id from species WHERE iupac='butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5300',
    'Q',
    (SELECT id from species WHERE iupac='butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '731-P',
    '', 'Value from the external prediction set.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-P'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4900',
    '?',
    (SELECT id from species WHERE iupac='butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(1-methylpropyl)-benzene',
    'C<sub>6</sub>H<sub>5</sub>C<sub>4</sub>H<sub>9</sub>',
    '<i>sec</i>-butylbenzene',
    '135-98-8',
    'ZJMWRROPUADPEA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='(1-methylpropyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='(1-methylpropyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '4600',
    'M',
    (SELECT id from species WHERE iupac='(1-methylpropyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;4</sup>',
    '2300',
    'M',
    (SELECT id from species WHERE iupac='(1-methylpropyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2904'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(1-methylpropyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(1-methylpropyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(1-methylpropyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(1-methylpropyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(1-methylpropyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(1-methylpropyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='(1-methylpropyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(1-methylpropyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(1-methylpropyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(1-methylpropyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(1-methylpropyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(1-methylpropyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(1-methylpropyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(1-methylpropyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(1-methylpropyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(1-methylpropyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(1-methylpropyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(1-methylpropyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(1-methylpropyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(1-methylpropyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(1-methylpropyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(2-methylpropyl)-benzene',
    'C<sub>6</sub>H<sub>5</sub>C<sub>4</sub>H<sub>9</sub>',
    'isobutylbenzene',
    '538-93-2',
    'KXUHSQYYJYAXGZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='(2-methylpropyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='(2-methylpropyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(2-methylpropyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(2-methylpropyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(2-methylpropyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(2-methylpropyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='(2-methylpropyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2-methylpropyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2-methylpropyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2-methylpropyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2-methylpropyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2-methylpropyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2-methylpropyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2-methylpropyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2-methylpropyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2-methylpropyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2-methylpropyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(2-methylpropyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(1,1-dimethylethyl)-benzene',
    'C<sub>6</sub>H<sub>5</sub>C<sub>4</sub>H<sub>9</sub>',
    '<i>tert</i>-butylbenzene',
    '98-06-6',
    'YTZKOQUCBOVLHL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='(1,1-dimethylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='(1,1-dimethylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '4700',
    'M',
    (SELECT id from species WHERE iupac='(1,1-dimethylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;4</sup>',
    '2400',
    'M',
    (SELECT id from species WHERE iupac='(1,1-dimethylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2904'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(1,1-dimethylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(1,1-dimethylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(1,1-dimethylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(1,1-dimethylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(1,1-dimethylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(1,1-dimethylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='(1,1-dimethylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(1,1-dimethylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(1,1-dimethylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(1,1-dimethylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(1,1-dimethylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(1,1-dimethylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(1,1-dimethylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(1,1-dimethylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(1,1-dimethylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(1,1-dimethylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(1,1-dimethylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(1,1-dimethylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-2-propylbenzene',
    'C<sub>10</sub>H<sub>14</sub>',
    '',
    '1074-17-5',
    'YQZBFMJOASEONC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-methyl-2-propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-2-propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-2-propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-3-propylbenzene',
    'C<sub>10</sub>H<sub>14</sub>',
    '',
    '1074-43-7',
    'QUEBYVKXYIKVSO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-methyl-3-propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-3-propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-3-propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-4-propylbenzene',
    'C<sub>10</sub>H<sub>14</sub>',
    '',
    '1074-55-1',
    'JXFVMNFKABWTHD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-methyl-4-propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-4-propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-4-propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-ethyl-m-xylene',
    'C<sub>10</sub>H<sub>14</sub>',
    '',
    '2870-04-4',
    'CHIKRULMSSADAF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-ethyl-m-xylene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-m-xylene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-m-xylene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-ethyl-m-xylene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-ethyl-p-xylene',
    'C<sub>10</sub>H<sub>14</sub>',
    '',
    '1758-88-9',
    'AXIUBBVSOWPLDA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-ethyl-p-xylene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-p-xylene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-p-xylene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-ethyl-p-xylene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-o-xylene',
    'C<sub>10</sub>H<sub>14</sub>',
    '',
    '933-98-2',
    'QUBBAXISAHIDNM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-o-xylene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-o-xylene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-o-xylene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-ethyl-o-xylene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-ethyl-o-xylene',
    'C<sub>10</sub>H<sub>14</sub>',
    '',
    '934-80-5',
    'SBUYFICWQNHBCM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-ethyl-o-xylene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-o-xylene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-o-xylene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-o-xylene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-ethyl-o-xylene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-ethyl-m-xylene',
    'C<sub>10</sub>H<sub>14</sub>',
    '',
    '874-41-9',
    'MEMBJMDZWKVOTB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-ethyl-m-xylene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-m-xylene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-m-xylene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-m-xylene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-ethyl-m-xylene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-ethyl-m-xylene',
    'C<sub>10</sub>H<sub>14</sub>',
    '1-ethyl-3,5-dimethylbenzene',
    '934-74-7',
    'LMAUULKNZLEMGN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='5-ethyl-m-xylene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-ethyl-m-xylene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-ethyl-m-xylene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-ethyl-m-xylene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-ethyl-m-xylene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-ethyl-m-xylene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='5-ethyl-m-xylene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-2-(1-methylethyl)-benzene',
    'C<sub>10</sub>H<sub>14</sub>',
    'o-cymene',
    '527-84-4',
    'WWRCMNKATXZARA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-methyl-2-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-methyl-2-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-methyl-2-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-methyl-2-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-methyl-2-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-2-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-2-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-2-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-2-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-2-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-2-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-2-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-2-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-2-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-2-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-methyl-2-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-3-(1-methylethyl)-benzene',
    'C<sub>10</sub>H<sub>14</sub>',
    'm-cymene',
    '535-77-3',
    'XCYJPXQACVEIOS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-methyl-3-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-methyl-3-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-methyl-3-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-methyl-3-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2124'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-methyl-3-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-methyl-3-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-3-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-3-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-3-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-3-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-3-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-3-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-methyl-3-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-4-(1-methylethyl)-benzene',
    'C<sub>10</sub>H<sub>14</sub>',
    'p-cymene; p-isopropyltoluene',
    '99-87-6',
    'HFPZCAJZSCWRBC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '4900',
    'M',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '2600',
    'M',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2904'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3678'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3678'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2124'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2487'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5300',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-Test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4500',
    '?',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-<i>tert</i>-butyltoluene',
    'C<sub>11</sub>H<sub>16</sub>',
    '',
    '98-51-1',
    'QCWXDVFBZVHKLV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-<i>tert</i>-butyltoluene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-<i>tert</i>-butyltoluene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-<i>tert</i>-butyltoluene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-<i>tert</i>-butyltoluene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-<i>tert</i>-butyltoluene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-<i>tert</i>-butyltoluene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-<i>tert</i>-butyltoluene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-<i>tert</i>-butyltoluene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pentylbenzene',
    'C<sub>6</sub>H<sub>5</sub>C<sub>5</sub>H<sub>11</sub>',
    '',
    '538-68-1',
    'PWATWSYOIIXYMA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;4</sup>',
    '6000',
    'L',
    (SELECT id from species WHERE iupac='pentylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3518-538-68-1-consicheck',
    '3518', 'Values at 298&nbsp;K in Tables&nbsp;C2 and C5 of Brockbank (2013) are inconsistent, with 8&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3518-538-68-1-consicheck'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;4</sup>',
    '5900',
    'L',
    (SELECT id from species WHERE iupac='pentylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='pentylbenzene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='pentylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2935'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pentylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pentylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pentylbenzene'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pentylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pentylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '7800',
    'V',
    (SELECT id from species WHERE iupac='pentylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2219'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;4</sup>',
    '5900',
    'T',
    (SELECT id from species WHERE iupac='pentylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='pentylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentylbenzene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pentylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pentylbenzene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pentylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pentamethylbenzene',
    'C<sub>11</sub>H<sub>16</sub>',
    '',
    '700-12-9',
    'BEZDDPMMPIDMGJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentamethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentamethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-dimethyl-3-propylbenzene',
    'C<sub>11</sub>H<sub>16</sub>',
    '',
    '17059-44-8',
    'IRUSTUOJENXLMN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,2-dimethyl-3-propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethyl-3-propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethyl-3-propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-dimethyl-4-propylbenzene',
    'C<sub>11</sub>H<sub>16</sub>',
    '',
    '3982-66-9',
    'FZJVYOOQGFZCSY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,2-dimethyl-4-propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethyl-4-propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethyl-4-propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3-dimethyl-2-propylbenzene',
    'C<sub>11</sub>H<sub>16</sub>',
    '',
    '17059-45-9',
    'POVRSTNZQPBWAS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,3-dimethyl-2-propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dimethyl-2-propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dimethyl-2-propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3-dimethyl-4-propylbenzene',
    'C<sub>11</sub>H<sub>16</sub>',
    '',
    '61827-85-8',
    'HPAXKQMKDWCLGU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,3-dimethyl-4-propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dimethyl-4-propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dimethyl-4-propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3-dimethyl-5-propylbenzene',
    'C<sub>11</sub>H<sub>16</sub>',
    '',
    '3982-64-7',
    'NBICXWXPZRNMPF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,3-dimethyl-5-propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dimethyl-5-propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dimethyl-5-propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4-dimethyl-2-propylbenzene',
    'C<sub>11</sub>H<sub>16</sub>',
    '',
    '3042-50-0',
    'PWEDYOIWLPZSRP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,4-dimethyl-2-propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dimethyl-2-propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dimethyl-2-propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-dimethyl-3-isopropylbenzene',
    'C<sub>11</sub>H<sub>16</sub>',
    '',
    '22539-65-7',
    'GDEQPEBFOWYWSA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,2-dimethyl-3-isopropylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethyl-3-isopropylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethyl-3-isopropylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-dimethyl-4-isopropylbenzene',
    'C<sub>11</sub>H<sub>16</sub>',
    '',
    '4132-77-8',
    'MGMSKQZIAGFMRU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,2-dimethyl-4-isopropylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethyl-4-isopropylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethyl-4-isopropylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3-dimethyl-2-isopropylbenzene',
    'C<sub>11</sub>H<sub>16</sub>',
    '',
    '14411-75-7',
    'IVCIQLTVLDOHKA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,3-dimethyl-2-isopropylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dimethyl-2-isopropylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dimethyl-2-isopropylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3-dimethyl-4-isopropylbenzene',
    'C<sub>11</sub>H<sub>16</sub>',
    '',
    '4706-89-2',
    'AADQFNAACHHRLT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,3-dimethyl-4-isopropylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dimethyl-4-isopropylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dimethyl-4-isopropylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3-dimethyl-5-isopropylbenzene',
    'C<sub>11</sub>H<sub>16</sub>',
    '',
    '4706-90-5',
    'RMKJTYPFCFNTGQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,3-dimethyl-5-isopropylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dimethyl-5-isopropylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dimethyl-5-isopropylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4-dimethyl-2-isopropylbenzene',
    'C<sub>11</sub>H<sub>16</sub>',
    '',
    '4132-72-3',
    'CLSBTDGUHSQYTO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,4-dimethyl-2-isopropylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dimethyl-2-isopropylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dimethyl-2-isopropylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-ethyl-2-propylbenzene',
    'C<sub>11</sub>H<sub>16</sub>',
    '',
    '16021-20-8',
    'DMUVQFCRCMDZPW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-ethyl-2-propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethyl-2-propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethyl-2-propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethyl-2-propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethyl-2-propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethyl-2-propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-ethyl-3-propylbenzene',
    'C<sub>11</sub>H<sub>16</sub>',
    '',
    '20024-91-3',
    'QCYGXOCMWHSXSU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-ethyl-3-propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethyl-3-propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethyl-3-propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-ethyl-4-propylbenzene',
    'C<sub>11</sub>H<sub>16</sub>',
    '',
    '20024-90-2',
    'ADQDTIAWIXUACV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-ethyl-4-propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethyl-4-propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethyl-4-propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-ethyl-2-isopropylbenzene',
    'C<sub>11</sub>H<sub>16</sub>',
    '',
    '18970-44-0',
    'ZAJYARZMPOEGLK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-ethyl-2-isopropylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethyl-2-isopropylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethyl-2-isopropylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-ethyl-3-isopropylbenzene',
    'C<sub>11</sub>H<sub>16</sub>',
    '',
    '4920-99-4',
    'GSLSBTNLESMZTN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-ethyl-3-isopropylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethyl-3-isopropylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethyl-3-isopropylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-ethyl-4-isopropylbenzene',
    'C<sub>11</sub>H<sub>16</sub>',
    '',
    '4218-48-8',
    'GUUDUUDWUWUTPD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-ethyl-4-isopropylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethyl-4-isopropylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethyl-4-isopropylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-2,3-diethylbenzene',
    'C<sub>11</sub>H<sub>16</sub>',
    '',
    '13632-93-4',
    'LRJOXARIJKBUFE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-methyl-2,3-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-2,3-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-2,3-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-2,4-diethylbenzene',
    'C<sub>11</sub>H<sub>16</sub>',
    '',
    '1758-85-6',
    'PZMJNJDRDKPVLB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-methyl-2,4-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-2,4-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-2,4-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-2,5-diethylbenzene',
    'C<sub>11</sub>H<sub>16</sub>',
    '',
    '13632-94-5',
    'ZEHGGUIGEDITMM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-methyl-2,5-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-2,5-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-2,5-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-2,6-diethylbenzene',
    'C<sub>11</sub>H<sub>16</sub>',
    '',
    '13632-95-6',
    'XZZNTLNFQVAKFD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-methyl-2,6-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-2,6-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-2,6-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-3,5-diethylbenzene',
    'C<sub>11</sub>H<sub>16</sub>',
    '',
    '2050-24-0',
    'HILAULICMJUOLK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-methyl-3,5-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-3,5-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-3,5-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-3,5-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-3,5-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-3,5-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-2-butylbenzene',
    'C<sub>11</sub>H<sub>16</sub>',
    '',
    '1595-11-5',
    'NUJILYKLNKQOOX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-methyl-2-butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-2-butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-2-butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-3-butylbenzene',
    'C<sub>11</sub>H<sub>16</sub>',
    '',
    '1595-04-6',
    'OAPCPUDMDJIBOQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-methyl-3-butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-3-butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-3-butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-4-butylbenzene',
    'C<sub>11</sub>H<sub>16</sub>',
    '',
    '1595-05-7',
    'SBBKUBSYOVDBBC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-methyl-4-butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-4-butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-4-butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-2-isobutylbenzene',
    'C<sub>11</sub>H<sub>16</sub>',
    '',
    '36301-29-8',
    'XNMPJDZAHSMAMN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-methyl-2-isobutylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-2-isobutylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-2-isobutylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-3-isobutylbenzene',
    'C<sub>11</sub>H<sub>16</sub>',
    '',
    '5160-99-6',
    'SDHYGAUOCHFYSR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-methyl-3-isobutylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-3-isobutylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-3-isobutylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-4-isobutylbenzene',
    'C<sub>11</sub>H<sub>16</sub>',
    '',
    '5161-04-6',
    'VCGBZXLLPCGFQM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-methyl-4-isobutylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-4-isobutylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-4-isobutylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-2-<i>sec</i>-butylbenzene',
    'C<sub>11</sub>H<sub>16</sub>',
    '',
    '1595-06-8',
    'AMBAWAHKHZZAAY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-methyl-2-<i>sec</i>-butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-2-<i>sec</i>-butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-2-<i>sec</i>-butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-3-<i>sec</i>-butylbenzene',
    'C<sub>11</sub>H<sub>16</sub>',
    '',
    '1772-10-7',
    'RMNILBOMCXQZFC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-methyl-3-<i>sec</i>-butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-3-<i>sec</i>-butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-3-<i>sec</i>-butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-4-<i>sec</i>-butylbenzene',
    'C<sub>11</sub>H<sub>16</sub>',
    '',
    '1595-16-0',
    'LWCFXYMSEGQWNB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-methyl-4-<i>sec</i>-butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-4-<i>sec</i>-butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-4-<i>sec</i>-butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-2-<i>tert</i>-butyl benzene',
    'C<sub>11</sub>H<sub>16</sub>',
    '',
    '1074-92-6',
    'AXHVNJGQOJFMHT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-methyl-2-<i>tert</i>-butyl benzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-2-<i>tert</i>-butyl benzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-2-<i>tert</i>-butyl benzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-3-<i>tert</i>-butylbenzene',
    'C<sub>11</sub>H<sub>16</sub>',
    '',
    '1075-38-3',
    'JTIAYWZZZOZUTK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-methyl-3-<i>tert</i>-butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-3-<i>tert</i>-butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-3-<i>tert</i>-butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-3,4-diethylbenzene',
    'C<sub>11</sub>H<sub>16</sub>',
    '',
    '13732-80-4',
    'MJQJAQGFUBIGIK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-methyl-3,4-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-3,4-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-3,4-diethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-phenyl-2,2-dimethylpropane',
    'C<sub>11</sub>H<sub>16</sub>',
    '',
    '1007-26-7',
    'CJGXJKVMUHXVHL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-phenyl-2,2-dimethylpropane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-phenyl-2,2-dimethylpropane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-phenyl-2,2-dimethylpropane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-phenyl-2-methylbutane',
    'C<sub>11</sub>H<sub>16</sub>',
    '',
    '3968-85-2',
    'IFDLFCDWOFLKEB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-phenyl-2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-phenyl-2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-phenyl-2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-phenyl-3-methylbutane',
    'C<sub>11</sub>H<sub>16</sub>',
    '',
    '2049-94-7',
    'XNXIYYFOYIUJIW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-phenyl-3-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-phenyl-3-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-phenyl-3-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-phenyl-3-methylbutane',
    'C<sub>11</sub>H<sub>16</sub>',
    '',
    '4481-30-5',
    'NQRMTOKLHZNAQH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-phenyl-3-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-phenyl-3-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-phenyl-3-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-phenylpentane',
    'C<sub>11</sub>H<sub>16</sub>',
    '',
    '2719-52-0',
    'LTHAIAJHDPJXLG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-phenylpentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-phenylpentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-phenylpentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-phenylpentane',
    'C<sub>11</sub>H<sub>16</sub>',
    '',
    '1196-58-3',
    'PBWHJRFXUPLZDS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-phenylpentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-phenylpentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-phenylpentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(1,1-dimethylpropyl)-benzene',
    'C<sub>6</sub>H<sub>5</sub>C<sub>5</sub>H<sub>11</sub>',
    '<i>tert</i>-amylbenzene',
    '2049-95-8',
    'QHTJSSMHBLGUHV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(1,1-dimethylpropyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='(1,1-dimethylpropyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(1,1-dimethylpropyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(1,1-dimethylpropyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(1,1-dimethylpropyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(1,1-dimethylpropyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(1,1-dimethylpropyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(1,1-dimethylpropyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(1,1-dimethylpropyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(1,1-dimethylpropyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(1,1-dimethylpropyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hexylbenzene',
    'C<sub>6</sub>H<sub>5</sub>C<sub>6</sub>H<sub>13</sub>',
    '',
    '1077-16-3',
    'LTEQMZWBSYACLV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;4</sup>',
    '6500',
    'L',
    (SELECT id from species WHERE iupac='hexylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;4</sup>',
    '6300',
    'L',
    (SELECT id from species WHERE iupac='hexylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexylbenzene'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;3</sup>',
    '9000',
    'V',
    (SELECT id from species WHERE iupac='hexylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2219'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;4</sup>',
    '6300',
    'T',
    (SELECT id from species WHERE iupac='hexylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='hexylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexylbenzene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='hexylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='hexylbenzene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='hexylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hexamethylbenzene',
    'C<sub>12</sub>H<sub>18</sub>',
    '',
    '87-85-4',
    'YUWFEBAXEOLKSG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexamethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexamethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3-triethylbenzene',
    'C<sub>12</sub>H<sub>18</sub>',
    '',
    '42205-08-3',
    'VIDOPANCAUPXNH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,2,3-triethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-triethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-triethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4-triethylbenzene',
    'C<sub>12</sub>H<sub>18</sub>',
    '',
    '877-44-1',
    'WNLWIOJSURYFIB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,2,4-triethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-triethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-triethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2,4-triethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3,5-triethylbenzene',
    'C<sub>12</sub>H<sub>18</sub>',
    '',
    '102-25-0',
    'WJYMPXJVHNDZHD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,3,5-triethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,3,5-triethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-triethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-triethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-<i>tert</i>-butyl-o-xylene',
    'C<sub>12</sub>H<sub>18</sub>',
    '',
    '7397-06-0',
    'QRPPSTNABSMSCS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-<i>tert</i>-butyl-o-xylene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-<i>tert</i>-butyl-o-xylene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-<i>tert</i>-butyl-o-xylene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-<i>tert</i>-butyl-o-xylene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-(1,1-dimethylethyl)-3,5-dimethylbenzene',
    'C<sub>12</sub>H<sub>18</sub>',
    '',
    '98-19-1',
    'FZSPYHREEHYLCB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-(1,1-dimethylethyl)-3,5-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-(1,1-dimethylethyl)-3,5-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-(1,1-dimethylethyl)-3,5-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-(1,1-dimethylethyl)-3,5-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'o-diisopropylbenzene',
    'C<sub>12</sub>H<sub>18</sub>',
    '',
    '25321-09-9',
    'OKIRBHVFJGXOIS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='o-diisopropylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'm-diisopropylbenzene',
    'C<sub>12</sub>H<sub>18</sub>',
    '',
    '99-62-7',
    'UNEATYXSUBPPKP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='m-diisopropylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='m-diisopropylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='m-diisopropylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'p-diisopropylbenzene',
    'C<sub>12</sub>H<sub>18</sub>',
    '',
    '100-18-5',
    'SPPWGCYEYAMHDT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='p-diisopropylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='p-diisopropylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='p-diisopropylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='p-diisopropylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-phenylcyclohexene',
    'C<sub>12</sub>H<sub>14</sub>',
    '',
    '4994-16-5',
    'XWCWNUSFQVJNDI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-phenylcyclohexene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'heptylbenzene',
    'C<sub>6</sub>H<sub>5</sub>C<sub>7</sub>H<sub>15</sub>',
    '',
    '1078-71-3',
    'LBNXAWYDQUGHGX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='heptylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='heptylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '11000',
    'V',
    (SELECT id from species WHERE iupac='heptylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2219'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='heptylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='heptylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-<i>tert</i>-butyl-1,2,3-trimethylbenzene',
    'C<sub>13</sub>H<sub>20</sub>',
    '',
    '98-23-7',
    'ZQVJKYPEIPJEIP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-<i>tert</i>-butyl-1,2,3-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-<i>tert</i>-butyl-1,2,3-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-<i>tert</i>-butyl-1,2,3-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-<i>tert</i>-butyl-1,2,3-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'octylbenzene',
    'C<sub>6</sub>H<sub>5</sub>C<sub>8</sub>H<sub>17</sub>',
    '',
    '2189-60-8',
    'CDKDZKXSXLNROY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='octylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='octylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;2</sup>',
    '12000',
    'V',
    (SELECT id from species WHERE iupac='octylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2219'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='octylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='octylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nonylbenzene',
    'C<sub>15</sub>H<sub>24</sub>',
    '',
    '1081-77-2',
    'LIXVMPBOGDCSRM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='nonylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='nonylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,5-di-<i>tert</i>-butyltoluene',
    'C<sub>15</sub>H<sub>24</sub>',
    '',
    '15181-11-0',
    'WIXDSJRJFDWTNY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;3</sup>',
    '9100',
    'M',
    (SELECT id from species WHERE iupac='3,5-di-<i>tert</i>-butyltoluene'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3,5-tris(1-methylethyl)benzene',
    'C<sub>15</sub>H<sub>24</sub>',
    '',
    '717-74-8',
    'VUMCUSHVMYIRMB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-tris(1-methylethyl)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-tris(1-methylethyl)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-tris(1-methylethyl)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-tris(1-methylethyl)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyl(phenylethyl)-benzene',
    'C<sub>16</sub>H<sub>18</sub>',
    '',
    '64800-83-5',
    'BDEIYMXBPHSOSG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl(phenylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl(phenylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl(phenylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl(phenylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-(1-phenylethyl)-m-xylene',
    'C<sub>16</sub>H<sub>18</sub>',
    '',
    '6165-52-2',
    'JOUBGGHXBLOLFY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-(1-phenylethyl)-m-xylene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-(1-phenylethyl)-m-xylene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-(1-phenylethyl)-m-xylene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-(1-phenylethyl)-m-xylene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'decylbenzene',
    'C<sub>16</sub>H<sub>26</sub>',
    '1-phenyldecane',
    '104-72-3',
    'UZILCZKGXMQEQR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='decylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;5</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='decylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='decylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='decylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='decylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3679'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='decylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-phenyldecane',
    'C<sub>16</sub>H<sub>26</sub>',
    '',
    '4537-13-7',
    'DDTJIQUCOLHYDL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-phenyldecane'),
    (SELECT id from literature WHERE bibtexkey='3679'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-phenyldecane',
    'C<sub>16</sub>H<sub>26</sub>',
    '',
    '4621-36-7',
    'PYVIFMPVFLOTLN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-phenyldecane'),
    (SELECT id from literature WHERE bibtexkey='3679'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-phenyldecane',
    'C<sub>16</sub>H<sub>26</sub>',
    '',
    '4537-12-6',
    'QTDBKYLPIZUTFN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-phenyldecane'),
    (SELECT id from literature WHERE bibtexkey='3679'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-phenyldecane',
    'C<sub>16</sub>H<sub>26</sub>',
    '',
    '4537-11-5',
    'CDOBABYRHNVZQG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='5-phenyldecane'),
    (SELECT id from literature WHERE bibtexkey='3679'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'undecylbenzene',
    'C<sub>17</sub>H<sub>28</sub>',
    '1-phenylundecane',
    '6742-54-7',
    'XBEADGFTLHRJRB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='undecylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-phenylundecane',
    'C<sub>17</sub>H<sub>28</sub>',
    '',
    '4536-88-3',
    'YHJBCRBYDBNEIK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-phenylundecane'),
    (SELECT id from literature WHERE bibtexkey='3679'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-phenylundecane',
    'C<sub>17</sub>H<sub>28</sub>',
    '',
    '4536-87-2',
    'NVHBFHMWJJMQTG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-phenylundecane'),
    (SELECT id from literature WHERE bibtexkey='3679'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-phenylundecane',
    'C<sub>17</sub>H<sub>28</sub>',
    '',
    '4536-86-1',
    'NSQAXMRLBNXEHK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-phenylundecane'),
    (SELECT id from literature WHERE bibtexkey='3679'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-phenylundecane',
    'C<sub>17</sub>H<sub>28</sub>',
    '',
    '4537-15-9',
    'RRPCXIBGXYGQNC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='5-phenylundecane'),
    (SELECT id from literature WHERE bibtexkey='3679'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '6-phenylundecane',
    'C<sub>17</sub>H<sub>28</sub>',
    '',
    '4537-14-8',
    'WCABIRIFXVXGQH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='6-phenylundecane'),
    (SELECT id from literature WHERE bibtexkey='3679'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dodecylbenzene',
    'C<sub>18</sub>H<sub>30</sub>',
    '1-phenyldodecane',
    '123-01-3',
    'KWKXNDCHNDYVRT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dodecylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-phenyldodecane',
    'C<sub>18</sub>H<sub>30</sub>',
    '',
    '2719-61-1',
    'VRPRIAVYSREHAN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-phenyldodecane'),
    (SELECT id from literature WHERE bibtexkey='3679'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-phenyldodecane',
    'C<sub>18</sub>H<sub>30</sub>',
    '',
    '2400-00-2',
    'PGVOXXHNGYYHHB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-phenyldodecane'),
    (SELECT id from literature WHERE bibtexkey='3679'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-phenyldodecane',
    'C<sub>18</sub>H<sub>30</sub>',
    '',
    '2719-64-4',
    'RHDHXBLZBVAPTL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-phenyldodecane'),
    (SELECT id from literature WHERE bibtexkey='3679'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-phenyldodecane',
    'C<sub>18</sub>H<sub>30</sub>',
    '',
    '2719-63-3',
    'NPAWGLOPXKCTCV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='5-phenyldodecane'),
    (SELECT id from literature WHERE bibtexkey='3679'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '6-phenyldodecane',
    'C<sub>18</sub>H<sub>30</sub>',
    '',
    '2719-62-2',
    'ZYHJQFMTTFCBKH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='6-phenyldodecane'),
    (SELECT id from literature WHERE bibtexkey='3679'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tridecylbenzene',
    'C<sub>19</sub>H<sub>32</sub>',
    '1-phenyltridecane',
    '123-02-4',
    'MCVUKOYZUCWLQQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tridecylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3679'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tridecylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-phenyltridecane',
    'C<sub>19</sub>H<sub>32</sub>',
    '',
    '4534-53-6',
    'FCXPVFLEDIQLLO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-phenyltridecane'),
    (SELECT id from literature WHERE bibtexkey='3679'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-phenyltridecane',
    'C<sub>19</sub>H<sub>32</sub>',
    '',
    '4534-52-5',
    'VZZMNLVGDGMQQV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-phenyltridecane'),
    (SELECT id from literature WHERE bibtexkey='3679'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-phenyltridecane',
    'C<sub>19</sub>H<sub>32</sub>',
    '',
    '4534-51-4',
    'RZGVZPAWCGDMCK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-phenyltridecane'),
    (SELECT id from literature WHERE bibtexkey='3679'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-phenyltridecane',
    'C<sub>19</sub>H<sub>32</sub>',
    '',
    '4534-50-3',
    'MZTIRLOLMGVVEK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='5-phenyltridecane'),
    (SELECT id from literature WHERE bibtexkey='3679'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '6-phenyltridecane',
    'C<sub>19</sub>H<sub>32</sub>',
    '',
    '4534-49-0',
    'OTSYFFDVDLHIKX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='6-phenyltridecane'),
    (SELECT id from literature WHERE bibtexkey='3679'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tetradecylbenzene',
    'C<sub>20</sub>H<sub>34</sub>',
    '1-phenyltetradecane',
    '1459-10-5',
    'JZALLXAUNPOCEU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetradecylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-phenyltetradecane',
    'C<sub>20</sub>H<sub>34</sub>',
    '',
    '4534-59-2',
    'GDFUGKICRHMMOT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-phenyltetradecane'),
    (SELECT id from literature WHERE bibtexkey='3679'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-phenyltetradecane',
    'C<sub>20</sub>H<sub>34</sub>',
    '',
    '4534-58-1',
    'ILOABSZOHZMWLD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-phenyltetradecane'),
    (SELECT id from literature WHERE bibtexkey='3679'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-phenyltetradecane',
    'C<sub>20</sub>H<sub>34</sub>',
    '',
    '4534-57-0',
    'YXLRHYCRTUAPMC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-phenyltetradecane'),
    (SELECT id from literature WHERE bibtexkey='3679'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-phenyltetradecane',
    'C<sub>20</sub>H<sub>34</sub>',
    '',
    '4534-56-9',
    'RAWFVRXBPRHWLJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='5-phenyltetradecane'),
    (SELECT id from literature WHERE bibtexkey='3679'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '6-phenyltetradecane',
    'C<sub>20</sub>H<sub>34</sub>',
    '',
    '4534-55-8',
    'MTDIFFBFSKQPIA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='6-phenyltetradecane'),
    (SELECT id from literature WHERE bibtexkey='3679'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pentadecylbenzene',
    'C<sub>21</sub>H<sub>36</sub>',
    '',
    '2131-18-2',
    'JIRNEODMTPGRGV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentadecylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethenylbenzene',
    'C<sub>8</sub>H<sub>8</sub>',
    'styrene',
    '100-42-5',
    'PPBRXRYQALVLMV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '3700',
    'L',
    (SELECT id from species WHERE iupac='ethenylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '4200',
    'L',
    (SELECT id from species WHERE iupac='ethenylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethenylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3032'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;3</sup>',
    '4600',
    'M',
    (SELECT id from species WHERE iupac='ethenylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethenylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2938'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethenylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3646'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '4100',
    'M',
    (SELECT id from species WHERE iupac='ethenylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2904'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '4800',
    'M',
    (SELECT id from species WHERE iupac='ethenylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2270'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethenylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2917'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethenylbenzene'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethenylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethenylbenzene'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethenylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethenylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '4200',
    'X',
    (SELECT id from species WHERE iupac='ethenylbenzene'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '3800',
    'C',
    (SELECT id from species WHERE iupac='ethenylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethenylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethenylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethenylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethenylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethenylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethenylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethenylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethenylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethenylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethenylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethenylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethenylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethenylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4800',
    'Q',
    (SELECT id from species WHERE iupac='ethenylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethenylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethenylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethenylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethenylbenzene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethenylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3700',
    '?',
    (SELECT id from species WHERE iupac='ethenylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethenylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethenylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethenylbenzene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='ethenylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2338'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2338',
    '2338', 'Because of discrepancies between the values shown in Tables&nbsp;4 and 5 of Shiu and Ma (2000), the data are not used here.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2338'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(E)-1-propenylbenzene',
    'C<sub>9</sub>H<sub>10</sub>',
    '',
    '873-66-5',
    'QROGIFZRVHSFLM-QHHAFSJGSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(E)-1-propenylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-propenylbenzene',
    'C<sub>9</sub>H<sub>10</sub>',
    '',
    '637-50-3',
    'QROGIFZRVHSFLM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-propenylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-propenylbenzene',
    'C<sub>9</sub>H<sub>10</sub>',
    'allylbenzene',
    '300-57-2',
    'HJWLCRVIBGQPNF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-propenylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2917'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propenylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propenylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propenylbenzene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-propenylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-ethenyl-3-methylbenzene',
    'C<sub>9</sub>H<sub>10</sub>',
    'm-methylstyrene',
    '100-80-1',
    'JZHGRUMIRATHIU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-ethenyl-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethenyl-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethenyl-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethenyl-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethenyl-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-ethenyl-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-ethenyl-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-ethenyl-4-methylbenzene',
    'C<sub>9</sub>H<sub>10</sub>',
    'p-methylstyrene',
    '622-97-9',
    'JLBJTVDPSNHSKJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-ethenyl-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-ethenyl-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-ethenyl-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethenyl-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethenyl-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethenyl-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethenyl-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethenyl-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethenyl-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethenyl-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethenyl-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethenyl-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-ethenyl-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-ethenyl-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(1-methylethenyl)-benzene',
    'C<sub>9</sub>H<sub>10</sub>',
    '&#945;-methyl styrene',
    '98-83-9',
    'XYLMUPLGERFSHI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(1-methylethenyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(1-methylethenyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(1-methylethenyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(1-methylethenyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(1-methylethenyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(1-methylethenyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phenylacetylene',
    'C<sub>8</sub>H<sub>6</sub>',
    '',
    '536-74-3',
    'UEXCJVNBTNXOEH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='phenylacetylene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='phenylacetylene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenylacetylene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenylacetylene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenylacetylene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenylacetylene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenylacetylene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenylacetylene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '&#945;-methylstyrene dimer',
    'C<sub>18</sub>H<sub>20</sub>',
    '',
    '6144-04-3',
    'ATSCZMXECPRPEA-BUHFOSPRSA-N',
    (SELECT id from subcategories WHERE subcatname='Mononuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#945;-methylstyrene dimer'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#945;-methylstyrene dimer'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#945;-methylstyrene dimer'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#945;-methylstyrene dimer'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#945;-methylstyrene dimer'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Terpenes and terpenoids',
    (SELECT id from categories WHERE catname='Hydrocarbons (C, H)'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-4-(1-methylethyl)-cyclohexane',
    'C<sub>10</sub>H<sub>20</sub>',
    'p-menthane',
    '99-82-1',
    'CFJYNSNXFXLKNS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Terpenes and terpenoids'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-cyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-cyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2124'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-cyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '&#945;-pinene',
    'C<sub>10</sub>H<sub>16</sub>',
    '',
    '80-56-8',
    'GRWFGVWFFZKLTI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Terpenes and terpenoids'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;5</sup>',
    '4700',
    'L',
    (SELECT id from species WHERE iupac='&#945;-pinene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;4</sup>',
    '1800',
    'M',
    (SELECT id from species WHERE iupac='&#945;-pinene'),
    (SELECT id from literature WHERE bibtexkey='3008'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;5</sup>',
    '4400',
    'M',
    (SELECT id from species WHERE iupac='&#945;-pinene'),
    (SELECT id from literature WHERE bibtexkey='2124'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='&#945;-pinene'),
    (SELECT id from literature WHERE bibtexkey='1922'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='&#945;-pinene'),
    (SELECT id from literature WHERE bibtexkey='3643'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='&#945;-pinene'),
    (SELECT id from literature WHERE bibtexkey='3670'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3670',
    '3670', 'Effective Henry''s law constants at several pH values are provided by van Ruth and Villeneuve (2002). Here, only the value at pH = 3 is shown.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3670'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='&#945;-pinene'),
    (SELECT id from literature WHERE bibtexkey='3611'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;5</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='&#945;-pinene'),
    (SELECT id from literature WHERE bibtexkey='2462'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;5</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='&#945;-pinene'),
    (SELECT id from literature WHERE bibtexkey='2460'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='&#945;-pinene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='&#945;-pinene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='&#945;-pinene'),
    (SELECT id from literature WHERE bibtexkey='2124'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='&#945;-pinene'),
    (SELECT id from literature WHERE bibtexkey='2487'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;5</sup>',
    '10000',
    'V',
    (SELECT id from species WHERE iupac='&#945;-pinene'),
    (SELECT id from literature WHERE bibtexkey='2464'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;5</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='&#945;-pinene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#945;-pinene'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#945;-pinene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#945;-pinene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#945;-pinene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#945;-pinene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#945;-pinene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '&#946;-pinene',
    'C<sub>10</sub>H<sub>16</sub>',
    '',
    '127-91-3',
    'WTARULDDTDQWMU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Terpenes and terpenoids'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='&#946;-pinene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='&#946;-pinene'),
    (SELECT id from literature WHERE bibtexkey='2955'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;4</sup>',
    '4500',
    'M',
    (SELECT id from species WHERE iupac='&#946;-pinene'),
    (SELECT id from literature WHERE bibtexkey='2124'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='&#946;-pinene'),
    (SELECT id from literature WHERE bibtexkey='1922'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;5</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='&#946;-pinene'),
    (SELECT id from literature WHERE bibtexkey='2460'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='&#946;-pinene'),
    (SELECT id from literature WHERE bibtexkey='2124'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='&#946;-pinene'),
    (SELECT id from literature WHERE bibtexkey='2487'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#946;-pinene'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#946;-pinene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#946;-pinene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#946;-pinene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#946;-pinene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-4-(1-methylethyl)-1,3-cyclohexadiene',
    'C<sub>10</sub>H<sub>16</sub>',
    '&#945;-terpinene',
    '99-86-5',
    'YHQGMYUVUMAZJR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Terpenes and terpenoids'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-1,3-cyclohexadiene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-1,3-cyclohexadiene'),
    (SELECT id from literature WHERE bibtexkey='3423'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;4</sup>',
    '4800',
    'M',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-1,3-cyclohexadiene'),
    (SELECT id from literature WHERE bibtexkey='2124'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-1,3-cyclohexadiene'),
    (SELECT id from literature WHERE bibtexkey='1922'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-1,3-cyclohexadiene'),
    (SELECT id from literature WHERE bibtexkey='2124'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-1,3-cyclohexadiene'),
    (SELECT id from literature WHERE bibtexkey='2487'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-1,3-cyclohexadiene'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-4-(1-methylethyl)-1,4-cyclohexadiene',
    'C<sub>10</sub>H<sub>16</sub>',
    '&#947;-terpinene',
    '99-85-4',
    'YKFLAYDHMOASIY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Terpenes and terpenoids'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;4</sup>',
    '4300',
    'L',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-1,4-cyclohexadiene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-1,4-cyclohexadiene'),
    (SELECT id from literature WHERE bibtexkey='3423'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;4</sup>',
    '4800',
    'M',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-1,4-cyclohexadiene'),
    (SELECT id from literature WHERE bibtexkey='2124'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-1,4-cyclohexadiene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-1,4-cyclohexadiene'),
    (SELECT id from literature WHERE bibtexkey='2124'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-1,4-cyclohexadiene'),
    (SELECT id from literature WHERE bibtexkey='2487'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;4</sup>',
    '8000',
    'V',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-1,4-cyclohexadiene'),
    (SELECT id from literature WHERE bibtexkey='2464'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-1,4-cyclohexadiene'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-1,4-cyclohexadiene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-1,4-cyclohexadiene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-4-(1-methylethenyl)-cyclohexene',
    'C<sub>10</sub>H<sub>16</sub>',
    'limonene',
    '138-86-3',
    'XMGQYMWWDOXHJM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Terpenes and terpenoids'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;4</sup>',
    '4700',
    'L',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethenyl)-cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;4</sup>',
    '4600',
    'M',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethenyl)-cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='3008'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethenyl)-cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='3554'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethenyl)-cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='2462'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethenyl)-cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='3646'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethenyl)-cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='2460'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethenyl)-cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethenyl)-cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethenyl)-cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='2124'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;4</sup>',
    '3000',
    'V',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethenyl)-cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='2125'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethenyl)-cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='2487'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;4</sup>',
    '10000',
    'V',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethenyl)-cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='2464'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethenyl)-cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethenyl)-cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethenyl)-cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethenyl)-cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethenyl)-cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethenyl)-cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethenyl)-cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(R)-1-methyl-4-(1-methylethenyl)-cyclohexene',
    'C<sub>10</sub>H<sub>16</sub>',
    'R-(+)-limonene; D-limonene',
    '5989-27-5',
    'XMGQYMWWDOXHJM-SNVBAGLBSA-N',
    (SELECT id from subcategories WHERE subcatname='Terpenes and terpenoids'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='(R)-1-methyl-4-(1-methylethenyl)-cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='3423'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='(R)-1-methyl-4-(1-methylethenyl)-cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='2955'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;4</sup>',
    '4500',
    'M',
    (SELECT id from species WHERE iupac='(R)-1-methyl-4-(1-methylethenyl)-cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='2124'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(R)-1-methyl-4-(1-methylethenyl)-cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(R)-1-methyl-4-(1-methylethenyl)-cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(R)-1-methyl-4-(1-methylethenyl)-cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='(R)-1-methyl-4-(1-methylethenyl)-cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='(R)-1-methyl-4-(1-methylethenyl)-cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(R)-1-methyl-4-(1-methylethenyl)-cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(R)-1-methyl-4-(1-methylethenyl)-cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(R)-1-methyl-4-(1-methylethenyl)-cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(R)-1-methyl-4-(1-methylethenyl)-cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(R)-1-methyl-4-(1-methylethenyl)-cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(R)-1-methyl-4-(1-methylethenyl)-cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(S)-1-methyl-4-(1-methylethenyl)-cyclohexene',
    'C<sub>10</sub>H<sub>16</sub>',
    'S-(-)-limonene',
    '5989-54-8',
    'XMGQYMWWDOXHJM-JTQLQIEISA-N',
    (SELECT id from subcategories WHERE subcatname='Terpenes and terpenoids'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='(S)-1-methyl-4-(1-methylethenyl)-cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='3423'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;4</sup>',
    '4400',
    'M',
    (SELECT id from species WHERE iupac='(S)-1-methyl-4-(1-methylethenyl)-cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='2124'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,7,7-trimethyl-bicyclo[4.1.0]hept-3-ene',
    'C<sub>10</sub>H<sub>16</sub>',
    '3-carene',
    '13466-78-9',
    'BQOFWKZOCNGFEC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Terpenes and terpenoids'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3,7,7-trimethyl-bicyclo[4.1.0]hept-3-ene'),
    (SELECT id from literature WHERE bibtexkey='2460'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,7,7-trimethyl-bicyclo[4.1.0]hept-3-ene'),
    (SELECT id from literature WHERE bibtexkey='2124'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,7,7-trimethyl-bicyclo[4.1.0]hept-3-ene'),
    (SELECT id from literature WHERE bibtexkey='2487'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '7-methyl-3-methylene-1,6-octadiene',
    'C<sub>10</sub>H<sub>16</sub>',
    'myrcene',
    '123-35-3',
    'UAHWPYUMFXYFJY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Terpenes and terpenoids'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='7-methyl-3-methylene-1,6-octadiene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='7-methyl-3-methylene-1,6-octadiene'),
    (SELECT id from literature WHERE bibtexkey='3423'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='7-methyl-3-methylene-1,6-octadiene'),
    (SELECT id from literature WHERE bibtexkey='2462'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='7-methyl-3-methylene-1,6-octadiene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='7-methyl-3-methylene-1,6-octadiene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='7-methyl-3-methylene-1,6-octadiene'),
    (SELECT id from literature WHERE bibtexkey='2124'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;4</sup>',
    '2800',
    'V',
    (SELECT id from species WHERE iupac='7-methyl-3-methylene-1,6-octadiene'),
    (SELECT id from literature WHERE bibtexkey='2125'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='7-methyl-3-methylene-1,6-octadiene'),
    (SELECT id from literature WHERE bibtexkey='2487'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='7-methyl-3-methylene-1,6-octadiene'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='7-methyl-3-methylene-1,6-octadiene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='7-methyl-3-methylene-1,6-octadiene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='7-methyl-3-methylene-1,6-octadiene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='7-methyl-3-methylene-1,6-octadiene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-4-(1-methylethylidene)-cyclohexene',
    'C<sub>10</sub>H<sub>16</sub>',
    '&#945;-terpinolene',
    '586-62-9',
    'MOYAFQVGZZPNRA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Terpenes and terpenoids'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;4</sup>',
    '5500',
    'L',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethylidene)-cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;4</sup>',
    '5300',
    'M',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethylidene)-cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='2124'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethylidene)-cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethylidene)-cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='2124'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethylidene)-cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='2487'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;4</sup>',
    '12000',
    'V',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethylidene)-cyclohexene'),
    (SELECT id from literature WHERE bibtexkey='2464'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '&#945;-phellandrene',
    'C<sub>10</sub>H<sub>16</sub>',
    '',
    '99-83-2',
    'OGLDWXZKYODSOB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Terpenes and terpenoids'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='&#945;-phellandrene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;4</sup>',
    '4500',
    'M',
    (SELECT id from species WHERE iupac='&#945;-phellandrene'),
    (SELECT id from literature WHERE bibtexkey='2124'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='&#945;-phellandrene'),
    (SELECT id from literature WHERE bibtexkey='2124'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='&#945;-phellandrene'),
    (SELECT id from literature WHERE bibtexkey='2487'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#945;-phellandrene'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(R)-(&#8722;)-&#945;-phellandrene',
    'C<sub>10</sub>H<sub>16</sub>',
    '',
    '4221-98-1',
    'OGLDWXZKYODSOB-SNVBAGLBSA-N',
    (SELECT id from subcategories WHERE subcatname='Terpenes and terpenoids'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='(R)-(&#8722;)-&#945;-phellandrene'),
    (SELECT id from literature WHERE bibtexkey='3423'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '&#946;-phellandrene',
    'C<sub>10</sub>H<sub>16</sub>',
    '',
    '555-10-2',
    'LFJQCDVYDGGFCH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Terpenes and terpenoids'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;4</sup>',
    '5100',
    'M',
    (SELECT id from species WHERE iupac='&#946;-phellandrene'),
    (SELECT id from literature WHERE bibtexkey='2124'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='&#946;-phellandrene'),
    (SELECT id from literature WHERE bibtexkey='2124'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='&#946;-phellandrene'),
    (SELECT id from literature WHERE bibtexkey='2487'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#946;-phellandrene'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,7-dimethyl-1,3,6-octatriene',
    'C<sub>10</sub>H<sub>16</sub>',
    '&#946;-ocimene',
    '13877-91-3',
    'IHPKGUQCSIINRJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Terpenes and terpenoids'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,7-dimethyl-1,3,6-octatriene'),
    (SELECT id from literature WHERE bibtexkey='2124'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(Z)-3,7-dimethyl-1,3,6-octatriene',
    'C<sub>10</sub>H<sub>16</sub>',
    '<i>cis</i>-&#946;-ocimene',
    '3338-55-4',
    'IHPKGUQCSIINRJ-NTMALXAHSA-N',
    (SELECT id from subcategories WHERE subcatname='Terpenes and terpenoids'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(Z)-3,7-dimethyl-1,3,6-octatriene'),
    (SELECT id from literature WHERE bibtexkey='2487'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(E)-3,7-dimethyl-1,3,6-octatriene',
    'C<sub>10</sub>H<sub>16</sub>',
    '<i>trans</i>-&#946;-ocimene',
    '3779-61-1',
    'IHPKGUQCSIINRJ-CSKARUKUSA-N',
    (SELECT id from subcategories WHERE subcatname='Terpenes and terpenoids'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(E)-3,7-dimethyl-1,3,6-octatriene'),
    (SELECT id from literature WHERE bibtexkey='2487'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dimethyl-3-methylene-bicyclo[2.2.1]heptane',
    'C<sub>10</sub>H<sub>16</sub>',
    'camphene',
    '79-92-5',
    'CRPUJAZIXJMDBK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Terpenes and terpenoids'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2,2-dimethyl-3-methylene-bicyclo[2.2.1]heptane'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2-dimethyl-3-methylene-bicyclo[2.2.1]heptane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2-dimethyl-3-methylene-bicyclo[2.2.1]heptane'),
    (SELECT id from literature WHERE bibtexkey='2124'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2-dimethyl-3-methylene-bicyclo[2.2.1]heptane'),
    (SELECT id from literature WHERE bibtexkey='2487'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methylene-1-(1-methylethyl)-bicyclo[3.1.0]hexane',
    'C<sub>10</sub>H<sub>16</sub>',
    'sabinene',
    '3387-41-5',
    'NDVASEGYNIMXJL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Terpenes and terpenoids'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='4-methylene-1-(1-methylethyl)-bicyclo[3.1.0]hexane'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-methylene-1-(1-methylethyl)-bicyclo[3.1.0]hexane'),
    (SELECT id from literature WHERE bibtexkey='2124'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-methylene-1-(1-methylethyl)-bicyclo[3.1.0]hexane'),
    (SELECT id from literature WHERE bibtexkey='2487'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tricyclo[3.3.1.1(3,7)]decane',
    'C<sub>10</sub>H<sub>16</sub>',
    'adamantane',
    '281-23-2',
    'ORILYTVJVMAKLC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Terpenes and terpenoids'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;4</sup>',
    '3400',
    'V',
    (SELECT id from species WHERE iupac='tricyclo[3.3.1.1(3,7)]decane'),
    (SELECT id from literature WHERE bibtexkey='2125'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tricyclo[3.3.1.1(3,7)]decane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '&#946;-caryophyllene',
    'C<sub>15</sub>H<sub>24</sub>',
    '',
    '87-44-5',
    'NPNUFJAVOOONJE-IOMPXFEGSA-N',
    (SELECT id from subcategories WHERE subcatname='Terpenes and terpenoids'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;4</sup>',
    '4500',
    'M',
    (SELECT id from species WHERE iupac='&#946;-caryophyllene'),
    (SELECT id from literature WHERE bibtexkey='3216'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#946;-caryophyllene'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#946;-caryophyllene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#946;-caryophyllene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#946;-caryophyllene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '&#945;-cedrene',
    'C<sub>15</sub>H<sub>24</sub>',
    '',
    '469-61-4',
    'IRAQOCYXUMOFCW-KYEXWDHISA-N',
    (SELECT id from subcategories WHERE subcatname='Terpenes and terpenoids'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;4</sup>',
    '4900',
    'M',
    (SELECT id from species WHERE iupac='&#945;-cedrene'),
    (SELECT id from literature WHERE bibtexkey='3216'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '&#945;-farnesene',
    'C<sub>15</sub>H<sub>24</sub>',
    '',
    '502-61-4',
    'CXENHBSYCFFKJS-VDQVFBMKSA-N',
    (SELECT id from subcategories WHERE subcatname='Terpenes and terpenoids'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '4300',
    'M',
    (SELECT id from species WHERE iupac='&#945;-farnesene'),
    (SELECT id from literature WHERE bibtexkey='3216'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;6</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='&#945;-farnesene'),
    (SELECT id from literature WHERE bibtexkey='3423'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '&#945;-humulene',
    'C<sub>15</sub>H<sub>24</sub>',
    '',
    '6753-98-6',
    'FAMPSKZZVDUYOS-HRGUGZIWSA-N',
    (SELECT id from subcategories WHERE subcatname='Terpenes and terpenoids'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;4</sup>',
    '4700',
    'M',
    (SELECT id from species WHERE iupac='&#945;-humulene'),
    (SELECT id from literature WHERE bibtexkey='3216'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '&#947;-gurjunene',
    'C<sub>15</sub>H<sub>24</sub>',
    '',
    '22567-17-5',
    'DUYRYUZIBGFLDD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Terpenes and terpenoids'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;4</sup>',
    '3700',
    'M',
    (SELECT id from species WHERE iupac='&#947;-gurjunene'),
    (SELECT id from literature WHERE bibtexkey='3216'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'isosativene',
    'C<sub>15</sub>H<sub>24</sub>',
    '',
    '24959-83-9',
    'CGZBLYYTRIVVTD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Terpenes and terpenoids'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '3600',
    'M',
    (SELECT id from species WHERE iupac='isosativene'),
    (SELECT id from literature WHERE bibtexkey='3216'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '&#945;-longipinene',
    'C<sub>15</sub>H<sub>24</sub>',
    '',
    '5989-08-2',
    'HICYDYJTCDBHMZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Terpenes and terpenoids'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '4100',
    'M',
    (SELECT id from species WHERE iupac='&#945;-longipinene'),
    (SELECT id from literature WHERE bibtexkey='3216'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '&#945;-neoclovene',
    'C<sub>15</sub>H<sub>24</sub>',
    '',
    '4545-68-0',
    'ZCJQJJWNFDNQGZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Terpenes and terpenoids'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;4</sup>',
    '3100',
    'M',
    (SELECT id from species WHERE iupac='&#945;-neoclovene'),
    (SELECT id from literature WHERE bibtexkey='3216'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '&#946;-neoclovene',
    'C<sub>15</sub>H<sub>24</sub>',
    '',
    '56684-96-9',
    'BUDWHMNUSAOQBI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Terpenes and terpenoids'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;4</sup>',
    '4600',
    'M',
    (SELECT id from species WHERE iupac='&#946;-neoclovene'),
    (SELECT id from literature WHERE bibtexkey='3216'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '&#947;-neoclovene',
    'C<sub>15</sub>H<sub>24</sub>',
    '',
    '',
    'ZYKFQRCKKGFKQR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Terpenes and terpenoids'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;4</sup>',
    '3200',
    'M',
    (SELECT id from species WHERE iupac='&#947;-neoclovene'),
    (SELECT id from literature WHERE bibtexkey='3216'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'valencene',
    'C<sub>15</sub>H<sub>24</sub>',
    '',
    '4630-07-3',
    'QEBNYNLSCGVZOH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Terpenes and terpenoids'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;4</sup>',
    '4500',
    'M',
    (SELECT id from species WHERE iupac='valencene'),
    (SELECT id from literature WHERE bibtexkey='3216'));
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Polynuclear aromatics',
    (SELECT id from categories WHERE catname='Hydrocarbons (C, H)'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bis(1-methylethyl)-1,1''-biphenyl',
    'C<sub>18</sub>H<sub>22</sub>',
    '',
    '36876-13-8',
    'NUEUMFZLNOCRCQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis(1-methylethyl)-1,1''-biphenyl'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis(1-methylethyl)-1,1''-biphenyl'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis(1-methylethyl)-1,1''-biphenyl'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis(1-methylethyl)-1,1''-biphenyl'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis(1-methylethyl)-1,1''-biphenyl'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1-bis(3,4-dimethylphenyl)ethane',
    'C<sub>18</sub>H<sub>22</sub>',
    '',
    '1742-14-9',
    'NCSVCMFDHINRJE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-bis(3,4-dimethylphenyl)ethane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-bis(3,4-dimethylphenyl)ethane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-bis(3,4-dimethylphenyl)ethane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-bis(3,4-dimethylphenyl)ethane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-benzyl-2-(2-methylbenzyl)benzene',
    'C<sub>21</sub>H<sub>20</sub>',
    '',
    '100404-06-6',
    'SMOZJCPUZPHHKQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-benzyl-2-(2-methylbenzyl)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-benzyl-2-(2-methylbenzyl)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-benzyl-2-(2-methylbenzyl)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-benzyl-2-(2-methylbenzyl)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5-dibenzyltoluene',
    'C<sub>21</sub>H<sub>20</sub>',
    '',
    '56310-11-3',
    'INLIRICAUXXHSB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dibenzyltoluene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dibenzyltoluene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dibenzyltoluene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dibenzyltoluene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'biphenyl',
    '(C<sub>6</sub>H<sub>5</sub>)<sub>2</sub>',
    '',
    '92-52-4',
    'ZUOUZKKEUPVFJK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '7000',
    'L',
    (SELECT id from species WHERE iupac='biphenyl'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='biphenyl'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='biphenyl'),
    (SELECT id from literature WHERE bibtexkey='2497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'M',
    (SELECT id from species WHERE iupac='biphenyl'),
    (SELECT id from literature WHERE bibtexkey='1107'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '1107notused',
    '1107', 'The values of Dewulf et&nbsp;al. (1999) are not used here because, according to them, the calculated regression does not match the theoretical expectation for this species.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1107notused'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='biphenyl'),
    (SELECT id from literature WHERE bibtexkey='2339'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='biphenyl'),
    (SELECT id from literature WHERE bibtexkey='1144'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='biphenyl'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='biphenyl'),
    (SELECT id from literature WHERE bibtexkey='490'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='biphenyl'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='biphenyl'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='biphenyl'),
    (SELECT id from literature WHERE bibtexkey='2338'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='biphenyl'),
    (SELECT id from literature WHERE bibtexkey='2339'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='biphenyl'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='biphenyl'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='biphenyl'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='biphenyl'),
    (SELECT id from literature WHERE bibtexkey='2302'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='biphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '6200',
    'V',
    (SELECT id from species WHERE iupac='biphenyl'),
    (SELECT id from literature WHERE bibtexkey='3794'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='biphenyl'),
    (SELECT id from literature WHERE bibtexkey='1910'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='biphenyl'),
    (SELECT id from literature WHERE bibtexkey='2471'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='biphenyl'),
    (SELECT id from literature WHERE bibtexkey='790'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;3</sup>',
    '2900',
    'T',
    (SELECT id from species WHERE iupac='biphenyl'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='biphenyl'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='biphenyl'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='biphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='biphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='biphenyl'),
    (SELECT id from literature WHERE bibtexkey='3665'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3665-COSMO',
    '', 'Calculated using the COSMO-RS method.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3665-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='biphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='biphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5100',
    'Q',
    (SELECT id from species WHERE iupac='biphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='biphenyl'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='biphenyl'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='biphenyl'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='biphenyl'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='biphenyl'),
    (SELECT id from literature WHERE bibtexkey='2481'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='biphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6000',
    '?',
    (SELECT id from species WHERE iupac='biphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='biphenyl'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-1,1''-biphenyl',
    'C<sub>13</sub>H<sub>12</sub>',
    '',
    '643-58-3',
    'ALLIZEAXNXSFGD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1,1''-biphenyl'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1,1''-biphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-1,1''-biphenyl',
    'C<sub>13</sub>H<sub>12</sub>',
    '',
    '643-93-6',
    'NPDIDUXTRAITDE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1,1''-biphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-1,1''-biphenyl',
    'C<sub>13</sub>H<sub>12</sub>',
    '',
    '644-08-6',
    'ZZLCFHIKESPLTH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1,1''-biphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diphenylmethane',
    'C<sub>13</sub>H<sub>12</sub>',
    '1,1''-methylenebisbenzene',
    '101-81-5',
    'CZZYITDELCSZES-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diphenylmethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diphenylmethane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='diphenylmethane'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='diphenylmethane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diphenylmethane'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diphenylmethane'),
    (SELECT id from literature WHERE bibtexkey='1910'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'X',
    (SELECT id from species WHERE iupac='diphenylmethane'),
    (SELECT id from literature WHERE bibtexkey='634'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'from3034',
    '3034', 'Value given here as quoted by Haynes (2014).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3034'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='diphenylmethane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diphenylmethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diphenylmethane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diphenylmethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diphenylmethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diphenylmethane'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='diphenylmethane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-diphenylethane',
    'C<sub>14</sub>H<sub>14</sub>',
    'dibenzyl',
    '103-29-7',
    'QWUWMCYKGHVNAV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-diphenylethane'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-diphenylethane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,2-diphenylethane'),
    (SELECT id from literature WHERE bibtexkey='634'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3034'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-isopropyl-1,1''-biphenyl',
    'C<sub>15</sub>H<sub>16</sub>',
    '',
    '20282-30-8',
    'LIWRTHVZRZXVFX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-isopropyl-1,1''-biphenyl'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3766_D1',
    '3766', 'Ebert et&nbsp;al. (2023) present "curated experimental" Henry''s law constants from the literature but do not provide any references. It is only mentioned that the value is from a single database or data collection and measured directly.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-isopropyl-1,1''-biphenyl',
    'C<sub>15</sub>H<sub>16</sub>',
    '',
    '7116-95-2',
    'KWSHGRJUSUJPQD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-isopropyl-1,1''-biphenyl'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'o-terphenyl',
    'C<sub>18</sub>H<sub>14</sub>',
    '',
    '84-15-1',
    'OIAQMFOKAXHPNH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='o-terphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='o-terphenyl'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='o-terphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='o-terphenyl'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='o-terphenyl'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='o-terphenyl'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='o-terphenyl'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'm-terphenyl',
    'C<sub>18</sub>H<sub>14</sub>',
    '',
    '92-06-8',
    'YJTKZCDBKVTVBY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '',
    'V',
    (SELECT id from species WHERE iupac='m-terphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '',
    'V',
    (SELECT id from species WHERE iupac='m-terphenyl'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='m-terphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='m-terphenyl'),
    (SELECT id from literature WHERE bibtexkey='3665'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3665-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'p-terphenyl',
    'C<sub>18</sub>H<sub>14</sub>',
    '',
    '92-94-4',
    'XJKSTNDFUHDPQJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0',
    '',
    'V',
    (SELECT id from species WHERE iupac='p-terphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='p-terphenyl'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2611_pc_problem'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='p-terphenyl'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='p-terphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='p-terphenyl'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='p-terphenyl'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='p-terphenyl'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='p-terphenyl'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='p-terphenyl'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='p-terphenyl'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'indene',
    'C<sub>9</sub>H<sub>8</sub>',
    '',
    '95-13-6',
    'YBYIRNPNPLQARY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='indene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-ethylidene-2-norbornene',
    'C<sub>9</sub>H<sub>12</sub>',
    '',
    '16219-75-3',
    'OJOWICOBYCXEKR-KRXBUXKQSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-ethylidene-2-norbornene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'indane',
    'C<sub>9</sub>H<sub>10</sub>',
    '',
    '496-11-7',
    'PQNFLJBBNBOBRQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='indane'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='indane'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='indane'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='indane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='indane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='indane'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='indane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='indane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='indane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='indane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='indane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='indane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='indane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='indane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='indane'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='indane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='indane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'azulene',
    'C<sub>10</sub>H<sub>8</sub>',
    '',
    '275-51-4',
    'CUFNKYGDVFVPHO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '7800',
    'M',
    (SELECT id from species WHERE iupac='azulene'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'naphthalene',
    'C<sub>10</sub>H<sub>8</sub>',
    '',
    '91-20-3',
    'UFWIBTONFRDIAS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '4400',
    'L',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='3681'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '5400',
    'L',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='2989'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'LDV',
    '', 'Literature-derived value.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='LDV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='2989'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'FAV',
    '', 'Final adjusted value.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '5300',
    'L',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '6100',
    'M',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='3014'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='2899'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='2497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '3600',
    'M',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='1107'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='981'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='2339'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '5100',
    'M',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='2904'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '5700',
    'M',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='1597'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='2937'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='1144'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='2479'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='2537'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='490'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='2459'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '5400',
    'M',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='2458'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='2338'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='981'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='2339'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='1910'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='2471'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '5100',
    'V',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='2375'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '5600',
    'V',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='2375'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='790'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '2100',
    'T',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='490'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '3600',
    'X',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='mccarty80'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'from2556',
    '2556', 'Value given here as quoted by Petrasek et&nbsp;al. (1983).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from2556'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='3071'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3400-COSMO',
    '', 'Calculated using COSMOtherm.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='3655'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3655-COSMO',
    '', 'Calculated using the COSMO-RS method.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3655-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='3665'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3665-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5200',
    'Q',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='2481'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5400',
    '?',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='naphthalene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'naphthalene-d8',
    'C<sub>10</sub>D<sub>8</sub>',
    '',
    '1146-65-2',
    'UFWIBTONFRDIAS-PGRXLJNUSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '5300',
    'M',
    (SELECT id from species WHERE iupac='naphthalene-d8'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methylnaphthalene',
    'C<sub>10</sub>H<sub>7</sub>CH<sub>3</sub>',
    '',
    '90-12-0',
    'QPUYECUOLPXSFR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '5800',
    'L',
    (SELECT id from species WHERE iupac='1-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '6100',
    'L',
    (SELECT id from species WHERE iupac='1-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '5900',
    'M',
    (SELECT id from species WHERE iupac='1-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '6100',
    'M',
    (SELECT id from species WHERE iupac='1-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2339'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='1144'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '4900',
    'M',
    (SELECT id from species WHERE iupac='1-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2458'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2338'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2339'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='1910'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3655'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3655-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5500',
    'Q',
    (SELECT id from species WHERE iupac='1-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5700',
    '?',
    (SELECT id from species WHERE iupac='1-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methylnaphthalene-d10',
    'C<sub>10</sub>D<sub>7</sub>CD<sub>3</sub>',
    '',
    '38072-94-5',
    'QPUYECUOLPXSFR-UZHHFJDZSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;2</sup>',
    '5400',
    'M',
    (SELECT id from species WHERE iupac='1-methylnaphthalene-d10'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methylnaphthalene',
    'C<sub>10</sub>H<sub>7</sub>CH<sub>3</sub>',
    '',
    '91-57-6',
    'QIMMUPPBPVKWKM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '5100',
    'L',
    (SELECT id from species WHERE iupac='2-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '5600',
    'L',
    (SELECT id from species WHERE iupac='2-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '5500',
    'M',
    (SELECT id from species WHERE iupac='2-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '5400',
    'M',
    (SELECT id from species WHERE iupac='2-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='981'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;5</sup>',
    '1200',
    'M',
    (SELECT id from species WHERE iupac='2-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='903'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='903'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='1144'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='981'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2339'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='634'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3034'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3655'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3655-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5500',
    'Q',
    (SELECT id from species WHERE iupac='2-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5700',
    '?',
    (SELECT id from species WHERE iupac='2-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='2-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2338'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2338'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-ethylnaphthalene',
    'C<sub>10</sub>H<sub>7</sub>C<sub>2</sub>H<sub>5</sub>',
    '',
    '1127-76-0',
    'ZMXIYERNXPIYFR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '5900',
    'L',
    (SELECT id from species WHERE iupac='1-ethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-ethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-ethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '4800',
    'M',
    (SELECT id from species WHERE iupac='1-ethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2458'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-ethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-ethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-ethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='1910'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-ethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='634'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3034'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-ethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3655'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3655-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-ethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-ethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-ethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-ethylnaphthalene',
    'C<sub>10</sub>H<sub>7</sub>C<sub>2</sub>H<sub>5</sub>',
    '',
    '939-27-5',
    'RJTJVVYSTUQWNI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2-ethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-ethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-ethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-ethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-ethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='634'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3034'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-ethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3655'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3655-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-ethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-ethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,4-tetrahydronaphthalene',
    'C<sub>10</sub>H<sub>12</sub>',
    'tetralin',
    '119-64-2',
    'CXWXQJXEFPUFDZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;3</sup>',
    '5300',
    'L',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrahydronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;3</sup>',
    '5400',
    'M',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrahydronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='1156'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1156'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrahydronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrahydronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrahydronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at301K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrahydronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrahydronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrahydronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrahydronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrahydronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrahydronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4900',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrahydronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5300',
    '?',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrahydronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrahydronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at301K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-dimethylnaphthalene',
    'C<sub>12</sub>H<sub>12</sub>',
    '',
    '573-98-8',
    'QNLZIZAQLLYXTC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,2-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,2-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3655'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3655-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3-dimethylnaphthalene',
    'C<sub>12</sub>H<sub>12</sub>',
    '',
    '575-41-7',
    'QHJMFSMPSZREIF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='1910'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3655'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3655-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,3-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4-dimethylnaphthalene',
    'C<sub>12</sub>H<sub>12</sub>',
    '',
    '571-58-4',
    'APQSQLNWAIULLK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='1910'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3655'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3655-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,4-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,4-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,5-dimethylnaphthalene',
    'C<sub>12</sub>H<sub>12</sub>',
    '',
    '571-61-9',
    'SDDBCEWUYXVGCQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,5-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2339'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,5-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,5-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,5-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,5-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,5-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3655'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3655-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,5-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,5-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,5-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,5-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,5-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,5-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,5-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,5-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,6-dimethylnaphthalene',
    'C<sub>12</sub>H<sub>12</sub>',
    '',
    '575-43-9',
    'CBMXCNPQDUJNHT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,6-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,6-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3655'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3655-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,7-dimethylnaphthalene',
    'C<sub>12</sub>H<sub>12</sub>',
    '',
    '575-37-1',
    'SPUWFVKLHHEKGV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,7-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3766_O2',
    '3766', 'Ebert et&nbsp;al. (2023) present "curated experimental" Henry''s law constants from the literature but do not provide any references. It is only mentioned that the value is from a single original paper and obtained from experimental vapor pressure and water solubility.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_O2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,8-dimethylnaphthalene',
    'C<sub>12</sub>H<sub>12</sub>',
    '',
    '569-41-5',
    'XAABPYINPXYOLM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,8-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3655'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3655-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethylnaphthalene',
    'C<sub>12</sub>H<sub>12</sub>',
    '',
    '581-40-8',
    'WWGUMAYGTYQSGA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='1910'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='2,3-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3655'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3655-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6-dimethylnaphthalene',
    'C<sub>12</sub>H<sub>12</sub>',
    '',
    '581-42-0',
    'YGYNBBAUIYTWBF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,6-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,6-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,6-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='1910'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3655'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3655-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,6-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,7-dimethylnaphthalene',
    'C<sub>12</sub>H<sub>12</sub>',
    '',
    '582-16-1',
    'LRQYSMQNJLZKPS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,7-dimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3655'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3655-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'acenaphthene',
    'C<sub>12</sub>H<sub>10</sub>',
    '',
    '83-32-9',
    'CWRYPZZKDGJXCA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;2</sup>',
    '6500',
    'L',
    (SELECT id from species WHERE iupac='acenaphthene'),
    (SELECT id from literature WHERE bibtexkey='3681'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;2</sup>',
    '5400',
    'L',
    (SELECT id from species WHERE iupac='acenaphthene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='acenaphthene'),
    (SELECT id from literature WHERE bibtexkey='2989'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='LDV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='acenaphthene'),
    (SELECT id from literature WHERE bibtexkey='2989'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '6500',
    'L',
    (SELECT id from species WHERE iupac='acenaphthene'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='acenaphthene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='acenaphthene'),
    (SELECT id from literature WHERE bibtexkey='3014'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;2</sup>',
    '6600',
    'M',
    (SELECT id from species WHERE iupac='acenaphthene'),
    (SELECT id from literature WHERE bibtexkey='2477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='acenaphthene'),
    (SELECT id from literature WHERE bibtexkey='2339'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='acenaphthene'),
    (SELECT id from literature WHERE bibtexkey='2937'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='acenaphthene'),
    (SELECT id from literature WHERE bibtexkey='1144'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='acenaphthene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='acenaphthene'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='acenaphthene'),
    (SELECT id from literature WHERE bibtexkey='490'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='acenaphthene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='acenaphthene'),
    (SELECT id from literature WHERE bibtexkey='2338'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='acenaphthene'),
    (SELECT id from literature WHERE bibtexkey='2339'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='acenaphthene'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='acenaphthene'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='acenaphthene'),
    (SELECT id from literature WHERE bibtexkey='1910'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='acenaphthene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '6000',
    'V',
    (SELECT id from species WHERE iupac='acenaphthene'),
    (SELECT id from literature WHERE bibtexkey='2375'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '2900',
    'T',
    (SELECT id from species WHERE iupac='acenaphthene'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '2800',
    'X',
    (SELECT id from species WHERE iupac='acenaphthene'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='acenaphthene'),
    (SELECT id from literature WHERE bibtexkey='mccarty80'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from2556'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='acenaphthene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='acenaphthene'),
    (SELECT id from literature WHERE bibtexkey='3071'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='acenaphthene'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='acenaphthene'),
    (SELECT id from literature WHERE bibtexkey='3083'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='acenaphthene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='acenaphthene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='acenaphthene'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='acenaphthene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='acenaphthene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='acenaphthene'),
    (SELECT id from literature WHERE bibtexkey='3665'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3665-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='acenaphthene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='acenaphthene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5500',
    'Q',
    (SELECT id from species WHERE iupac='acenaphthene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='acenaphthene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='acenaphthene'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='acenaphthene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='acenaphthene'),
    (SELECT id from literature WHERE bibtexkey='2481'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='acenaphthene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6600',
    '?',
    (SELECT id from species WHERE iupac='acenaphthene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'acenaphthylene',
    'C<sub>12</sub>H<sub>8</sub>',
    '',
    '208-96-8',
    'HXGDTGSAIMULJN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;2</sup>',
    '6300',
    'L',
    (SELECT id from species WHERE iupac='acenaphthylene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='acenaphthylene'),
    (SELECT id from literature WHERE bibtexkey='2989'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='LDV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='acenaphthylene'),
    (SELECT id from literature WHERE bibtexkey='2989'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;2</sup>',
    '6700',
    'L',
    (SELECT id from species WHERE iupac='acenaphthylene'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;2</sup>',
    '6600',
    'M',
    (SELECT id from species WHERE iupac='acenaphthylene'),
    (SELECT id from literature WHERE bibtexkey='2477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='acenaphthylene'),
    (SELECT id from literature WHERE bibtexkey='1144'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='acenaphthylene'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='acenaphthylene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='acenaphthylene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='acenaphthylene'),
    (SELECT id from literature WHERE bibtexkey='2339'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '5000',
    'T',
    (SELECT id from species WHERE iupac='acenaphthylene'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='acenaphthylene'),
    (SELECT id from literature WHERE bibtexkey='3071'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='acenaphthylene'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='acenaphthylene'),
    (SELECT id from literature WHERE bibtexkey='3083'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='acenaphthylene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='acenaphthylene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='acenaphthylene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='acenaphthylene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='acenaphthylene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5600',
    'Q',
    (SELECT id from species WHERE iupac='acenaphthylene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='acenaphthylene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='acenaphthylene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6600',
    '?',
    (SELECT id from species WHERE iupac='acenaphthylene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='acenaphthylene'),
    (SELECT id from literature WHERE bibtexkey='2338'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2338'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4-trimethylnaphthalene',
    'C<sub>13</sub>H<sub>14</sub>',
    '',
    '2717-42-2',
    'JCNGSJUYPCVGAM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-trimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3,7-trimethylnaphthalene',
    'C<sub>13</sub>H<sub>14</sub>',
    '',
    '2131-38-6',
    'HXDVFWJRDVUZFT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,3,7-trimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_O2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3,8-trimethylnaphthalene',
    'C<sub>13</sub>H<sub>14</sub>',
    '',
    '17057-91-9',
    'XYTKCJHHXQVFCK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,3,8-trimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_O2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4,5-trimethylnaphthalene',
    'C<sub>13</sub>H<sub>14</sub>',
    '',
    '2131-41-1',
    'FSAWRQYDMHSDRN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4,5-trimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4,5-trimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4,5-trimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3655'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3655-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4,6-trimethylnaphthalene',
    'C<sub>13</sub>H<sub>14</sub>',
    '',
    '2131-42-2',
    'VGKRZAKNKJAKDN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,4,6-trimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_O2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,6-trimethylnaphthalene',
    'C<sub>13</sub>H<sub>14</sub>',
    '',
    '829-26-5',
    'UNBZRJCHIWTUHB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3,6-trimethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_O2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-(1-methylethyl)naphthalene',
    'C<sub>13</sub>H<sub>14</sub>',
    '1-isopropylnaphthalene',
    '6158-45-8',
    'PMPBFICDXLLSRM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-(1-methylethyl)naphthalene'),
    (SELECT id from literature WHERE bibtexkey='3655'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3655-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-(1-methylethyl)naphthalene',
    'C<sub>13</sub>H<sub>14</sub>',
    '2-isopropylnaphthalene',
    '2027-17-0',
    'TVYVQNHYIHAJTD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(1-methylethyl)naphthalene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(1-methylethyl)naphthalene'),
    (SELECT id from literature WHERE bibtexkey='3655'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3655-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-ethyl-6-methylnaphthalene',
    'C<sub>13</sub>H<sub>14</sub>',
    '',
    '7372-86-3',
    'ZOYUJOHRFWIQTH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-6-methylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-benzindene',
    'C<sub>13</sub>H<sub>10</sub>',
    'fluorene',
    '86-73-7',
    'NIHNNTQXNPWCJQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '6100',
    'L',
    (SELECT id from species WHERE iupac='2,3-benzindene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2,3-benzindene'),
    (SELECT id from literature WHERE bibtexkey='2989'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='LDV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2,3-benzindene'),
    (SELECT id from literature WHERE bibtexkey='2989'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '6000',
    'L',
    (SELECT id from species WHERE iupac='2,3-benzindene'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2,3-benzindene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3-benzindene'),
    (SELECT id from literature WHERE bibtexkey='3014'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '6200',
    'M',
    (SELECT id from species WHERE iupac='2,3-benzindene'),
    (SELECT id from literature WHERE bibtexkey='2477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;2</sup>',
    '7400',
    'M',
    (SELECT id from species WHERE iupac='2,3-benzindene'),
    (SELECT id from literature WHERE bibtexkey='2914'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3-benzindene'),
    (SELECT id from literature WHERE bibtexkey='981'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3-benzindene'),
    (SELECT id from literature WHERE bibtexkey='2339'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3-benzindene'),
    (SELECT id from literature WHERE bibtexkey='1144'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3-benzindene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3-benzindene'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3-benzindene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3-benzindene'),
    (SELECT id from literature WHERE bibtexkey='2338'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3-benzindene'),
    (SELECT id from literature WHERE bibtexkey='981'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3-benzindene'),
    (SELECT id from literature WHERE bibtexkey='2339'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3-benzindene'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3-benzindene'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3-benzindene'),
    (SELECT id from literature WHERE bibtexkey='1910'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '6400',
    'V',
    (SELECT id from species WHERE iupac='2,3-benzindene'),
    (SELECT id from literature WHERE bibtexkey='2375'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '3700',
    'T',
    (SELECT id from species WHERE iupac='2,3-benzindene'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;2</sup>',
    '3000',
    'X',
    (SELECT id from species WHERE iupac='2,3-benzindene'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3-benzindene'),
    (SELECT id from literature WHERE bibtexkey='mccarty80'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from2556'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='2,3-benzindene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='2,3-benzindene'),
    (SELECT id from literature WHERE bibtexkey='3071'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='2,3-benzindene'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='2,3-benzindene'),
    (SELECT id from literature WHERE bibtexkey='3083'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-benzindene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-benzindene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-benzindene'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-benzindene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-benzindene'),
    (SELECT id from literature WHERE bibtexkey='3665'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3665-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-benzindene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-benzindene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5100',
    'Q',
    (SELECT id from species WHERE iupac='2,3-benzindene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-benzindene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-benzindene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-Test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-benzindene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3-benzindene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5400',
    '?',
    (SELECT id from species WHERE iupac='2,3-benzindene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3-benzindene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-9H-fluorene',
    'C<sub>14</sub>H<sub>12</sub>',
    '',
    '1730-37-6',
    'GKEUODMJRFDLJY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-methyl-9H-fluorene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-9H-fluorene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-9H-fluorene',
    'C<sub>14</sub>H<sub>12</sub>',
    '',
    '1430-97-3',
    'RKJHJMAZNPASHY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-9H-fluorene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '9-methyl-9H-fluorene',
    'C<sub>14</sub>H<sub>12</sub>',
    '',
    '2523-37-7',
    'ZVEJRZRAUYJYCO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='9-methyl-9H-fluorene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,5,6-tetramethylnaphthalene',
    'C<sub>14</sub>H<sub>16</sub>',
    '',
    '2131-43-3',
    'ONIJFQFZCKJNDH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,5,6-tetramethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4,6,7-tetramethylnaphthalene',
    'C<sub>14</sub>H<sub>16</sub>',
    '',
    '13764-18-6',
    'VPSPONOBLZCLIU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,4,6,7-tetramethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_O2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-7-(1-methylethyl)-naphthalene',
    'C<sub>14</sub>H<sub>16</sub>',
    '',
    '490-65-3',
    'UZVVHZJKXPCUQU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-7-(1-methylethyl)-naphthalene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(E)-stilbene',
    'C<sub>14</sub>H<sub>12</sub>',
    '<i>trans</i>-1,2-diphenylethene',
    '103-30-0',
    'PJANXHGTPQOBST-VAWYXSNFSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(E)-stilbene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(E)-stilbene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(E)-stilbene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='(E)-stilbene'),
    (SELECT id from literature WHERE bibtexkey='634'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3034'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(E)-stilbene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(E)-stilbene'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phenanthrene',
    'C<sub>14</sub>H<sub>10</sub>',
    '',
    '85-01-8',
    'YNPNZTXNASCQKK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '4500',
    'L',
    (SELECT id from species WHERE iupac='phenanthrene'),
    (SELECT id from literature WHERE bibtexkey='3681'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '7100',
    'L',
    (SELECT id from species WHERE iupac='phenanthrene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='phenanthrene'),
    (SELECT id from literature WHERE bibtexkey='2989'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='LDV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='phenanthrene'),
    (SELECT id from literature WHERE bibtexkey='2989'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '4200',
    'L',
    (SELECT id from species WHERE iupac='phenanthrene'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='phenanthrene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='phenanthrene'),
    (SELECT id from literature WHERE bibtexkey='3014'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '7700',
    'M',
    (SELECT id from species WHERE iupac='phenanthrene'),
    (SELECT id from literature WHERE bibtexkey='2819'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '6000',
    'M',
    (SELECT id from species WHERE iupac='phenanthrene'),
    (SELECT id from literature WHERE bibtexkey='2477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '7600',
    'M',
    (SELECT id from species WHERE iupac='phenanthrene'),
    (SELECT id from literature WHERE bibtexkey='2914'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='phenanthrene'),
    (SELECT id from literature WHERE bibtexkey='981'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='phenanthrene'),
    (SELECT id from literature WHERE bibtexkey='2339'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '3800',
    'M',
    (SELECT id from species WHERE iupac='phenanthrene'),
    (SELECT id from literature WHERE bibtexkey='1597'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='phenanthrene'),
    (SELECT id from literature WHERE bibtexkey='2937'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='phenanthrene'),
    (SELECT id from literature WHERE bibtexkey='1144'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='phenanthrene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='phenanthrene'),
    (SELECT id from literature WHERE bibtexkey='490'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='phenanthrene'),
    (SELECT id from literature WHERE bibtexkey='2459'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='phenanthrene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='phenanthrene'),
    (SELECT id from literature WHERE bibtexkey='2338'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='phenanthrene'),
    (SELECT id from literature WHERE bibtexkey='981'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='phenanthrene'),
    (SELECT id from literature WHERE bibtexkey='2339'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='phenanthrene'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='phenanthrene'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='phenanthrene'),
    (SELECT id from literature WHERE bibtexkey='1910'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='phenanthrene'),
    (SELECT id from literature WHERE bibtexkey='2459'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='phenanthrene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '6500',
    'V',
    (SELECT id from species WHERE iupac='phenanthrene'),
    (SELECT id from literature WHERE bibtexkey='2375'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;2</sup>',
    '4900',
    'T',
    (SELECT id from species WHERE iupac='phenanthrene'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='phenanthrene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='phenanthrene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;2</sup>',
    '4700',
    'X',
    (SELECT id from species WHERE iupac='phenanthrene'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='phenanthrene'),
    (SELECT id from literature WHERE bibtexkey='mccarty80'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from2556'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='phenanthrene'),
    (SELECT id from literature WHERE bibtexkey='3071'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at294K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='phenanthrene'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenanthrene'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenanthrene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenanthrene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenanthrene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenanthrene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenanthrene'),
    (SELECT id from literature WHERE bibtexkey='3665'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3665-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenanthrene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenanthrene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4800',
    'Q',
    (SELECT id from species WHERE iupac='phenanthrene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenanthrene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenanthrene'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenanthrene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenanthrene'),
    (SELECT id from literature WHERE bibtexkey='2481'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='phenanthrene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5300',
    '?',
    (SELECT id from species WHERE iupac='phenanthrene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='phenanthrene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '9,10-dihydrophenanthrene',
    'C<sub>14</sub>H<sub>12</sub>',
    '',
    '776-35-2',
    'XXPBFNVKTVJZKF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '7500',
    'M',
    (SELECT id from species WHERE iupac='9,10-dihydrophenanthrene'),
    (SELECT id from literature WHERE bibtexkey='2489'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='9,10-dihydrophenanthrene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='9,10-dihydrophenanthrene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='9,10-dihydrophenanthrene'),
    (SELECT id from literature WHERE bibtexkey='3665'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3665-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='9,10-dihydrophenanthrene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5400',
    'Q',
    (SELECT id from species WHERE iupac='9,10-dihydrophenanthrene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7500',
    '?',
    (SELECT id from species WHERE iupac='9,10-dihydrophenanthrene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'anthracene',
    'C<sub>14</sub>H<sub>10</sub>',
    '',
    '120-12-7',
    'MWPLVEDNUUSJAV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '4800',
    'L',
    (SELECT id from species WHERE iupac='anthracene'),
    (SELECT id from literature WHERE bibtexkey='3681'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '6700',
    'L',
    (SELECT id from species WHERE iupac='anthracene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='anthracene'),
    (SELECT id from literature WHERE bibtexkey='2989'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='LDV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='anthracene'),
    (SELECT id from literature WHERE bibtexkey='2989'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '5700',
    'L',
    (SELECT id from species WHERE iupac='anthracene'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='anthracene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='anthracene'),
    (SELECT id from literature WHERE bibtexkey='3014'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '5600',
    'M',
    (SELECT id from species WHERE iupac='anthracene'),
    (SELECT id from literature WHERE bibtexkey='2489'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '6000',
    'M',
    (SELECT id from species WHERE iupac='anthracene'),
    (SELECT id from literature WHERE bibtexkey='2477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '6500',
    'M',
    (SELECT id from species WHERE iupac='anthracene'),
    (SELECT id from literature WHERE bibtexkey='2914'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='anthracene'),
    (SELECT id from literature WHERE bibtexkey='2339'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '3500',
    'M',
    (SELECT id from species WHERE iupac='anthracene'),
    (SELECT id from literature WHERE bibtexkey='1597'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='anthracene'),
    (SELECT id from literature WHERE bibtexkey='2937'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='anthracene'),
    (SELECT id from literature WHERE bibtexkey='1144'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='anthracene'),
    (SELECT id from literature WHERE bibtexkey='2537'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='anthracene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='anthracene'),
    (SELECT id from literature WHERE bibtexkey='2459'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='anthracene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='anthracene'),
    (SELECT id from literature WHERE bibtexkey='2338'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='anthracene'),
    (SELECT id from literature WHERE bibtexkey='2339'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='anthracene'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='anthracene'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='anthracene'),
    (SELECT id from literature WHERE bibtexkey='1910'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='anthracene'),
    (SELECT id from literature WHERE bibtexkey='2459'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='anthracene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>1</sup>',
    '7000',
    'V',
    (SELECT id from species WHERE iupac='anthracene'),
    (SELECT id from literature WHERE bibtexkey='2375'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;3</sup>',
    '3100',
    'T',
    (SELECT id from species WHERE iupac='anthracene'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '4000',
    'X',
    (SELECT id from species WHERE iupac='anthracene'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='anthracene'),
    (SELECT id from literature WHERE bibtexkey='mccarty80'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from2556'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='anthracene'),
    (SELECT id from literature WHERE bibtexkey='3071'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='anthracene'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='anthracene'),
    (SELECT id from literature WHERE bibtexkey='2236'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='anthracene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='anthracene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='anthracene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='anthracene'),
    (SELECT id from literature WHERE bibtexkey='3665'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3665-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='anthracene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='anthracene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6400',
    'Q',
    (SELECT id from species WHERE iupac='anthracene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='anthracene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='anthracene'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='anthracene'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='anthracene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='anthracene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5100',
    '?',
    (SELECT id from species WHERE iupac='anthracene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '9,10-dihydroanthracene',
    'C<sub>14</sub>H<sub>12</sub>',
    '',
    '613-31-0',
    'WPDAVTSOEQEGMS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='9,10-dihydroanthracene'),
    (SELECT id from literature WHERE bibtexkey='3665'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3665-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dihydro-1,1,3,3,5-pentamethyl-1H-indene',
    'C<sub>14</sub>H<sub>20</sub>',
    '',
    '81-03-8',
    'NNXHDILUOAXSPU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dihydro-1,1,3,3,5-pentamethyl-1H-indene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dihydro-1,1,3,3,5-pentamethyl-1H-indene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dihydro-1,1,3,3,5-pentamethyl-1H-indene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dihydro-1,1,3,3,5-pentamethyl-1H-indene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methylanthracene',
    'C<sub>15</sub>H<sub>12</sub>',
    '',
    '610-48-0',
    'KZNJSFHJUQDYHE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methylanthracene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methylanthracene',
    'C<sub>15</sub>H<sub>12</sub>',
    '',
    '613-12-7',
    'GYMFBYTZOGMSQJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylanthracene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylanthracene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '9-methylanthracene',
    'C<sub>15</sub>H<sub>12</sub>',
    '',
    '779-02-2',
    'CPGPAVAKSZHMBP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='9-methylanthracene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='9-methylanthracene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='9-methylanthracene'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='9-methylanthracene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='9-methylanthracene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='9-methylanthracene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '9-methyl-phenanthrene',
    'C<sub>15</sub>H<sub>12</sub>',
    '',
    '883-20-5',
    'DALBHIYZSZZWBS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='9-methyl-phenanthrene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '9-ethylfluorene',
    'C<sub>15</sub>H<sub>14</sub>',
    '',
    '2294-82-8',
    'QBBCCEYJCKGWIK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='9-ethylfluorene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,7-dimethylfluorene',
    'C<sub>15</sub>H<sub>14</sub>',
    '',
    '442-66-0',
    'NHPVHXMCRWRSNW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,7-dimethylfluorene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methylphenanthrene',
    'C<sub>15</sub>H<sub>12</sub>',
    '',
    '832-69-9',
    'DOWJXOHBNXRUOD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '4600',
    'M',
    (SELECT id from species WHERE iupac='1-methylphenanthrene'),
    (SELECT id from literature WHERE bibtexkey='2477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methylphenanthrene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methylphenanthrene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methylphenanthrene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methylphenanthrene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methylphenanthrene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5200',
    'Q',
    (SELECT id from species WHERE iupac='1-methylphenanthrene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-methylphenanthrene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4600',
    '?',
    (SELECT id from species WHERE iupac='1-methylphenanthrene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3-diisopropylnaphthalene',
    'C<sub>16</sub>H<sub>20</sub>',
    '',
    '57122-16-4',
    'JDBFIFNXALGSOF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-diisopropylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3655'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3655-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,5-diisopropylnaphthalene',
    'C<sub>16</sub>H<sub>20</sub>',
    '',
    '27351-96-8',
    'GFZWCYSEPXDDRI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,5-diisopropylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3655'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3655-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,7-diisopropylnaphthalene',
    'C<sub>16</sub>H<sub>20</sub>',
    '',
    '94133-80-9',
    'XNSUVOOWWSAQMZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,7-diisopropylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6-diisopropylnaphthalene',
    'C<sub>16</sub>H<sub>20</sub>',
    '',
    '24157-81-1',
    'GWLLTEXUIOFAFE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-diisopropylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3655'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3655-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,7-diisopropylnaphthalene',
    'C<sub>16</sub>H<sub>20</sub>',
    '',
    '40458-98-8',
    'YGDMAJYAQCDTNG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,7-diisopropylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3655'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3655-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-ethylanthracene',
    'C<sub>16</sub>H<sub>14</sub>',
    '',
    '52251-71-5',
    'ZXAGXLDEMUNQSH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-ethylanthracene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylanthracene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3-dimethylphenanthrene',
    'C<sub>16</sub>H<sub>14</sub>',
    '',
    '16664-45-2',
    'UJUUQKOWULNFNG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dimethylphenanthrene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,6-dimethylphenanthrene',
    'C<sub>16</sub>H<sub>14</sub>',
    '',
    '1576-67-6',
    'OMIBPZBOAJFEJS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,6-dimethylphenanthrene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethylanthracene',
    'C<sub>16</sub>H<sub>14</sub>',
    '',
    '613-06-9',
    'OGVRJXPGSVLDRD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylanthracene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '9,10-dimethylanthracene',
    'C<sub>16</sub>H<sub>14</sub>',
    '',
    '781-43-1',
    'JTGMTYWYUZDRBK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'V',
    (SELECT id from species WHERE iupac='9,10-dimethylanthracene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='9,10-dimethylanthracene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='9,10-dimethylanthracene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '9-propyl-9H-fluorene',
    'C<sub>16</sub>H<sub>16</sub>',
    '',
    '4037-45-0',
    'ZTBWLZNGULENBG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='9-propyl-9H-fluorene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pyrene',
    'C<sub>16</sub>H<sub>10</sub>',
    '',
    '129-00-0',
    'BBEAQIROQSPTKN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;1</sup>',
    '5500',
    'L',
    (SELECT id from species WHERE iupac='pyrene'),
    (SELECT id from literature WHERE bibtexkey='3681'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '6900',
    'L',
    (SELECT id from species WHERE iupac='pyrene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='pyrene'),
    (SELECT id from literature WHERE bibtexkey='2989'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='LDV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='pyrene'),
    (SELECT id from literature WHERE bibtexkey='2989'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;1</sup>',
    '4800',
    'L',
    (SELECT id from species WHERE iupac='pyrene'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='pyrene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='pyrene'),
    (SELECT id from literature WHERE bibtexkey='3014'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;1</sup>',
    '6300',
    'M',
    (SELECT id from species WHERE iupac='pyrene'),
    (SELECT id from literature WHERE bibtexkey='2489'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'M',
    (SELECT id from species WHERE iupac='pyrene'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;1</sup>',
    '5500',
    'M',
    (SELECT id from species WHERE iupac='pyrene'),
    (SELECT id from literature WHERE bibtexkey='2477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='pyrene'),
    (SELECT id from literature WHERE bibtexkey='981'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'M',
    (SELECT id from species WHERE iupac='pyrene'),
    (SELECT id from literature WHERE bibtexkey='981'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='pyrene'),
    (SELECT id from literature WHERE bibtexkey='2339'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='pyrene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='pyrene'),
    (SELECT id from literature WHERE bibtexkey='2459'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='pyrene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='pyrene'),
    (SELECT id from literature WHERE bibtexkey='2338'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'V',
    (SELECT id from species WHERE iupac='pyrene'),
    (SELECT id from literature WHERE bibtexkey='981'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='pyrene'),
    (SELECT id from literature WHERE bibtexkey='2339'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pyrene'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='pyrene'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pyrene'),
    (SELECT id from literature WHERE bibtexkey='1910'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pyrene'),
    (SELECT id from literature WHERE bibtexkey='2459'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '7600',
    'V',
    (SELECT id from species WHERE iupac='pyrene'),
    (SELECT id from literature WHERE bibtexkey='2375'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '5700',
    'T',
    (SELECT id from species WHERE iupac='pyrene'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    'C',
    (SELECT id from species WHERE iupac='pyrene'),
    (SELECT id from literature WHERE bibtexkey='3071'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'at299K',
    '', 'Value at T = 299&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at299K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='pyrene'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6',
    '',
    'C',
    (SELECT id from species WHERE iupac='pyrene'),
    (SELECT id from literature WHERE bibtexkey='2556'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pyrene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pyrene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pyrene'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pyrene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pyrene'),
    (SELECT id from literature WHERE bibtexkey='3665'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3665-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pyrene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pyrene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5200',
    'Q',
    (SELECT id from species WHERE iupac='pyrene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pyrene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pyrene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pyrene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5500',
    '?',
    (SELECT id from species WHERE iupac='pyrene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pyrene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benzo[jk]fluorene',
    'C<sub>16</sub>H<sub>10</sub>',
    'fluoranthene',
    '206-44-0',
    'GVEPBJHOBDJJJI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;1</sup>',
    '5900',
    'L',
    (SELECT id from species WHERE iupac='benzo[jk]fluorene'),
    (SELECT id from literature WHERE bibtexkey='3681'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;1</sup>',
    '6900',
    'L',
    (SELECT id from species WHERE iupac='benzo[jk]fluorene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='benzo[jk]fluorene'),
    (SELECT id from literature WHERE bibtexkey='2989'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='LDV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='benzo[jk]fluorene'),
    (SELECT id from literature WHERE bibtexkey='2989'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;1</sup>',
    '4800',
    'L',
    (SELECT id from species WHERE iupac='benzo[jk]fluorene'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='benzo[jk]fluorene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='benzo[jk]fluorene'),
    (SELECT id from literature WHERE bibtexkey='3014'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;1</sup>',
    '4900',
    'M',
    (SELECT id from species WHERE iupac='benzo[jk]fluorene'),
    (SELECT id from literature WHERE bibtexkey='2477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='benzo[jk]fluorene'),
    (SELECT id from literature WHERE bibtexkey='981'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '6900',
    'M',
    (SELECT id from species WHERE iupac='benzo[jk]fluorene'),
    (SELECT id from literature WHERE bibtexkey='1146'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '8700',
    'V',
    (SELECT id from species WHERE iupac='benzo[jk]fluorene'),
    (SELECT id from literature WHERE bibtexkey='3006'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzo[jk]fluorene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzo[jk]fluorene'),
    (SELECT id from literature WHERE bibtexkey='2338'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzo[jk]fluorene'),
    (SELECT id from literature WHERE bibtexkey='981'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzo[jk]fluorene'),
    (SELECT id from literature WHERE bibtexkey='2339'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzo[jk]fluorene'),
    (SELECT id from literature WHERE bibtexkey='2975'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'at283K',
    '', 'Value at T = 283&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at283K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzo[jk]fluorene'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '5400',
    'T',
    (SELECT id from species WHERE iupac='benzo[jk]fluorene'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'C',
    (SELECT id from species WHERE iupac='benzo[jk]fluorene'),
    (SELECT id from literature WHERE bibtexkey='3071'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'C',
    (SELECT id from species WHERE iupac='benzo[jk]fluorene'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='benzo[jk]fluorene'),
    (SELECT id from literature WHERE bibtexkey='2556'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzo[jk]fluorene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzo[jk]fluorene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzo[jk]fluorene'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzo[jk]fluorene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzo[jk]fluorene'),
    (SELECT id from literature WHERE bibtexkey='3665'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3665-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzo[jk]fluorene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzo[jk]fluorene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5100',
    'Q',
    (SELECT id from species WHERE iupac='benzo[jk]fluorene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    '?',
    (SELECT id from species WHERE iupac='benzo[jk]fluorene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5000',
    '?',
    (SELECT id from species WHERE iupac='benzo[jk]fluorene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,4-tetrahydro-1,1,3,4,4,6-hexamethylnaphthalene',
    'C<sub>16</sub>H<sub>24</sub>',
    '',
    '2084-69-7',
    'JIVANURAWUCQIG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrahydro-1,1,3,4,4,6-hexamethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrahydro-1,1,3,4,4,6-hexamethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrahydro-1,1,3,4,4,6-hexamethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrahydro-1,1,3,4,4,6-hexamethylnaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '[2.2]paracyclophane',
    'C<sub>16</sub>H<sub>16</sub>',
    '',
    '1633-22-3',
    'OOLUVSIJOMLOCB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='[2.2]paracyclophane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='[2.2]paracyclophane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='[2.2]paracyclophane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='[2.2]paracyclophane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benzo[a]fluorene',
    'C<sub>17</sub>H<sub>12</sub>',
    '',
    '238-84-6',
    'HKMTVMBEALTRRR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '4400',
    'M',
    (SELECT id from species WHERE iupac='benzo[a]fluorene'),
    (SELECT id from literature WHERE bibtexkey='2477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzo[a]fluorene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzo[a]fluorene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzo[a]fluorene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6300',
    'Q',
    (SELECT id from species WHERE iupac='benzo[a]fluorene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='benzo[a]fluorene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4400',
    '?',
    (SELECT id from species WHERE iupac='benzo[a]fluorene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='benzo[a]fluorene'),
    (SELECT id from literature WHERE bibtexkey='2338'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2338'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methylpyrene',
    'C<sub>17</sub>H<sub>12</sub>',
    '',
    '2381-21-7',
    'KBSPJIWZDWBDGM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methylpyrene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methylpyrene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methylpyrene',
    'C<sub>17</sub>H<sub>12</sub>',
    '',
    '3442-78-2',
    'VIRFPLJXRDHVEI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpyrene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methylfluoranthene',
    'C<sub>17</sub>H<sub>12</sub>',
    '',
    '30997-39-8',
    'VVRCMNWZFPMXQZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylfluoranthene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '9-n-propylphenanthrene',
    'C<sub>17</sub>H<sub>16</sub>',
    '',
    '17024-03-2',
    'PIWHTUVAMGYSIC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='9-n-propylphenanthrene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,6-trimethylphenanthrene',
    'C<sub>17</sub>H<sub>16</sub>',
    '',
    '30436-55-6',
    'MYWOJODOMFBVCB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,6-trimethylphenanthrene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '9-butyl-9H-fluorene',
    'C<sub>17</sub>H<sub>18</sub>',
    '',
    '3952-42-9',
    'RBDADLSAYYPJAN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='9-butyl-9H-fluorene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '11H-benzo[b]fluorene',
    'C<sub>17</sub>H<sub>12</sub>',
    '',
    '243-17-4',
    'HAPOJKSPCGLOOD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='11H-benzo[b]fluorene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='11H-benzo[b]fluorene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,7-dimethylpyrene',
    'C<sub>18</sub>H<sub>14</sub>',
    '',
    '15679-24-0',
    'GSKHIRFMTJUBSM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,7-dimethylpyrene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,7-dimethylpyrene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chrysene',
    'C<sub>18</sub>H<sub>12</sub>',
    '',
    '218-01-9',
    'WDECIBYCCFPHNR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '12000',
    'L',
    (SELECT id from species WHERE iupac='chrysene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'L',
    (SELECT id from species WHERE iupac='chrysene'),
    (SELECT id from literature WHERE bibtexkey='2989'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='LDV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    'L',
    (SELECT id from species WHERE iupac='chrysene'),
    (SELECT id from literature WHERE bibtexkey='2989'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'M',
    (SELECT id from species WHERE iupac='chrysene'),
    (SELECT id from literature WHERE bibtexkey='3014'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '13000',
    'M',
    (SELECT id from species WHERE iupac='chrysene'),
    (SELECT id from literature WHERE bibtexkey='2477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4',
    '',
    'M',
    (SELECT id from species WHERE iupac='chrysene'),
    (SELECT id from literature WHERE bibtexkey='2937'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chrysene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chrysene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chrysene'),
    (SELECT id from literature WHERE bibtexkey='2338'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'V',
    (SELECT id from species WHERE iupac='chrysene'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '6400',
    'T',
    (SELECT id from species WHERE iupac='chrysene'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4',
    '',
    'C',
    (SELECT id from species WHERE iupac='chrysene'),
    (SELECT id from literature WHERE bibtexkey='3071'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='chrysene'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6',
    '',
    'C',
    (SELECT id from species WHERE iupac='chrysene'),
    (SELECT id from literature WHERE bibtexkey='2556'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chrysene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chrysene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chrysene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chrysene'),
    (SELECT id from literature WHERE bibtexkey='3665'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3665-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chrysene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chrysene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    '?',
    (SELECT id from species WHERE iupac='chrysene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'naphthacene',
    'C<sub>18</sub>H<sub>12</sub>',
    '2,3-benzanthracene',
    '92-24-0',
    'IFLREYGFSNHWGE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='naphthacene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='naphthacene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='naphthacene'),
    (SELECT id from literature WHERE bibtexkey='634'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3034'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='naphthacene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='naphthacene'),
    (SELECT id from literature WHERE bibtexkey='2532'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'triphenylene',
    'C<sub>18</sub>H<sub>12</sub>',
    'benzo[l]phenanthrene',
    '217-59-4',
    'SLGBZMMZGDRARJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='triphenylene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='triphenylene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2611_pc_problem'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='triphenylene'),
    (SELECT id from literature WHERE bibtexkey='634'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3034'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triphenylene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triphenylene'),
    (SELECT id from literature WHERE bibtexkey='3665'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3665-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triphenylene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triphenylene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triphenylene'),
    (SELECT id from literature WHERE bibtexkey='2532'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benz[a]anthracene',
    'C<sub>18</sub>H<sub>12</sub>',
    '',
    '56-55-3',
    'DXBHBZVCASKNBY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'L',
    (SELECT id from species WHERE iupac='benz[a]anthracene'),
    (SELECT id from literature WHERE bibtexkey='2989'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='LDV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'L',
    (SELECT id from species WHERE iupac='benz[a]anthracene'),
    (SELECT id from literature WHERE bibtexkey='2989'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;1</sup>',
    '7900',
    'L',
    (SELECT id from species WHERE iupac='benz[a]anthracene'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'M',
    (SELECT id from species WHERE iupac='benz[a]anthracene'),
    (SELECT id from literature WHERE bibtexkey='3014'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;1</sup>',
    '8300',
    'M',
    (SELECT id from species WHERE iupac='benz[a]anthracene'),
    (SELECT id from literature WHERE bibtexkey='2477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9',
    '',
    'M',
    (SELECT id from species WHERE iupac='benz[a]anthracene'),
    (SELECT id from literature WHERE bibtexkey='2937'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'M',
    (SELECT id from species WHERE iupac='benz[a]anthracene'),
    (SELECT id from literature WHERE bibtexkey='2459'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'V',
    (SELECT id from species WHERE iupac='benz[a]anthracene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '',
    'V',
    (SELECT id from species WHERE iupac='benz[a]anthracene'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benz[a]anthracene'),
    (SELECT id from literature WHERE bibtexkey='3945'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0',
    '',
    'V',
    (SELECT id from species WHERE iupac='benz[a]anthracene'),
    (SELECT id from literature WHERE bibtexkey='2459'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '6100',
    'T',
    (SELECT id from species WHERE iupac='benz[a]anthracene'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5',
    '',
    'C',
    (SELECT id from species WHERE iupac='benz[a]anthracene'),
    (SELECT id from literature WHERE bibtexkey='3071'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at297K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8',
    '',
    'C',
    (SELECT id from species WHERE iupac='benz[a]anthracene'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='benz[a]anthracene'),
    (SELECT id from literature WHERE bibtexkey='2556'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benz[a]anthracene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benz[a]anthracene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benz[a]anthracene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benz[a]anthracene'),
    (SELECT id from literature WHERE bibtexkey='3665'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3665-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benz[a]anthracene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benz[a]anthracene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6100',
    'Q',
    (SELECT id from species WHERE iupac='benz[a]anthracene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benz[a]anthracene'),
    (SELECT id from literature WHERE bibtexkey='2532'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='benz[a]anthracene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '8300',
    '?',
    (SELECT id from species WHERE iupac='benz[a]anthracene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='benz[a]anthracene'),
    (SELECT id from literature WHERE bibtexkey='2338'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2338'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,5-dimethylpyrene',
    'C<sub>18</sub>H<sub>14</sub>',
    '',
    '15679-25-1',
    'MCZKPUHBCIHFBZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,5-dimethylpyrene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethylfluoranthene',
    'C<sub>18</sub>H<sub>14</sub>',
    '',
    '20496-16-6',
    'JXUOLJXLPIIRTP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethylfluoranthene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,6,9-tetramethylphenanthrene',
    'C<sub>18</sub>H<sub>18</sub>',
    '',
    '204256-39-3',
    'XFJWRZAPBOJONX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,6,9-tetramethylphenanthrene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,9-dimethyl-5-ethylphenanthrene',
    'C<sub>18</sub>H<sub>18</sub>',
    '',
    '',
    'MDZYWNWRMJIOPN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,9-dimethyl-5-ethylphenanthrene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,9-dimethyl-7-ethylphenanthrene',
    'C<sub>18</sub>H<sub>18</sub>',
    '',
    '',
    'NFFCDFHAMXFVEK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,9-dimethyl-7-ethylphenanthrene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,4-tetrahydro-5-(1-phenylethyl)-naphthalene',
    'C<sub>18</sub>H<sub>20</sub>',
    '',
    '60466-61-7',
    'TXOHWLOHKUPUKO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrahydro-5-(1-phenylethyl)-naphthalene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrahydro-5-(1-phenylethyl)-naphthalene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrahydro-5-(1-phenylethyl)-naphthalene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrahydro-5-(1-phenylethyl)-naphthalene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methylchrysene',
    'C<sub>19</sub>H<sub>14</sub>',
    '',
    '3351-30-2',
    'BLVHWJCLSMYFMT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylchrysene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-methylchrysene',
    'C<sub>19</sub>H<sub>14</sub>',
    '',
    '3697-24-3',
    'GOHBXWHNJHENRX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methylchrysene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '6-methylchrysene',
    'C<sub>19</sub>H<sub>14</sub>',
    '',
    '1705-85-7',
    'ASVDRLYVNFOSCI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-methylchrysene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-propylpyrene',
    'C<sub>19</sub>H<sub>16</sub>',
    '',
    '42211-33-6',
    'HIOZPFGGCXEPAP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-propylpyrene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '7-methylbenz[a]anthracene',
    'C<sub>19</sub>H<sub>14</sub>',
    '',
    '2541-69-7',
    'DIIFUCUPDHMNIV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='7-methylbenz[a]anthracene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '10-methylbenz[a]anthracene',
    'C<sub>19</sub>H<sub>14</sub>',
    '',
    '2381-15-9',
    'WUMGYHICFXGLAB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='10-methylbenz[a]anthracene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '12-methylbenz[a]anthracene',
    'C<sub>19</sub>H<sub>14</sub>',
    '',
    '2422-79-9',
    'ACYOLKMEHHTLAB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='12-methylbenz[a]anthracene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '6-ethylchrysene',
    'C<sub>20</sub>H<sub>16</sub>',
    '',
    '2732-58-3',
    'ZJSYTTGSPQNXKT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-ethylchrysene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,9-dimethylbenz[a]anthracene',
    'C<sub>20</sub>H<sub>16</sub>',
    '',
    '316-51-8',
    'DBPDWIZRMPUWRH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,9-dimethylbenz[a]anthracene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-butylpyrene',
    'C<sub>20</sub>H<sub>18</sub>',
    '',
    '35980-18-8',
    'UFOTZLIYHMGVAV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butylpyrene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '7,12-dimethyl-benz[a]anthracene',
    'C<sub>20</sub>H<sub>16</sub>',
    '',
    '57-97-6',
    'ARSRBNBHOADGJU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6',
    '',
    'V',
    (SELECT id from species WHERE iupac='7,12-dimethyl-benz[a]anthracene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='7,12-dimethyl-benz[a]anthracene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='7,12-dimethyl-benz[a]anthracene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='7,12-dimethyl-benz[a]anthracene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='7,12-dimethyl-benz[a]anthracene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '9,10-dimethyl-benz[a]anthracene',
    'C<sub>20</sub>H<sub>16</sub>',
    '',
    '58429-99-5',
    'GKVUDAZMZLMNJQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='9,10-dimethyl-benz[a]anthracene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2611_pc_problem'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benzo[b]fluoranthene',
    'C<sub>20</sub>H<sub>12</sub>',
    '',
    '205-99-2',
    'FTOVXSOBNPWTSH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '5400',
    'L',
    (SELECT id from species WHERE iupac='benzo[b]fluoranthene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='benzo[b]fluoranthene'),
    (SELECT id from literature WHERE bibtexkey='2989'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='LDV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='benzo[b]fluoranthene'),
    (SELECT id from literature WHERE bibtexkey='2989'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '5400',
    'M',
    (SELECT id from species WHERE iupac='benzo[b]fluoranthene'),
    (SELECT id from literature WHERE bibtexkey='1146'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '7500',
    'T',
    (SELECT id from species WHERE iupac='benzo[b]fluoranthene'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='benzo[b]fluoranthene'),
    (SELECT id from literature WHERE bibtexkey='3071'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzo[b]fluoranthene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzo[b]fluoranthene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzo[b]fluoranthene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzo[b]fluoranthene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzo[b]fluoranthene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4700',
    'Q',
    (SELECT id from species WHERE iupac='benzo[b]fluoranthene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzo[b]fluoranthene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='benzo[b]fluoranthene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5400',
    '?',
    (SELECT id from species WHERE iupac='benzo[b]fluoranthene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benzo[k]fluoranthene',
    'C<sub>20</sub>H<sub>12</sub>',
    '',
    '207-08-9',
    'HAXBIWFMXWRORI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='benzo[k]fluoranthene'),
    (SELECT id from literature WHERE bibtexkey='2989'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='LDV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='benzo[k]fluoranthene'),
    (SELECT id from literature WHERE bibtexkey='2989'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='benzo[k]fluoranthene'),
    (SELECT id from literature WHERE bibtexkey='3014'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '5900',
    'M',
    (SELECT id from species WHERE iupac='benzo[k]fluoranthene'),
    (SELECT id from literature WHERE bibtexkey='1146'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzo[k]fluoranthene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2611_pc_problem'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzo[k]fluoranthene'),
    (SELECT id from literature WHERE bibtexkey='981'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzo[k]fluoranthene'),
    (SELECT id from literature WHERE bibtexkey='2339'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '6900',
    'T',
    (SELECT id from species WHERE iupac='benzo[k]fluoranthene'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;3</sup>',
    '1900',
    'X',
    (SELECT id from species WHERE iupac='benzo[k]fluoranthene'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='benzo[k]fluoranthene'),
    (SELECT id from literature WHERE bibtexkey='3071'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzo[k]fluoranthene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzo[k]fluoranthene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzo[k]fluoranthene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzo[k]fluoranthene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzo[k]fluoranthene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6300',
    'Q',
    (SELECT id from species WHERE iupac='benzo[k]fluoranthene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzo[k]fluoranthene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='benzo[k]fluoranthene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5800',
    '?',
    (SELECT id from species WHERE iupac='benzo[k]fluoranthene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benzo[a]pyrene',
    'C<sub>20</sub>H<sub>12</sub>',
    'benz[a]pyrene',
    '50-32-8',
    'FMMWHPNWAFZXNH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5',
    '8500',
    'L',
    (SELECT id from species WHERE iupac='benzo[a]pyrene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='benzo[a]pyrene'),
    (SELECT id from literature WHERE bibtexkey='2989'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='LDV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='benzo[a]pyrene'),
    (SELECT id from literature WHERE bibtexkey='2989'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2',
    '',
    'M',
    (SELECT id from species WHERE iupac='benzo[a]pyrene'),
    (SELECT id from literature WHERE bibtexkey='3014'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='benzo[a]pyrene'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '4700',
    'M',
    (SELECT id from species WHERE iupac='benzo[a]pyrene'),
    (SELECT id from literature WHERE bibtexkey='1146'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzo[a]pyrene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzo[a]pyrene'),
    (SELECT id from literature WHERE bibtexkey='981'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzo[a]pyrene'),
    (SELECT id from literature WHERE bibtexkey='2339'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzo[a]pyrene'),
    (SELECT id from literature WHERE bibtexkey='2975'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at283K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzo[a]pyrene'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzo[a]pyrene'),
    (SELECT id from literature WHERE bibtexkey='3945'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzo[a]pyrene'),
    (SELECT id from literature WHERE bibtexkey='2459'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;1</sup>',
    '8200',
    'T',
    (SELECT id from species WHERE iupac='benzo[a]pyrene'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '110',
    'X',
    (SELECT id from species WHERE iupac='benzo[a]pyrene'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='benzo[a]pyrene'),
    (SELECT id from literature WHERE bibtexkey='3071'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;4</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='benzo[a]pyrene'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzo[a]pyrene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzo[a]pyrene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzo[a]pyrene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzo[a]pyrene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzo[a]pyrene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4900',
    'Q',
    (SELECT id from species WHERE iupac='benzo[a]pyrene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzo[a]pyrene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='benzo[a]pyrene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4700',
    '?',
    (SELECT id from species WHERE iupac='benzo[a]pyrene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='benzo[a]pyrene'),
    (SELECT id from literature WHERE bibtexkey='2338'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2338'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benzo[e]pyrene',
    'C<sub>20</sub>H<sub>12</sub>',
    '',
    '192-97-2',
    'TXVHTIQJNYSSKO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzo[e]pyrene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzo[e]pyrene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzo[e]pyrene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '8300',
    'T',
    (SELECT id from species WHERE iupac='benzo[e]pyrene'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzo[e]pyrene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzo[e]pyrene'),
    (SELECT id from literature WHERE bibtexkey='2532'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='benzo[e]pyrene'),
    (SELECT id from literature WHERE bibtexkey='2338'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2338'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'perylene',
    'C<sub>20</sub>H<sub>12</sub>',
    'dibenz[de,kl]anthracene',
    '198-55-0',
    'CSHWQDPOILHKBI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    'V',
    (SELECT id from species WHERE iupac='perylene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='perylene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2611_pc_problem'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'V',
    (SELECT id from species WHERE iupac='perylene'),
    (SELECT id from literature WHERE bibtexkey='2966'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '6300',
    'T',
    (SELECT id from species WHERE iupac='perylene'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='perylene'),
    (SELECT id from literature WHERE bibtexkey='634'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3034'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='perylene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='perylene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='perylene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='perylene'),
    (SELECT id from literature WHERE bibtexkey='2532'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-benzfluoranthene',
    'C<sub>20</sub>H<sub>12</sub>',
    '',
    '203-33-8',
    'OQDXASJSCOTNQS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-benzfluoranthene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benzo[j]fluoranthene',
    'C<sub>20</sub>H<sub>12</sub>',
    '',
    '205-82-3',
    'KHNYNFUTFKJLDD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzo[j]fluoranthene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3,6-trimethylchrysene',
    'C<sub>21</sub>H<sub>18</sub>',
    '',
    '1586755-28-3',
    'UGLPREDFUVNEMJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,6-trimethylchrysene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '6-propylchrysene',
    'C<sub>21</sub>H<sub>18</sub>',
    '',
    '6910-41-4',
    'PGBSMHMYMMBHFF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-propylchrysene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '20-methylcholanthrene',
    'C<sub>21</sub>H<sub>16</sub>',
    '',
    '56-49-5',
    'PPQNQXQZIWHJRB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    'V',
    (SELECT id from species WHERE iupac='20-methylcholanthrene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    'V',
    (SELECT id from species WHERE iupac='20-methylcholanthrene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='20-methylcholanthrene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2611_pc_problem'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='20-methylcholanthrene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '6-butylchrysene',
    'C<sub>22</sub>H<sub>20</sub>',
    '',
    '6901-71-9',
    'XJQKMLMKECCWEO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-butylchrysene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dibenz[a,h]anthracene',
    'C<sub>22</sub>H<sub>14</sub>',
    '',
    '53-70-3',
    'LHRCREOYAASXPZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dibenz[a,h]anthracene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>2</sup>',
    '12000',
    'V',
    (SELECT id from species WHERE iupac='dibenz[a,h]anthracene'),
    (SELECT id from literature WHERE bibtexkey='3006'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dibenz[a,h]anthracene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dibenz[a,h]anthracene'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '7800',
    'T',
    (SELECT id from species WHERE iupac='dibenz[a,h]anthracene'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='dibenz[a,h]anthracene'),
    (SELECT id from literature WHERE bibtexkey='3071'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibenz[a,h]anthracene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibenz[a,h]anthracene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibenz[a,h]anthracene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibenz[a,h]anthracene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibenz[a,h]anthracene'),
    (SELECT id from literature WHERE bibtexkey='2532'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'indeno[1,2,3-cd]pyrene',
    'C<sub>22</sub>H<sub>12</sub>',
    '',
    '193-39-5',
    'SXQBHARYMNFBPS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='indeno[1,2,3-cd]pyrene'),
    (SELECT id from literature WHERE bibtexkey='2989'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='LDV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='indeno[1,2,3-cd]pyrene'),
    (SELECT id from literature WHERE bibtexkey='2989'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>1</sup>',
    '3600',
    'M',
    (SELECT id from species WHERE iupac='indeno[1,2,3-cd]pyrene'),
    (SELECT id from literature WHERE bibtexkey='1146'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '7400',
    'T',
    (SELECT id from species WHERE iupac='indeno[1,2,3-cd]pyrene'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='indeno[1,2,3-cd]pyrene'),
    (SELECT id from literature WHERE bibtexkey='3071'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='indeno[1,2,3-cd]pyrene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='indeno[1,2,3-cd]pyrene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='indeno[1,2,3-cd]pyrene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='indeno[1,2,3-cd]pyrene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='indeno[1,2,3-cd]pyrene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5100',
    'Q',
    (SELECT id from species WHERE iupac='indeno[1,2,3-cd]pyrene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='indeno[1,2,3-cd]pyrene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3600',
    '?',
    (SELECT id from species WHERE iupac='indeno[1,2,3-cd]pyrene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benzo[ghi]perylene',
    'C<sub>22</sub>H<sub>12</sub>',
    '',
    '191-24-2',
    'GYFAGKUZYNFMBN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='benzo[ghi]perylene'),
    (SELECT id from literature WHERE bibtexkey='2989'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='LDV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='benzo[ghi]perylene'),
    (SELECT id from literature WHERE bibtexkey='2989'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>1</sup>',
    '3200',
    'M',
    (SELECT id from species WHERE iupac='benzo[ghi]perylene'),
    (SELECT id from literature WHERE bibtexkey='1146'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzo[ghi]perylene'),
    (SELECT id from literature WHERE bibtexkey='981'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzo[ghi]perylene'),
    (SELECT id from literature WHERE bibtexkey='2339'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzo[ghi]perylene'),
    (SELECT id from literature WHERE bibtexkey='2478'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0',
    '9200',
    'T',
    (SELECT id from species WHERE iupac='benzo[ghi]perylene'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='benzo[ghi]perylene'),
    (SELECT id from literature WHERE bibtexkey='634'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3034'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='benzo[ghi]perylene'),
    (SELECT id from literature WHERE bibtexkey='3071'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzo[ghi]perylene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzo[ghi]perylene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzo[ghi]perylene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzo[ghi]perylene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzo[ghi]perylene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3700',
    'Q',
    (SELECT id from species WHERE iupac='benzo[ghi]perylene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzo[ghi]perylene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='benzo[ghi]perylene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3300',
    '?',
    (SELECT id from species WHERE iupac='benzo[ghi]perylene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benzo[b]triphenylene',
    'C<sub>22</sub>H<sub>14</sub>',
    'dibenz[a,c]anthracene',
    '215-58-7',
    'RAASUWZPTOJQAY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '8600',
    'V',
    (SELECT id from species WHERE iupac='benzo[b]triphenylene'),
    (SELECT id from literature WHERE bibtexkey='3006'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzo[b]triphenylene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzo[b]triphenylene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzo[b]triphenylene'),
    (SELECT id from literature WHERE bibtexkey='2532'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dibenz[a,j]anthracene',
    'C<sub>22</sub>H<sub>14</sub>',
    '',
    '224-41-9',
    'KLIHYVJAYWCEDM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibenz[a,j]anthracene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibenz[a,j]anthracene'),
    (SELECT id from literature WHERE bibtexkey='2532'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'picene',
    'C<sub>22</sub>H<sub>14</sub>',
    '',
    '213-46-7',
    'GBROPGWFBFCKAG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='picene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='picene'),
    (SELECT id from literature WHERE bibtexkey='2532'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benzo[c]chrysene',
    'C<sub>22</sub>H<sub>14</sub>',
    '',
    '194-69-4',
    'YZWGEMSQAMDWEM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzo[c]chrysene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benzo[g]chrysene',
    'C<sub>22</sub>H<sub>14</sub>',
    '',
    '196-78-1',
    'JZOIZKBKSZMVRV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzo[g]chrysene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dibenzo[a,e]pyrene',
    'C<sub>24</sub>H<sub>14</sub>',
    '',
    '192-65-4',
    'KGHMWBNEMFNJFZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibenzo[a,e]pyrene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dibenzo[a,h]pyrene',
    'C<sub>24</sub>H<sub>14</sub>',
    '',
    '189-64-0',
    'RXUSYFJGDZFVND-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibenzo[a,h]pyrene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dibenzo[a,i]pyrene',
    'C<sub>24</sub>H<sub>14</sub>',
    '',
    '189-55-9',
    'TUGYIJVAYAHHHM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibenzo[a,i]pyrene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'coronene',
    'C<sub>24</sub>H<sub>12</sub>',
    '',
    '191-07-1',
    'VPUGDVKSAQVFFS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='coronene'),
    (SELECT id from literature WHERE bibtexkey='2611'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2611_pc_problem'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dibenz[a,e]aceanthrylene',
    'C<sub>24</sub>H<sub>14</sub>',
    '',
    '5385-75-1',
    'JHOWUOKQHJHGMU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibenz[a,e]aceanthrylene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dibenzo[b,k]chrysene',
    'C<sub>26</sub>H<sub>16</sub>',
    '',
    '217-54-9',
    'DHCSBRKYHMINPB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polynuclear aromatics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibenzo[b,k]chrysene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO categories (catname) VALUES (
    'Organic species with oxygen (O)');
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Carbon oxides',
    (SELECT id from categories WHERE catname='Organic species with oxygen (O)'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'carbon monoxide',
    'CO',
    '',
    '630-08-0',
    'UGFAIRIUMAVXCW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carbon oxides'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;6</sup>',
    '1300',
    'L',
    (SELECT id from species WHERE iupac='carbon monoxide'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;6</sup>',
    '1400',
    'L',
    (SELECT id from species WHERE iupac='carbon monoxide'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;6</sup>',
    '1300',
    'L',
    (SELECT id from species WHERE iupac='carbon monoxide'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;6</sup>',
    '1400',
    'L',
    (SELECT id from species WHERE iupac='carbon monoxide'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;6</sup>',
    '1300',
    'L',
    (SELECT id from species WHERE iupac='carbon monoxide'),
    (SELECT id from literature WHERE bibtexkey='2828'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;6</sup>',
    '1300',
    'L',
    (SELECT id from species WHERE iupac='carbon monoxide'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;6</sup>',
    '1300',
    'L',
    (SELECT id from species WHERE iupac='carbon monoxide'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;6</sup>',
    '1300',
    'L',
    (SELECT id from species WHERE iupac='carbon monoxide'),
    (SELECT id from literature WHERE bibtexkey='2105'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2105'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'L',
    (SELECT id from species WHERE iupac='carbon monoxide'),
    (SELECT id from literature WHERE bibtexkey='3866'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3866',
    '3866,3529', 'Cargill (1990) recommends the data from Rettich et&nbsp;al. (1982).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3866'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;6</sup>',
    '1300',
    'L',
    (SELECT id from species WHERE iupac='carbon monoxide'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;6</sup>',
    '1300',
    'M',
    (SELECT id from species WHERE iupac='carbon monoxide'),
    (SELECT id from literature WHERE bibtexkey='3529'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3529-630-08-0-ABC',
    '3529', 'The data from Rettich et&nbsp;al. (1982) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;188.21737 +8974.05844/T +25.72558&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3529-630-08-0-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;6</sup>',
    '1500',
    'M',
    (SELECT id from species WHERE iupac='carbon monoxide'),
    (SELECT id from literature WHERE bibtexkey='3777'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HTdep_r2_lessthan_0.9'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3777'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;5</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='carbon monoxide'),
    (SELECT id from literature WHERE bibtexkey='505'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;6</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='carbon monoxide'),
    (SELECT id from literature WHERE bibtexkey='3787'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;6</sup>',
    '1200',
    'M',
    (SELECT id from species WHERE iupac='carbon monoxide'),
    (SELECT id from literature WHERE bibtexkey='1911'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref1911-630-08-0-ABC',
    '1911', 'The data from Douglas (1967) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;180.92848 +8514.05914/T +24.68060&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref1911-630-08-0-ABC'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '1911seawater',
    '', 'Solubility in sea water at 20.99&nbsp;% chlorinity.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1911seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;6</sup>',
    '1300',
    'M',
    (SELECT id from species WHERE iupac='carbon monoxide'),
    (SELECT id from literature WHERE bibtexkey='2834'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2834-630-08-0-ABC',
    '2834', 'The data from Winkler (1901) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;163.07031 +7890.85881/T +21.94517&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2834-630-08-0-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;6</sup>',
    '1200',
    'M',
    (SELECT id from species WHERE iupac='carbon monoxide'),
    (SELECT id from literature WHERE bibtexkey='3717'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3717'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;6</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='carbon monoxide'),
    (SELECT id from literature WHERE bibtexkey='766'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='carbon monoxide'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='carbon monoxide'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;6</sup>',
    '1300',
    '?',
    (SELECT id from species WHERE iupac='carbon monoxide'),
    (SELECT id from literature WHERE bibtexkey='3811'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='carbon monoxide'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;6</sup>',
    '1400',
    '?',
    (SELECT id from species WHERE iupac='carbon monoxide'),
    (SELECT id from literature WHERE bibtexkey='379'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0379-630-08-0-ABC',
    '379', 'The data from Dean and Lange (1999) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;161.93492 +7852.78262/T +21.76812&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0379-630-08-0-ABC'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='379'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='carbon monoxide'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'carbon dioxide',
    'CO<sub>2</sub>',
    '',
    '124-38-9',
    'CURLTUGMZLYLDI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carbon oxides'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '2300',
    'L',
    (SELECT id from species WHERE iupac='carbon dioxide'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;4</sup>',
    '2600',
    'L',
    (SELECT id from species WHERE iupac='carbon dioxide'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '2300',
    'L',
    (SELECT id from species WHERE iupac='carbon dioxide'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;4</sup>',
    '2600',
    'L',
    (SELECT id from species WHERE iupac='carbon dioxide'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;4</sup>',
    '2400',
    'L',
    (SELECT id from species WHERE iupac='carbon dioxide'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;4</sup>',
    '2400',
    'L',
    (SELECT id from species WHERE iupac='carbon dioxide'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;4</sup>',
    '2300',
    'L',
    (SELECT id from species WHERE iupac='carbon dioxide'),
    (SELECT id from literature WHERE bibtexkey='2105'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2105'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '2300',
    'L',
    (SELECT id from species WHERE iupac='carbon dioxide'),
    (SELECT id from literature WHERE bibtexkey='631'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '2400',
    'L',
    (SELECT id from species WHERE iupac='carbon dioxide'),
    (SELECT id from literature WHERE bibtexkey='1153'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '2300',
    'L',
    (SELECT id from species WHERE iupac='carbon dioxide'),
    (SELECT id from literature WHERE bibtexkey='3085'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '2400',
    'L',
    (SELECT id from species WHERE iupac='carbon dioxide'),
    (SELECT id from literature WHERE bibtexkey='540'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;4</sup>',
    '2400',
    'L',
    (SELECT id from species WHERE iupac='carbon dioxide'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '2400',
    'L',
    (SELECT id from species WHERE iupac='carbon dioxide'),
    (SELECT id from literature WHERE bibtexkey='1779'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '2300',
    'M',
    (SELECT id from species WHERE iupac='carbon dioxide'),
    (SELECT id from literature WHERE bibtexkey='921'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0921-124-38-9-ABC',
    '921', 'The data from Zheng et&nbsp;al. (1997) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;144.44443 +8071.06186/T +19.20040&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0921-124-38-9-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;4</sup>',
    '2400',
    'M',
    (SELECT id from species WHERE iupac='carbon dioxide'),
    (SELECT id from literature WHERE bibtexkey='3568'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3568-124-38-9-ABC',
    '3568', 'The data from Murray and Riley (1971) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;167.86941 +9146.24434/T +22.67331&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3568-124-38-9-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='carbon dioxide'),
    (SELECT id from literature WHERE bibtexkey='3787'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;4</sup>',
    '2400',
    'M',
    (SELECT id from species WHERE iupac='carbon dioxide'),
    (SELECT id from literature WHERE bibtexkey='3783'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3783-124-38-9-ABC',
    '3783', 'The data from Morrison and Billett (1952) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;126.83009 +7302.88179/T +16.55553&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3783-124-38-9-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='carbon dioxide'),
    (SELECT id from literature WHERE bibtexkey='3702'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;4</sup>',
    '2300',
    'M',
    (SELECT id from species WHERE iupac='carbon dioxide'),
    (SELECT id from literature WHERE bibtexkey='3709'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;4</sup>',
    '2500',
    'M',
    (SELECT id from species WHERE iupac='carbon dioxide'),
    (SELECT id from literature WHERE bibtexkey='3711'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '2400',
    'M',
    (SELECT id from species WHERE iupac='carbon dioxide'),
    (SELECT id from literature WHERE bibtexkey='2841'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2841-124-38-9-ABC',
    '2841', 'The data from Bohr (1899) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;140.70007 +7951.73013/T +18.60961&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2841-124-38-9-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '2500',
    'M',
    (SELECT id from species WHERE iupac='carbon dioxide'),
    (SELECT id from literature WHERE bibtexkey='3717'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3717'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='carbon dioxide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '2400',
    'R',
    (SELECT id from species WHERE iupac='carbon dioxide'),
    (SELECT id from literature WHERE bibtexkey='1137'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;4</sup>',
    '2400',
    'T',
    (SELECT id from species WHERE iupac='carbon dioxide'),
    (SELECT id from literature WHERE bibtexkey='87'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;4</sup>',
    '2400',
    'T',
    (SELECT id from species WHERE iupac='carbon dioxide'),
    (SELECT id from literature WHERE bibtexkey='3540'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='carbon dioxide'),
    (SELECT id from literature WHERE bibtexkey='perry73'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from492'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '2400',
    'C',
    (SELECT id from species WHERE iupac='carbon dioxide'),
    (SELECT id from literature WHERE bibtexkey='31'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '2400',
    'C',
    (SELECT id from species WHERE iupac='carbon dioxide'),
    (SELECT id from literature WHERE bibtexkey='34'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='carbon dioxide'),
    (SELECT id from literature WHERE bibtexkey='3705'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='carbon dioxide'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='carbon dioxide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2900',
    'Q',
    (SELECT id from species WHERE iupac='carbon dioxide'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'E',
    (SELECT id from species WHERE iupac='carbon dioxide'),
    (SELECT id from literature WHERE bibtexkey='3662'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3662',
    '1943,3662', 'As mentioned by Fogg and Sangster (2003), the fitting equation by Scharlin (1996) is erroneous. It appears that a correction factor of about 10<sup>6</sup> is necessary for consistency with their own data in Table&nbsp;1.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3662'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2400',
    '?',
    (SELECT id from species WHERE iupac='carbon dioxide'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='carbon dioxide'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;4</sup>',
    '2400',
    '?',
    (SELECT id from species WHERE iupac='carbon dioxide'),
    (SELECT id from literature WHERE bibtexkey='3811'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='carbon dioxide'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;4</sup>',
    '2400',
    '?',
    (SELECT id from species WHERE iupac='carbon dioxide'),
    (SELECT id from literature WHERE bibtexkey='379'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0379-124-38-9-ABC',
    '379', 'The data from Dean and Lange (1999) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;138.54120 +7859.16351/T +18.28486&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0379-124-38-9-ABC'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='379'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='carbon dioxide'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '2400',
    '?',
    (SELECT id from species WHERE iupac='carbon dioxide'),
    (SELECT id from literature WHERE bibtexkey='523'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;4</sup>',
    '2400',
    '?',
    (SELECT id from species WHERE iupac='carbon dioxide'),
    (SELECT id from literature WHERE bibtexkey='103'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'carbon suboxide',
    'C<sub>3</sub>O<sub>2</sub>',
    '',
    '504-64-3',
    'GNEVIACKFGQMHB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carbon oxides'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='carbon suboxide'),
    (SELECT id from literature WHERE bibtexkey='3248'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3248',
    '3248', 'Keßel et&nbsp;al. (2017) provide data at several pH values. Here, only the value at pH = 2 is shown because hydrolysis occurs in more alkaline solutions.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3248'));
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Alcohols (ROH)',
    (SELECT id from categories WHERE catname='Organic species with oxygen (O)'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methanol',
    'CH<sub>3</sub>OH',
    '',
    '67-56-1',
    'OKKJLVBELUTLKV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '5500',
    'L',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '5500',
    'L',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '5400',
    'L',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '5600',
    'L',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2626-67-56-1-consicheck',
    '2626', 'The H298 and A, B, C data listed in Table&nbsp;5.4 of Sander et&nbsp;al. (2011) are inconsistent, with 92&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2626-67-56-1-consicheck'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '5300',
    'L',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='1831'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '5200',
    'L',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '5500',
    'L',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='3065'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '4500',
    'L',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '5400',
    'L',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='3064'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at353K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '5300',
    'M',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='3526'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'M',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='2925'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='2955'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '5300',
    'M',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='3694'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '5600',
    'M',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='3132'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='alsosalt'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6',
    '5900',
    'M',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='1574'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '5500',
    'M',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='2961'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'M',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'M',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='3657'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'M',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='3631'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'M',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='2457'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6',
    '3900',
    'M',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='3648'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '5200',
    'M',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='483'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'M',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='3635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='3669'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'M',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='2218'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'M',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='496'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'M',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='712'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'improved711',
    '711', 'This paper supersedes earlier work with more concentrated solutions (Butler et&nbsp;al., 1933).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='improved711'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='2580'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '6200',
    'V',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='3693'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    'V',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '',
    'V',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='2966'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5400',
    'V',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '5700',
    'R',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='2222'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '5400',
    'T',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='3674'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'X',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'X',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '5600',
    'X',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='859'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'X',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='gaffney84'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'from715',
    '715', 'Value given here as quoted by Gaffney et&nbsp;al. (1987).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from715'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'X',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='timmermans60'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'from714',
    '714', 'Value given here as quoted by Hine and Weimar (1965).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from714'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6200',
    'Q',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='2531'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    '?',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5000',
    '?',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    '?',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    '?',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    '?',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    '?',
    (SELECT id from species WHERE iupac='methanol'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethanol',
    'C<sub>2</sub>H<sub>5</sub>OH',
    '',
    '64-17-5',
    'LFQSCWFLJHTTHZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '6400',
    'L',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '6400',
    'L',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '6300',
    'L',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '6400',
    'L',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '6300',
    'L',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='1831'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '6600',
    'L',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '6300',
    'L',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='3065'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '5700',
    'L',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '6300',
    'L',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '6200',
    'L',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='3659'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '5900',
    'M',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='3271'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '5500',
    'M',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='3526'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='2925'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '5800',
    'M',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='3112'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='alsosalt'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='1937'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='2483'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='cdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='1516'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '5800',
    'M',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='2961'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='3402'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='3657'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='3631'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='2457'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '3900',
    'M',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='3648'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='2449'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '6600',
    'M',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='483'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='3635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '6000',
    'M',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='3661'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='3669'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='2218'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='792'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='496'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '6500',
    'M',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='3660'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='712'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='2580'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '6300',
    'V',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='3693'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6300',
    'V',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '6300',
    'T',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='3674'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '6400',
    'X',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='859'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='gaffney84'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from715'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='timmermans60'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from714'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6500',
    'Q',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='3393'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6400',
    '?',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethanol'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-propanol',
    'C<sub>3</sub>H<sub>7</sub>OH',
    '',
    '71-23-8',
    'BDERNNFJNOPAEC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '6900',
    'L',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3500-71-23-8-consicheck',
    '3500', 'The H298 and A, B, C data listed in Table&nbsp;5-4 of Burkholder et&nbsp;al. (2019) are inconsistent, with 10&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3500-71-23-8-consicheck'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '6900',
    'L',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3245-71-23-8-consicheck',
    '3245', 'The H298 and A, B, C data listed in Table&nbsp;5-4 of Burkholder et&nbsp;al. (2015) are inconsistent, with 10&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3245-71-23-8-consicheck'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '7000',
    'L',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3518-71-23-8-consicheck',
    '3518', 'Values at 298&nbsp;K in Tables&nbsp;C2 and C5 of Brockbank (2013) are inconsistent, with 8&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3518-71-23-8-consicheck'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '6900',
    'L',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2626-71-23-8-consicheck',
    '2626', 'The H298 and A, B, C data listed in Table&nbsp;5.4 of Sander et&nbsp;al. (2011) are inconsistent, with 10&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2626-71-23-8-consicheck'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '7500',
    'L',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '6900',
    'L',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3065'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '6200',
    'L',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '6900',
    'L',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2925'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '6200',
    'M',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3112'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='alsosalt'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='1937'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3643'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3670'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3670'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3611'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '6200',
    'M',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2961'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3657'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3631'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2457'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '7500',
    'M',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='483'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3669'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2218'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='496'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='712'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='improved711'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2580'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '7700',
    'V',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3693'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;2</sup>',
    '4500',
    'V',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3638'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6900',
    'V',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '6900',
    'T',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3674'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6900',
    'Q',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7500',
    '?',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-propanol'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-propanol',
    'C<sub>3</sub>H<sub>7</sub>OH',
    'isopropanol',
    '67-63-0',
    'KFZMGEQAYNKOFK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '7100',
    'L',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '7100',
    'L',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '6900',
    'L',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '7500',
    'L',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '7500',
    'L',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '6200',
    'L',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '7000',
    'L',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '8400',
    'M',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2955'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '7300',
    'M',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3694'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2483'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='cdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='1856'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='cdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2969'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2969epics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2969'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2969linear'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2969'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2969direct'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2837'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3657'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3631'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;1</sup>',
    '5700',
    'M',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='857'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='857'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3648'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3675'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '7400',
    'M',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='483'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3669'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2218'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='712'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '7100',
    'V',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3527'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '7600',
    'V',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3693'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'R',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='714'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6900',
    'Q',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535dupl'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-Test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2531'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6000',
    '?',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-propanol'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'glycidol',
    'C<sub>3</sub>H<sub>6</sub>O<sub>2</sub>',
    '',
    '556-52-5',
    'CTKINSOISVBQLD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='glycidol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-butanol',
    'C<sub>4</sub>H<sub>9</sub>OH',
    '',
    '71-36-3',
    'LRHPLDYGYMQRHN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '7500',
    'L',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '7500',
    'L',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '7500',
    'L',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '7500',
    'L',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '7200',
    'L',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '7500',
    'L',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3065'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '6300',
    'L',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '7400',
    'L',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '7000',
    'M',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3719'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '6800',
    'M',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2999'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2925'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '6000',
    'M',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2997'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2997',
    '', 'Extrapolated from data above 298&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2997'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;1</sup>',
    '6200',
    'M',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3112'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='alsosalt'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;1</sup>',
    '6100',
    'M',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3609'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3643'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3670'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3670'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3611'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2837'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;1</sup>',
    '6200',
    'M',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2961'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3402'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3657'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='1073'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3631'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2457'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;1</sup>',
    '5600',
    'M',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='857'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='857'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '7200',
    'M',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='483'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at303K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2218'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2388'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='754'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='496'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='712'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='improved711'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '4700',
    'V',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3638'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7400',
    'V',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2388'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='712'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7200',
    'Q',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6900',
    '?',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2233'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-butanol',
    'C<sub>4</sub>H<sub>10</sub>O',
    '<i>sec</i>-butanol',
    '78-92-2',
    'BTANRVKWQNVYAZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '7600',
    'L',
    (SELECT id from species WHERE iupac='2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '7600',
    'L',
    (SELECT id from species WHERE iupac='2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;1</sup>',
    '7600',
    'L',
    (SELECT id from species WHERE iupac='2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '7300',
    'L',
    (SELECT id from species WHERE iupac='2-butanol'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '7300',
    'L',
    (SELECT id from species WHERE iupac='2-butanol'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '7400',
    'L',
    (SELECT id from species WHERE iupac='2-butanol'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '7600',
    'L',
    (SELECT id from species WHERE iupac='2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3657'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '7300',
    'M',
    (SELECT id from species WHERE iupac='2-butanol'),
    (SELECT id from literature WHERE bibtexkey='483'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-butanol'),
    (SELECT id from literature WHERE bibtexkey='2218'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-butanol'),
    (SELECT id from literature WHERE bibtexkey='712'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;1</sup>',
    '7600',
    'V',
    (SELECT id from species WHERE iupac='2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3527'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-butanol'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-butanol'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;1</sup>',
    '7500',
    'T',
    (SELECT id from species WHERE iupac='2-butanol'),
    (SELECT id from literature WHERE bibtexkey='2377'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-butanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7200',
    'Q',
    (SELECT id from species WHERE iupac='2-butanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butanol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butanol'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butanol'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butanol'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7100',
    '?',
    (SELECT id from species WHERE iupac='2-butanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-butanol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-butanol'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-1-propanol',
    'C<sub>4</sub>H<sub>10</sub>O',
    'isobutanol',
    '78-83-1',
    'ZXEKIIBDNHEJCQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;1</sup>',
    '7200',
    'L',
    (SELECT id from species WHERE iupac='2-methyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;1</sup>',
    '7200',
    'L',
    (SELECT id from species WHERE iupac='2-methyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;1</sup>',
    '7400',
    'L',
    (SELECT id from species WHERE iupac='2-methyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'L',
    (SELECT id from species WHERE iupac='2-methyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'L',
    (SELECT id from species WHERE iupac='2-methyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;1</sup>',
    '7200',
    'L',
    (SELECT id from species WHERE iupac='2-methyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3032'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2483'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='cdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;1</sup>',
    '6100',
    'M',
    (SELECT id from species WHERE iupac='2-methyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3609'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2339'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3657'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3631'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='483'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2218'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='712'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;1</sup>',
    '7200',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3527'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2339'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7200',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '8100',
    '?',
    (SELECT id from species WHERE iupac='2-methyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2233'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-2-propanol',
    'C<sub>4</sub>H<sub>10</sub>O',
    '<i>tert</i>-butanol',
    '75-65-0',
    'DKGAVHZHDRPRBM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;1</sup>',
    '7600',
    'L',
    (SELECT id from species WHERE iupac='2-methyl-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;1</sup>',
    '8300',
    'L',
    (SELECT id from species WHERE iupac='2-methyl-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;1</sup>',
    '8300',
    'L',
    (SELECT id from species WHERE iupac='2-methyl-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;1</sup>',
    '7700',
    'L',
    (SELECT id from species WHERE iupac='2-methyl-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '7900',
    'M',
    (SELECT id from species WHERE iupac='2-methyl-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methyl-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methyl-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3657'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methyl-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='542'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '542',
    '542', 'Koga (1995) found that <i>tert</i>-butanol does not obey Henry''s law at c  &gt;  3.8&nbsp;mM.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='542'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;1</sup>',
    '8300',
    'M',
    (SELECT id from species WHERE iupac='2-methyl-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='483'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methyl-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2218'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methyl-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='712'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;1</sup>',
    '7700',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3527'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;1</sup>',
    '6500',
    'C',
    (SELECT id from species WHERE iupac='2-methyl-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2431'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7200',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methyl-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '8300',
    '?',
    (SELECT id from species WHERE iupac='2-methyl-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methyl-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methyl-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='2-methyl-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3500-75-65-0',
    '3500', 'Incorrect data are given by Burkholder et&nbsp;al. (2019) for 2-methyl-2-propanol. The correct parameter for the temperature dependence is C = 37.98 (Robert E.&nbsp;Huie, personal communication, 2021).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3500-75-65-0'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='2-methyl-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3245-75-65-0',
    '3245', 'Incorrect data are given by Burkholder et&nbsp;al. (2015) for 2-methyl-2-propanol. The correct parameter for the temperature dependence is C = 37.98 (Robert E.&nbsp;Huie, personal communication, 2021).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3245-75-65-0'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-pentanol',
    'C<sub>5</sub>H<sub>11</sub>OH',
    'amyl alcohol',
    '71-41-0',
    'AMQJEAYHLZJPGS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;1</sup>',
    '7400',
    'L',
    (SELECT id from species WHERE iupac='1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '7900',
    'L',
    (SELECT id from species WHERE iupac='1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3065'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;1</sup>',
    '7800',
    'L',
    (SELECT id from species WHERE iupac='1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;1</sup>',
    '7100',
    'M',
    (SELECT id from species WHERE iupac='1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2999'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;1</sup>',
    '6100',
    'M',
    (SELECT id from species WHERE iupac='1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2997'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2997'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;1</sup>',
    '6800',
    'M',
    (SELECT id from species WHERE iupac='1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3112'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='alsosalt'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;1</sup>',
    '6900',
    'M',
    (SELECT id from species WHERE iupac='1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2961'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3657'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3631'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2457'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2218'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='712'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;1</sup>',
    '4900',
    'V',
    (SELECT id from species WHERE iupac='1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3638'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7800',
    'V',
    (SELECT id from species WHERE iupac='1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2388'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='712'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7600',
    'Q',
    (SELECT id from species WHERE iupac='1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-P'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7700',
    '?',
    (SELECT id from species WHERE iupac='1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2233'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-pentanol',
    'C<sub>5</sub>H<sub>12</sub>O',
    '<i>sec</i>-pentanol',
    '6032-29-7',
    'JYVLIDXNZAXMDK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;1</sup>',
    '7900',
    'L',
    (SELECT id from species WHERE iupac='2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;1</sup>',
    '8000',
    'L',
    (SELECT id from species WHERE iupac='2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;1</sup>',
    '8000',
    'M',
    (SELECT id from species WHERE iupac='2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3633'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3643'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3670'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3670'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3611'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3657'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='712'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7600',
    'Q',
    (SELECT id from species WHERE iupac='2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7900',
    '?',
    (SELECT id from species WHERE iupac='2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-pentanol',
    'C<sub>5</sub>H<sub>12</sub>O',
    '',
    '584-02-1',
    'AQIXEPGDORPWBJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;1</sup>',
    '7600',
    'L',
    (SELECT id from species WHERE iupac='3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;1</sup>',
    '8000',
    'M',
    (SELECT id from species WHERE iupac='3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3633'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;1</sup>',
    '7900',
    'T',
    (SELECT id from species WHERE iupac='3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2377'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7600',
    'Q',
    (SELECT id from species WHERE iupac='3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7500',
    '?',
    (SELECT id from species WHERE iupac='3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-1-butanol',
    'C<sub>5</sub>H<sub>12</sub>O',
    '',
    '137-32-6',
    'QPRQEDXDYOZYLA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;1</sup>',
    '7900',
    'L',
    (SELECT id from species WHERE iupac='2-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;1</sup>',
    '7700',
    'M',
    (SELECT id from species WHERE iupac='2-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3633'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3631'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='712'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7600',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-Test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6800',
    '?',
    (SELECT id from species WHERE iupac='2-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(S)-2-methyl-1-butanol',
    'C<sub>5</sub>H<sub>12</sub>O',
    '',
    '1565-80-6',
    'QPRQEDXDYOZYLA-RXMQYKEDSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(S)-2-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-1-butanol',
    'C<sub>5</sub>H<sub>12</sub>O',
    'isopentanol',
    '123-51-3',
    'PHTQWCKDNZKARW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;1</sup>',
    '8000',
    'L',
    (SELECT id from species WHERE iupac='3-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='3-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;1</sup>',
    '6900',
    'M',
    (SELECT id from species WHERE iupac='3-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3788'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;1</sup>',
    '7700',
    'M',
    (SELECT id from species WHERE iupac='3-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3633'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3643'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3670'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3670'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3611'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3521'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3521',
    '', 'Calculated for an aqueous solution containing 60&nbsp;% ethanol by volume as the solvent.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7600',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '8200',
    '?',
    (SELECT id from species WHERE iupac='3-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-2-butanol',
    'C<sub>5</sub>H<sub>12</sub>O',
    '<i>tert</i>-pentanol',
    '75-85-4',
    'MSXVEPNJUHWQHW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;1</sup>',
    '7900',
    'L',
    (SELECT id from species WHERE iupac='2-methyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;1</sup>',
    '8200',
    'L',
    (SELECT id from species WHERE iupac='2-methyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;1</sup>',
    '8200',
    'M',
    (SELECT id from species WHERE iupac='2-methyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3633'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3657'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='712'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7600',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7200',
    '?',
    (SELECT id from species WHERE iupac='2-methyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-2-butanol',
    'C<sub>5</sub>H<sub>12</sub>O',
    '',
    '598-75-4',
    'MXLMTQWGSQIYOW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;1</sup>',
    '7600',
    'L',
    (SELECT id from species WHERE iupac='3-methyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;1</sup>',
    '7800',
    'M',
    (SELECT id from species WHERE iupac='3-methyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3633'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-methyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7600',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7500',
    '?',
    (SELECT id from species WHERE iupac='3-methyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-methyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dimethyl-1-propanol',
    'C<sub>5</sub>H<sub>12</sub>O',
    '',
    '75-84-3',
    'KPSSIOMAKSHJJG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '7800',
    'L',
    (SELECT id from species WHERE iupac='2,2-dimethyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3518-75-84-3-consicheck',
    '3518', 'Values at 298&nbsp;K in Tables&nbsp;C2 and C5 of Brockbank (2013) are inconsistent, with 6&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3518-75-84-3-consicheck'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2-dimethyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2-dimethyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2-dimethyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7600',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;1</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='2,2-dimethyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '588',
    '588', 'Value obtained by Saxena and Hildemann (1996) using the group contribution method.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7900',
    '?',
    (SELECT id from species WHERE iupac='2,2-dimethyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-hexanol',
    'C<sub>6</sub>H<sub>14</sub>O',
    '',
    '111-27-3',
    'ZSIAUFGUXNUGDI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;1</sup>',
    '7800',
    'L',
    (SELECT id from species WHERE iupac='1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;1</sup>',
    '8200',
    'L',
    (SELECT id from species WHERE iupac='1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;1</sup>',
    '7300',
    'M',
    (SELECT id from species WHERE iupac='1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='2999'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;1</sup>',
    '6100',
    'M',
    (SELECT id from species WHERE iupac='1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='2997'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2997'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '5800',
    'M',
    (SELECT id from species WHERE iupac='1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3112'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='alsosalt'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3671'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3643'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3670'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3670'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3611'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '5800',
    'M',
    (SELECT id from species WHERE iupac='1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='2961'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3402'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3657'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='2457'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='2218'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='754'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '5100',
    'V',
    (SELECT id from species WHERE iupac='1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3638'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '8200',
    'V',
    (SELECT id from species WHERE iupac='1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='712'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7900',
    'Q',
    (SELECT id from species WHERE iupac='1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '8400',
    '?',
    (SELECT id from species WHERE iupac='1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-hexanol',
    'C<sub>6</sub>H<sub>14</sub>O',
    '',
    '626-93-7',
    'QNVRIHYSUZMSGM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '8100',
    'L',
    (SELECT id from species WHERE iupac='2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3657'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-hexanol',
    'C<sub>6</sub>H<sub>14</sub>O',
    '',
    '623-37-0',
    'ZOCHHNOQQHDWHG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '8400',
    'L',
    (SELECT id from species WHERE iupac='3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;1</sup>',
    '8400',
    'L',
    (SELECT id from species WHERE iupac='3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '8400',
    'T',
    (SELECT id from species WHERE iupac='3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='2377'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-1-pentanol',
    'C<sub>6</sub>H<sub>14</sub>O',
    '',
    '105-30-6',
    'PFNHSEQQEPMLNI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2-methyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-1-pentanol',
    'C<sub>6</sub>H<sub>14</sub>O',
    '',
    '589-35-5',
    'IWTBVKIGCDZRPL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;1</sup>',
    '8600',
    'L',
    (SELECT id from species WHERE iupac='3-methyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-2-pentanol',
    'C<sub>6</sub>H<sub>14</sub>O',
    '',
    '590-36-3',
    'WFRBDWRZVBPBDO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-2-pentanol',
    'C<sub>6</sub>H<sub>14</sub>O',
    '',
    '565-60-6',
    'ZXNBBWHRUSXUFZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='3-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-2-pentanol',
    'C<sub>6</sub>H<sub>14</sub>O',
    '',
    '108-11-2',
    'WVYWICLMDOOCFB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '7300',
    'L',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7900',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '8700',
    '?',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'at300K',
    '', 'Value at T = 300&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at300K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-3-pentanol',
    'C<sub>6</sub>H<sub>14</sub>O',
    '',
    '565-67-3',
    'ISTJMQSHILQAEC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-Test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-3-pentanol',
    'C<sub>6</sub>H<sub>14</sub>O',
    '',
    '77-74-7',
    'FRDAATYAJDYRNW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '7300',
    'L',
    (SELECT id from species WHERE iupac='3-methyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='3-methyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3-methyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3657'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-methyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-ethyl-1-butanol',
    'C<sub>6</sub>H<sub>14</sub>O',
    '',
    '97-95-0',
    'TZYRSLHNPKPEFV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2-ethyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-ethyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-ethyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dimethyl-1-butanol',
    'C<sub>6</sub>H<sub>14</sub>O',
    '',
    '1185-33-7',
    'XRMVWAKMXZNZIL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethyl-1-butanol',
    'C<sub>6</sub>H<sub>14</sub>O',
    '',
    '19550-30-2',
    'SXSWMAUXEHKFGX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '1162inconsistent',
    '1162', 'The error given by Suzuki et&nbsp;al. (1992) is not the difference between the observed and the calculated value, as it should be. It is unclear which of the numbers is wrong.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162inconsistent'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethyl-2-butanol',
    'C<sub>6</sub>H<sub>14</sub>O',
    '',
    '594-60-5',
    'IKECULIHBUCAKR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2,3-dimethyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3-dimethyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3-dimethyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '642dimebu',
    '642', 'The species is probably 2,3-dimethyl-2-butanol and not 2,3-dimethylbutanol as listed in Hine and Mookerjee (1975).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='642dimebu'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3-dimethyl-1-butanol',
    'C<sub>6</sub>H<sub>14</sub>O',
    '',
    '624-95-3',
    'DUXCSEISVMREAX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3-dimethyl-2-butanol',
    'C<sub>6</sub>H<sub>14</sub>O',
    '',
    '464-07-3',
    'DFOXKPDFWGNLJU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-bis(hydroxymethyl)-1-butanol',
    'C<sub>6</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '77-99-6',
    'ZJCCRDAZUWHFQH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2-bis(hydroxymethyl)-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-bis(hydroxymethyl)-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-heptanol',
    'C<sub>7</sub>H<sub>16</sub>O',
    '',
    '111-70-6',
    'BBMCTIGTTCKYKF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;1</sup>',
    '8200',
    'L',
    (SELECT id from species WHERE iupac='1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;1</sup>',
    '8600',
    'L',
    (SELECT id from species WHERE iupac='1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '7200',
    'M',
    (SELECT id from species WHERE iupac='1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='2999'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;1</sup>',
    '6300',
    'M',
    (SELECT id from species WHERE iupac='1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='2997'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2997'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='2339'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='2339'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6',
    '5300',
    'V',
    (SELECT id from species WHERE iupac='1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3638'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;1</sup>',
    '8700',
    'V',
    (SELECT id from species WHERE iupac='1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='712'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '8300',
    'Q',
    (SELECT id from species WHERE iupac='1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3539'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3539-111-70-6',
    '3539,583', 'Rumble (2021) refers to Moore et&nbsp;al. (1995) as the source, but this value cannot be found there.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3539-111-70-6'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '9400',
    '?',
    (SELECT id from species WHERE iupac='1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-heptanol',
    'C<sub>7</sub>H<sub>16</sub>O',
    '',
    '543-49-7',
    'CETWDUZRCINIHU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '8700',
    'L',
    (SELECT id from species WHERE iupac='2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at303K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at303K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-heptanol',
    'C<sub>7</sub>H<sub>16</sub>O',
    '',
    '589-82-2',
    'RZKSECIXORKHQS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '9100',
    'L',
    (SELECT id from species WHERE iupac='3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-heptanol',
    'C<sub>7</sub>H<sub>16</sub>O',
    '',
    '589-55-9',
    'YVBCULSIZWMTFY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '9100',
    'L',
    (SELECT id from species WHERE iupac='4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '9100',
    'T',
    (SELECT id from species WHERE iupac='4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='2377'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-1-hexanol',
    'C<sub>7</sub>H<sub>16</sub>O',
    '',
    '624-22-6',
    'LCFKURIJYIJNRU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;1</sup>',
    '11000',
    'M',
    (SELECT id from species WHERE iupac='2-methyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-1-hexanol',
    'C<sub>7</sub>H<sub>16</sub>O',
    '',
    '13231-81-7',
    'YGZVAQICDGBHMD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-1-hexanol',
    'C<sub>7</sub>H<sub>16</sub>O',
    '',
    '818-49-5',
    'YNPVNLWKVZZBTM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-methyl-1-hexanol',
    'C<sub>7</sub>H<sub>16</sub>O',
    '',
    '627-98-5',
    'ZVHAANQOQZVVFD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-2-hexanol',
    'C<sub>7</sub>H<sub>16</sub>O',
    '',
    '625-23-0',
    'KRIMXCDMVRMCTC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-2-hexanol',
    'C<sub>7</sub>H<sub>16</sub>O',
    '',
    '2313-65-7',
    'IRLSKJITMWPWNY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-2-hexanol',
    'C<sub>7</sub>H<sub>16</sub>O',
    '',
    '2313-61-3',
    'KZUBXUKRWLMPIO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-methyl-2-hexanol',
    'C<sub>7</sub>H<sub>16</sub>O',
    '',
    '627-59-8',
    'ZDVJGWXFXGJSIU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-3-hexanol',
    'C<sub>7</sub>H<sub>16</sub>O',
    '',
    '617-29-8',
    'RGRUUTLDBCWYBL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-3-hexanol',
    'C<sub>7</sub>H<sub>16</sub>O',
    '',
    '597-96-6',
    'KYWJZCSJMOILIZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-3-hexanol',
    'C<sub>7</sub>H<sub>16</sub>O',
    '',
    '615-29-2',
    'NZPGYIBESMMUFU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-methyl-3-hexanol',
    'C<sub>7</sub>H<sub>16</sub>O',
    '',
    '623-55-2',
    'RGCZULIFYUPTAR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='5-methyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-ethyl-1-pentanol',
    'C<sub>7</sub>H<sub>16</sub>O',
    '',
    '27522-11-8',
    'UKFQWAVMIMCNEH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-ethyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-1-pentanol',
    'C<sub>7</sub>H<sub>16</sub>O',
    '',
    '66225-51-2',
    'DVEFUHVVWJONKR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-2-pentanol',
    'C<sub>7</sub>H<sub>16</sub>O',
    '',
    '609-27-8',
    'NEHRITNOSGFGGS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-3-pentanol',
    'C<sub>7</sub>H<sub>16</sub>O',
    '',
    '597-49-9',
    'XKIRHOWVQWCYBT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='3-ethyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dimethyl-1-pentanol',
    'C<sub>7</sub>H<sub>16</sub>O',
    '',
    '2370-12-9',
    'QTOMCRXZFDHJOL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2-dimethyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethyl-1-pentanol',
    'C<sub>7</sub>H<sub>16</sub>O',
    '',
    '10143-23-4',
    'MIBBFRQOCRYDDB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dimethyl-1-pentanol',
    'C<sub>7</sub>H<sub>16</sub>O',
    '',
    '6305-71-1',
    'OVOVDHYEOQJKMD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4-dimethyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3-dimethyl-1-pentanol',
    'C<sub>7</sub>H<sub>16</sub>O',
    '',
    '19264-94-9',
    'IFDHMBHPLKHMOY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4-dimethyl-1-pentanol',
    'C<sub>7</sub>H<sub>16</sub>O',
    '',
    '6570-87-2',
    'SVJNECJVNWTYQG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4-dimethyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,4-dimethyl-1-pentanol',
    'C<sub>7</sub>H<sub>16</sub>O',
    '',
    '3121-79-7',
    'OWCNPTHAWPMOJU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,4-dimethyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethyl-2-pentanol',
    'C<sub>7</sub>H<sub>16</sub>O',
    '',
    '4911-70-0',
    'YRSIFCHKXFKNME-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dimethyl-2-pentanol',
    'C<sub>7</sub>H<sub>16</sub>O',
    '',
    '625-06-9',
    'FMLSQAUAAGVTJO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3-dimethyl-2-pentanol',
    'C<sub>7</sub>H<sub>16</sub>O',
    '',
    '19781-24-9',
    'FCUOIGTWJDBTHR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3-dimethyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4-dimethyl-2-pentanol',
    'C<sub>7</sub>H<sub>16</sub>O',
    '',
    '64502-86-9',
    'SODKTKJZYBOMMT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,4-dimethyl-2-pentanol',
    'C<sub>7</sub>H<sub>16</sub>O',
    '',
    '6144-93-0',
    'OIBKGNPMOMMSSI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dimethyl-3-pentanol',
    'C<sub>7</sub>H<sub>16</sub>O',
    '',
    '3970-62-5',
    'HMSVXZJWPVIVIV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethyl-3-pentanol',
    'C<sub>7</sub>H<sub>16</sub>O',
    '',
    '595-41-5',
    'RFZHJHSNHYIRNE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dimethyl-3-pentanol',
    'C<sub>7</sub>H<sub>16</sub>O',
    '',
    '600-36-2',
    'BAYAKMPRFGNNFW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-ethyl-2-methyl-1-butanol',
    'C<sub>7</sub>H<sub>16</sub>O',
    '',
    '18371-13-6',
    'KMWHQWJVSALJAW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-2-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-ethyl-3-methyl-1-butanol',
    'C<sub>7</sub>H<sub>16</sub>O',
    '',
    '32444-34-1',
    'OXFFPTMSBXBVLZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-3-methyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3-trimethyl-1-butanol',
    'C<sub>7</sub>H<sub>16</sub>O',
    '',
    '55505-23-2',
    'FAMOAJMEFGYSNY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3-trimethyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3-trimethyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3-trimethyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3-trimethyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3-trimethyl-1-butanol',
    'C<sub>7</sub>H<sub>16</sub>O',
    '',
    '36794-64-6',
    'IWWVOLGZHKFWKK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,3-trimethyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3-trimethyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3-trimethyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3-trimethyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3-trimethyl-2-butanol',
    'C<sub>7</sub>H<sub>16</sub>O',
    '',
    '594-83-2',
    'OKXVARYIKDXAEO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3-trimethyl-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-octanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '111-87-5',
    'KBPLFHHGFOOTCA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '9000',
    'L',
    (SELECT id from species WHERE iupac='1-octanol'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '8900',
    'L',
    (SELECT id from species WHERE iupac='1-octanol'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '7000',
    'M',
    (SELECT id from species WHERE iupac='1-octanol'),
    (SELECT id from literature WHERE bibtexkey='3719'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '6900',
    'M',
    (SELECT id from species WHERE iupac='1-octanol'),
    (SELECT id from literature WHERE bibtexkey='2999'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '6000',
    'M',
    (SELECT id from species WHERE iupac='1-octanol'),
    (SELECT id from literature WHERE bibtexkey='2997'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2997'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-octanol'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-octanol'),
    (SELECT id from literature WHERE bibtexkey='3402'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-octanol'),
    (SELECT id from literature WHERE bibtexkey='754'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-octanol'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-octanol'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '8900',
    'V',
    (SELECT id from species WHERE iupac='1-octanol'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-octanol'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-octanol'),
    (SELECT id from literature WHERE bibtexkey='712'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octanol'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octanol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octanol'),
    (SELECT id from literature WHERE bibtexkey='3025'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octanol'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '8600',
    'Q',
    (SELECT id from species WHERE iupac='1-octanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octanol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octanol'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octanol'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octanol'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octanol'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octanol'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-octanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7700',
    '?',
    (SELECT id from species WHERE iupac='1-octanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-octanol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-octanol'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-octanol'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-octanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '123-96-6',
    'SJWFXCIHNDVPSH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '9600',
    'L',
    (SELECT id from species WHERE iupac='2-octanol'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2-octanol'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-octanol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-octanol'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-octanol'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-octanol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-octanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-octanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-octanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-octanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-octanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-octanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-octanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-octanol'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-octanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-octanol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-octanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '589-98-0',
    'NMRPBPVERJPACX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='3-octanol'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '8300',
    'M',
    (SELECT id from species WHERE iupac='3-octanol'),
    (SELECT id from literature WHERE bibtexkey='3719'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-octanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-octanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-octanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-octanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-octanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-octanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-octanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '589-62-8',
    'WOFPPJOZXUTRAU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-octanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-octanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-1-heptanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '60435-70-3',
    'QZESEQBMSFFHRY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '1115_60435-70-3',
    '1115', 'It is assumed here that entry number 72 in Table&nbsp;1 of Yaws et&nbsp;al. (1997) refers to 2-methyl-1-heptanol, not 2-methyl-2-heptanol.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1115_60435-70-3'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-1-heptanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '1070-32-2',
    'MUPPEBVXFKNMCI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-1-heptanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '817-91-4',
    'LLUQZGDMUIMPTC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-methyl-1-heptanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '7212-53-5',
    'KFARNLMRENFOHE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '6-methyl-1-heptanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '1653-40-3',
    'BWDBEAQIHAEVLV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='6-methyl-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='6-methyl-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-methyl-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-methyl-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-2-heptanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '625-25-2',
    'ACBMYYVZWKYLIP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-2-heptanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '31367-46-1',
    'SZERMVMTUUAYML-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-2-heptanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '56298-90-9',
    'GUHWHNUGIGOSCN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-methyl-2-heptanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '54630-50-1',
    'FYMBAYNKBWGEIK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='5-methyl-2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '6-methyl-2-heptanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '4730-22-7',
    'FCOUHTHQYOMLJT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-methyl-2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-methyl-2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-3-heptanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '18720-62-2',
    'QGVFLDUEHSIZIG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-3-heptanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '5582-82-1',
    'PQOSNJHBSNZITJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-3-heptanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '14979-39-6',
    'BKQICAFAUMRYLZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-methyl-3-heptanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '18720-65-5',
    'SECKOSOTZOBWEI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='5-methyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '6-methyl-3-heptanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '18720-66-6',
    'MNBIBGDICHMQFN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='6-methyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-methyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-methyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-4-heptanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '21570-35-4',
    'QXPLZEKPCGUWEM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-4-heptanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '1838-73-9',
    'JMRDKKYZLXDPLN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-4-heptanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '598-01-6',
    'IQXKGRKRIRMQCQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-ethyl-1-hexanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '104-76-7',
    'YIWUKEYIRIRTPP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2-ethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '7200',
    'M',
    (SELECT id from species WHERE iupac='2-ethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3719'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-ethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-ethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-ethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-1-hexanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '41065-95-6',
    'LWWJDXKGQVEZKT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-ethyl-1-hexanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '66576-32-7',
    'RLGDVTUGYZAYIX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-ethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dimethyl-1-hexanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '2370-13-0',
    'GSSDZVRLQDXOPL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethyl-1-hexanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '',
    'HIYTVAULOHUDEC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3-dimethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dimethyl-1-hexanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '3965-59-1',
    'GDRBQWCGBCJTLB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4-dimethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5-dimethyl-1-hexanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '6886-16-4',
    'OBOHUKJIPIBYTA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,5-dimethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3-dimethyl-1-hexanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '10524-70-6',
    'RAKYQWCHMSXUEG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3-dimethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4-dimethyl-1-hexanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '66576-57-6',
    'QVFKMROLPSPCIX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4-dimethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,5-dimethyl-1-hexanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '13501-73-0',
    'WETBJXIDTZXCBL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,5-dimethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,4-dimethyl-1-hexanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '6481-95-4',
    'VZWIUKUDEGQHIO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,4-dimethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,5-dimethyl-1-hexanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '60564-76-3',
    'QABJATQYUASJEM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,5-dimethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,5-dimethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,5-dimethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5,5-dimethyl-1-hexanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '2768-18-5',
    'QYFVEEMPFRRFNN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='5,5-dimethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5,5-dimethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5,5-dimethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-2-hexanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '24448-19-9',
    'YBQZSEZVMFENOM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-ethyl-2-hexanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '',
    'ALAPJJMGVQNJIU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-ethyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethyl-2-hexanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '19550-03-9',
    'BFKOEFFCVFMWPF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dimethyl-2-hexanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '42328-76-7',
    'RTRZHEPXWQXCCI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5-dimethyl-2-hexanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '3730-60-7',
    'JPUIYNHIEXIFMV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3-dimethyl-2-hexanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '22025-20-3',
    'LTTHCWFPLXSQOD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3-dimethyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4-dimethyl-2-hexanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '19550-05-1',
    'LBJWJHMCZHKLQU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4-dimethyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,5-dimethyl-2-hexanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '66576-27-0',
    'VGGMROOHXNLMTP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,5-dimethyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,4-dimethyl-2-hexanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '',
    'CJGWLHDFPXIKQX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,4-dimethyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,5-dimethyl-2-hexanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '',
    'KHSOOQUMPPYGAW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,5-dimethyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,5-dimethyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,5-dimethyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5,5-dimethyl-2-hexanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '31841-77-7',
    'NMSUCVXVCHZTEH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='5,5-dimethyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5,5-dimethyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5,5-dimethyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5,5-dimethyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-3-hexanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '597-76-2',
    'WNDLTOTUHMHNOC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-ethyl-3-hexanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '19780-44-0',
    'BOJLCKCCKQMGKD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-ethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dimethyl-3-hexanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '4209-90-9',
    'PFHLGQKVKALLMD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2-dimethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethyl-3-hexanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '4166-46-5',
    'CGWJMIUMPDDHQC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dimethyl-3-hexanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '13432-25-2',
    'UCRQJBCLZKHOGX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5-dimethyl-3-hexanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '19550-07-3',
    'SNKTZHPOKPYBPT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4-dimethyl-3-hexanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '19550-08-4',
    'FJXOYCIYKQJAAF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,5-dimethyl-3-hexanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '4209-91-0',
    'INMGJWCKWKKMPN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,5-dimethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,4-dimethyl-3-hexanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '19550-09-5',
    'BARKHVPKOOSMNW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,5-dimethyl-3-hexanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '',
    'UAVZZCGGBCLHIP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,5-dimethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,5-dimethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,5-dimethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5,5-dimethyl-3-hexanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '66576-31-6',
    'NPZRPUOKIPAIEL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5,5-dimethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-propyl-1-pentanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '58175-57-8',
    'LASHFHLFDRTERB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-ethyl-2-methyl-1-pentanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '5970-63-8',
    'VZCOFGHOKLEMPL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-2-methyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-ethyl-3-methyl-1-pentanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '',
    'ALPFTHGDLMTYRM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-ethyl-3-methyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-3-methyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-3-methyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-ethyl-4-methyl-1-pentanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '106-67-2',
    'QCHSJPKDWOFACC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-4-methyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-2-methyl-1-pentanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '',
    'VWQDMMBTEFDWNM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-2-methyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2-methyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2-methyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-3-methyl-1-pentanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '10524-71-7',
    'XYUCPYMMHKJJSS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-3-methyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-3-methyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-3-methyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-4-methyl-1-pentanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '38514-13-5',
    'RWIFVESHBHTZEM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-4-methyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-4-methyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-4-methyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3-trimethyl-1-pentanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '57409-53-7',
    'GBONVOIRPAJSLA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3-trimethyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,4-trimethyl-1-pentanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '123-44-4',
    'CWPPDTVYIJETDF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3-trimethyl-1-pentanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '',
    'LFRFDOWJBYDJGD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,3-trimethyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3-trimethyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3-trimethyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4-trimethyl-1-pentanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '6570-88-3',
    'PAZDSSMTPLLLIR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,4-trimethyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,4-trimethyl-1-pentanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '16325-63-6',
    'ZNRVRWHPZZOTIE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4-trimethyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4-trimethyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3,4-trimethyl-1-pentanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '',
    'OIPMJJVCOSACDS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3,4-trimethyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4-trimethyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4-trimethyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4,4-trimethyl-1-pentanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '16325-64-7',
    'FQNYRSRCONKFCN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4,4-trimethyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,4-trimethyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,4-trimethyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-2-methyl-2-pentanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '19780-63-3',
    'FRUMTAZIGSJVOJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-4-methyl-2-pentanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '66576-23-6',
    'PFRFNYYIOSQSDD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-4-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-4-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-4-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-4-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3-trimethyl-2-pentanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '23171-85-9',
    'FBWWGYIEJGQWJP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,3-trimethyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3-trimethyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3-trimethyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3-trimethyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4-trimethyl-2-pentanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '66576-26-9',
    'FTPXXARYDFWPGE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,4-trimethyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,4-trimethyl-2-pentanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '690-37-9',
    'BSYJHYLAMMJNRC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4-trimethyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3,4-trimethyl-2-pentanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '19411-41-7',
    'BOBYQFFCQPQLOB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3,4-trimethyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4-trimethyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4-trimethyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4-trimethyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4,4-trimethyl-2-pentanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '10575-56-1',
    'MXDGSCZQIMQLII-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,4-trimethyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-2-methyl-3-pentanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '597-05-7',
    'DMHIJUVUPKCGLJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-2-methyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2-methyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2-methyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2-methyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-3-methyl-2-pentanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '66576-22-5',
    'SLBLSROGXMXPPF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-3-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-3-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-3-methyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3-trimethyl-3-pentanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '7294-05-5',
    'KLIHWYNSISMOMR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3-trimethyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3-trimethyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,4-trimethyl-3-pentanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '5162-48-1',
    'AXINNNJHLJWMTC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4-trimethyl-3-pentanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '3054-92-0',
    'PLSMHHUFDLYURK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,4-trimethyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-2-(1-methylethyl)-1-butanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '18593-92-5',
    'IDGDEUZERZKYHG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-2-(1-methylethyl)-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-(1-methylethyl)-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-(1-methylethyl)-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-(1-methylethyl)-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,3-tetramethyl-1-butanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '66576-24-7',
    'OCTRJUXIYWWVAR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3,3-tetramethyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3-tetramethyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3-tetramethyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-diethyl-1-butanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '13023-60-4',
    'CBHXDVOSUKFRBE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2-diethyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-diethyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-diethyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethyl-2-ethyl-1-butanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '',
    'YPIJDMPDVZUWJO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3-dimethyl-2-ethyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-2-ethyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-2-ethyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3-dimethyl-2-ethyl-1-butanol',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '66576-56-5',
    'WOVMYJCSCISMAU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3-dimethyl-2-ethyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-2-ethyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-2-ethyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-(hexyloxy)-ethanol',
    'C<sub>8</sub>H<sub>18</sub>O<sub>2</sub>',
    '',
    '112-25-4',
    'UPGSWASWQBLSKZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-(hexyloxy)-ethanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(hexyloxy)-ethanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-nonanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '143-08-8',
    'ZWRUINPWMLAQRD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '9300',
    'L',
    (SELECT id from species WHERE iupac='1-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '6300',
    'M',
    (SELECT id from species WHERE iupac='1-nonanol'),
    (SELECT id from literature WHERE bibtexkey='2999'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '6200',
    'M',
    (SELECT id from species WHERE iupac='1-nonanol'),
    (SELECT id from literature WHERE bibtexkey='2997'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2997-143-08-8-consicheck',
    '2997', 'KWAC and KAWp from Table&nbsp;2 of Lei et&nbsp;al. (2007) are inconsistent, with 10&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2997-143-08-8-consicheck'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2997'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-nonanol'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-nonanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3521'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nonanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nonanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nonanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nonanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nonanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nonanol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nonanol'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nonanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-nonanol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-nonanol'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-nonanol'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-nonanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '628-99-9',
    'NGDNVOAEIVQRFH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '11000',
    'L',
    (SELECT id from species WHERE iupac='2-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3643'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3670'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3670'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3611'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nonanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nonanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nonanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nonanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nonanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-nonanol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-nonanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '624-51-1',
    'GYSCXPVAKHVAAY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-nonanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-nonanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-nonanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '5932-79-6',
    'IXUOEGRSQCCEHB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-nonanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nonanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-nonanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '623-93-8',
    'FCBBRODPXVPZAH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='5-nonanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-nonanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-1-octanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '818-81-5',
    'IGVGCQGTEINVOH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-1-octanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '38514-02-2',
    'CLFSZAMBOZSCOS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-1-octanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '38514-03-3',
    'MWWKESKJRHQWEF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-methyl-1-octanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '38514-04-4',
    'CGCDFYUPZXVGIX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='5-methyl-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '6-methyl-1-octanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '38514-05-5',
    'WWRGKAMABZHMCN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='6-methyl-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-methyl-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-methyl-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '7-methyl-1-octanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '2430-22-0',
    'QDTDKYHPHANITQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='7-methyl-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='7-methyl-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='7-methyl-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-2-octanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '628-44-4',
    'KBCNUEXDHWDIFX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-2-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-octanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-octanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-octanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-2-octanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '27644-49-1',
    'WQADSKJNOTZWML-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-2-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-octanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-octanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-methyl-2-octanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '66793-81-5',
    'IWFICVXFFNDWOJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='5-methyl-2-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-2-octanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-2-octanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '7-methyl-2-octanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '66793-83-7',
    'NOEKZKTXHKNMAQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='7-methyl-2-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='7-methyl-2-octanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='7-methyl-2-octanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-3-octanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '26533-34-6',
    'DIVBBSLQUDHECU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-3-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-octanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-octanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-octanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-3-octanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '5340-36-3',
    'JEWXYDDSLPIBBO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-3-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-3-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-3-octanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-3-octanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-3-octanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-3-octanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-3-octanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-3-octanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '66793-80-4',
    'XPWBBDBJJRZCPW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-3-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-3-octanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-3-octanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '6-methyl-3-octanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '40225-75-0',
    'MFYHIHFYDULUQP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='6-methyl-3-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-methyl-3-octanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-methyl-3-octanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '7-methyl-3-octanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '66793-84-8',
    'IDCFJIMYNKBKMB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='7-methyl-3-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='7-methyl-3-octanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='7-methyl-3-octanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-4-octanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '40575-41-5',
    'BIAVIOIDPRPYJK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-4-octanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '26533-35-7',
    'MJOKZMZDONULOD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-4-octanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '23418-37-3',
    'RXSIKQJQLQRQQY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-methyl-4-octanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '59734-23-5',
    'YLTHHPQUTLMNIF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='5-methyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '6-methyl-4-octanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '66793-82-6',
    'KFRCBGHGDZSOJV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='6-methyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-methyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-methyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '7-methyl-4-octanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '33933-77-6',
    'KJMBBHZOLRRVMV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='7-methyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='7-methyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='7-methyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-ethyl-1-heptanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '817-60-7',
    'QNJAZNNWHWYOEO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-ethyl-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-1-heptanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '3525-25-5',
    'VRZRVMXNGMZLDB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-ethyl-1-heptanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '998-65-2',
    'GOJBFVJUMYSMJJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='5-ethyl-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-ethyl-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-2-heptanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '19780-39-3',
    'MMQDVLWWGWJSFS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-3-heptanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '19780-41-7',
    'XKRZDNKKANUBPV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-ethyl-4-heptanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '597-90-0',
    'GNROHGFUVTWFNG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-ethyl-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dimethyl-1-heptanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '14250-79-4',
    'WENIXZFPXMQPQQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2-dimethyl-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,6-dimethyl-1-heptanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '820-05-3',
    'GCBXGQPBCBPHSP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,6-dimethyl-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,6-dimethyl-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,6-dimethyl-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '6,6-dimethyl-1-heptanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '65769-10-0',
    'IOFUAVGBFVXDAO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='6,6-dimethyl-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6,6-dimethyl-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6,6-dimethyl-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethyl-2-heptanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '66794-00-1',
    'PQSMEVPHTJECDZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3-dimethyl-2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dimethyl-2-heptanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '65822-93-7',
    'VORBOMMQBCSRQF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4-dimethyl-2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5-dimethyl-2-heptanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '1561-18-8',
    'LVIFBEPHIBJBEU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,5-dimethyl-2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyl-2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6-dimethyl-2-heptanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '13254-34-7',
    'HGDVHRITTGWMJK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,6-dimethyl-2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethyl-2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethyl-2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethyl-2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,6-dimethyl-2-heptanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '51079-52-8',
    'YYUGBYFBCFRGNZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,6-dimethyl-2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,6-dimethyl-2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,6-dimethyl-2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,6-dimethyl-2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5,6-dimethyl-2-heptanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '58795-24-7',
    'ONBXNGYZXZBRJA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='5,6-dimethyl-2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5,6-dimethyl-2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5,6-dimethyl-2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5,6-dimethyl-2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dimethyl-3-heptanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '19549-70-3',
    'QENWAAAGDINHGE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2-dimethyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethyl-3-heptanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '19549-71-4',
    'JIEGVNXCNNWVPH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3-dimethyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6-dimethyl-3-heptanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '19549-73-6',
    'XZDMJRIWJSNEGC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,6-dimethyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,5-dimethyl-3-heptanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '19549-74-7',
    'NOSOEGQGQOMHBF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,5-dimethyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dimethyl-4-heptanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '66793-99-5',
    'ZIKNXBYJTDTRQA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2-dimethyl-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dimethyl-4-heptanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '19549-77-0',
    'QKRRAXACNUNGCF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4-dimethyl-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5-dimethyl-4-heptanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '',
    'NXLQTSHQSAVKJB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyl-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6-dimethyl-4-heptanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '108-82-7',
    'HXQPUEQDBSPXTE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '9300',
    'L',
    (SELECT id from species WHERE iupac='2,6-dimethyl-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,6-dimethyl-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethyl-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethyl-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethyl-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethyl-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethyl-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethyl-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethyl-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethyl-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,6-dimethyl-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3-dimethyl-4-heptanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '19549-78-1',
    'UGAZGYFCTFGQQH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3-dimethyl-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,5-dimethyl-4-heptanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '19549-79-2',
    'ZKXITRNXHWEQJU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,5-dimethyl-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethyl-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethyl-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,6-dimethyl-3-heptanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '1573-28-0',
    'HVPGGLNDHUWMLS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,6-dimethyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,6-dimethyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,6-dimethyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-ethyl-3-methyl-1-hexanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '66794-04-5',
    'DXXCMAAACWSRPE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-ethyl-3-methyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-3-methyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-3-methyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-ethyl-4-methyl-1-hexanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '66794-06-7',
    'NRZVENBFUFCASY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-ethyl-4-methyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-4-methyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-4-methyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-4-methyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-ethyl-5-methyl-1-hexanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '66794-07-8',
    'KVJOUCNJVQBRAO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-ethyl-5-methyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-5-methyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-5-methyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-1-methyl-1-hexanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '',
    'YNZQSDTXBBBFQH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-1-methyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-1-methyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-1-methyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-2-methyl-1-hexanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '66794-01-2',
    'UDZCUJOKBNABRS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2-methyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3,5-trimethyl-1-hexanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '1484-87-3',
    'HRXNWQMMTLLJJQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3,5-trimethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,5-trimethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,5-trimethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4,4-trimethyl-1-hexanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '66793-73-5',
    'OLRPKAJSAOYYCY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4,4-trimethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,4-trimethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,4-trimethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,4-trimethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,5,5-trimethyl-1-hexanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '3452-97-9',
    'BODRLKRKPXBDBN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,5,5-trimethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5,5-trimethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5,5-trimethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5,5-trimethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,5,5-trimethyl-1-hexanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '66793-75-7',
    'IECJUMYEWJOKHM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,5,5-trimethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,5,5-trimethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,5,5-trimethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,5,5-trimethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-propyl-1-hexanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '817-46-9',
    'JSUXZEJWGVYJJG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-propyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-propyl-1-hexanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '66793-85-9',
    'MHJIVMDBOGBUHH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-propyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-propyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-propyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-2-methyl-2-hexanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '66794-02-3',
    'HTOYXTGJEOUKPM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-2-methyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2-methyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2-methyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2-methyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4-trimethyl-2-hexanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '21102-13-6',
    'JTOONBKGYWVPOY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,4-trimethyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,4-trimethyl-2-hexanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '66793-91-7',
    'QMEHJTXRYVSFES-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4,4-trimethyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4-trimethyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,5-trimethyl-2-hexanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '66793-93-9',
    'CIVZBWYMPDUPSQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4,5-trimethyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5-trimethyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5,5-trimethyl-2-hexanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '66793-71-3',
    'ASOCSFZHADJKFU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,5,5-trimethyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5,5-trimethyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-2-methyl-3-hexanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '66794-03-4',
    'VUMFTWNZYFBYEB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-2-methyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2-methyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2-methyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2-methyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-4-methyl-3-hexanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '51200-80-7',
    'YOCLWWFBEJQTBM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-4-methyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-4-methyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-4-methyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-5-methyl-3-hexanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '597-77-3',
    'RMBUNHOAKTUXTC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-5-methyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-5-methyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-5-methyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-5-methyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-ethyl-2-methyl-3-hexanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '33943-21-4',
    'GBUYIUMHXYBONU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-ethyl-2-methyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-2-methyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-2-methyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-ethyl-3-methyl-3-hexanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '66794-05-6',
    'DUGZCTGTSJAPCV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-ethyl-3-methyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-3-methyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-3-methyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3-trimethyl-3-hexanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '5340-41-0',
    'DHNHHYWBZNQHGN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3-trimethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3-trimethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3-trimethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3-trimethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,4-trimethyl-3-hexanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '66793-89-3',
    'YMBVVPXERVAJTB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,4-trimethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,5-trimethyl-3-hexanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '3970-60-3',
    'UCLXUUYVWJKXIK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,5-trimethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,5-trimethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,5-trimethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4-trimethyl-3-hexanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '66793-90-6',
    'LTKHKGAPVGSECA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,4-trimethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,5-trimethyl-3-hexanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '65927-60-8',
    'ZVKQNIUBLJYSGN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,5-trimethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5-trimethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,4-trimethyl-3-hexanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '66793-92-8',
    'PDIVDRVTPZNRDZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4,4-trimethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4-trimethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4-trimethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5,5-trimethyl-3-hexanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '66793-72-4',
    'NPUIBFBNZSKEAP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,5,5-trimethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5,5-trimethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5,5-trimethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4,4-trimethyl-3-hexanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '66793-74-6',
    'QWJDXMFJOMPTCV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4,4-trimethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,4-trimethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,4-trimethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,5,5-trimethyl-3-hexanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '66810-87-5',
    'HGGJNDQMXCTKCR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,5,5-trimethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5,5-trimethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-2-propyl-1-pentanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '54004-41-0',
    'IGSWOIOCVJEQRH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-2-propyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-propyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-propyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-propyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-2-(1-methylethyl)-1-pentanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '55505-24-3',
    'CBHPZSADBWMIGE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-2-(1-methylethyl)-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-(1-methylethyl)-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-(1-methylethyl)-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-(1-methylethyl)-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-ethyl-2,4-dimethyl-1-pentanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '66793-98-4',
    'JIZZVMCXCCJUHI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-ethyl-2,4-dimethyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-2,4-dimethyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-2,4-dimethyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-2,4-dimethyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-2,2-dimethyl-1-pentanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '66793-95-1',
    'HEQYMZTUSVDQBW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-2,2-dimethyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,2-dimethyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,2-dimethyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3,4-tetramethyl-2-pentanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '66793-86-0',
    'HLWCPAJEXXTJHY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,3,4-tetramethyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3,4-tetramethyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3,4-tetramethyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,4-tetramethyl-2-pentanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '66793-87-1',
    'DBCCRNKDJIOKIO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,4,4-tetramethyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,4-tetramethyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,4-tetramethyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3,4,4-tetramethyl-2-pentanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '66793-88-2',
    'AIQOKYGLKGGWOI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3,4,4-tetramethyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4-tetramethyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4-tetramethyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4-tetramethyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3-diethyl-2-pentanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '66793-94-0',
    'IENXYHLNFHBNRR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3-diethyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-diethyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-diethyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethyl-3-ethyl-2-pentanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '66793-97-3',
    'AVQHNUMJCWRCBA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3-dimethyl-3-ethyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-3-ethyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-3-ethyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,4-dimethyl-3-ethyl-2-pentanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '21102-09-0',
    'YGQDLQQRBCOMKJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,4-dimethyl-3-ethyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethyl-3-ethyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethyl-3-ethyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-2,2-dimethyl-3-pentanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '66793-96-2',
    'CFWIFHZJKFFDFU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-2,2-dimethyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,2-dimethyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,2-dimethyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,2-dimethyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-2,4-dimethyl-3-pentanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '3970-59-0',
    'PZPYIRQFCOFLGJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-2,4-dimethyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-2,4-dimethyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,4-dimethyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,4-dimethyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,4-dimethyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,4-dimethyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,4-dimethyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,4-tetramethyl-3-pentanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '29772-39-2',
    'KNTFAYXQHRNXSM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3,4-tetramethyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,4-tetramethyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,4-tetramethyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,4-tetramethyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,4,4-tetramethyl-3-pentanol',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '14609-79-1',
    'WFJSIIHYYLHRHB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,4,4-tetramethyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,4-tetramethyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,4-tetramethyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-decanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '112-30-1',
    'MWKFXSUHUHTGQN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '9200',
    'L',
    (SELECT id from species WHERE iupac='1-decanol'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3518-112-30-1-consicheck',
    '3518', 'Values at 298&nbsp;K in Tables&nbsp;C2 and C5 of Brockbank (2013) are inconsistent, with 8&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3518-112-30-1-consicheck'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;2</sup>',
    '6600',
    'M',
    (SELECT id from species WHERE iupac='1-decanol'),
    (SELECT id from literature WHERE bibtexkey='2999'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;2</sup>',
    '5300',
    'M',
    (SELECT id from species WHERE iupac='1-decanol'),
    (SELECT id from literature WHERE bibtexkey='2997'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2997'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-decanol'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-decanol'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-decanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-decanol'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-decanol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-decanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-decanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-decanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-decanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-decanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-decanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-decanol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-decanol'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-decanol'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-decanol'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-decanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-decanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-decanol'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-decanol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-decanol'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-decanol'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-decanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '1120-06-5',
    'ACUZDYFTRHEKOS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-decanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-decanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '1565-81-7',
    'ICEQLCZWZXUUIJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-decanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-decanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-decanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-decanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-decanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-decanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-decanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '2051-31-2',
    'DTDMYWXTWWFLGJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-decanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-decanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-decanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-decanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-decanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '5205-34-5',
    'SZMNDOUFZGODBR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='5-decanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-decanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-decanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-decanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-1-nonanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '40589-14-8',
    'BEGNRPGEHZBNKK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-1-nonanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-nonanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-2-nonanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '10297-57-1',
    'VREDNSVJXRJXRI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-2-nonanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-3-nonanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '26533-33-5',
    'OFIYMUXECPHIPZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-3-nonanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-nonanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-4-nonanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '26533-31-3',
    'IBHHTADZYDLHPM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-4-nonanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-4-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-4-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-5-nonanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '29843-62-7',
    'RLQVUGAVOCBRNQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-5-nonanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-5-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-5-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-1-nonanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '22663-64-5',
    'BXQPYGLPOMTAPU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-1-nonanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-2-nonanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '60671-32-1',
    'QCBDLZKDRUKOFS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-2-nonanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-3-nonanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '21078-72-8',
    'VZBFPIMCUSPDLS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-3-nonanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-3-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-3-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-5-nonanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '',
    'QRZAYHZIHWIJHD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-5-nonanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-5-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-5-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-1-nonanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '1489-47-0',
    'HECVGHIJHFNAIL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-1-nonanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-4-nonanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '23418-38-4',
    'GDCOAKPWVJCNGI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-4-nonanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-4-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-4-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-methyl-1-nonanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '2768-16-3',
    'DBJSFYCKLLBKGB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='5-methyl-1-nonanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-1-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-1-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-methyl-2-nonanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '66731-95-1',
    'KZTLXVUOEODDMR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='5-methyl-2-nonanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-2-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-2-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-methyl-3-nonanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '66719-43-5',
    'CCSZLOPBDJWYHV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='5-methyl-3-nonanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-3-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-3-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-methyl-4-nonanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '66719-44-6',
    'BFYIAYZULSQBFQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='5-methyl-4-nonanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-4-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-4-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-methyl-5-nonanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '33933-78-7',
    'AGSIGVZAVLOKLP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='5-methyl-5-nonanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-5-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-5-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '6-methyl-2-nonanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '66256-60-8',
    'OYTRLQQQIHEJFE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='6-methyl-2-nonanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-methyl-2-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-methyl-2-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '7-methyl-1-nonanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '33234-93-4',
    'BJKXZCGJAOWNTN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='7-methyl-1-nonanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='7-methyl-1-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='7-methyl-1-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '7-methyl-2-nonanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '66256-61-9',
    'GCOBJHFUTQUABB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='7-methyl-2-nonanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='7-methyl-2-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '7-methyl-4-nonanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '26981-98-6',
    'KLZAWUYSXUGWGQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='7-methyl-4-nonanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='7-methyl-4-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='7-methyl-4-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '8-methyl-1-nonanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    'isodecanol',
    '25339-17-7',
    'PLLBRTOLHQQAQQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='8-methyl-1-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '8-methyl-2-nonanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '14779-92-1',
    'ZVZKLBCGIYWGOU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='8-methyl-2-nonanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='8-methyl-2-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='8-methyl-2-nonanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dimethyl-1-octanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '2370-14-1',
    'KEXGXAGJHHCTKD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2-dimethyl-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dimethyl-3-octanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '19841-72-6',
    'AZIWNYAWODSERA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2-dimethyl-3-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-3-octanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-3-octanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dimethyl-4-octanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '66719-52-6',
    'IVLDCRDTRQCTIY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2-dimethyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethyl-3-octanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '19781-10-3',
    'AWHYRPPRRQITHX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3-dimethyl-3-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-3-octanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-3-octanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-3-octanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dimethyl-2-octanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '18675-20-2',
    'WHJCLXRXPLJSSV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4-dimethyl-2-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-2-octanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dimethyl-4-octanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '33933-79-8',
    'VRFMFHBPJUSGFK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4-dimethyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5-dimethyl-4-octanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '66719-53-7',
    'VIHAZZPWGKHJQE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,5-dimethyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6-dimethyl-1-octanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '62417-08-7',
    'ZKWASVBZSAGDBI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,6-dimethyl-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethyl-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethyl-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6-dimethyl-2-octanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '18479-57-7',
    'WRFXXJKURVTLSY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,6-dimethyl-2-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethyl-2-octanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6-dimethyl-4-octanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '66719-54-8',
    'ZFOGJEKQQNVCFB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,6-dimethyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,7-dimethyl-2-octanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '42007-73-8',
    'JJZZVQICFJITMO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,7-dimethyl-2-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,7-dimethyl-2-octanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,7-dimethyl-3-octanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '66719-55-9',
    'VFUOFVONEDBLIJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,7-dimethyl-3-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,7-dimethyl-3-octanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,7-dimethyl-3-octanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,7-dimethyl-3-octanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,7-dimethyl-4-octanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '19781-11-4',
    'FRJOBNOTOHIMIH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,7-dimethyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,7-dimethyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,7-dimethyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4-dimethyl-4-octanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '66719-30-0',
    'JEBZCASOCDXENQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4-dimethyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,5-dimethyl-3-octanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '56065-42-0',
    'DMIBTMSBSULJMT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,5-dimethyl-3-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethyl-3-octanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethyl-3-octanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,6-dimethyl-3-octanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '151-19-9',
    'NPHCXUPGMINOPP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,6-dimethyl-3-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,6-dimethyl-3-octanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,6-dimethyl-3-octanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,6-dimethyl-3-octanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,6-dimethyl-4-octanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '66719-31-1',
    'XFUFFAQPWAGSDK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,6-dimethyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,6-dimethyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,6-dimethyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,7-dimethyl-1-octanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    'pelargol',
    '106-21-8',
    'PRNCMAKCNVRZFX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,7-dimethyl-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,7-dimethyl-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,7-dimethyl-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,7-dimethyl-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,7-dimethyl-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,7-dimethyl-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,7-dimethyl-2-octanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '15340-96-2',
    'XCWMPEYBKUYTLZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,7-dimethyl-2-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,7-dimethyl-2-octanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,7-dimethyl-2-octanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,7-dimethyl-3-octanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '78-69-3',
    'DLHQZZUEERVIGQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,7-dimethyl-3-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,7-dimethyl-3-octanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,7-dimethyl-3-octanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,7-dimethyl-3-octanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,5-dimethyl-1-octanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '66719-32-2',
    'UQKHXPAWOMZBLN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,5-dimethyl-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,5-dimethyl-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,5-dimethyl-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,6-dimethyl-1-octanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '66719-33-3',
    'JOWDWXPTKVUHBV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,6-dimethyl-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,6-dimethyl-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,6-dimethyl-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,6-dimethyl-4-octanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '56065-43-1',
    'QJVDAQVYZBSYCB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,6-dimethyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,6-dimethyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,6-dimethyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,7-dimethyl-1-octanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '66719-34-4',
    'UWAGZVFFZJGLJU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,7-dimethyl-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,7-dimethyl-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,7-dimethyl-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,7-dimethyl-4-octanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '19781-13-6',
    'OTISWHNJCUMBFI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,7-dimethyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,7-dimethyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,7-dimethyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,7-dimethyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '7,7-dimethyl-1-octanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '66719-35-5',
    'RYFZXYQQFYLUHM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='7,7-dimethyl-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='7,7-dimethyl-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='7,7-dimethyl-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-ethyl-1-octanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '20592-10-3',
    'HTRVTKUOKQWGMO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-ethyl-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-1-octanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '66719-36-6',
    'VXOCEIUJVCHLRR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-3-octanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '2051-32-3',
    'NPQPNSNHYJTUSA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-3-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-3-octanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-3-octanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-3-octanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-4-octanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '63126-48-7',
    'WXJDPIWUPZLVSF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-ethyl-4-octanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '38395-42-5',
    'OYBUBRUQIKTRET-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-ethyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-4-octanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '6-ethyl-3-octanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '19781-27-2',
    'JWZFCOOWAQHCBP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='6-ethyl-3-octanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-ethyl-3-octanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-ethyl-3-octanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3-trimethyl-3-heptanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '29772-40-5',
    'GCLFPNQSLCWZAQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3-trimethyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3-trimethyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3-trimethyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3-trimethyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,4-trimethyl-4-heptanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '57233-31-5',
    'KNACVESXMPHLNM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,4-trimethyl-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethyl-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethyl-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,5-trimethyl-4-heptanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '66256-42-6',
    'JHHGGYCQTXZCTL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,5-trimethyl-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,5-trimethyl-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,6-trimethyl-3-heptanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '66256-43-7',
    'AXUPPSSNJCYJOX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,6-trimethyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,6-trimethyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,6-trimethyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,6-trimethyl-4-heptanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '66256-44-8',
    'ITTQYDBLGDGLMB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,6-trimethyl-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,6-trimethyl-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,6-trimethyl-3-heptanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '58046-40-5',
    'BAZNZYUOJWCTIQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,6-trimethyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,6-trimethyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,6-trimethyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,5-trimethyl-4-heptanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '66256-46-0',
    'RCSCLTAIPNDFGC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4,5-trimethyl-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5-trimethyl-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,6-trimethyl-2-heptanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '66256-47-1',
    'VUZHXHGZVRACMM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4,6-trimethyl-2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trimethyl-2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trimethyl-2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,6-trimethyl-4-heptanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '60836-07-9',
    'QSVYJSJPLCSACO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4,6-trimethyl-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trimethyl-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trimethyl-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5,6-trimethyl-2-heptanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '66256-48-2',
    'LQQYOLMGDBGEBC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,5,6-trimethyl-2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5,6-trimethyl-2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5,6-trimethyl-2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5,6-trimethyl-2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3,6-trimethyl-4-heptanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '',
    'LTDMOZOPTDNTLG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3,6-trimethyl-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,6-trimethyl-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,5,5-trimethyl-3-heptanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '66256-50-6',
    'WOUVARFKMJIYBY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,5,5-trimethyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5,5-trimethyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5,5-trimethyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5,5-trimethyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,6,6-trimethyl-2-heptanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '51079-79-9',
    'FHQUDZUTAZYJRH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,6,6-trimethyl-2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,6,6-trimethyl-2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,6,6-trimethyl-2-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-(1-methylethyl)-1-heptanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '38514-15-7',
    'NTGBCQFKKOCODF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-(1-methylethyl)-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-(1-methylethyl)-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-(1-methylethyl)-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-(1-methylethyl)-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-(1-methylethyl)-4-heptanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '51200-82-9',
    'OHSMKBPEDBXYDU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-(1-methylethyl)-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-(1-methylethyl)-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-(1-methylethyl)-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-(1-methylethyl)-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-2-methyl-3-heptanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '66719-37-7',
    'GYCRUUSYQLIIBA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-2-methyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2-methyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2-methyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2-methyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-5-methyl-3-heptanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '',
    'FGJMKJVRSBVZPS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-5-methyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-5-methyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-5-methyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-ethyl-4-methyl-3-heptanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '66731-94-0',
    'XVSHXHABYNUHNI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='5-ethyl-4-methyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-ethyl-4-methyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-ethyl-4-methyl-3-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-propyl-1-heptanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '10042-59-8',
    'YLQLIQIAXYRMDL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-propyl-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propyl-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propyl-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propyl-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-propyl-4-heptanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '2198-72-3',
    'SJTPBRMACCDJPZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-propyl-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-propyl-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-propyl-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-propyl-4-heptanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,4-tetramethyl-3-hexanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '66256-63-1',
    'SAFMWGCEQYLRLS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3,4-tetramethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,4-tetramethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,4-tetramethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,4-tetramethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,4,4-tetramethyl-3-hexanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '66256-65-3',
    'LKAPNEGVXBMYKE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,4,4-tetramethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,4-tetramethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,4-tetramethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4,4-tetramethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,5,5-tetramethyl-3-hexanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '55073-86-4',
    'CFEYPBVKHMZCFR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,5,5-tetramethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,5,5-tetramethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,5,5-tetramethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,4-tetramethyl-2-hexanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '66256-66-4',
    'IELWGTFQRBDDCZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,4,4-tetramethyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,4-tetramethyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,4-tetramethyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,4-tetramethyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,4-tetramethyl-3-hexanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '66256-67-5',
    'ZQFIWHOYWCJIHU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,4,4-tetramethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,4-tetramethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,4-tetramethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,4-tetramethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,5,5-tetramethyl-3-hexanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '5396-09-8',
    'KTSYBVKVNWGHBC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,5,5-tetramethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5,5-tetramethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5,5-tetramethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,4,5-tetramethyl-3-hexanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '66256-68-6',
    'VVRHXTVKOHXZJX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4,4,5-tetramethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4,5-tetramethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4,5-tetramethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3,5,5-tetramethyl-2-hexanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '66256-69-7',
    'USWOQOMRDCYQMW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3,5,5-tetramethyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,5,5-tetramethyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,5,5-tetramethyl-2-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4,4,5-tetramethyl-3-hexanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '66256-39-1',
    'UHJJSHWWLQIIOU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4,4,5-tetramethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,4,5-tetramethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,4,5-tetramethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,4,5-tetramethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4,5,5-tetramethyl-3-hexanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '66256-40-4',
    'LBLUJHQRJVUQJR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4,5,5-tetramethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,5,5-tetramethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,5,5-tetramethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,5,5-tetramethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dimethyl-4-ethyl-3-hexanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '66719-48-0',
    'NLGGBBOPZSANIC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4-dimethyl-4-ethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-4-ethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-butyl-1-hexanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '2768-15-2',
    'LAPPDPWPIZBBJY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-ethyl-2,2-dimethyl-3-hexanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '66719-47-9',
    'UOYRABPBVGDJLW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-ethyl-2,2-dimethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-2,2-dimethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethyl-2,2-dimethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-2-(1-methylethyl)-1-hexanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '66719-41-3',
    'VHGVOODVCUKVCL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-2-(1-methylethyl)-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-(1-methylethyl)-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-(1-methylethyl)-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-(1-methylethyl)-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-2-propyl-1-hexanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '66256-62-0',
    'VZXWJVFQXZUFQS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-2-propyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-propyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-propyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-propyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5,5-dimethyl-2-ethyl-1-hexanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '',
    'DXDJMJLAABGHOH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='5,5-dimethyl-2-ethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5,5-dimethyl-2-ethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5,5-dimethyl-2-ethyl-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5,5-dimethyl-3-ethyl-3-hexanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '5340-62-5',
    'FVVBGHIXYRKNGT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='5,5-dimethyl-3-ethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5,5-dimethyl-3-ethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5,5-dimethyl-3-ethyl-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-methyl-2-(1-methylethyl)-1-hexanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '2051-33-4',
    'SFIQHFBITUEIBP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='5-methyl-2-(1-methylethyl)-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-2-(1-methylethyl)-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-2-(1-methylethyl)-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-2-(1-methylethyl)-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-3-(1-methylethyl)-3-hexanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '2,4-dimethyl-3-propyl-3-pentanol',
    '51200-81-8',
    'GGOIYPAZTVTJBE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-3-(1-methylethyl)-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-3-(1-methylethyl)-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-(1-methylethyl)-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-(1-methylethyl)-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-(1-methylethyl)-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-(1-methylethyl)-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-(1-methylethyl)-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-(1-methylethyl)-3-hexanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,4,4-pentamethyl-3-pentanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '5857-69-2',
    'UYFZQUABCZILAI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2,3,4,4-pentamethyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,4,4-pentamethyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,4,4-pentamethyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,4,4-pentamethyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethyl-2-<i>tert</i>-butyl-1-butanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '81931-81-9',
    'WQRJEFGWAMKEBO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3-dimethyl-2-<i>tert</i>-butyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-2-<i>tert</i>-butyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-2-<i>tert</i>-butyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dimethyl-3-(1-methylethyl)-3-pentanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '51200-83-0',
    'IFXNWIUSZUHIDG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-(1-methylethyl)-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-(1-methylethyl)-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-(1-methylethyl)-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-(1-methylethyl)-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4-dimethyl-3-isopropyl-2-pentanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '66719-50-4',
    'DNBJFVXHMLZKHP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4-dimethyl-3-isopropyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyl-3-isopropyl-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,4-dimethyl-3-isopropyl-1-pentanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '66719-51-5',
    'DQWFOEIWLQBIFY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,4-dimethyl-3-isopropyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethyl-3-isopropyl-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-2,2,4-trimethyl-3-pentanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '66256-41-5',
    'CHZVHXPAKQDRSE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-2,2,4-trimethyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,2,4-trimethyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,2,4-trimethyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2,2,4-trimethyl-3-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-2-(2-methylpropyl)-1-pentanol',
    'C<sub>10</sub>H<sub>22</sub>O',
    '',
    '22417-45-4',
    'FXXCTCCAZGTNNO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-2-(2-methylpropyl)-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-(2-methylpropyl)-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-(2-methylpropyl)-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-(2-methylpropyl)-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-undecanol',
    'C<sub>11</sub>H<sub>24</sub>O',
    '',
    '112-42-5',
    'KJIOQYGWTQBHNH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-undecanol'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-undecanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-undecanol'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-undecanol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-undecanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-undecanol'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-undecanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-undecanol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-undecanol',
    'C<sub>11</sub>H<sub>24</sub>O',
    '',
    '1653-30-1',
    'XMUJIPOFTAHSOK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-undecanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-undecanol'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-undecanol',
    'C<sub>11</sub>H<sub>24</sub>O',
    '',
    '6929-08-4',
    'HCARCYFXWDRVBZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-undecanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-undecanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-undecanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-dodecanol',
    'C<sub>12</sub>H<sub>26</sub>O',
    '',
    '112-53-8',
    'LQZZUXJYWNFBMV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-dodecanol'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-dodecanol'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '9800',
    'V',
    (SELECT id from species WHERE iupac='1-dodecanol'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-dodecanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-dodecanol'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-dodecanol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-dodecanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-dodecanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-dodecanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-dodecanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-dodecanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-dodecanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-dodecanol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-dodecanol'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-dodecanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-dodecanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-dodecanol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-dodecanol'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-dodecanol',
    'C<sub>12</sub>H<sub>26</sub>O',
    '',
    '10203-30-2',
    'OKDGZLITBCRLLJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-dodecanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-dodecanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-dodecanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6,8-trimethyl-4-nonanol',
    'C<sub>12</sub>H<sub>26</sub>O',
    '',
    '123-17-1',
    'LFEHSRSSAGQWNI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6,8-trimethyl-4-nonanol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6,8-trimethyl-4-nonanol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6,8-trimethyl-4-nonanol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6,8-trimethyl-4-nonanol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-tridecanol',
    'C<sub>13</sub>H<sub>28</sub>O',
    '',
    '112-70-9',
    'XFRVVPUIAFSTFO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-tridecanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-tridecanol'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-tridecanol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-tridecanol'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-tridecanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-tridecanol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-tetradecanol',
    'C<sub>14</sub>H<sub>30</sub>O',
    '',
    '112-72-1',
    'HLZKNKRTKFSKGZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-tetradecanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-tetradecanol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='1-tetradecanol'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-tetradecanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-tetradecanol'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-tetradecanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-tetradecanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-tetradecanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-tetradecanol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-tetradecanol'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-tetradecanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-tetradecanol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-tetradecanol'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '789-112-72-1-consicheck',
    '789', 'Different types of Henry''s law constants of Yaws and Yang (1992) are inconsistent, with 16&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='789-112-72-1-consicheck'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-tetradecanol',
    'C<sub>14</sub>H<sub>30</sub>O',
    '',
    '4706-81-4',
    'BRGJIIMZXMWMCC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-tetradecanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-pentadecanol',
    'C<sub>15</sub>H<sub>32</sub>O',
    '',
    '629-76-5',
    'REIUXOLGHVXAEO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-pentadecanol'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-pentadecanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentadecanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentadecanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentadecanol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentadecanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-pentadecanol'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '789-629-76-5-consicheck',
    '789', 'Different types of Henry''s law constants of Yaws and Yang (1992) are inconsistent, with 10&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='789-629-76-5-consicheck'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-hexadecanol',
    'C<sub>16</sub>H<sub>34</sub>O',
    'cetyl alcohol',
    '124-29-8',
    'BXWNKGSJHAJOGX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hexadecanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hexadecanol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='1-hexadecanol'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-hexadecanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexadecanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexadecanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexadecanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexadecanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexadecanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexadecanol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexadecanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-hexadecanol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-hexadecanol'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-hexadecanol',
    'C<sub>16</sub>H<sub>34</sub>O',
    '',
    '14852-31-4',
    'FVDRFBGMOWJEOR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-hexadecanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hexadecanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-heptadecanol',
    'C<sub>17</sub>H<sub>36</sub>O',
    '',
    '1454-85-9',
    'GOQYKNQRPGWPLP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-heptadecanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-heptadecanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-heptadecanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-heptadecanol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-heptadecanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-heptadecanol'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-heptadecanol',
    'C<sub>17</sub>H<sub>36</sub>O',
    '',
    '16813-18-6',
    'ZNYQHFLBAPNPRC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-heptadecanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-heptadecanol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-octadecanol',
    'C<sub>18</sub>H<sub>38</sub>O',
    '',
    '112-92-5',
    'GLDOVTGHNKAZLK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-octadecanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-octadecanol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='1-octadecanol'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octadecanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octadecanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octadecanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octadecanol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octadecanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-octadecanol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'at307K',
    '', 'Value at T = 307&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at307K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-octadecanol'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at307K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-nonadecanol',
    'C<sub>19</sub>H<sub>40</sub>O',
    '',
    '1454-84-8',
    'XGFDHKJUZCCPKQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nonadecanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-eicosanol',
    'C<sub>20</sub>H<sub>42</sub>O',
    '',
    '629-96-9',
    'BTFJIXJJCSYFAL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-eicosanol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-eicosanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-eicosanol'),
    (SELECT id from literature WHERE bibtexkey='1115'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-docosanol',
    'C<sub>22</sub>H<sub>46</sub>O',
    'behenic alcohol',
    '661-19-8',
    'NOPFSRXAKWQILS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-docosanol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-tetracosanol',
    'C<sub>24</sub>H<sub>50</sub>O',
    '',
    '506-51-4',
    'TYWMIZZBOVGFOV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-tetracosanol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cyclopentanol',
    'C<sub>5</sub>H<sub>9</sub>OH',
    '',
    '96-41-3',
    'XCIXKGXIYUWCLL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2',
    '8200',
    'L',
    (SELECT id from species WHERE iupac='cyclopentanol'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '5900',
    'M',
    (SELECT id from species WHERE iupac='cyclopentanol'),
    (SELECT id from literature WHERE bibtexkey='3609'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3',
    '8000',
    'T',
    (SELECT id from species WHERE iupac='cyclopentanol'),
    (SELECT id from literature WHERE bibtexkey='2377'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopentanol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopentanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7200',
    'Q',
    (SELECT id from species WHERE iupac='cyclopentanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopentanol'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7300',
    '?',
    (SELECT id from species WHERE iupac='cyclopentanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3',
    '',
    '?',
    (SELECT id from species WHERE iupac='cyclopentanol'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cyclohexanol',
    'C<sub>6</sub>H<sub>11</sub>OH',
    '',
    '108-93-0',
    'HPXRVTGHNJAIIH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3',
    '7700',
    'L',
    (SELECT id from species WHERE iupac='cyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4',
    '8500',
    'L',
    (SELECT id from species WHERE iupac='cyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'M',
    (SELECT id from species WHERE iupac='cyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3',
    '7700',
    'M',
    (SELECT id from species WHERE iupac='cyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='3609'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'M',
    (SELECT id from species WHERE iupac='cyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    'V',
    (SELECT id from species WHERE iupac='cyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='cyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='cyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='cyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'V',
    (SELECT id from species WHERE iupac='cyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1',
    '8500',
    'T',
    (SELECT id from species WHERE iupac='cyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='2377'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9',
    '',
    'X',
    (SELECT id from species WHERE iupac='cyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6',
    '',
    'X',
    (SELECT id from species WHERE iupac='cyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='howard93'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'from636',
    '636', 'Value given here as quoted by Mackay et&nbsp;al. (1995).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7500',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    '?',
    (SELECT id from species WHERE iupac='cyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7500',
    '?',
    (SELECT id from species WHERE iupac='cyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9',
    '',
    '?',
    (SELECT id from species WHERE iupac='cyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1',
    '',
    '?',
    (SELECT id from species WHERE iupac='cyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cycloheptanol',
    'C<sub>7</sub>H<sub>13</sub>OH',
    '',
    '502-41-0',
    'QCRFMSUKWRQZEM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6',
    '9000',
    'L',
    (SELECT id from species WHERE iupac='cycloheptanol'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2',
    '9000',
    'T',
    (SELECT id from species WHERE iupac='cycloheptanol'),
    (SELECT id from literature WHERE bibtexkey='2377'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cycloheptanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cycloheptanol'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2',
    '',
    '?',
    (SELECT id from species WHERE iupac='cycloheptanol'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methylcyclohexanol',
    'C<sub>7</sub>H<sub>13</sub>OH',
    '',
    '589-91-3',
    'MQWCXKGKQLNYQG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-methylcyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methylcyclohexanol',
    'C<sub>7</sub>H<sub>14</sub>O',
    '',
    '583-59-5',
    'NDVWOBYBJYUSMF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methylcyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methylcyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylcyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylcyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylcyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylcyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylcyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylcyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylcyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methylcyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methylcyclohexanol',
    'C<sub>7</sub>H<sub>14</sub>O',
    '',
    '591-23-1',
    'HTSABYAWKQAHBT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9',
    '',
    'M',
    (SELECT id from species WHERE iupac='3-methylcyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    'M',
    (SELECT id from species WHERE iupac='3-methylcyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylcyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylcyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylcyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylcyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylcyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylcyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-methylcyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C8BCOH',
    'C<sub>8</sub>H<sub>14</sub>O',
    '',
    '',
    'CEOBYJRLFASWKF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8BCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8BCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8BCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(4-methylcyclohexyl)methanol',
    'C<sub>8</sub>H<sub>16</sub>O',
    '',
    '34885-03-5',
    'OSINZLLLLCUKJH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(4-methylcyclohexyl)methanol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'borneol',
    'C<sub>10</sub>H<sub>18</sub>O',
    '',
    '507-70-0',
    'DTGKSKDOIYIVQL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='borneol'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fenchol',
    'C<sub>10</sub>H<sub>18</sub>O',
    'fenchyl alcohol',
    '1632-73-1',
    'IAIHUHQCLTYTSF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fenchol'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_O2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'menthol',
    'C<sub>10</sub>H<sub>20</sub>O',
    '',
    '1490-04-6',
    'NOOLISFMXDJSKH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='menthol'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methylisoborneol',
    'C<sub>11</sub>H<sub>20</sub>O',
    '',
    '2371-42-8',
    'LFYXNXGVLGKVCJ-BOBPJJCASA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;2</sup>',
    '9800',
    'M',
    (SELECT id from species WHERE iupac='2-methylisoborneol'),
    (SELECT id from literature WHERE bibtexkey='3303'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylisoborneol'),
    (SELECT id from literature WHERE bibtexkey='3719'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3719-SPARC',
    '', 'Calculated using SPARC Performs Automated Reasoning in Chemistry (SPARC). It is assumed here that the value refers to T&nbsp;= 298.15&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3719-SPARC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'geosmin',
    'C<sub>12</sub>H<sub>22</sub>O',
    '',
    '19700-21-1',
    'JLPUXFOGCDVKGO-GRYCIOLGSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;2</sup>',
    '9800',
    'M',
    (SELECT id from species WHERE iupac='geosmin'),
    (SELECT id from literature WHERE bibtexkey='3303'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='geosmin'),
    (SELECT id from literature WHERE bibtexkey='3719'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3719-SPARC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cyclododecanol',
    'C<sub>12</sub>H<sub>24</sub>O',
    '',
    '1724-39-6',
    'SFVWPXMPRCIVOK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4',
    '',
    'M',
    (SELECT id from species WHERE iupac='cyclododecanol'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclododecanol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclododecanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclododecanol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclododecanol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclododecanol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclododecanol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclododecanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclododecanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4',
    '',
    '?',
    (SELECT id from species WHERE iupac='cyclododecanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cedrol',
    'C<sub>15</sub>H<sub>26</sub>O',
    '',
    '77-53-2',
    'SVURIXNDRWRAFU-OGMFBOKVSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cedrol'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'patchoulol',
    'C<sub>15</sub>H<sub>26</sub>O',
    '',
    '5986-55-0',
    'GGHMUJBZYLPWFD-CUZKYEQNSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='patchoulol'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'perhydrobisphenol a',
    'C<sub>15</sub>H<sub>28</sub>O<sub>2</sub>',
    '',
    '80-04-6',
    'CDBAMNGURPMUTG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='perhydrobisphenol a'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='perhydrobisphenol a'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='perhydrobisphenol a'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='perhydrobisphenol a'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-(5,5,6-trimethyl-2-norbornyl)cyclohexanol',
    'C<sub>16</sub>H<sub>28</sub>O',
    '',
    '3407-42-9',
    'BWVZAZPLUTUBKD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-(5,5,6-trimethyl-2-norbornyl)cyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-(5,5,6-trimethyl-2-norbornyl)cyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-(5,5,6-trimethyl-2-norbornyl)cyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-(5,5,6-trimethyl-2-norbornyl)cyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-(5,5,6-trimethylbicyclo[2.2.1]hept-2-yl)cyclohexan-1-ol',
    'C<sub>16</sub>H<sub>28</sub>O',
    '',
    '66068-84-6',
    'PCFHYANYPQEMPU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-(5,5,6-trimethylbicyclo[2.2.1]hept-2-yl)cyclohexan-1-ol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-(5,5,6-trimethylbicyclo[2.2.1]hept-2-yl)cyclohexan-1-ol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-(5,5,6-trimethylbicyclo[2.2.1]hept-2-yl)cyclohexan-1-ol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-(5,5,6-trimethylbicyclo[2.2.1]hept-2-yl)cyclohexan-1-ol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-((1R,2R,4R)-born-2-yl)cyclohexanol',
    'C<sub>16</sub>H<sub>28</sub>O',
    '',
    '66072-32-0',
    'LFHQKYSBKVWWOS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-((1R,2R,4R)-born-2-yl)cyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-((1R,2R,4R)-born-2-yl)cyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-((1R,2R,4R)-born-2-yl)cyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-((1R,2R,4R)-born-2-yl)cyclohexanol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethenol',
    'C<sub>2</sub>H<sub>4</sub>O',
    'vinyl alcohol',
    '557-75-5',
    'IMROMDMJAWUWLK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethenol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethenol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethenol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-propen-1-ol',
    'C<sub>3</sub>H<sub>5</sub>OH',
    'allyl alcohol',
    '107-18-6',
    'XXROGKLTLUQVRX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6500',
    'L',
    (SELECT id from species WHERE iupac='2-propen-1-ol'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-propen-1-ol'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-propen-1-ol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3',
    '7200',
    'X',
    (SELECT id from species WHERE iupac='2-propen-1-ol'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-propen-1-ol'),
    (SELECT id from literature WHERE bibtexkey='2223'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'from642',
    '642', 'Value given here as quoted by Hine and Mookerjee (1975).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propen-1-ol'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propen-1-ol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propen-1-ol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propen-1-ol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propen-1-ol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propen-1-ol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propen-1-ol'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propen-1-ol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propen-1-ol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propen-1-ol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propen-1-ol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propen-1-ol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propen-1-ol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propen-1-ol'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propen-1-ol'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propen-1-ol'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propen-1-ol'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propen-1-ol'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propen-1-ol'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-propen-1-ol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-propen-1-ol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-propen-1-ol'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-propen-1-ol'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-propyn-1-ol',
    'C<sub>3</sub>H<sub>4</sub>O',
    'propargyl alcohol',
    '107-19-7',
    'TVDSBUOJIPERQY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8',
    '7400',
    'M',
    (SELECT id from species WHERE iupac='2-propyn-1-ol'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-propyn-1-ol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-propyn-1-ol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propyn-1-ol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propyn-1-ol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propyn-1-ol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-buten-1-ol',
    'CH<sub>3</sub>CHCHCH<sub>2</sub>OH',
    '',
    '6117-91-5',
    'WCASXYBKJHWFMY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6900',
    'L',
    (SELECT id from species WHERE iupac='2-buten-1-ol'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-buten-1-ol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-buten-1-ol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-buten-1-ol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-buten-1-ol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '',
    'E',
    (SELECT id from species WHERE iupac='2-buten-1-ol'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-buten-1-ol',
    'C<sub>4</sub>H<sub>8</sub>O',
    '',
    '627-27-0',
    'ZSPTYLOMNJNZNG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7000',
    'L',
    (SELECT id from species WHERE iupac='3-buten-1-ol'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-penten-1-ol',
    'C<sub>5</sub>H<sub>10</sub>O',
    '',
    '821-09-0',
    'LQAVWYMTUMSFBE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7300',
    'L',
    (SELECT id from species WHERE iupac='4-penten-1-ol'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-pentyn-1-ol',
    'C<sub>5</sub>H<sub>8</sub>O',
    '',
    '10229-10-4',
    'IDYNOORNKYEHHO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7800',
    'L',
    (SELECT id from species WHERE iupac='3-pentyn-1-ol'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-3-buten-2-ol',
    'C<sub>5</sub>H<sub>9</sub>O',
    '',
    '115-18-4',
    'HNVRRHSXBLFLIG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methyl-3-buten-2-ol'),
    (SELECT id from literature WHERE bibtexkey='1004'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at303K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methyl-3-buten-2-ol'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-buten-2-ol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-buten-2-ol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-buten-2-ol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-buten-2-ol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-buten-2-ol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-buten-2-ol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-buten-2-ol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-buten-2-ol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-buten-2-ol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-buten-2-ol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methyl-3-buten-2-ol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-3-butyn-2-ol',
    'C<sub>5</sub>H<sub>8</sub>O',
    '',
    '115-19-5',
    'CEBKHWWANWSNTI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methyl-3-butyn-2-ol'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-butyn-2-ol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-butyn-2-ol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-butyn-2-ol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-butyn-2-ol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methyl-3-butyn-2-ol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-1-pentyn-3-ol',
    'C<sub>6</sub>H<sub>10</sub>O',
    'meparfynol; methyl pentynol',
    '77-75-8',
    'QXLPXWSKPNOQLE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-pentyn-3-ol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-pentyn-3-ol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-pentyn-3-ol'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-cyclohexen-1-ol',
    'C<sub>6</sub>H<sub>10</sub>O',
    '',
    '822-67-3',
    'PQANGXXSEABURG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '8500',
    'L',
    (SELECT id from species WHERE iupac='2-cyclohexen-1-ol'),
    (SELECT id from literature WHERE bibtexkey='3673'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bicyclo[2.2.1]heptan-2-ol',
    'C<sub>7</sub>H<sub>12</sub>O',
    'norborneol',
    '1632-68-4',
    'ZQTYQMYDIHMKQB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '5000',
    'V',
    (SELECT id from species WHERE iupac='bicyclo[2.2.1]heptan-2-ol'),
    (SELECT id from literature WHERE bibtexkey='2125'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-octen-1-ol',
    'C<sub>8</sub>H<sub>16</sub>O',
    '',
    '22104-78-5',
    'AYQPVPFZWIQERS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-octen-1-ol'),
    (SELECT id from literature WHERE bibtexkey='3719'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3719-SPARC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-octen-3-ol',
    'C<sub>8</sub>H<sub>16</sub>O',
    '',
    '3391-86-4',
    'VSMOENVRRABVKN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '7900',
    'M',
    (SELECT id from species WHERE iupac='1-octen-3-ol'),
    (SELECT id from literature WHERE bibtexkey='3719'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-octen-3-ol'),
    (SELECT id from literature WHERE bibtexkey='3645'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-octen-3-ol'),
    (SELECT id from literature WHERE bibtexkey='2389'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,7-dimethyl-6-octen-1-ol',
    'C<sub>10</sub>H<sub>20</sub>O',
    'citronellol',
    '106-22-9',
    'QMVPMAAFGQKVCJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,7-dimethyl-6-octen-1-ol'),
    (SELECT id from literature WHERE bibtexkey='3678'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3678'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,7-dimethyl-6-octen-1-ol'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,7-dimethyl-1,6-octadien-3-ol',
    'C<sub>10</sub>H<sub>18</sub>O',
    'linalool',
    '78-70-6',
    'CDOSHBSSFJOMGT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '4400',
    'M',
    (SELECT id from species WHERE iupac='3,7-dimethyl-1,6-octadien-3-ol'),
    (SELECT id from literature WHERE bibtexkey='3008'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3,7-dimethyl-1,6-octadien-3-ol'),
    (SELECT id from literature WHERE bibtexkey='3554'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3,7-dimethyl-1,6-octadien-3-ol'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,7-dimethyl-1,6-octadien-3-ol'),
    (SELECT id from literature WHERE bibtexkey='3678'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3678'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,7-dimethyl-1,6-octadien-3-ol'),
    (SELECT id from literature WHERE bibtexkey='2124'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,7-dimethyl-1,6-octadien-3-ol'),
    (SELECT id from literature WHERE bibtexkey='2487'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '14000',
    'V',
    (SELECT id from species WHERE iupac='3,7-dimethyl-1,6-octadien-3-ol'),
    (SELECT id from literature WHERE bibtexkey='2464'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,7-dimethyl-1,6-octadien-3-ol'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,7-dimethyl-1,6-octadien-3-ol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,7-dimethyl-1,6-octadien-3-ol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,7-dimethyl-1,6-octadien-3-ol'),
    (SELECT id from literature WHERE bibtexkey='3025'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,7-dimethyl-1,6-octadien-3-ol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,7-dimethyl-1,6-octadien-3-ol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,7-dimethyl-1,6-octadien-3-ol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,7-dimethyl-1,6-octadien-3-ol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,7-dimethyl-1,6-octadien-3-ol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,7-dimethyl-1,6-octadien-3-ol'),
    (SELECT id from literature WHERE bibtexkey='2599'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'at373K',
    '', 'Value at T = 373&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at373K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,7-dimethyl-1,6-octadien-3-ol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'linalool oxide',
    'C<sub>10</sub>H<sub>18</sub>O<sub>2</sub>',
    '',
    '1365-19-1',
    'BXOURKNXQXLKRK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='linalool oxide'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(E)-3,7-dimethyl-2,6-octadien-1-ol',
    'C<sub>10</sub>H<sub>18</sub>O',
    'geraniol',
    '106-24-1',
    'GLZPCOQZEFWAFX-JXMROGBWSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='(E)-3,7-dimethyl-2,6-octadien-1-ol'),
    (SELECT id from literature WHERE bibtexkey='3678'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3678'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(E)-3,7-dimethyl-2,6-octadien-1-ol'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(E)-3,7-dimethyl-2,6-octadien-1-ol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(Z)-3,7-dimethyl-2,6-octadien-1-ol',
    'C<sub>10</sub>H<sub>18</sub>O',
    '',
    '106-25-2',
    'GLZPCOQZEFWAFX-YFHOEESVSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(Z)-3,7-dimethyl-2,6-octadien-1-ol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(Z)-3,7-dimethyl-2,6-octadien-1-ol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tricyclo[3.3.1.1(3,7)]decan-1-ol',
    'C<sub>10</sub>H<sub>16</sub>O',
    '1-adamantanol',
    '768-95-6',
    'VLLNJDMHDJRNFK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0',
    '5300',
    'V',
    (SELECT id from species WHERE iupac='tricyclo[3.3.1.1(3,7)]decan-1-ol'),
    (SELECT id from literature WHERE bibtexkey='2125'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,7,11-trimethyl-2,6,10-dodecatrien-1-ol',
    'C<sub>15</sub>H<sub>26</sub>O',
    'farnesol',
    '4602-84-0',
    'CRDAMVZIKSXKFV-YFVJMOTDSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,7,11-trimethyl-2,6,10-dodecatrien-1-ol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(Z)-9-octadecen-1-ol',
    'C<sub>18</sub>H<sub>36</sub>O',
    'oleyl alcohol',
    '143-28-2',
    'ALSTYHKOOCGGFT-KTKRTIGZSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(Z)-9-octadecen-1-ol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(3E,13Z)-octadeca-3,13-dien-1-ol',
    'C<sub>18</sub>H<sub>34</sub>O',
    '',
    '66410-28-4',
    'QBNCGBJHGBGHLS-IYUNJCAYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(3E,13Z)-octadeca-3,13-dien-1-ol'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dihydroabietyl alcohol',
    'C<sub>20</sub>H<sub>34</sub>O',
    '',
    '26266-77-3',
    'FLMIYUXOBAUKJM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dihydroabietyl alcohol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dihydroabietyl alcohol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dihydroabietyl alcohol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dihydroabietyl alcohol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethylestrenol',
    'C<sub>20</sub>H<sub>32</sub>O',
    '',
    '965-90-2',
    'AOXRBFRFYPMWLR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethylestrenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>trans</i>-phytol',
    'C<sub>20</sub>H<sub>40</sub>O',
    '',
    '150-86-7',
    'BOTWFXYSPFMFNR-PYDDKJGSSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='<i>trans</i>-phytol'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hydroxybenzene',
    'C<sub>6</sub>H<sub>5</sub>OH',
    'phenol',
    '108-95-2',
    'ISWSIDIOOBJBQZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '3000',
    'L',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3681'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '8900',
    'L',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '9800',
    'M',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3724'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>1</sup>',
    '2700',
    'M',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2183'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4',
    '7700',
    'M',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2488'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>1</sup>',
    '5900',
    'M',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1513'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1930'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 4.2',
    '',
    'M',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>1</sup>',
    '7400',
    'M',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2451'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2',
    '',
    'M',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1484'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at283K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '6000',
    'M',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1907'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1155'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '6100',
    'M',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2291'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6',
    '',
    'M',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='638'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4',
    '',
    'V',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2966'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1068'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'at281K',
    '', 'Value at T = 281&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at281K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8',
    '',
    'R',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='714'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>1</sup>',
    '6800',
    'T',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='724'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'assumedMatm',
    '', 'It is assumed here that the thermodynamic data refer to the units [mol&nbsp;dm<sup>&#8722;3</sup>] and [atm] as standard states.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='assumedMatm'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '3600',
    'X',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1154'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '7300',
    'X',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='howard89'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'from638',
    '638', 'Value given here as quoted by Shiu et&nbsp;al. (1994).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from638'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='gaffney84'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from715'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='mccarty80'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from2556'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2165'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6',
    '',
    'C',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='638'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6',
    '',
    'C',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3071'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6',
    '',
    'C',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3083'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6200',
    'Q',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5400',
    '?',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(hydroxymethyl)-benzene',
    'C<sub>6</sub>H<sub>5</sub>CH<sub>2</sub>OH',
    'benzyl alcohol',
    '100-51-6',
    'WVDDGKGOMKODPV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='(hydroxymethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 3.7&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='(hydroxymethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(hydroxymethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(hydroxymethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(hydroxymethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>1</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='(hydroxymethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='(hydroxymethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='(hydroxymethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='(hydroxymethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='howard93'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(hydroxymethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(hydroxymethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(hydroxymethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(hydroxymethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(hydroxymethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(hydroxymethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(hydroxymethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(hydroxymethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(hydroxymethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(hydroxymethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(hydroxymethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(hydroxymethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(hydroxymethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(hydroxymethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(hydroxymethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(hydroxymethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>1</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='(hydroxymethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(hydroxymethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(hydroxymethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3088-3072',
    '3088,3072,1500', 'HSDB (2015) refers to Abraham et&nbsp;al. (1994b) as the source, but this value cannot be found there. Maybe the value is taken from Abraham et&nbsp;al. (1990).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-3072'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(hydroxymethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(hydroxymethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-hydroxy-2-methylbenzene',
    'HOC<sub>6</sub>H<sub>4</sub>CH<sub>3</sub>',
    '2-cresol; o-cresol',
    '95-48-7',
    'QWVGKYWNOKOFNN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7',
    '7400',
    'L',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2',
    '8500',
    'M',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2488'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '6700',
    'M',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1513'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6',
    '5800',
    'M',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1907'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1155'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2',
    '7300',
    'M',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='725'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='assumedMatm'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2613_pc_problem',
    '2613', 'Mackay et&nbsp;al. (2006c) list a vapor pressure p, a solubility c, and a Henry''s law constant calculated as p/c. However, the data are internally inconsistent and deviate by more than 10&nbsp;%.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2613_pc_problem'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1068'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at281K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6',
    '4600',
    'X',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1154'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='howard89'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from638'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='gaffney84'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from715'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3',
    '',
    'C',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2165'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6500',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '8100',
    '?',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-hydroxy-3-methylbenzene',
    'HOC<sub>6</sub>H<sub>4</sub>CH<sub>3</sub>',
    '3-cresol; m-cresol',
    '108-39-4',
    'RLSSMJSEOOYNOY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '6200',
    'L',
    (SELECT id from species WHERE iupac='1-hydroxy-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9',
    '9000',
    'M',
    (SELECT id from species WHERE iupac='1-hydroxy-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2488'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-hydroxy-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '6000',
    'M',
    (SELECT id from species WHERE iupac='1-hydroxy-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1907'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2165'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1068'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at281K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-hydroxy-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1',
    '7700',
    'X',
    (SELECT id from species WHERE iupac='1-hydroxy-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1154'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-hydroxy-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='howard89'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from638'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6500',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-hydroxy-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6500',
    '?',
    (SELECT id from species WHERE iupac='1-hydroxy-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-hydroxy-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-hydroxy-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-hydroxy-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-hydroxy-4-methylbenzene',
    'HOC<sub>6</sub>H<sub>4</sub>CH<sub>3</sub>',
    '4-cresol; p-cresol',
    '106-44-5',
    'IWDCLRJOBJJRNH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '6600',
    'L',
    (SELECT id from species WHERE iupac='1-hydroxy-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '9300',
    'M',
    (SELECT id from species WHERE iupac='1-hydroxy-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2488'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 2.9',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-hydroxy-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '6100',
    'M',
    (SELECT id from species WHERE iupac='1-hydroxy-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1907'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-hydroxy-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1155'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '7200',
    'M',
    (SELECT id from species WHERE iupac='1-hydroxy-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='725'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='assumedMatm'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1068'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at281K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3945'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-hydroxy-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2',
    '4600',
    'X',
    (SELECT id from species WHERE iupac='1-hydroxy-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1154'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-hydroxy-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='howard89'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from638'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-hydroxy-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='gaffney84'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from715'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1-hydroxy-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2165'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6500',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-hydroxy-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6000',
    '?',
    (SELECT id from species WHERE iupac='1-hydroxy-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-hydroxy-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-hydroxy-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-hydroxy-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-hydroxy-2,3-dimethylbenzene',
    'C<sub>8</sub>H<sub>10</sub>O',
    '2,3-xylenol; 2,3-dimethylphenol',
    '526-75-0',
    'QWBBPBRQALCEIZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7',
    '6100',
    'L',
    (SELECT id from species WHERE iupac='1-hydroxy-2,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-hydroxy-2,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1930'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '6800',
    'M',
    (SELECT id from species WHERE iupac='1-hydroxy-2,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1907'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-2,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-2,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-2,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-2,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1068'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at281K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='1-hydroxy-2,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-hydroxy-2,3-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-hydroxy-2,4-dimethylbenzene',
    'C<sub>8</sub>H<sub>10</sub>O',
    '2,4-xylenol; 2,4-dimethylphenol',
    '105-67-9',
    'KUFFULVDNCHOFZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5',
    '5500',
    'L',
    (SELECT id from species WHERE iupac='1-hydroxy-2,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-hydroxy-2,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1930'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '6100',
    'M',
    (SELECT id from species WHERE iupac='1-hydroxy-2,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1907'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '-3200',
    'M',
    (SELECT id from species WHERE iupac='1-hydroxy-2,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1156'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HTdep_r2_lessthan_0.9'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1156'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-2,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-2,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-2,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-2,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-2,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-2,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1068'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at281K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='1-hydroxy-2,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-hydroxy-2,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1',
    '6600',
    'X',
    (SELECT id from species WHERE iupac='1-hydroxy-2,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-hydroxy-2,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='howard89'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from638'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1-hydroxy-2,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3071'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1-hydroxy-2,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1-hydroxy-2,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2556'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-hydroxy-2,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-hydroxy-2,5-dimethylbenzene',
    'C<sub>8</sub>H<sub>10</sub>O',
    '2,5-xylenol; 2,5-dimethylphenol',
    '95-87-4',
    'NKTOLZVEWDHZMU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2',
    '8700',
    'L',
    (SELECT id from species WHERE iupac='1-hydroxy-2,5-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5',
    '6800',
    'M',
    (SELECT id from species WHERE iupac='1-hydroxy-2,5-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1907'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-2,5-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-2,5-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-2,5-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-2,5-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1068'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at281K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8',
    '',
    'R',
    (SELECT id from species WHERE iupac='1-hydroxy-2,5-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-hydroxy-2,5-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,5-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,5-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,5-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,5-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,5-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,5-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,5-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,5-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,5-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,5-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,5-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,5-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,5-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-Test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,5-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-hydroxy-2,5-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-hydroxy-2,6-dimethylbenzene',
    'C<sub>8</sub>H<sub>10</sub>O',
    '2,6-xylenol; 2,6-dimethylphenol',
    '576-26-1',
    'NXXYKOUNUYWIHA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '6300',
    'L',
    (SELECT id from species WHERE iupac='1-hydroxy-2,6-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '6200',
    'M',
    (SELECT id from species WHERE iupac='1-hydroxy-2,6-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1907'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-hydroxy-2,6-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2232'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-2,6-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-2,6-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-2,6-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='638'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-2,6-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1068'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at281K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9',
    '',
    'R',
    (SELECT id from species WHERE iupac='1-hydroxy-2,6-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-hydroxy-2,6-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,6-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,6-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,6-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,6-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,6-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,6-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,6-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,6-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,6-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,6-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,6-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-hydroxy-2,6-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-hydroxy-2,6-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-hydroxy-3,4-dimethylbenzene',
    'C<sub>8</sub>H<sub>10</sub>O',
    '3,4-xylenol; 3,4-dimethylphenol',
    '95-65-8',
    'YCOXTKKNXUZSKD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>1</sup>',
    '7200',
    'L',
    (SELECT id from species WHERE iupac='1-hydroxy-3,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>1</sup>',
    '7100',
    'M',
    (SELECT id from species WHERE iupac='1-hydroxy-3,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1907'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-3,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-3,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-3,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-3,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='638'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-3,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1068'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at281K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>1</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='1-hydroxy-3,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-hydroxy-3,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-3,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-3,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-3,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-3,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-3,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-3,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-3,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-3,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-3,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-3,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-3,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-3,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-hydroxy-3,4-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-hydroxy-3,5-dimethylbenzene',
    'C<sub>8</sub>H<sub>10</sub>O',
    '3,5-xylenol; 3,5-dimethylphenol',
    '108-68-9',
    'TUAMRELNJMMDMT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '7600',
    'L',
    (SELECT id from species WHERE iupac='1-hydroxy-3,5-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '6900',
    'M',
    (SELECT id from species WHERE iupac='1-hydroxy-3,5-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1907'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-3,5-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-3,5-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-3,5-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-3,5-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='638'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-3,5-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1068'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at281K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='1-hydroxy-3,5-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-hydroxy-3,5-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-3,5-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-3,5-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-3,5-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-3,5-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-3,5-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-3,5-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-3,5-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-3,5-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-3,5-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-3,5-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-3,5-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-hydroxy-3,5-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methylbenzenemethanol',
    'C<sub>8</sub>H<sub>10</sub>O',
    '',
    '89-95-2',
    'XPNGNIFUDRPBFJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbenzenemethanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbenzenemethanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbenzenemethanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methylbenzenemethanol',
    'C<sub>8</sub>H<sub>10</sub>O',
    '',
    '587-03-1',
    'JJCKHVUTVOPLBV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbenzenemethanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbenzenemethanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbenzenemethanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methylbenzenemethanol',
    'C<sub>8</sub>H<sub>10</sub>O',
    '',
    '589-18-4',
    'KMTDMTZBNYGUNX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-methylbenzenemethanol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylbenzenemethanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylbenzenemethanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylbenzenemethanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '&#945;-methylbenzyl alcohol',
    'C<sub>8</sub>H<sub>10</sub>O',
    '',
    '98-85-1',
    'WAPNOHKVXSQRPX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#945;-methylbenzyl alcohol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-hydroxy-2-ethylbenzene',
    'C<sub>8</sub>H<sub>10</sub>O',
    '2-ethylphenol',
    '90-00-6',
    'IXQGCWUGDFDQMF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-2-ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-2-ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-2-ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2-ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2-ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2-ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2-ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2-ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2-ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2-ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2-ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2-ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2-ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-hydroxy-3-ethylbenzene',
    'C<sub>8</sub>H<sub>10</sub>O',
    '3-ethylphenol',
    '620-17-7',
    'HMNKTRSOROOSPP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-hydroxy-3-ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1922'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='1-hydroxy-3-ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-3-ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-3-ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-3-ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-3-ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-3-ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-3-ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-3-ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-3-ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-3-ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-3-ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-3-ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-hydroxy-3-ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-hydroxy-4-ethylbenzene',
    'C<sub>8</sub>H<sub>10</sub>O',
    '4-ethylphenol',
    '123-07-9',
    'HXDOZKJGKXYMEW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-4-ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-4-ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='1-hydroxy-4-ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-4-ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-4-ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-4-ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-4-ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-4-ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-4-ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-4-ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-4-ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-4-ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-hydroxy-4-ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4-trimethylphenol',
    'C<sub>9</sub>H<sub>12</sub>O',
    '',
    '526-85-2',
    'XRUGBBIQLIVCSI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethylphenol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethylphenol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethylphenol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,5-trimethylphenol',
    'C<sub>9</sub>H<sub>12</sub>O',
    '',
    '697-82-5',
    'OGRAOKJKVGDSFR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,5-trimethylphenol'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,5-trimethylphenol'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,6-trimethylphenol',
    'C<sub>9</sub>H<sub>12</sub>O',
    '',
    '2416-94-6',
    'QQOMQLYQAXGHSU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,6-trimethylphenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,6-trimethylphenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,6-trimethylphenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,6-trimethylphenol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,6-trimethylphenol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,6-trimethylphenol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,6-trimethylphenol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,6-trimethylphenol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,6-trimethylphenol',
    'C<sub>9</sub>H<sub>12</sub>O',
    '',
    '527-60-6',
    'BPRYUXCVCCNUFE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4,6-trimethylphenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4,6-trimethylphenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4,6-trimethylphenol'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4,6-trimethylphenol'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trimethylphenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trimethylphenol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trimethylphenol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trimethylphenol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trimethylphenol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trimethylphenol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trimethylphenol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trimethylphenol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trimethylphenol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4,5-trimethylphenol',
    'C<sub>9</sub>H<sub>12</sub>O',
    '',
    '527-54-8',
    'FDQQNNZKEJIHMS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,4,5-trimethylphenol'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,4,5-trimethylphenol'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-hydroxy-4-propylbenzene',
    'C<sub>9</sub>H<sub>12</sub>O',
    '4-propylphenol',
    '645-56-7',
    'KLSLBUSXWBJMEC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-4-propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6',
    '',
    'R',
    (SELECT id from species WHERE iupac='1-hydroxy-4-propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-4-propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-4-propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-4-propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-4-propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-4-propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-4-propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-4-propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-4-propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-4-propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-4-propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-hydroxy-4-propylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-(1-methylethyl)-phenol',
    'C<sub>9</sub>H<sub>12</sub>O',
    '',
    '88-69-7',
    'CRBJBYGJVIBWIY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-(1-methylethyl)-phenol'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(1-methylethyl)-phenol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(1-methylethyl)-phenol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(1-methylethyl)-phenol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(1-methylethyl)-phenol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-phenylisopropanol',
    'C<sub>9</sub>H<sub>12</sub>O',
    '',
    '617-94-7',
    'BDCFWIDZNLCTMF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-phenylisopropanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-phenylisopropanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-phenylisopropanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-phenylisopropanol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-ethyl-3-methylphenol',
    'C<sub>9</sub>H<sub>12</sub>O',
    '',
    '6161-62-2',
    'OCKYMBMCPOAFLL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-3-methylphenol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-3-methylphenol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-3-methylphenol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-ethyl-5-methylphenol',
    'C<sub>9</sub>H<sub>12</sub>O',
    '',
    '1687-61-2',
    'LTRVUFFOMIUCPJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-5-methylphenol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-5-methylphenol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-5-methylphenol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-ethyl-6-methylphenol',
    'C<sub>9</sub>H<sub>12</sub>O',
    '',
    '1687-64-5',
    'CIRRFAQIWQFQSS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-6-methylphenol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-6-methylphenol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-6-methylphenol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-ethyl-3-methylphenol',
    'C<sub>9</sub>H<sub>12</sub>O',
    '',
    '698-71-5',
    'XTCHLXABLZQNNN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='5-ethyl-3-methylphenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-ethyl-3-methylphenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-ethyl-3-methylphenol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-ethyl-3-methylphenol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-ethyl-3-methylphenol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-ethyl-3-methylphenol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-ethyl-3-methylphenol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-(2-methylphenyl)ethanol',
    'C<sub>9</sub>H<sub>12</sub>O',
    '',
    '7287-82-3',
    'SDCBYRLJYGORNK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-(2-methylphenyl)ethanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-(2-methylphenyl)ethanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-(2-methylphenyl)ethanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-propylphenol',
    'C<sub>9</sub>H<sub>12</sub>O',
    '',
    '644-35-9',
    'LCHYEKKJCUJAKN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propylphenol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propylphenol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propylphenol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-phenyl-1-propanol',
    'C<sub>9</sub>H<sub>12</sub>O',
    '',
    '93-54-9',
    'DYUQAZSOFZSPHD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-phenyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-phenyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-phenyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethylbenzyl alcohol',
    'C<sub>9</sub>H<sub>12</sub>O',
    '',
    '13651-14-4',
    'ZQQIVMXQYUZKIQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylbenzyl alcohol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylbenzyl alcohol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylbenzyl alcohol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4-dimethylbenzyl alcohol',
    'C<sub>9</sub>H<sub>12</sub>O',
    '',
    '6966-10-5',
    'OKGZCXPDJKKZAP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethylbenzyl alcohol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethylbenzyl alcohol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethylbenzyl alcohol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,5-dimethylbenzyl alcohol',
    'C<sub>9</sub>H<sub>12</sub>O',
    '',
    '27129-87-9',
    'IQWWTJDRVBWBEL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethylbenzyl alcohol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethylbenzyl alcohol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethylbenzyl alcohol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-(1,1-dimethylethyl)-phenol',
    'C<sub>10</sub>H<sub>14</sub>O',
    '',
    '88-18-6',
    'WJQOZHYUIDYNHM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-(1,1-dimethylethyl)-phenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(1,1-dimethylethyl)-phenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(1,1-dimethylethyl)-phenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-(1,1-dimethylethyl)-phenol',
    'C<sub>10</sub>H<sub>14</sub>O',
    '',
    '585-34-2',
    'CYEKUDPFXBLGHH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-(1,1-dimethylethyl)-phenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-(1,1-dimethylethyl)-phenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-(1-methylpropyl)phenol',
    'C<sub>10</sub>H<sub>14</sub>O',
    '',
    '89-72-5',
    'NGFPWHGISWUQOI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(1-methylpropyl)phenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-(1-methylpropyl)-phenol',
    'C<sub>10</sub>H<sub>14</sub>O',
    '4-<i>sec</i>-butylphenol',
    '99-71-8',
    'ZUTYZAFDFLLILI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-(1-methylpropyl)-phenol'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-(1-methylpropyl)-phenol'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-<i>tert</i>-butylphenol',
    'C<sub>10</sub>H<sub>14</sub>O',
    '',
    '98-54-4',
    'QHPQWRBYOIRBIT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9',
    '7700',
    'M',
    (SELECT id from species WHERE iupac='4-<i>tert</i>-butylphenol'),
    (SELECT id from literature WHERE bibtexkey='725'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='assumedMatm'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-<i>tert</i>-butylphenol'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-<i>tert</i>-butylphenol'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-<i>tert</i>-butylphenol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-<i>tert</i>-butylphenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-<i>tert</i>-butylphenol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-<i>tert</i>-butylphenol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-<i>tert</i>-butylphenol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-<i>tert</i>-butylphenol'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-<i>tert</i>-butylphenol'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-<i>tert</i>-butylphenol'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-<i>tert</i>-butylphenol'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-<i>tert</i>-butylphenol'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-<i>tert</i>-butylphenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-<i>tert</i>-butylphenol'),
    (SELECT id from literature WHERE bibtexkey='510'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '510buph',
    '510,754', 'Betterton (1992) gives Buttery et&nbsp;al. (1969) as the source. However, no data were found in that reference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='510buph'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-<i>tert</i>-butylphenol'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-5-(1-methylethyl)-phenol',
    'C<sub>10</sub>H<sub>14</sub>O',
    'carvacrol',
    '499-75-2',
    'RECUKUPTGUEGMW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-5-(1-methylethyl)-phenol'),
    (SELECT id from literature WHERE bibtexkey='3678'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3678'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '9300',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-5-(1-methylethyl)-phenol'),
    (SELECT id from literature WHERE bibtexkey='2125'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-methyl-2-(1-methylethyl)-phenol',
    'C<sub>10</sub>H<sub>14</sub>O',
    'thymol',
    '89-83-8',
    'MGSRCZKZVOBKFT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='5-methyl-2-(1-methylethyl)-phenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='5-methyl-2-(1-methylethyl)-phenol'),
    (SELECT id from literature WHERE bibtexkey='3678'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3678'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '9300',
    'V',
    (SELECT id from species WHERE iupac='5-methyl-2-(1-methylethyl)-phenol'),
    (SELECT id from literature WHERE bibtexkey='2125'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-2-(1-methylethyl)-phenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-2-(1-methylethyl)-phenol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-2-(1-methylethyl)-phenol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-2-(1-methylethyl)-phenol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-2-(1-methylethyl)-phenol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-2-(1-methylethyl)-phenol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-(3,5-dimethylphenyl)ethanol',
    'C<sub>10</sub>H<sub>14</sub>O',
    '',
    '5379-18-0',
    'RHBAJFPGUNNLFA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-(3,5-dimethylphenyl)ethanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-(3,5-dimethylphenyl)ethanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-(3,5-dimethylphenyl)ethanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '6-ethyl-2,4-xylenol',
    'C<sub>10</sub>H<sub>14</sub>O',
    '',
    '2219-79-6',
    'MXHAHSBTOVFDBK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-ethyl-2,4-xylenol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-ethyl-2,4-xylenol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-ethyl-2,4-xylenol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-(1,1-dimethylethyl)-4-methylphenol',
    'C<sub>11</sub>H<sub>16</sub>O',
    '',
    '2409-55-4',
    'IKEHOXWJQXIQAG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(1,1-dimethylethyl)-4-methylphenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-(1,1-dimethylpropyl)phenol',
    'C<sub>11</sub>H<sub>16</sub>O',
    '',
    '80-46-6',
    'NRZWYNLTFLDQQX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-(1,1-dimethylpropyl)phenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DE35TOH',
    'C<sub>11</sub>H<sub>16</sub>O',
    '',
    '',
    'OZZOZHVUMWFILP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DE35TOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DE35TOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DE35TOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DEMPHOH',
    'C<sub>11</sub>H<sub>16</sub>O',
    '',
    '',
    'VUDWBUZLGAXSDX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DEMPHOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DEMPHOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DEMPHOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'josenol',
    'C<sub>11</sub>H<sub>14</sub>O',
    '2-methyl-3-(4-methylphenyl)-2-propen-1-ol',
    '56138-10-4',
    'WWHATUWNHYNMNW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='josenol'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'lilyflore',
    'C<sub>12</sub>H<sub>16</sub>O',
    '',
    '285977-85-7',
    'UWSPWQQZFOSTHS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='lilyflore'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benzhydrol',
    'C<sub>13</sub>H<sub>12</sub>O',
    '',
    '91-01-0',
    'QILSFLSDHQAZET-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='benzhydrol'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-hydroxy-4-octylbenzene',
    'C<sub>14</sub>H<sub>22</sub>O',
    '4-octylphenol',
    '1806-26-4',
    'NTDQQZYCCIDJRK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-4-octylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-4-octylbenzene'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-(1,1,3,3-tetramethylbutyl)-phenol',
    'C<sub>14</sub>H<sub>22</sub>O',
    'p-<i>tert</i>-octylphenol',
    '140-66-9',
    'ISAVYTVYFVQUDY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '9000',
    'M',
    (SELECT id from species WHERE iupac='4-(1,1,3,3-tetramethylbutyl)-phenol'),
    (SELECT id from literature WHERE bibtexkey='1942'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-(1,1,3,3-tetramethylbutyl)-phenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-(1,1,3,3-tetramethylbutyl)-phenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-(1,1,3,3-tetramethylbutyl)-phenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-(1,1,3,3-tetramethylbutyl)-phenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-(1,1,3,3-tetramethylbutyl)-phenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-hydroxy-4-nonylbenzene',
    'C<sub>15</sub>H<sub>24</sub>O',
    '4-nonylphenol',
    '104-40-5',
    'IGFHQQFPSIBGKE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-4-nonylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-4-nonylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-4-nonylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-4-nonylbenzene'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-4-nonylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6-bis(1,1-dimethylethyl)-4-methylphenol',
    'C<sub>15</sub>H<sub>24</sub>O',
    'butylated hydroxytoluene; BHT',
    '128-37-0',
    'NLZUEZXRPGMBCV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,6-bis(1,1-dimethylethyl)-4-methylphenol'),
    (SELECT id from literature WHERE bibtexkey='2971'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-(3'',5''-dimethyl-3''-heptyl)-phenol(+)',
    'C<sub>15</sub>H<sub>24</sub>O',
    '',
    '',
    'RYIHVIPUIXFRNI-IUODEOHRSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9',
    '8700',
    'M',
    (SELECT id from species WHERE iupac='4-(3'',5''-dimethyl-3''-heptyl)-phenol(+)'),
    (SELECT id from literature WHERE bibtexkey='1942'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-(3'',5''-dimethyl-3''-heptyl)-phenol(-)',
    'C<sub>15</sub>H<sub>24</sub>O',
    '',
    '',
    'RYIHVIPUIXFRNI-SWLSCSKDSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3',
    '8600',
    'M',
    (SELECT id from species WHERE iupac='4-(3'',5''-dimethyl-3''-heptyl)-phenol(-)'),
    (SELECT id from literature WHERE bibtexkey='1942'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-phenylethanol',
    'C<sub>8</sub>H<sub>10</sub>O',
    '',
    '60-12-8',
    'WRMNZCZEMHIOCP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '7200',
    'L',
    (SELECT id from species WHERE iupac='2-phenylethanol'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 3.7&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-phenylethanol'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-phenylethanol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='2-phenylethanol'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-phenylethanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-phenylethanol'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-phenylethanol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-phenylethanol'),
    (SELECT id from literature WHERE bibtexkey='3521'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-phenylethanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-phenylethanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-phenylethanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-phenylethanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-phenylethanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-phenylethanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-phenylethanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-phenylethanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-phenylethanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-phenylethanol'),
    (SELECT id from literature WHERE bibtexkey='2597'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at373K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-phenylethanol'),
    (SELECT id from literature WHERE bibtexkey='2598'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at373K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-phenylethanol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-phenylethanol'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-phenylethanol'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-Test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-phenylethanol'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-phenylethanol'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-phenylethanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-phenylethanol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-phenyl-1-propanol',
    'C<sub>9</sub>H<sub>12</sub>O',
    '',
    '122-97-4',
    'VAJVDSVGBWFCLW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 1.8&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3-phenyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>1</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='3-phenyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-phenyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-phenyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-phenyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-phenyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-phenyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-phenyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-phenyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-phenyl-1-butanol',
    'C<sub>10</sub>H<sub>14</sub>O',
    '',
    '3360-41-6',
    'LDZLXQFDGRCELX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 6.7',
    '',
    'M',
    (SELECT id from species WHERE iupac='4-phenyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-phenyl-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-naphthalenol',
    'C<sub>10</sub>H<sub>8</sub>O',
    '1-naphthol',
    '90-15-3',
    'KJCVRFUGPWSIIH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-naphthalenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-naphthalenol'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='1-naphthalenol'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-naphthalenol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-naphthalenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-naphthalenol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-naphthalenol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-naphthalenol'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-naphthalenol'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-naphthalenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-naphthalenol',
    'C<sub>10</sub>H<sub>8</sub>O',
    '2-naphthol',
    '135-19-3',
    'JWAZRIHNYRIHIV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-naphthalenol'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>2</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='2-naphthalenol'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-naphthalenol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-naphthalenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-naphthalenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-naphthalenol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-naphthalenol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2-naphthalenol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-naphthalenol'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-naphthalenol'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-naphthalenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7200',
    '?',
    (SELECT id from species WHERE iupac='2-naphthalenol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'o-hydroxybiphenyl',
    'C<sub>12</sub>H<sub>10</sub>O',
    '',
    '90-43-7',
    'LLEMOWNGBBNAJR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4',
    '',
    'V',
    (SELECT id from species WHERE iupac='o-hydroxybiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4',
    '',
    'V',
    (SELECT id from species WHERE iupac='o-hydroxybiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='o-hydroxybiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='o-hydroxybiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='o-hydroxybiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='o-hydroxybiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'p-hydroxybiphenyl',
    'C<sub>12</sub>H<sub>10</sub>O',
    '',
    '92-69-3',
    'YXVFYQXJAXKLAK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='p-hydroxybiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='p-hydroxybiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,6-tris(1,1-dimethylethyl)phenol',
    'C<sub>18</sub>H<sub>30</sub>O',
    '',
    '732-26-3',
    'PFEFOYRSMXVNEL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-tris(1,1-dimethylethyl)phenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-tris(1,1-dimethylethyl)phenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-tris(1,1-dimethylethyl)phenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-tris(1,1-dimethylethyl)phenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dehydroabietol',
    'C<sub>20</sub>H<sub>30</sub>O',
    '',
    '3772-55-2',
    'WSKGRAGZAQRSED-IOJLRTSASA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dehydroabietol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dehydroabietol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dehydroabietol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dehydroabietol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2''-methylenebis(6-(1,1-dimethylethyl)-4-methylphenol)',
    'C<sub>23</sub>H<sub>32</sub>O<sub>2</sub>',
    '',
    '119-47-1',
    'KGRVJHAUYBGFFP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2''-methylenebis(6-(1,1-dimethylethyl)-4-methylphenol)'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dinonylphenol',
    'C<sub>24</sub>H<sub>42</sub>O',
    '',
    '137-99-5',
    'FDAJTLLBHNHECW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Alcohols (ROH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dinonylphenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dinonylphenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dinonylphenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dinonylphenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dinonylphenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Polyols (R(OH)<sub>n</sub>)',
    (SELECT id from categories WHERE catname='Organic species with oxygen (O)'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methanediol',
    'HOCH<sub>2</sub>OH',
    '',
    '463-57-0',
    'CKFGINPQOCXMAZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>1</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='methanediol'),
    (SELECT id from literature WHERE bibtexkey='3300'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3300',
    '', 'Intermediate of estimates employing the bond method from the EPI HENRYWIN software.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3300'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>3</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='methanediol'),
    (SELECT id from literature WHERE bibtexkey='3563'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3563',
    '3563', 'Although Mansfield (2020) writes that his "Table&nbsp;6 summarizes numerical calculations for formaldehyde and acetaldehyde assuming the values given in Tables&nbsp;4 and 5", different values for the Henry''s law constants are shown in these tables.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>2</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='methanediol'),
    (SELECT id from literature WHERE bibtexkey='3563'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3563'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1-ethanediol',
    'CH<sub>3</sub>CH<sub>2</sub>(OH)<sub>2</sub>',
    '',
    '4433-56-1',
    'AZHSSKPUVBVXLK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>1</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='1,1-ethanediol'),
    (SELECT id from literature WHERE bibtexkey='3563'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='1,1-ethanediol'),
    (SELECT id from literature WHERE bibtexkey='3563'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3563'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-ethanediol',
    'HO(CH<sub>2</sub>)<sub>2</sub>OH',
    'ethylene glycol',
    '107-21-1',
    'LYCAIKOWRPUZTN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,2-ethanediol'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,2-ethanediol'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-ethanediol'),
    (SELECT id from literature WHERE bibtexkey='641'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-ethanediol'),
    (SELECT id from literature WHERE bibtexkey='713'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'bad713',
    '588', 'Saxena and Hildemann (1996) say that this value is unreliable.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='bad713'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-ethanediol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>3</sup>',
    '8800',
    'V',
    (SELECT id from species WHERE iupac='1,2-ethanediol'),
    (SELECT id from literature WHERE bibtexkey='3067'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-ethanediol'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,2-ethanediol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,2-ethanediol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-ethanediol'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-ethanediol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-ethanediol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-ethanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-ethanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-ethanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-ethanediol'),
    (SELECT id from literature WHERE bibtexkey='3246'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3246-FEP',
    '', 'Calculated using the free energy perturbation (FEP) method.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3246-FEP'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-ethanediol'),
    (SELECT id from literature WHERE bibtexkey='3246'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3246-TI',
    '', 'Calculated using the thermodynamic integration (TI) method.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3246-TI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-ethanediol'),
    (SELECT id from literature WHERE bibtexkey='3246'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3246-BAR',
    '', 'Calculated using the Bennett acceptance ratio (BAR) method.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3246-BAR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-ethanediol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-ethanediol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-ethanediol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-ethanediol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-ethanediol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-ethanediol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-ethanediol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-ethanediol'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-ethanediol'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-ethanediol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-ethanediol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-propanediol',
    'C<sub>3</sub>H<sub>8</sub>O<sub>2</sub>',
    'propylene glycol',
    '57-55-6',
    'DNIAPMSPPWPWGF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,2-propanediol'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,2-propanediol'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-propanediol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-propanediol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>3</sup>',
    '9500',
    'V',
    (SELECT id from species WHERE iupac='1,2-propanediol'),
    (SELECT id from literature WHERE bibtexkey='3067'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,2-propanediol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,2-propanediol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-propanediol'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-propanediol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-propanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-propanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-propanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-propanediol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-propanediol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'E',
    (SELECT id from species WHERE iupac='1,2-propanediol'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '588-57-55-6-range',
    '588', 'Saxena and Hildemann (1996) give a range of 9.9&times;10<sup>2</sup>&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>  &lt;  H<sub>s</sub><sup>cp</sup> &lt;  5.9&times;10<sup>4</sup>&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588-57-55-6-range'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3-propanediol',
    'C<sub>3</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '504-63-2',
    'YPFDHNVEDLHUCE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,3-propanediol'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,3-propanediol'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,3-propanediol'),
    (SELECT id from literature WHERE bibtexkey='641'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '9500',
    'V',
    (SELECT id from species WHERE iupac='1,3-propanediol'),
    (SELECT id from literature WHERE bibtexkey='3067'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-propanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-propanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-propanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-propanediol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-propanediol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-propanediol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-propanediol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-propanediol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3-propanetriol',
    'C<sub>3</sub>H<sub>8</sub>O<sub>3</sub>',
    'glycerol',
    '56-81-5',
    'PEDCQBHIVMGVHV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,2,3-propanetriol'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,2,3-propanetriol'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2,3-propanetriol'),
    (SELECT id from literature WHERE bibtexkey='713'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='bad713'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>6</sup>',
    '11000',
    'V',
    (SELECT id from species WHERE iupac='1,2,3-propanetriol'),
    (SELECT id from literature WHERE bibtexkey='3067'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3-propanetriol'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-propanetriol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-propanetriol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'E',
    (SELECT id from species WHERE iupac='1,2,3-propanetriol'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '588-56-81-5-range',
    '588', 'Saxena and Hildemann (1996) give a range of 5.9&times;10<sup>6</sup>&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>  &lt;  H<sub>s</sub><sup>cp</sup> &lt;  3.9&times;10<sup>9</sup>&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588-56-81-5-range'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2,3-propanetriol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-butanediol',
    'C<sub>4</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '584-03-2',
    'BMRWNKZVCUKKSR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,2-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3500-584-03-2',
    '3500', 'The formula of 1,2-butanediol is incorrectly given as "HOCH(OH)C<sub>2</sub>H<sub>5</sub>" by Burkholder et&nbsp;al. (2019).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3500-584-03-2'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,2-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3245-584-03-2',
    '3245', 'The formula of 1,2-butanediol is incorrectly given as "HOCH(OH)C<sub>2</sub>H<sub>5</sub>" by Burkholder et&nbsp;al. (2015).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3245-584-03-2'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 3.4&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-butanediol'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '9900',
    'V',
    (SELECT id from species WHERE iupac='1,2-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3067'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3-butanediol',
    'C<sub>4</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '107-88-0',
    'PUPZLCDOIYMWBV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,3-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,3-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>3</sup>',
    '10000',
    'V',
    (SELECT id from species WHERE iupac='1,3-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3067'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>4</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='1,3-butanediol'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4-butanediol',
    'C<sub>4</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '110-63-4',
    'WERYXYBDKMZEQL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,4-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,4-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 9.0&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,4-butanediol'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>4</sup>',
    '11000',
    'V',
    (SELECT id from species WHERE iupac='1,4-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3067'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-butanediol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-butanediol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-butanediol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-butanediol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-butanediol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'E',
    (SELECT id from species WHERE iupac='1,4-butanediol'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '588-110-63-4-range',
    '588', 'Saxena and Hildemann (1996) give a range of 9.9&times;10<sup>2</sup>&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>  &lt;  H<sub>s</sub><sup>cp</sup> &lt;  4.9&times;10<sup>4</sup>&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588-110-63-4-range'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,4-butanediol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-butanediol',
    'C<sub>4</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '513-85-9',
    'OWBTYPJTUOEWEK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2,3-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2,3-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '9900',
    'V',
    (SELECT id from species WHERE iupac='2,3-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3067'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3-butanediol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'E',
    (SELECT id from species WHERE iupac='2,3-butanediol'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '588-513-85-9-range',
    '588', 'Saxena and Hildemann (1996) give a range of 3.9&times;10<sup>2</sup>&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>  &lt;  H<sub>s</sub><sup>cp</sup> &lt;  3.9&times;10<sup>4</sup>&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588-513-85-9-range'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>meso</i>-2,3-butanediol',
    'C<sub>4</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '5341-95-7',
    'OWBTYPJTUOEWEK-ZXZARUISSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='<i>meso</i>-2,3-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>meso</i>-2,3-butanediol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>meso</i>-2,3-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>meso</i>-2,3-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>meso</i>-2,3-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methylpropane-1,2-diol',
    'C<sub>4</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '558-43-0',
    'BTVWZWFKMIUSGS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropane-1,2-diol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropane-1,2-diol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropane-1,2-diol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methylpropane-1,3-diol',
    'C<sub>4</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '2163-42-0',
    'QWGRWMMWNDWRQN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropane-1,3-diol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropane-1,3-diol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropane-1,3-diol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropane-1,3-diol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3-butanetriol',
    'C<sub>4</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '4435-50-1',
    'YAXKTBLXMTYWDQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>9</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='1,2,3-butanetriol'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4-butanetriol',
    'C<sub>4</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '3068-00-6',
    'ARXKVVRQIIOZGF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-butanetriol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-butanetriol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-butanetriol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>9</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='1,2,4-butanetriol'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,4-butanetetrol',
    'C<sub>4</sub>H<sub>10</sub>O<sub>4</sub>',
    '1,2,3,4-tetrahydroxybutane; tetritol',
    '7541-59-5',
    'UNXHWFMMPAWVPI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>14</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='1,2,3,4-butanetetrol'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2(R),3(S)-1,2,3,4-butanetetrol',
    'C<sub>4</sub>H<sub>10</sub>O<sub>4</sub>',
    'erythritol',
    '149-32-6',
    'UNXHWFMMPAWVPI-ZXZARUISSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>10</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2(R),3(S)-1,2,3,4-butanetetrol'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>10</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2(R),3(S)-1,2,3,4-butanetetrol'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>9</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2(R),3(S)-1,2,3,4-butanetetrol'),
    (SELECT id from literature WHERE bibtexkey='3575'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3575-LogKH',
    '', 'Calculated based on atmospheric measurements.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3575-LogKH'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>10</sup>',
    '16000',
    'V',
    (SELECT id from species WHERE iupac='2(R),3(S)-1,2,3,4-butanetetrol'),
    (SELECT id from literature WHERE bibtexkey='3067'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2(R),3(S)-1,2,3,4-butanetetrol'),
    (SELECT id from literature WHERE bibtexkey='3575'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3575-epi',
    '', 'Calculated using EPI.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3575-epi'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2(R),3(S)-1,2,3,4-butanetetrol'),
    (SELECT id from literature WHERE bibtexkey='3575'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3575-sparc',
    '', 'Calculated using SPARC.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3575-sparc'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2(R),3(S)-1,2,3,4-butanetetrol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-pentanediol',
    'C<sub>5</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '5343-92-0',
    'WCVRQHFDJLLWFE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-pentanediol'),
    (SELECT id from literature WHERE bibtexkey='3067'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-pentanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-pentanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-pentanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3-pentanediol',
    'C<sub>5</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '3174-67-2',
    'RUOPINZRYMFPBF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-pentanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-pentanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-pentanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4-pentanediol',
    'C<sub>5</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '626-95-9',
    'GLOBUAZSRIOKLN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-pentanediol'),
    (SELECT id from literature WHERE bibtexkey='3067'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-pentanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-pentanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-pentanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,5-pentanediol',
    'C<sub>5</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '111-29-5',
    'ALQSHHUCVQOPAS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>4</sup>',
    '12000',
    'V',
    (SELECT id from species WHERE iupac='1,5-pentanediol'),
    (SELECT id from literature WHERE bibtexkey='3067'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,5-pentanediol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,5-pentanediol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,5-pentanediol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,5-pentanediol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>4</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='1,5-pentanediol'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-pentanediol',
    'C<sub>5</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '42027-23-6',
    'XLMFDCKSFJWJTP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-pentanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-pentanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-pentanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>4</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='2,3-pentanediol'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-pentanediol',
    'C<sub>5</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '625-69-4',
    'GTCCGKPBSJZVRZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4-pentanediol'),
    (SELECT id from literature WHERE bibtexkey='3067'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-pentanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-pentanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-pentanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>4</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='2,4-pentanediol'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methylbutane-1,2-diol',
    'C<sub>5</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '50468-22-9',
    'HJJZIMFAIMUSBW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutane-1,2-diol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutane-1,2-diol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutane-1,2-diol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methylbutane-1,3-diol',
    'C<sub>5</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '2568-33-4',
    'XPFCZYUVICHKDS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutane-1,3-diol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutane-1,3-diol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutane-1,3-diol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methylbutane-1,2-diol',
    'C<sub>5</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '41051-72-3',
    'DOPZLYNWNJHAOS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbutane-1,2-diol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbutane-1,2-diol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbutane-1,2-diol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methylbutane-1,3-diol',
    'C<sub>5</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '684-84-4',
    'GNBPEYCZELNJMS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbutane-1,3-diol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbutane-1,3-diol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbutane-1,3-diol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methylbutane-1,4-diol',
    'C<sub>5</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '2938-98-9',
    'MWCBGWLCXSUTHK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbutane-1,4-diol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbutane-1,4-diol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbutane-1,4-diol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methylbutane-2,3-diol',
    'C<sub>5</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '5396-58-7',
    'IDEOPBXRUBNYBN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbutane-2,3-diol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbutane-2,3-diol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbutane-2,3-diol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dimethylpropane-1,3-diol',
    'C<sub>5</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '126-30-7',
    'SLCVBVWXLSEKPL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylpropane-1,3-diol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylpropane-1,3-diol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylpropane-1,3-diol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-(hydroxymethyl)-2-methyl-1,3-propanediol',
    'C<sub>5</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '77-85-0',
    'QXJQHYBHAIHNGG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(hydroxymethyl)-2-methyl-1,3-propanediol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methylbutane-1,2,4-triol',
    'C<sub>5</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '62875-07-4',
    'XYHGSPUTABMVOC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbutane-1,2,4-triol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbutane-1,2,4-triol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbutane-1,2,4-triol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C56OH',
    'C<sub>5</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'RXEJCNRKXVSXDJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C56OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C56OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C56OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO124C5',
    'C<sub>5</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'MOIOWCZVZKHQIC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO124C5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO124C5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO124C5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO134C5',
    'C<sub>5</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'ANUUQAHHEZMTAS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO134C5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO134C5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO134C5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MBOAOH',
    'C<sub>5</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'QFZITDCVRJQLMZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MBOAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MBOAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MBOAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-pentene-2,4,5-triol',
    'C<sub>5</sub>H<sub>10</sub>O<sub>3</sub>',
    'ME1TRIOL',
    '',
    'MTMASQITBHTGFW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>7</sup>',
    '11000',
    'Q',
    (SELECT id from species WHERE iupac='2-pentene-2,4,5-triol'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3765-GROMHE',
    '1917', 'Henry''s law constants calculated using the GROMHE model. Temperature dependences calculated with the method of Kühne et&nbsp;al. (2005).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-3-butene-1,2,3-triol',
    'C<sub>5</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'YXPJRFSYSVRDQI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>8</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methyl-3-butene-1,2,3-triol'),
    (SELECT id from literature WHERE bibtexkey='3575'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3575-LogKH'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-butene-1,2,3-triol'),
    (SELECT id from literature WHERE bibtexkey='3575'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3575-epi'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-butene-1,2,3-triol'),
    (SELECT id from literature WHERE bibtexkey='3575'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3575-sparc'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(E)-2-methyl-1-butene-1,3,4-triol',
    'C<sub>5</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'FVYHKVMWBMOFGS-DUXPYHPUSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>8</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='(E)-2-methyl-1-butene-1,3,4-triol'),
    (SELECT id from literature WHERE bibtexkey='3575'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3575-LogKH'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(E)-2-methyl-1-butene-1,3,4-triol'),
    (SELECT id from literature WHERE bibtexkey='3575'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3575-epi'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(E)-2-methyl-1-butene-1,3,4-triol'),
    (SELECT id from literature WHERE bibtexkey='3575'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3575-sparc'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(Z)-2-methyl-1-butene-1,3,4-triol',
    'C<sub>5</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'FVYHKVMWBMOFGS-RQOWECAXSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>8</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='(Z)-2-methyl-1-butene-1,3,4-triol'),
    (SELECT id from literature WHERE bibtexkey='3575'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3575-LogKH'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(Z)-2-methyl-1-butene-1,3,4-triol'),
    (SELECT id from literature WHERE bibtexkey='3575'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3575-epi'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(Z)-2-methyl-1-butene-1,3,4-triol'),
    (SELECT id from literature WHERE bibtexkey='3575'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3575-sparc'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methylthreitol',
    'C<sub>5</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'HGVJFBSSLICXEM-WHFBIAKZSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>8</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methylthreitol'),
    (SELECT id from literature WHERE bibtexkey='3575'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3575-LogKH'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylthreitol'),
    (SELECT id from literature WHERE bibtexkey='3575'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3575-epi'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylthreitol'),
    (SELECT id from literature WHERE bibtexkey='3575'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3575-sparc'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methylerythritol',
    'C<sub>5</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '93921-83-6',
    'HGVJFBSSLICXEM-CRCLSJGQSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>8</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methylerythritol'),
    (SELECT id from literature WHERE bibtexkey='3575'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3575-LogKH'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylerythritol'),
    (SELECT id from literature WHERE bibtexkey='3575'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3575-epi'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylerythritol'),
    (SELECT id from literature WHERE bibtexkey='3575'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3575-sparc'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylerythritol'),
    (SELECT id from literature WHERE bibtexkey='3413'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3413wrongref_GROMHE',
    '3413,2546', 'Isaacman-VanWertz et&nbsp;al. (2016) refer to Raventos-Duran et&nbsp;al. (2010) as the source, but the quoted value cannot be found there.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3413wrongref_GROMHE'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3413GROMHE',
    '', 'Calculated using GROMHE.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3413GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylerythritol'),
    (SELECT id from literature WHERE bibtexkey='3413'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3413wrongref_SPARC',
    '3413', 'Isaacman-VanWertz et&nbsp;al. (2016) refer to a paper by Hilal et al.&nbsp;as the source, but the quoted value cannot be found there.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3413wrongref_SPARC'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3413SPARC',
    '', 'Calculated using SPARC.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3413SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylerythritol'),
    (SELECT id from literature WHERE bibtexkey='3413'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3413the bond contribution of HENRYWIN',
    '', 'Calculated using the bond contribution of HENRYWIN.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3413the bond contribution of HENRYWIN'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-Methylbutane-1,2,3,4-tetrol',
    'C<sub>5</sub>H<sub>12</sub>O<sub>4</sub>',
    'MeBuTETROL',
    '42933-13-1',
    'HGVJFBSSLICXEM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>10</sup>',
    '14000',
    'Q',
    (SELECT id from species WHERE iupac='2-Methylbutane-1,2,3,4-tetrol'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-bis(hydroxymethyl)1,3-propanediol',
    'C<sub>5</sub>H<sub>12</sub>O<sub>4</sub>',
    'pentaerythritol',
    '115-77-5',
    'WXZMFSXDPGVJKK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>10</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2,2-bis(hydroxymethyl)1,3-propanediol'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>10</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2,2-bis(hydroxymethyl)1,3-propanediol'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>10</sup>',
    '16000',
    'V',
    (SELECT id from species WHERE iupac='2,2-bis(hydroxymethyl)1,3-propanediol'),
    (SELECT id from literature WHERE bibtexkey='3067'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>9</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2-bis(hydroxymethyl)1,3-propanediol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-bis(hydroxymethyl)1,3-propanediol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-bis(hydroxymethyl)1,3-propanediol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-bis(hydroxymethyl)1,3-propanediol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,4,5-pentanepentol',
    'C<sub>5</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '7643-75-6',
    'HEBKCHPVOIAQTA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>18</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='1,2,3,4,5-pentanepentol'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(2R,3R,4S)-pentane-1,2,3,4,5-pentol',
    'C<sub>5</sub>H<sub>12</sub>O<sub>5</sub>',
    'xylitol',
    '87-99-0',
    'HEBKCHPVOIAQTA-SCDXWVJYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>8</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='(2R,3R,4S)-pentane-1,2,3,4,5-pentol'),
    (SELECT id from literature WHERE bibtexkey='3575'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3575-LogKH'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>11</sup>',
    '17000',
    'V',
    (SELECT id from species WHERE iupac='(2R,3R,4S)-pentane-1,2,3,4,5-pentol'),
    (SELECT id from literature WHERE bibtexkey='3067'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2R,3R,4S)-pentane-1,2,3,4,5-pentol'),
    (SELECT id from literature WHERE bibtexkey='3575'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3575-epi'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2R,3R,4S)-pentane-1,2,3,4,5-pentol'),
    (SELECT id from literature WHERE bibtexkey='3575'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3575-sparc'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2R,3R,4S)-pentane-1,2,3,4,5-pentol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(2R,3S,4S)-pentane-1,2,3,4,5-pentol',
    'C<sub>5</sub>H<sub>12</sub>O<sub>5</sub>',
    'adonitol; ribitol',
    '488-81-3',
    'HEBKCHPVOIAQTA-ZXFHETKHSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>11</sup>',
    '18000',
    'V',
    (SELECT id from species WHERE iupac='(2R,3S,4S)-pentane-1,2,3,4,5-pentol'),
    (SELECT id from literature WHERE bibtexkey='3067'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(2R,4R)-pentane-1,2,3,4,5-pentol',
    'C<sub>5</sub>H<sub>12</sub>O<sub>5</sub>',
    'arabitol; arabinitol',
    '2152-56-9',
    'HEBKCHPVOIAQTA-QWWZWVQMSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>9</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='(2R,4R)-pentane-1,2,3,4,5-pentol'),
    (SELECT id from literature WHERE bibtexkey='3575'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3575-LogKH'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>11</sup>',
    '18000',
    'V',
    (SELECT id from species WHERE iupac='(2R,4R)-pentane-1,2,3,4,5-pentol'),
    (SELECT id from literature WHERE bibtexkey='3067'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2R,4R)-pentane-1,2,3,4,5-pentol'),
    (SELECT id from literature WHERE bibtexkey='3575'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3575-epi'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2R,4R)-pentane-1,2,3,4,5-pentol'),
    (SELECT id from literature WHERE bibtexkey='3575'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3575-sparc'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'levoglucosan',
    'C<sub>6</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '498-07-7',
    'TWNIBLMWSKIRAT-VFUOTHLCSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>10</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='levoglucosan'),
    (SELECT id from literature WHERE bibtexkey='3575'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3575-LogKH'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='levoglucosan'),
    (SELECT id from literature WHERE bibtexkey='3575'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3575-epi'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='levoglucosan'),
    (SELECT id from literature WHERE bibtexkey='3575'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3575-sparc'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fructose',
    'C<sub>6</sub>H<sub>12</sub>O<sub>6</sub>',
    '',
    '30237-26-4',
    'BJHIKXHVCXFQLS-UYFOZJQFSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>9</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='fructose'),
    (SELECT id from literature WHERE bibtexkey='3575'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3575-LogKH'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fructose'),
    (SELECT id from literature WHERE bibtexkey='3575'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3575-epi'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>14</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fructose'),
    (SELECT id from literature WHERE bibtexkey='3575'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3575-sparc'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'mannose',
    'C<sub>6</sub>H<sub>12</sub>O<sub>6</sub>',
    '',
    '3458-28-4',
    'GZCGUPFRVQAUEE-KVTDHHQDSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>9</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='mannose'),
    (SELECT id from literature WHERE bibtexkey='3575'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3575-LogKH'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='mannose'),
    (SELECT id from literature WHERE bibtexkey='3575'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3575-epi'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>13</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='mannose'),
    (SELECT id from literature WHERE bibtexkey='3575'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3575-sparc'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'glucose',
    'C<sub>6</sub>H<sub>12</sub>O<sub>6</sub>',
    '',
    '50-99-7',
    'GZCGUPFRVQAUEE-SLPGGIOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>8</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='glucose'),
    (SELECT id from literature WHERE bibtexkey='3575'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3575-LogKH'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='glucose'),
    (SELECT id from literature WHERE bibtexkey='3575'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3575-epi'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>15</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='glucose'),
    (SELECT id from literature WHERE bibtexkey='3575'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3575-sparc'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-hexanediol',
    'C<sub>6</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '6920-22-5',
    'FHKSXSQHXQEMOK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-hexanediol'),
    (SELECT id from literature WHERE bibtexkey='3067'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-hexanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-hexanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-hexanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4-hexanediol',
    'C<sub>6</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '16432-53-4',
    'QVTWBMUAJHVAIJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-hexanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-hexanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-hexanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,6-hexanediol',
    'C<sub>6</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '629-11-8',
    'XXMIOPMDWAUFGU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,6-hexanediol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>4</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='1,6-hexanediol'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-hexanediol',
    'C<sub>6</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '617-30-1',
    'QCIYAEYRVFUFAP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-hexanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-hexanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-hexanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5-hexanediol',
    'C<sub>6</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '2935-44-6',
    'OHMBHFSEKCCCBW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,5-hexanediol'),
    (SELECT id from literature WHERE bibtexkey='3067'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-hexanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-hexanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-hexanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>4</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='2,5-hexanediol'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-cyclohexanediol',
    'C<sub>6</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '931-17-9',
    'PFURGBBHAOXLIO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-cyclohexanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-cyclohexanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-cyclohexanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-1,3-pentanediol',
    'C<sub>6</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '149-31-5',
    'SPXWGAHNKXLXAP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>4</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='2-methyl-1,3-pentanediol'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-1,4-pentanediol',
    'C<sub>6</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '6287-17-8',
    'PNJNLCNHYSWUPT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1,4-pentanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1,4-pentanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1,4-pentanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-2,4-pentanediol',
    'C<sub>6</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '107-41-5',
    'SVTBMSDMJJWYQN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2,4-pentanediol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>4</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='2-methyl-2,4-pentanediol'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-1,3-pentanediol',
    'C<sub>6</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '33879-72-0',
    'HIYKOZFIVZIBFO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1,3-pentanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1,3-pentanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1,3-pentanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-1,4-pentanediol',
    'C<sub>6</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '26787-63-3',
    'WOHXXIWTEHLCQK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1,4-pentanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1,4-pentanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1,4-pentanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-1,4-pentanediol',
    'C<sub>6</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '1462-10-8',
    'HAIVWDGLCRYQMC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1,4-pentanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1,4-pentanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1,4-pentanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethyl-2,3-butanediol',
    'C<sub>6</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '76-09-5',
    'IVDFJHOHABJVEH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-2,3-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-2,3-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-2,3-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethyl-1,4-butanediol',
    'C<sub>6</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '57716-80-0',
    'SKQUTIPQJKQFRA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-1,4-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-1,4-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyl-1,4-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dimethyl-1,4-butanediol',
    'C<sub>6</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '32812-23-0',
    'GQSZUUPRBBBHRI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-1,4-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-1,4-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-1,4-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,6-hexanetriol',
    'C<sub>6</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '106-69-4',
    'ZWVMLYRJXORSEP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>9</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='1,2,6-hexanetriol'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H134M3C5',
    'C<sub>6</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'XPUHQLFLUQJINS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H134M3C5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H134M3C5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H134M3C5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,4,5,6-hexahydroxy hexane',
    'C<sub>6</sub>H<sub>14</sub>O<sub>6</sub>',
    '',
    '45007-61-2',
    'FBPFZTCFMRRESA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>23</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='1,2,3,4,5,6-hexahydroxy hexane'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(2S,3R,4R,5R)-hexane-1,2,3,4,5,6-hexol',
    'C<sub>6</sub>H<sub>14</sub>O<sub>6</sub>',
    'sorbitol',
    '50-70-4',
    'FBPFZTCFMRRESA-JGWLITMVSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>14</sup>',
    '22000',
    'V',
    (SELECT id from species WHERE iupac='(2S,3R,4R,5R)-hexane-1,2,3,4,5,6-hexol'),
    (SELECT id from literature WHERE bibtexkey='3067'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2S,3R,4R,5R)-hexane-1,2,3,4,5,6-hexol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(2R,3R,4R,5R)-hexane-1,2,3,4,5,6-hexol',
    'C<sub>6</sub>H<sub>14</sub>O<sub>6</sub>',
    'mannitol',
    '69-65-8',
    'FBPFZTCFMRRESA-KVTDHHQDSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>9</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='(2R,3R,4R,5R)-hexane-1,2,3,4,5,6-hexol'),
    (SELECT id from literature WHERE bibtexkey='3575'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3575-LogKH'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>15</sup>',
    '22000',
    'V',
    (SELECT id from species WHERE iupac='(2R,3R,4R,5R)-hexane-1,2,3,4,5,6-hexol'),
    (SELECT id from literature WHERE bibtexkey='3067'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2R,3R,4R,5R)-hexane-1,2,3,4,5,6-hexol'),
    (SELECT id from literature WHERE bibtexkey='3575'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3575-epi'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>15</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2R,3R,4R,5R)-hexane-1,2,3,4,5,6-hexol'),
    (SELECT id from literature WHERE bibtexkey='3575'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3575-sparc'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2R,3R,4R,5R)-hexane-1,2,3,4,5,6-hexol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(2R,3S,4R,5S)-hexane-1,2,3,4,5,6-hexol',
    'C<sub>6</sub>H<sub>14</sub>O<sub>6</sub>',
    'dulcitol; galactitol',
    '608-66-2',
    'FBPFZTCFMRRESA-GUCUJZIJSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>14</sup>',
    '22000',
    'V',
    (SELECT id from species WHERE iupac='(2R,3S,4R,5S)-hexane-1,2,3,4,5,6-hexol'),
    (SELECT id from literature WHERE bibtexkey='3067'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4,5-cyclohexanetetrol',
    'C<sub>6</sub>H<sub>12</sub>O<sub>4</sub>',
    '1,2,4,5-tetrahydroxycyclohexane',
    '35652-37-0',
    'RDIDGZFQASQXBU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>14</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='1,2,4,5-cyclohexanetetrol'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,4,5,6-hexahydroxycyclohexane',
    'C<sub>6</sub>H<sub>12</sub>O<sub>6</sub>',
    '',
    '87-89-8',
    'CDAISMWEOUEBRE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>23</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='1,2,3,4,5,6-hexahydroxycyclohexane'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,7-heptanediol',
    'C<sub>7</sub>H<sub>16</sub>O<sub>2</sub>',
    '',
    '629-30-1',
    'SXCBDZAEHILGLM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,7-heptanediol'),
    (SELECT id from literature WHERE bibtexkey='3067'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3067-629-30-1-range',
    '3067', 'Compernolle and Müller (2014b) recommend H<sub>s</sub><sup>cp</sup> for 1,7-heptanediol in the range of 4.5&times;10<sup>4</sup>&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>  &lt;  H<sub>s</sub><sup>cp</sup> &lt;  8.3&times;10<sup>4</sup>&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3067-629-30-1-range'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>4</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='1,7-heptanediol'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-heptanediol',
    'C<sub>7</sub>H<sub>16</sub>O<sub>2</sub>',
    '',
    '20748-86-1',
    'XVEOUOTUJBYHNL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>4</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='2,4-heptanediol'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5-heptanediol',
    'C<sub>7</sub>H<sub>16</sub>O<sub>2</sub>',
    '',
    '70444-25-6',
    'XTVHTJKQKUOEQA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-heptanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-heptanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-heptanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-1,4-hexanediol',
    'C<sub>7</sub>H<sub>16</sub>O<sub>2</sub>',
    '',
    '40646-08-0',
    'ZRCYHJNCCBSTSZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1,4-hexanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1,4-hexanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1,4-hexanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-2,5-hexanediol',
    'C<sub>7</sub>H<sub>16</sub>O<sub>2</sub>',
    '',
    '29044-06-2',
    'KZWQVDXGMOSSNY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2,5-hexanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2,5-hexanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2,5-hexanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-2,5-hexanediol',
    'C<sub>7</sub>H<sub>16</sub>O<sub>2</sub>',
    '',
    '',
    'PMORVUNYTOZCSE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2,5-hexanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2,5-hexanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2,5-hexanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-diethyl-1,3-propanediol',
    'C<sub>7</sub>H<sub>16</sub>O<sub>2</sub>',
    '',
    '115-76-4',
    'XRVCFZPJAHWYTB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>4</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='2,2-diethyl-1,3-propanediol'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,4,5-pentahydroxyheptane',
    'C<sub>7</sub>H<sub>16</sub>O<sub>5</sub>',
    '',
    '',
    'HUYORHVLGRMTGF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>18</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='1,2,3,4,5-pentahydroxyheptane'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,4,6-pentahydroxyheptane',
    'C<sub>7</sub>H<sub>16</sub>O<sub>5</sub>',
    '',
    '',
    'HBKKLPCMKBGRJH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>18</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='1,2,3,4,6-pentahydroxyheptane'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,5,7-pentahydroxyheptane',
    'C<sub>7</sub>H<sub>16</sub>O<sub>5</sub>',
    '',
    '',
    'NSOOVWLSFZLKQX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>18</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='1,2,3,5,7-pentahydroxyheptane'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,4,5,6-hexahydroxyheptane',
    'C<sub>7</sub>H<sub>16</sub>O<sub>6</sub>',
    '1-deoxy-heptitol',
    '688007-16-1',
    'YMEXGEAJNZRQEH-VIFPVBQESA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>23</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='1,2,3,4,5,6-hexahydroxyheptane'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,6-octanediol',
    'C<sub>8</sub>H<sub>18</sub>O<sub>2</sub>',
    '',
    '24434-09-1',
    'BCKOQWWRTRBSGR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,6-octanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,6-octanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,6-octanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4-cyclohexanedimethanol',
    'C<sub>8</sub>H<sub>16</sub>O<sub>2</sub>',
    '',
    '105-08-8',
    'YIMQCDZDWXUDCA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-cyclohexanedimethanol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-ethyl-1,3-hexanediol',
    'C<sub>8</sub>H<sub>18</sub>O<sub>2</sub>',
    '',
    '94-96-2',
    'RWLALWYNXFYRGW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-ethyl-1,3-hexanediol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-1,3-hexanediol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-1,3-hexanediol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-1,3-hexanediol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-1,3-hexanediol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-1,3-hexanediol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-1,3-hexanediol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>4</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='2-ethyl-1,3-hexanediol'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,4-trimethyl-1,3-pentanediol',
    'C<sub>8</sub>H<sub>18</sub>O<sub>2</sub>',
    '',
    '144-19-4',
    'JCTXKRPTIMZBJT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2,4-trimethyl-1,3-pentanediol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethyl-1,3-pentanediol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethyl-1,3-pentanediol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5-dimethyl-2,5-hexanediol',
    'C<sub>8</sub>H<sub>18</sub>O<sub>2</sub>',
    '',
    '110-03-2',
    'ZWNMRZQYWRLGMM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyl-2,5-hexanediol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyl-2,5-hexanediol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyl-2,5-hexanediol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyl-2,5-hexanediol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,9-nonanediol',
    'C<sub>9</sub>H<sub>20</sub>O<sub>2</sub>',
    '',
    '3937-56-2',
    'ALVZNPYWJMLXKV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,9-nonanediol'),
    (SELECT id from literature WHERE bibtexkey='3067'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3067-3937-56-2-range',
    '3067', 'Compernolle and Müller (2014b) recommend H<sub>s</sub><sup>cp</sup> for 1,9-nonanediol in the range of 2.4&times;10<sup>4</sup>&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>  &lt;  H<sub>s</sub><sup>cp</sup> &lt;  3.9&times;10<sup>4</sup>&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3067-3937-56-2-range'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,6-nonanediol',
    'C<sub>9</sub>H<sub>20</sub>O<sub>2</sub>',
    '',
    '4469-85-6',
    'YKEWIFGQPMVBEF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,6-nonanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,6-nonanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,6-nonanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,10-decanediol',
    'C<sub>10</sub>H<sub>22</sub>O<sub>2</sub>',
    '',
    '112-47-0',
    'FOTKYAAJKYLFFN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,10-decanediol'),
    (SELECT id from literature WHERE bibtexkey='3067'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3067-112-47-0-range',
    '3067', 'Compernolle and Müller (2014b) recommend H<sub>s</sub><sup>cp</sup> for 1,10-decanediol in the range of 2.5&times;10<sup>4</sup>&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>  &lt;  H<sub>s</sub><sup>cp</sup> &lt;  3.0&times;10<sup>4</sup>&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3067-112-47-0-range'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,6-decanediol',
    'C<sub>10</sub>H<sub>22</sub>O<sub>2</sub>',
    '',
    '',
    'RBFBEPALGOYNGK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,6-decanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,6-decanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,6-decanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:APINBOH',
    'C<sub>10</sub>H<sub>18</sub>O<sub>2</sub>',
    '',
    '',
    'MOILFCKRQFQVFS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:APINBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:APINBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:APINBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:APINCOH',
    'C<sub>10</sub>H<sub>18</sub>O<sub>2</sub>',
    '',
    '',
    'OMDMTHRBGUBUCO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:APINCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:APINCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:APINCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BPINAOH',
    'C<sub>10</sub>H<sub>18</sub>O<sub>2</sub>',
    '',
    '',
    'VXXAKGMRLUXFQH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BPINAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BPINAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BPINAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BPINCOH',
    'C<sub>10</sub>H<sub>18</sub>O<sub>2</sub>',
    '',
    '',
    'XYKGEKWHBMLSGS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BPINCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BPINCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BPINCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO36C11',
    'C<sub>11</sub>H<sub>24</sub>O<sub>2</sub>',
    '',
    '',
    'VCLRIEYYOZNUNU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO36C11'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO36C11'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO36C11'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO36C12',
    'C<sub>12</sub>H<sub>26</sub>O<sub>2</sub>',
    '',
    '',
    'CLQOYXKLYNGAHW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO36C12'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO36C12'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO36C12'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-butene-1,4-diol',
    'C<sub>4</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '110-64-5',
    'ORTVZLZNOYNASJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 3.4&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-butene-1,4-diol'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butene-1,4-diol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butene-1,4-diol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butene-1,4-diol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-butene-1,2-diol',
    'C<sub>4</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '497-06-3',
    'ITMIAZBRRZANGB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-butene-1,2-diol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-butene-1,2-diol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-butene-1,2-diol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-butyne-1,4-diol',
    'C<sub>4</sub>H<sub>6</sub>O<sub>2</sub>',
    '1,4-dihydroxy-2-butyne',
    '110-65-6',
    'DLDJFQGPPSQZKI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 2.0&times;10<sup>3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-butyne-1,4-diol'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-butyne-1,4-diol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C524OH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'PGARYUHLQUORKU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C524OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C524OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C524OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ISOPAOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'FLXLJBCLEUWWCG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ISOPAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ISOPAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ISOPAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ISOPBOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'XZRGYMKUQMPDQH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ISOPBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ISOPBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ISOPBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ISOPDOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'HBHXLSPUXXXICF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ISOPDOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ISOPDOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ISOPDOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C622OH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'VCGCHTQYUUAIGQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C622OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C622OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C622OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C624OH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'BZQZWOYZOVQJLT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C624OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C624OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C624OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C720OH',
    'C<sub>7</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'JRLLENLHZCUEBJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C720OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C720OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C720OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:LIMAOH',
    'C<sub>10</sub>H<sub>18</sub>O<sub>2</sub>',
    '',
    '',
    'WKZWTZTZWGWEGE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:LIMCOH',
    'C<sub>10</sub>H<sub>18</sub>O<sub>2</sub>',
    '',
    '',
    'ZJALAEQNHJQSTN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(E,E)-8,10-dodecadien-1-ol',
    'C<sub>12</sub>H<sub>22</sub>O',
    'codlemone',
    '33956-49-9',
    'CSWBSLXBXRFNST-MQQKCMAXSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    '?',
    (SELECT id from species WHERE iupac='(E,E)-8,10-dodecadien-1-ol'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BCAOH',
    'C<sub>15</sub>H<sub>26</sub>O<sub>2</sub>',
    '',
    '',
    'XZTGVWRBZDBQLP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BCCOH',
    'C<sub>15</sub>H<sub>26</sub>O<sub>2</sub>',
    '',
    '',
    'ALNVAIGKARRJOT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-dihydroxybenzene',
    'C<sub>6</sub>H<sub>4</sub>(OH)<sub>2</sub>',
    'pyrocatechol',
    '120-80-9',
    'YCIMNLLNPGFGHC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dihydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dihydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dihydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dihydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2165'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dihydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dihydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dihydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dihydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dihydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dihydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dihydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dihydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dihydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dihydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '8300',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dihydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7400',
    '?',
    (SELECT id from species WHERE iupac='1,2-dihydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3-dihydroxybenzene',
    'C<sub>6</sub>H<sub>4</sub>(OH)<sub>2</sub>',
    'resorcinol',
    '108-46-3',
    'GHMLBKRAJCXXBS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3-dihydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3-dihydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3-dihydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3-dihydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2165'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,3-dihydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'from2521',
    '2521', 'Value given here as quoted by Hilal et&nbsp;al. (2008).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>4</sup>',
    '6300',
    'X',
    (SELECT id from species WHERE iupac='1,3-dihydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dihydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dihydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dihydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4-dihydroxybenzene',
    'C<sub>6</sub>H<sub>4</sub>(OH)<sub>2</sub>',
    'hydroquinone',
    '123-31-9',
    'QIGBRXMKCJKVMJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-dihydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-dihydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-dihydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-dihydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2165'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-dihydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-dihydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,4-dihydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dihydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dihydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dihydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dihydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dihydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dihydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '8300',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dihydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dihydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7700',
    '?',
    (SELECT id from species WHERE iupac='1,4-dihydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3-benzenetriol',
    'C<sub>6</sub>H<sub>6</sub>O<sub>3</sub>',
    'pyrogallic acid',
    '87-66-1',
    'WQGWDDDVZFFDIG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3-benzenetriol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-benzenetriol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-dihydroxy-3-methylbenzene',
    'C<sub>7</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '488-17-5',
    'PGSWEKYNAOWQDF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dihydroxy-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dihydroxy-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dihydroxy-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ECATECHOL',
    'C<sub>8</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'UUCQGNWZASKXNN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ECATECHOL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ECATECHOL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ECATECHOL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MXYCATECH',
    'C<sub>8</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'YGLVLWAMIJMBPF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYCATECH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYCATECH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYCATECH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OXYCATECH',
    'C<sub>8</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'RYHGQTREHREIBC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYCATECH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYCATECH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYCATECH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PXYCATECH',
    'C<sub>8</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'RGUZWBOJHNWZOK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYCATECH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYCATECH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYCATECH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPCATECHOL',
    'C<sub>9</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'XLZHGKDRKSKCAU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPCATECHOL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPCATECHOL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPCATECHOL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:METCATECH',
    'C<sub>9</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'IFERDVOUSBGAOD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METCATECH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METCATECH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METCATECH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OETCATECH',
    'C<sub>9</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'QTXIMHKRKLVXRS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OETCATECH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OETCATECH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OETCATECH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PCATECHOL',
    'C<sub>9</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'GOZVFLWHGAXTPA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PCATECHOL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PCATECHOL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PCATECHOL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PETCATECH',
    'C<sub>9</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'WVRWBYUJPWRFQO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PETCATECH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PETCATECH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PETCATECH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:T123CATECH',
    'C<sub>9</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'DEIKGXRMQUHZJD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:T123CATECH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:T123CATECH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:T123CATECH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:T124CATECH',
    'C<sub>9</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'NZEZVJPYSAXNTR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:T124CATECH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:T124CATECH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:T124CATECH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dihydroxynaphthalene',
    'C<sub>10</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '92-44-4',
    'JRNGUTKWMSBIBF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3-dihydroxynaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hexylresorcinol',
    'C<sub>12</sub>H<sub>18</sub>O<sub>2</sub>',
    '',
    '136-77-6',
    'WFJIVOKAWHGMBH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexylresorcinol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6-bis(1,1-dimethylethyl)phenol',
    'C<sub>14</sub>H<sub>22</sub>O',
    '',
    '128-39-2',
    'DKCPKDPYUFEZCP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-bis(1,1-dimethylethyl)phenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-(1-methyl-1-phenylethyl)phenol',
    'C<sub>15</sub>H<sub>16</sub>O',
    '',
    '599-64-4',
    'QBDSZLJBMIMQRS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-(1-methyl-1-phenylethyl)phenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3088-EPI-Suite',
    '', 'Calculated using the EPI Suite method at <a href="https://www.epa.gov/tsca-screening-tools/epi-suitetm-estimation-program-interface"><tt>https://www.epa.gov/tsca-screening-tools/epi-suitetm-estimation-program-interface</tt></a> (last access: 18 September 2023).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3''-tetrahydro-3,3,3'',3''-tetramethyl-1,1''-spirobi(1H-indene)-6,6''-diol',
    'C<sub>21</sub>H<sub>24</sub>O<sub>2</sub>',
    '',
    '1568-80-5',
    'SICLLPHPVFCNTJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3''-tetrahydro-3,3,3'',3''-tetramethyl-1,1''-spirobi(1H-indene)-6,6''-diol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3''-tetrahydro-3,3,3'',3''-tetramethyl-1,1''-spirobi(1H-indene)-6,6''-diol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3''-tetrahydro-3,3,3'',3''-tetramethyl-1,1''-spirobi(1H-indene)-6,6''-diol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3''-tetrahydro-3,3,3'',3''-tetramethyl-1,1''-spirobi(1H-indene)-6,6''-diol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,4''-(3,3,5-trimethylcyclohexane-1,1-diyl)diphenol',
    'C<sub>21</sub>H<sub>26</sub>O<sub>2</sub>',
    '',
    '129188-99-4',
    'UMPGNGRIGSEMTC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4''-(3,3,5-trimethylcyclohexane-1,1-diyl)diphenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4''-(3,3,5-trimethylcyclohexane-1,1-diyl)diphenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4''-(3,3,5-trimethylcyclohexane-1,1-diyl)diphenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4''-(3,3,5-trimethylcyclohexane-1,1-diyl)diphenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3,3'',3''-tetramethyl-1,1''-spirobi(indan)-5,5'',6,6''-tetrol',
    'C<sub>21</sub>H<sub>24</sub>O<sub>4</sub>',
    '',
    '77-08-7',
    'POFMQEVZKZVAPQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>14</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,3'',3''-tetramethyl-1,1''-spirobi(indan)-5,5'',6,6''-tetrol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,3'',3''-tetramethyl-1,1''-spirobi(indan)-5,5'',6,6''-tetrol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,3'',3''-tetramethyl-1,1''-spirobi(indan)-5,5'',6,6''-tetrol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,3'',3''-tetramethyl-1,1''-spirobi(indan)-5,5'',6,6''-tetrol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '9,9-bis(4-hydroxyphenyl)fluorene',
    'C<sub>25</sub>H<sub>18</sub>O<sub>2</sub>',
    '',
    '3236-71-3',
    'YWFPGFJLYRKYJZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polyols (R(OH)<sub>n</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='9,9-bis(4-hydroxyphenyl)fluorene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='9,9-bis(4-hydroxyphenyl)fluorene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='9,9-bis(4-hydroxyphenyl)fluorene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='9,9-bis(4-hydroxyphenyl)fluorene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Peroxides (ROOH) and peroxy radicals (ROO)',
    (SELECT id from categories WHERE catname='Organic species with oxygen (O)'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl hydroperoxide',
    'CH<sub>3</sub>OOH',
    'methyl peroxide',
    '3031-73-0',
    'MEUKEBNAABNAEX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '5300',
    'L',
    (SELECT id from species WHERE iupac='methyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '5300',
    'L',
    (SELECT id from species WHERE iupac='methyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '5200',
    'L',
    (SELECT id from species WHERE iupac='methyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9',
    '5200',
    'L',
    (SELECT id from species WHERE iupac='methyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='2828'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '5300',
    'L',
    (SELECT id from species WHERE iupac='methyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '5300',
    'L',
    (SELECT id from species WHERE iupac='methyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '5300',
    'L',
    (SELECT id from species WHERE iupac='methyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '4400',
    'M',
    (SELECT id from species WHERE iupac='methyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='2913'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 6.9',
    '',
    'M',
    (SELECT id from species WHERE iupac='methyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='844'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '844',
    '', 'Value for the temperature range from 261&nbsp;K to 281&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='844'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='1200'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'at278K',
    '', 'Value at T = 278&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at278K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '5200',
    'M',
    (SELECT id from species WHERE iupac='methyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='516'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '5300',
    'M',
    (SELECT id from species WHERE iupac='methyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='311'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='311'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6200',
    'Q',
    (SELECT id from species WHERE iupac='methyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5200',
    '?',
    (SELECT id from species WHERE iupac='methyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyl hydroperoxide',
    'C<sub>2</sub>H<sub>5</sub>OOH',
    'ethyl peroxide',
    '3031-74-1',
    'ILHIHKRJJMKBEE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3',
    '6000',
    'L',
    (SELECT id from species WHERE iupac='ethyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3',
    '6000',
    'L',
    (SELECT id from species WHERE iupac='ethyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3',
    '6000',
    'L',
    (SELECT id from species WHERE iupac='ethyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3',
    '6000',
    'L',
    (SELECT id from species WHERE iupac='ethyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='1200'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at278K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3',
    '6000',
    'M',
    (SELECT id from species WHERE iupac='ethyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='516'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6600',
    'Q',
    (SELECT id from species WHERE iupac='ethyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6000',
    '?',
    (SELECT id from species WHERE iupac='ethyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hydroxymethyl hydroperoxide',
    'HOCH<sub>2</sub>OOH',
    'HMHP; HMP',
    '15932-89-5',
    'NEZWFWIACBUQMN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '9900',
    'L',
    (SELECT id from species WHERE iupac='hydroxymethyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '9900',
    'L',
    (SELECT id from species WHERE iupac='hydroxymethyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '9900',
    'L',
    (SELECT id from species WHERE iupac='hydroxymethyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '9900',
    'L',
    (SELECT id from species WHERE iupac='hydroxymethyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '10000',
    'L',
    (SELECT id from species WHERE iupac='hydroxymethyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '9700',
    'M',
    (SELECT id from species WHERE iupac='hydroxymethyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='516'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '10000',
    'M',
    (SELECT id from species WHERE iupac='hydroxymethyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='799'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>3</sup>',
    '1500',
    'M',
    (SELECT id from species WHERE iupac='hydroxymethyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='800'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydroxymethyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydroxymethyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydroxymethyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '8600',
    'Q',
    (SELECT id from species WHERE iupac='hydroxymethyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '10000',
    '?',
    (SELECT id from species WHERE iupac='hydroxymethyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bis-(hydroxymethyl)-peroxide',
    'HOCH<sub>2</sub>OOCH<sub>2</sub>OH',
    'BHMP',
    '17088-73-2',
    'JLJXMZMKMRQOLN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 9.9&times;10<sup>4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='bis-(hydroxymethyl)-peroxide'),
    (SELECT id from literature WHERE bibtexkey='799'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>3</sup>',
    '8400',
    'M',
    (SELECT id from species WHERE iupac='bis-(hydroxymethyl)-peroxide'),
    (SELECT id from literature WHERE bibtexkey='800'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '9400',
    'Q',
    (SELECT id from species WHERE iupac='bis-(hydroxymethyl)-peroxide'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '8500',
    '?',
    (SELECT id from species WHERE iupac='bis-(hydroxymethyl)-peroxide'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>tert</i>-butyl hydroperoxide',
    'C<sub>4</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '75-91-2',
    'CIHOLLKRGTVIJN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>tert</i>-butyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>tert</i>-butyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>tert</i>-butyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>tert</i>-butyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'di-<i>tert</i>-butylperoxide',
    'C<sub>8</sub>H<sub>18</sub>O<sub>2</sub>',
    '',
    '110-05-4',
    'LSXWFXONGKSEMY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='di-<i>tert</i>-butylperoxide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='di-<i>tert</i>-butylperoxide'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='di-<i>tert</i>-butylperoxide'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-1-phenylethylhydroperoxide',
    'C<sub>9</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '80-15-9',
    'YQHLDYVWEZKEOX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-methyl-1-phenylethylhydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-methyl-1-phenylethylhydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-1-phenylethylhydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-1-phenylethylhydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-1-phenylethylhydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-1-phenylethylhydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-1-phenylethylhydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-1-phenylethylhydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dicumyl peroxide',
    'C<sub>18</sub>H<sub>22</sub>O<sub>2</sub>',
    '',
    '80-43-3',
    'XMNIXWIUMCBBBL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dicumyl peroxide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methylperoxy radical',
    'CH<sub>3</sub>OO',
    '',
    '2143-58-0',
    'WTFNSXYULBQCQV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '3700',
    'E',
    (SELECT id from species WHERE iupac='methylperoxy radical'),
    (SELECT id from literature WHERE bibtexkey='1442'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '1442',
    '1442', 'Leriche et&nbsp;al. (2000) assume H<sub>s</sub>(ROO) = H<sub>s</sub>(ROOH) &times;H<sub>s</sub>(HO<sub>2</sub>) / H<sub>s</sub>(H<sub>2</sub>O<sub>2</sub>).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1442'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'E',
    (SELECT id from species WHERE iupac='methylperoxy radical'),
    (SELECT id from literature WHERE bibtexkey='31'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '31CH3OO',
    '31', 'Lelieveld and Crutzen (1991) assume H<sub>s</sub>(CH<sub>3</sub>OO) = H<sub>s</sub>(HO<sub>2</sub>).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='31CH3OO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;2</sup>',
    '5600',
    'E',
    (SELECT id from species WHERE iupac='methylperoxy radical'),
    (SELECT id from literature WHERE bibtexkey='46'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '46CH3OO',
    '46', 'Jacob (1986) assumes H<sub>s</sub>(CH<sub>3</sub>OO) = H<sub>s</sub>(CH<sub>3</sub>OOH) &times;H<sub>s</sub>(HO<sub>2</sub>) / H<sub>s</sub>(H<sub>2</sub>O<sub>2</sub>).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='46CH3OO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hydroxymethylperoxy radical',
    'HOCH<sub>2</sub>OO',
    '',
    '27828-51-9',
    'OLHGCLQZCFQBGO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>2</sup>',
    '8200',
    'E',
    (SELECT id from species WHERE iupac='hydroxymethylperoxy radical'),
    (SELECT id from literature WHERE bibtexkey='1442'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1442'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'peroxyacetyl radical',
    'CH<sub>3</sub>C(O)O<sub>2</sub>',
    '',
    '36709-10-1',
    'ZBQKPDHUDKSCRS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&lt; 9.9&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='peroxyacetyl radical'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&lt; 9.9&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='peroxyacetyl radical'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&lt; 9.9&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='peroxyacetyl radical'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&lt; 9.9&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='peroxyacetyl radical'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&lt; 9.9&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='peroxyacetyl radical'),
    (SELECT id from literature WHERE bibtexkey='995'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ACO3H',
    'C<sub>3</sub>H<sub>4</sub>O<sub>3</sub>',
    '',
    '',
    'AZIQALWHRUQPHV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IC3H7OOH',
    'C<sub>3</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '',
    'SGJUFIMCHSLMRJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IC3H7OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IC3H7OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IC3H7OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NC3H7OOH',
    'C<sub>3</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '',
    'TURGQPDWYFJEDY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC3H7OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC3H7OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC3H7OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PERPROACID',
    'C<sub>3</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '',
    'CZPZWMPYEINMCF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PERPROACID'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PERPROACID'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PERPROACID'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C3DBCO3H',
    'C<sub>4</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '',
    'TXNBRZBEFMJQMW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3DBCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3DBCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3DBCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IC4H9OOH',
    'C<sub>4</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'FUHWWEDRJKHMKK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IC4H9OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IC4H9OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IC4H9OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MACO3H',
    'C<sub>4</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '',
    'OELQSSWXRGADDE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MACO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MACO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MACO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'IEPOX1CO3H',
    'C<sub>4</sub>H<sub>6</sub>O<sub>5</sub>',
    '',
    '',
    'DJPWYFXNRMHUNU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>2</sup>',
    '14000',
    'Q',
    (SELECT id from species WHERE iupac='IEPOX1CO3H'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NC4H9OOH',
    'C<sub>4</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'AKUNSTOMHUXJOZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC4H9OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC4H9OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC4H9OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PERBUACID',
    'C<sub>4</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'LBAYFEDWGHXMSM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PERBUACID'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PERBUACID'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PERBUACID'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PERIBUACID',
    'C<sub>4</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'LVQKOPBJHBWELS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PERIBUACID'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PERIBUACID'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PERIBUACID'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:SC4H9OOH',
    'C<sub>4</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'SPQMVUPFYWDFCB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:SC4H9OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:SC4H9OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:SC4H9OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BUT2CO3H',
    'C<sub>5</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'LWBFPIVRZGBOFS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BUT2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BUT2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BUT2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C3ME3CO3H',
    'C<sub>5</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'GTLLKMCVRPVGBK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3ME3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3ME3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3ME3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPEAOOH',
    'C<sub>5</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'HIHRAMNMOMKJDG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPEAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPEAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPEAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPEBOOH',
    'C<sub>5</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'VIUWCQFVAFABHL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPEBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPEBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPEBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPECOOH',
    'C<sub>5</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'XRXANEMIFVRKLN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPECOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPECOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPECOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NEOPOOH',
    'C<sub>5</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'UEQURRFROJBOLG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NEOPOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NEOPOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NEOPOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PEAOOH',
    'C<sub>5</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'KCHNMIKAMRQBHD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PEAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PEAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PEAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PEBOOH',
    'C<sub>5</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'XRIRVAYMWUMXBR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PEBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PEBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PEBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PECOOH',
    'C<sub>5</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'RLBQWRSRDVXRTJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PECOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PECOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PECOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PERPENACID',
    'C<sub>5</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'UQGPCEVQKLOLLM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PERPENACID'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PERPENACID'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PERPENACID'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TBUTCO3H',
    'C<sub>5</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'YVAACGXAZGGQSM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TBUTCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TBUTCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TBUTCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'C520OOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>7</sub>',
    '',
    '',
    'GRPDYNZWDDUILX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>11</sup>',
    '22000',
    'Q',
    (SELECT id from species WHERE iupac='C520OOH'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'C518OOH',
    'C<sub>5</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'PQEISBQMLHJHJQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>4</sup>',
    '14000',
    'Q',
    (SELECT id from species WHERE iupac='C518OOH'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C54CO3H',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'JTSRVXQXWWOTER-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C54CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C54CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C54CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5H11CO3H',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'NQUPKCJGWCPODR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5H11CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5H11CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5H11CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ROO6R7OOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'UPAWKBDHGPWUCG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>7</sup>',
    '14000',
    'Q',
    (SELECT id from species WHERE iupac='ROO6R7OOH'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ROO6R6OOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'QZPUZDFJKAEVLL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>8</sup>',
    '14000',
    'Q',
    (SELECT id from species WHERE iupac='ROO6R6OOH'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'C624OOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>6</sub>',
    '',
    '',
    'FUTSLQULSAKEJA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>13</sup>',
    '20000',
    'Q',
    (SELECT id from species WHERE iupac='C624OOH'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CHEXOOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'FGGJBCRKSVGDPO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHEXOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHEXOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHEXOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HEXAOOH',
    'C<sub>6</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '',
    'RZICEOJUAFHYFO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEXAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEXAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEXAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HEXBOOH',
    'C<sub>6</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '',
    'XWXUHAUZCICPHE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '7300',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEXBOOH'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEXBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEXBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEXBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HEXCOOH',
    'C<sub>6</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '',
    'NMNOLZYZNVYLRJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEXCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEXCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEXCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:M22C3CO3H',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'RQLGMECUXRQENU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M22C3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M22C3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M22C3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:M22C43OOH',
    'C<sub>6</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '',
    'XDWQBMWWYOVNSC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M22C43OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M22C43OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M22C43OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:M22C4OOH',
    'C<sub>6</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '',
    'VWOCCXGIWJLCIT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M22C4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M22C4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M22C4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:M23C43OOH',
    'C<sub>6</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '',
    'UPTQBPSUWRBZRD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M23C43OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M23C43OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M23C43OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:M23C4OOH',
    'C<sub>6</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '',
    'MCTQHWIBGOKRHO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M23C4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M23C4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M23C4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:M2C43CO3H',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'KGAQRBNLHLEGET-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2C43CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2C43CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2C43CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:M2PEAOOH',
    'C<sub>6</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '',
    'OTKKOLXSCMINFN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2PEAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2PEAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2PEAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:M2PEBOOH',
    'C<sub>6</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '',
    'XHHITPKXZQXJIC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2PEBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2PEBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2PEBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:M2PECOOH',
    'C<sub>6</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '',
    'JBJSMFBSVBRLAK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2PECOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2PECOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2PECOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:M2PEDOOH',
    'C<sub>6</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '',
    'BZGMEGUFFDTCNP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2PEDOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2PEDOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2PEDOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:M33C3CO3H',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'IHLWWYDUPGXTHJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M33C3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M33C3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M33C3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:M33C4OOH',
    'C<sub>6</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '',
    'OUMLJDCULPJYHU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M33C4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M33C4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M33C4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:M3C4CO3H',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'CHSVHHKRTQKZCN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M3C4CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M3C4CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M3C4CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:M3PEAOOH',
    'C<sub>6</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '',
    'AOZFMIRWQXSLHO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M3PEAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M3PEAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M3PEAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:M3PEBOOH',
    'C<sub>6</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '',
    'XCSSHHOKPSJZJS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M3PEBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M3PEBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M3PEBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:M3PECOOH',
    'C<sub>6</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '',
    'BWMWVYKKWYNWMF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M3PECOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M3PECOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M3PECOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ROO6R5OOH',
    'C<sub>7</sub>H<sub>12</sub>O<sub>6</sub>',
    '',
    '',
    'RAASFOSVQCCDRJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>7</sup>',
    '16000',
    'Q',
    (SELECT id from species WHERE iupac='ROO6R5OOH'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6H13CO3H',
    'C<sub>7</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'GLAYRDYYNSCSPO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6H13CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6H13CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6H13CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HEPTOOH',
    'C<sub>7</sub>H<sub>16</sub>O<sub>2</sub>',
    '',
    '',
    'RCPMMXGHMBPBLI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEPTOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEPTOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEPTOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:M2HEXAOOH',
    'C<sub>7</sub>H<sub>16</sub>O<sub>2</sub>',
    '',
    '',
    'MZRXBNCEXTUOSL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2HEXAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2HEXAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2HEXAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:M2HEXBOOH',
    'C<sub>7</sub>H<sub>16</sub>O<sub>2</sub>',
    '',
    '',
    'VERXWMXNIBWXFV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2HEXBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2HEXBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2HEXBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:M3HEXAOOH',
    'C<sub>7</sub>H<sub>16</sub>O<sub>2</sub>',
    '',
    '',
    'SLXXGGKZGKGOKQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M3HEXAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M3HEXAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M3HEXAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:M3HEXBOOH',
    'C<sub>7</sub>H<sub>16</sub>O<sub>2</sub>',
    '',
    '',
    'YDBMAIVJCSJSKQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M3HEXBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M3HEXBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M3HEXBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methylhexyl hydroperoxide',
    'C<sub>7</sub>H<sub>16</sub>O<sub>2</sub>',
    'C7H15O2H',
    '762-46-9',
    'FWELUXZVATZEMI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;1</sup>',
    '7600',
    'Q',
    (SELECT id from species WHERE iupac='1-methylhexyl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'C7OHOOH',
    'C<sub>7</sub>H<sub>16</sub>O<sub>3</sub>',
    '',
    '',
    'KHWIBANUCNWWGW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>3</sup>',
    '12000',
    'Q',
    (SELECT id from species WHERE iupac='C7OHOOH'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C8BCOOH',
    'C<sub>8</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '',
    'TWXDGALDAWYAQL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8BCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8BCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8BCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OCTOOH',
    'C<sub>8</sub>H<sub>18</sub>O<sub>2</sub>',
    '',
    '',
    'PXUMFRDGKQLDGL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OCTOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OCTOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OCTOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methylheptl hydroperoxide',
    'C<sub>8</sub>H<sub>18</sub>O<sub>2</sub>',
    'C8H17O2H',
    '',
    'NAXZMRYIZGEALQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;1</sup>',
    '8000',
    'Q',
    (SELECT id from species WHERE iupac='1-methylheptl hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'C8OHOOH',
    'C<sub>8</sub>H<sub>18</sub>O<sub>3</sub>',
    '',
    '',
    'QQTSMKQYSKGCOU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>3</sup>',
    '12000',
    'Q',
    (SELECT id from species WHERE iupac='C8OHOOH'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NONOOH',
    'C<sub>9</sub>H<sub>20</sub>O<sub>2</sub>',
    '',
    '',
    'BXPIMWLPPYUCSQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NONOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NONOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NONOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DECOOH',
    'C<sub>10</sub>H<sub>22</sub>O<sub>2</sub>',
    '',
    '',
    'MPMVWDJTKHXCAN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DECOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DECOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DECOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'C5H112O2H',
    'C<sub>10</sub>H<sub>22</sub>O<sub>4</sub>',
    '',
    '',
    'AXIHYONNAPPFSO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '7000',
    'Q',
    (SELECT id from species WHERE iupac='C5H112O2H'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'LIMAB15OOH2',
    'C<sub>10</sub>H<sub>20</sub>O<sub>6</sub>',
    '',
    '',
    'IRUZCTPAAZATQM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>12</sup>',
    '20000',
    'Q',
    (SELECT id from species WHERE iupac='LIMAB15OOH2'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'RO5R1O2H',
    'C<sub>10</sub>H<sub>18</sub>O<sub>4</sub>',
    '',
    '',
    'NSOHXIGSWKLSHV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>5</sup>',
    '17000',
    'Q',
    (SELECT id from species WHERE iupac='RO5R1O2H'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'RO5R2O2H',
    'C<sub>10</sub>H<sub>18</sub>O<sub>5</sub>',
    '',
    '',
    'MFXJOKCSTDMZRM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>7</sup>',
    '19000',
    'Q',
    (SELECT id from species WHERE iupac='RO5R2O2H'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ROO6R1OOH',
    'C<sub>10</sub>H<sub>18</sub>O<sub>5</sub>',
    '',
    '',
    'GBBPAXKBVMQHIG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>4</sup>',
    '16000',
    'Q',
    (SELECT id from species WHERE iupac='ROO6R1OOH'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'RO5R3O2H',
    'C<sub>10</sub>H<sub>18</sub>O<sub>6</sub>',
    '',
    '',
    'IEPFJXDIWPQIRC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>7</sup>',
    '22000',
    'Q',
    (SELECT id from species WHERE iupac='RO5R3O2H'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:UDECOOH',
    'C<sub>11</sub>H<sub>24</sub>O<sub>2</sub>',
    '',
    '',
    'PPEGYVQDERYKNI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:UDECOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:UDECOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:UDECOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DDECOOH',
    'C<sub>12</sub>H<sub>26</sub>O<sub>2</sub>',
    '',
    '',
    'ONWAGJMEBPWHEG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DDECOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DDECOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DDECOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6H5OOH',
    'C<sub>6</sub>H<sub>6</sub>O<sub>2</sub>',
    '',
    '',
    'JYINMLPNDRBKKZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6H5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6H5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6H5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6H5CH2OOH',
    'C<sub>7</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '',
    'YVJRCWCFDJYONJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6H5CH2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6H5CH2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6H5CH2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6H5CO3H',
    'C<sub>7</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '',
    'XCRBXWCUXJNEFX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6H5CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6H5CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6H5CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MXYL1OOH',
    'C<sub>7</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '',
    'VCTGBWYTEXZDNM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYL1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYL1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYL1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OXYL1OOH',
    'C<sub>7</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '',
    'OCSKWYCRTWOMLG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYL1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYL1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYL1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PXYL1OOH',
    'C<sub>7</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '',
    'ZCUUEQJCOSBJOR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYL1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYL1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYL1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6H5C2CO3H',
    'C<sub>8</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'BXGXGTXWGGOFSP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6H5C2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6H5C2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6H5C2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6H5C2OOH',
    'C<sub>8</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'VZQOBPXGQJXYGY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6H5C2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6H5C2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6H5C2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DM123OOH',
    'C<sub>8</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'FPXURWFXMHYDGM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DM123OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DM123OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DM123OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DM124OOH',
    'C<sub>8</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'UQJVEYMRRMOLPI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DM124OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DM124OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DM124OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DMPHOOH',
    'C<sub>8</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'AGQLZSPEKWKXRP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMPHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMPHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMPHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EBENZOOH',
    'C<sub>8</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'SULLUHFYVRLICT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBENZOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBENZOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBENZOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MXY1OOH',
    'C<sub>8</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'LDNGPDBEDBLXJS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXY1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXY1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXY1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MXYLCO3H',
    'C<sub>8</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'INFFZTZRGNVBOC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYLCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYLCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYLCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MXYLOOH',
    'C<sub>8</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'UTKFWOZXPFIBPQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OXYLCO3H',
    'C<sub>8</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'DNEXRQSSNZPAJJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYLCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYLCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYLCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OXYLOOH',
    'C<sub>8</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'JTJQZHCBMBJJMV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PXY1OOH',
    'C<sub>8</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'QBGYVNGBYXOUAG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXY1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXY1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXY1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PXYLCO3H',
    'C<sub>8</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'IFDPVSBDNAQBRQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYLCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYLCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYLCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PXYLOOH',
    'C<sub>8</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'VCEHMDXCOGIOJJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EMPHOOH',
    'C<sub>9</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'MKWUSWBHCPKVBI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EMPHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EMPHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EMPHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ETOLOOH',
    'C<sub>9</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'DWPOLKIWKCGPAM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPBENZOOH',
    'C<sub>9</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'CZNJIWCDRJWKLG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBENZOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBENZOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBENZOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MET1OOH',
    'C<sub>9</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'HUAUUZDXRNWOSS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MET1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MET1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MET1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OET1OOH',
    'C<sub>9</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'KVZSMDLRNLVTLK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OET1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OET1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OET1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PBENZOOH',
    'C<sub>9</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'BFUPNGCSYHWOOH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBENZOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBENZOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBENZOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PET1OOH',
    'C<sub>9</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'IKLGQZOVXYBNEV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PET1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PET1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PET1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PHC3OOH',
    'C<sub>9</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'JYLUDNGUBXOJPX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PHC3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PHC3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PHC3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TM123BCO3H',
    'C<sub>9</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'NQSDUJYDMWXHMR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM123BCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM123BCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM123BCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TM123BOOH',
    'C<sub>9</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'HSKYDUVZGAHSEO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM123BOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM123BOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM123BOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TM123OOH',
    'C<sub>9</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'QIIZMGNSXSJCNA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM123OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM123OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM123OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TM124BCO3H',
    'C<sub>9</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'HPLBJCPAWPQKDU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124BCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124BCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124BCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TM124BOOH',
    'C<sub>9</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'ZUEBLWOBXMLPMV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124BOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124BOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124BOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TM124OOH',
    'C<sub>9</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'DSGKIBNJTLHQCN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TMBCO3H',
    'C<sub>9</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'APDYULOMODUXLL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TMBCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TMBCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TMBCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TMBOOH',
    'C<sub>9</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'GOKTXPLVCSLYGI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TMBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TMBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TMBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DM35EBOOH',
    'C<sub>10</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '',
    'NSJZLSFVHPJVDL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DM35EBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DM35EBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DM35EBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EMPHCO3H',
    'C<sub>10</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'GYXFVTDASBFNQD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EMPHCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EMPHCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EMPHCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DE35TOOH',
    'C<sub>11</sub>H<sub>16</sub>O<sub>2</sub>',
    '',
    '',
    'HPTJZRKCFIXEOP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DE35TOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DE35TOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DE35TOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HOCH2CO3H',
    'C<sub>2</sub>H<sub>4</sub>O<sub>4</sub>',
    '',
    '',
    'IUEZWLCUORJBDZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOCH2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOCH2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOCH2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HYETHO2H',
    'C<sub>2</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '',
    'FKPAKAOEHCFKLE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HYETHO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HYETHO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HYETHO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C2OHOCOOH',
    'C<sub>3</sub>H<sub>6</sub>O<sub>5</sub>',
    '',
    '',
    'GTTVGDRVLZEEEW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C2OHOCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C2OHOCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C2OHOCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C3DIOLOOH',
    'C<sub>3</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'XSLBWJPPWWFTQY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3DIOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3DIOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3DIOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO1C3OOH',
    'C<sub>3</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'LTKFKDLZMYUGKU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO1C3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO1C3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO1C3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HOC2H4CO3H',
    'C<sub>3</sub>H<sub>6</sub>O<sub>4</sub>',
    '',
    '',
    'HPIZQAHZLDXVRM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOC2H4CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOC2H4CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOC2H4CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HYPROPO2H',
    'C<sub>3</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'CGHALRGHFXEMJB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HYPROPO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HYPROPO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HYPROPO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPROPOLO2H',
    'C<sub>3</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'LGTUXDWECPSIQO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPROPOLO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPROPOLO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPROPOLO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPROPOLPER',
    'C<sub>3</sub>H<sub>6</sub>O<sub>4</sub>',
    '',
    '',
    'LLWVBKQQPPRNEX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPROPOLPER'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPROPOLPER'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPROPOLPER'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BUT2OLOOH',
    'C<sub>4</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'VRQPOZSYDWHVQK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BUT2OLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BUT2OLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BUT2OLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BUTDAOOH',
    'C<sub>4</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'ATNKTSDVMCPWQK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BUTDAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BUTDAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BUTDAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BUTDBOOH',
    'C<sub>4</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'VQGAWAMXUXLZCZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BUTDBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BUTDBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BUTDBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BUTDCOOH',
    'C<sub>4</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'TVUDLONEIXNOQY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BUTDCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BUTDCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BUTDCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HC3CCO3H',
    'C<sub>4</sub>H<sub>6</sub>O<sub>4</sub>',
    '',
    '',
    'ZSVMRAYUVFDTKB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HC3CCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HC3CCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HC3CCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HC3CO3H',
    'C<sub>4</sub>H<sub>6</sub>O<sub>4</sub>',
    '',
    '',
    'AVWVUWGQXKTDKD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HC3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HC3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HC3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HMACO3H',
    'C<sub>4</sub>H<sub>6</sub>O<sub>4</sub>',
    '',
    '',
    'IZGOVIKWSGSSGB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HMACO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HMACO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HMACO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO13C3CO3H',
    'C<sub>4</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'SAVJJQFYFPVKTL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO13C3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO13C3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO13C3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO13C4OOH',
    'C<sub>4</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'WTIWPVYZJGYFOG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO13C4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO13C4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO13C4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO1C4OOH',
    'C<sub>4</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'RCPPCOTVBKCJGX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO1C4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO1C4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO1C4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO2C3CO3H',
    'C<sub>4</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'WSXMRWGMMYXEOT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO2C4OOH',
    'C<sub>4</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'VJLLYXNZUMWUFH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO3C3CO3H',
    'C<sub>4</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'BPXTXQLLUZFFNC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO3C4OOH',
    'C<sub>4</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'RMYCTZOJULYKEL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HOC3H6CO3H',
    'C<sub>4</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'CAGKPIQTEWLESW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOC3H6CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOC3H6CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOC3H6CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HOIPRCO3H',
    'C<sub>4</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'XMJMNOOOSJCSST-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOIPRCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOIPRCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOIPRCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IBUTOLBO2H',
    'C<sub>4</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'NCECNUIKMRTTTQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IBUTOLBO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IBUTOLBO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IBUTOLBO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IBUTOLCO2H',
    'C<sub>4</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'IYIYQILWOLBTBM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IBUTOLCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IBUTOLCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IBUTOLCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPRHOCO3H',
    'C<sub>4</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'VAHIZEUROSIQMC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRHOCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRHOCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRHOCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NBUTOLAOOH',
    'C<sub>4</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'KPUCJKMFRKKADT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBUTOLAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBUTOLAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBUTOLAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NBUTOLBOOH',
    'C<sub>4</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'UKXKMFPUVLQYHV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBUTOLBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBUTOLBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBUTOLBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TBUTOLOOH',
    'C<sub>4</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'OLMJQPVPWWPTBW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TBUTOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TBUTOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TBUTOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C3M3OHCO3H',
    'C<sub>5</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'OPXDDGDNASPZKO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3M3OHCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3M3OHCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3M3OHCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C42CO3H',
    'C<sub>5</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'ZMIMRJOKAFWNST-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C42CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C42CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C42CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C46CO3H',
    'C<sub>5</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'VWNMYJVYTYSNQP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C46CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C46CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C46CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4OH2CO3H',
    'C<sub>5</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'WQUIEUVQOLAPHC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4OH2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4OH2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4OH2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4OHCO3H',
    'C<sub>5</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'OQVSVCDIVLTQNI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4OHCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4OHCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4OHCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C51OH2OOH',
    'C<sub>5</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'YEVLRKKUVOPQLT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C51OH2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C51OH2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C51OH2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C524OOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'CMYVSBWTXHBCDK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C524OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C524OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C524OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C52OH1OOH',
    'C<sub>5</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'UCQFCLCUMHUGLJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C52OH1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C52OH1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C52OH1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C52OH3OOH',
    'C<sub>5</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'HJJMDLGJAJYCSL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C52OH3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C52OH3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C52OH3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C52OOH',
    'C<sub>5</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'ZPHQYWRKWRKGNS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C52OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C52OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C52OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C53OH2OOH',
    'C<sub>5</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'AJVYEIIRONFKES-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C53OH2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C53OH2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C53OH2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C54OOH',
    'C<sub>5</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'YUSGXJKDHCBGQE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C54OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C54OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C54OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C56OOH',
    'C<sub>5</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'ZJCLGCDNIIJGCW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C56OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C56OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C56OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H13C43CO3H',
    'C<sub>5</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'AHAADFOLDXPWKJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H13C43CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H13C43CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H13C43CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H2M2C3CO3H',
    'C<sub>5</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'WNBRWGLXVYJADJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M2C3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M2C3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M2C3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H2M3C4OOH',
    'C<sub>5</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'ZUPZYIDTDVLJQO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M3C4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M3C4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M3C4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HC4ACO3H',
    'C<sub>5</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'RKJIARBOZVRICG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HC4ACO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HC4ACO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HC4ACO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HC4CCO3H',
    'C<sub>5</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'BKBSBVFBLVOVGK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HC4CCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HC4CCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HC4CCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HM22C3OOH',
    'C<sub>5</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'YTVLHPDOOITGNI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM22C3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM22C3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM22C3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HM22CO3H',
    'C<sub>5</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'JLDURWTXWMLEQQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM22CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM22CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM22CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HM2C43OOH',
    'C<sub>5</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'HSLVQIVCJSWUOZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM2C43OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM2C43OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM2C43OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HM33C3OOH',
    'C<sub>5</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'WHBWUNCJQHRHKD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM33C3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM33C3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM33C3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO13C5OOH',
    'C<sub>5</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'MPQCFHWMMIVYQV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO13C5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO13C5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO13C5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO1C5OOH',
    'C<sub>5</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'NOIFGIIKGVCIDM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO1C5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO1C5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO1C5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO24C4CO3H',
    'C<sub>5</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'BPXJXZFDALRNCD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO24C4CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO24C4CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO24C4CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO24C5OOH',
    'C<sub>5</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'LXCUFKDAZLTFBK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO24C5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO24C5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO24C5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO2C43CO3H',
    'C<sub>5</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'JJSNUFSNLCXQDD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C43CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C43CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C43CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO2C4CO3H',
    'C<sub>5</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'WEYKGJBTAJHRDZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C4CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C4CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C4CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO2C54OOH',
    'C<sub>5</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'NQEGDBNDYHCERX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C54OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C54OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C54OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO2C5OOH',
    'C<sub>5</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'GSRFGQMXWRCOMF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>3</sup>',
    '11000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C5OOH'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO2M2C4OOH',
    'C<sub>5</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'BPHNXEOBBWBBGO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2M2C4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2M2C4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2M2C4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO3C4CO3H',
    'C<sub>5</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'OFXAQZFPCOWEPU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C4CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C4CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C4CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO3C5OOH',
    'C<sub>5</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'AMTQAQGRUCFWLQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HOBUT2CO3H',
    'C<sub>5</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'HHXRGEGWJUDFIW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOBUT2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOBUT2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOBUT2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HOIBUTCO3H',
    'C<sub>5</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'JVGUWDNKCJEDLO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOIBUTCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOIBUTCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOIBUTCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ISOPAOOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'PEJOQVDRQFVMLE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ISOPAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ISOPAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ISOPAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ISOPBOOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'QTGGFXPTAQEODO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '9900',
    'M',
    (SELECT id from species WHERE iupac='MCM:ISOPBOOH'),
    (SELECT id from literature WHERE bibtexkey='3578'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ISOPBOOH'),
    (SELECT id from literature WHERE bibtexkey='3578'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3578-EA',
    '', 'Calculated using EVAPORATION and AIOMFAC.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3578-EA'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ISOPBOOH'),
    (SELECT id from literature WHERE bibtexkey='3578'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3578-GROMHE',
    '', 'Calculated using the GROMHE model.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3578-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ISOPBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ISOPBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ISOPBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ISOPCOOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'FCLDANRCFPUKED-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ISOPCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ISOPCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ISOPCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ISOPDOOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'HYHMYONEYJINON-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '7500',
    'M',
    (SELECT id from species WHERE iupac='MCM:ISOPDOOH'),
    (SELECT id from literature WHERE bibtexkey='3578'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ISOPDOOH'),
    (SELECT id from literature WHERE bibtexkey='3578'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3578-EA'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ISOPDOOH'),
    (SELECT id from literature WHERE bibtexkey='3578'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3578-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ISOPDOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ISOPDOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ISOPDOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:M2BU2OLOOH',
    'C<sub>5</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'YWZMEYHQKKHRJF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2BU2OLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2BU2OLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2BU2OLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:M2BUOL2OOH',
    'C<sub>5</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'KLOVYRXVQOACLZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2BUOL2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2BUOL2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2BUOL2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:M3BU2OLOOH',
    'C<sub>5</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'AFEDOYRLNKBWPZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M3BU2OLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M3BU2OLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M3BU2OLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MBOAOOH',
    'C<sub>5</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'VJEOLZUQMDEVMO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MBOAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MBOAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MBOAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MBOBOOH',
    'C<sub>5</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'GXJWPCHTRDIVHR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MBOBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MBOBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MBOBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ME2BUOLOOH',
    'C<sub>5</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'SAXHQAUHEBEDAO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ME2BUOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ME2BUOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ME2BUOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ME3BUOLOOH',
    'C<sub>5</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'MUYQYONVNPPJGI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ME3BUOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ME3BUOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ME3BUOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PROL11MOOH',
    'C<sub>5</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'UVDGWSPEOVCOFS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PROL11MOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PROL11MOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PROL11MOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PROL1MCO3H',
    'C<sub>5</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'KTQROZYFUGXCGA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PROL1MCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PROL1MCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PROL1MCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BZBIPER2OH',
    'C<sub>6</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'BVNIDXNYDXJAFS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BZBIPER2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BZBIPER2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BZBIPER2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BZBIPEROOH',
    'C<sub>6</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'MXPMOVDECINDPN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BZBIPEROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BZBIPEROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BZBIPEROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4ME2OHOOH',
    'C<sub>6</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'HOGFDWYRBLIMGM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4ME2OHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4ME2OHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4ME2OHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C518CO3H',
    'C<sub>6</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'HLKDNTMYLJJNIF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C518CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C518CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C518CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C622OOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'GWTGWFHICNOSTQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '12000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C622OOH'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C622OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C622OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C622OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C624OOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'DDEGWHJCSBWJSM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C624OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C624OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C624OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C64OH5OOH',
    'C<sub>6</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'ZEOCDIHFKNFYIT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C64OH5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C64OH5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C64OH5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C65OH4OOH',
    'C<sub>6</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'PVVIDEIOKNUTFV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C65OH4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C65OH4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C65OH4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6OH5OOH',
    'C<sub>6</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'HRDCBAWVKIWIOZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6OH5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6OH5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6OH5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CYHXOLAOOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'UBIBQRDHLFTCKX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CYHXOLAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CYHXOLAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CYHXOLAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H13M3C5OOH',
    'C<sub>6</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'KEIPMCKLLYLETP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H13M3C5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H13M3C5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H13M3C5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H1MC5OOH',
    'C<sub>6</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'NRUVZELSEXXOEO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H1MC5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H1MC5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H1MC5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H2M2C4CO3H',
    'C<sub>6</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'NRXKHRBCIJLLIW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M2C4CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M2C4CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M2C4CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H2M3C4CO3H',
    'C<sub>6</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'BSSSRXSGDLZQTD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M3C4CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M3C4CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M3C4CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H2MC5OOH',
    'C<sub>6</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'VFABJBQUVDJTMS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2MC5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2MC5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2MC5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H3M2C4CO3H',
    'C<sub>6</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'BXUACBWFNFVFRM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3M2C4CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3M2C4CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3M2C4CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H3M3C4CO3H',
    'C<sub>6</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'QREFYDOYYWEEBY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3M3C4CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3M3C4CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3M3C4CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H3M3C5OOH',
    'C<sub>6</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'SFWIETIRFCEPBV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3M3C5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3M3C5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3M3C5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HM22C3CO3H',
    'C<sub>6</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'CFTUKLJUHGJIMT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM22C3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM22C3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM22C3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HM22C4OOH',
    'C<sub>6</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'RBKQZGUZSABUAQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM22C4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM22C4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM22C4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HM23C4OOH',
    'C<sub>6</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'OEDZXCCMDSIVQE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM23C4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM23C4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM23C4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HM2C43CO3H',
    'C<sub>6</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'AAGQWOGOWVBCOC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM2C43CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM2C43CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM2C43CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HM33C3CO3H',
    'C<sub>6</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'CJLFHOYFCBYSAF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM33C3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM33C3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM33C3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HM33C4OOH',
    'C<sub>6</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'IRDKGYBPQHNNSI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM33C4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM33C4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM33C4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO1C6OOH',
    'C<sub>6</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'AODLLEVTDATZKZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO1C6OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO1C6OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO1C6OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO1MC5OOH',
    'C<sub>6</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'XFJAYUAZOYAZNW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO1MC5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO1MC5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO1MC5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO2C54CO3H',
    'C<sub>6</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'HFXNQHIGYFOTHL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C54CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C54CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C54CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO2C6OOH',
    'C<sub>6</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'BVOYWPYSMMRYPX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>3</sup>',
    '11000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C6OOH'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C6OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C6OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C6OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO2M2C5OOH',
    'C<sub>6</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'XDJWSJNLVSIJHD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2M2C5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2M2C5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2M2C5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO2MC5OOH',
    'C<sub>6</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'AGNBGPUCVJMPGZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2MC5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2MC5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2MC5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO3C5CO3H',
    'C<sub>6</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'NIDIDJCFEJYKBD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C5CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C5CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C5CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO3C6OOH',
    'C<sub>6</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'WSWZWPBQPMRENX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C6OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C6OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C6OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO4C5CO3H',
    'C<sub>6</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'YRMQNGAQYQCFSB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO4C5CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO4C5CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO4C5CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO5C5CO3H',
    'C<sub>6</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'ZOLITBGWKBFVQG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO5C5CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO5C5CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO5C5CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO5C6OOH',
    'C<sub>6</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'VKWHJFIJUJODAG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO5C6OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO5C6OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO5C6OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PHENOH',
    'C<sub>6</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'JRROYJLQPIXCRD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PHENOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PHENOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PHENOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PHENOOH',
    'C<sub>6</sub>H<sub>8</sub>O<sub>6</sub>',
    '',
    '',
    'WQYYYMQUZFKHHO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>12</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PHENOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PHENOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PHENOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C622CO3H',
    'C<sub>7</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'JSEAPEOJJJOJEL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C622CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C622CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C622CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C624CO3H',
    'C<sub>7</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'VELNAHZLHYPPOS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C624CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C624CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C624CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C720OOH',
    'C<sub>7</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'LPMHECUYQWFTDP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C720OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C720OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C720OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CRESOH',
    'C<sub>7</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'UMHUAUCNJCQCRC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CRESOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CRESOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CRESOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CRESOOH',
    'C<sub>7</sub>H<sub>10</sub>O<sub>6</sub>',
    '',
    '',
    'POYQJFWARUGMBT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CRESOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CRESOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CRESOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H2M2C65OOH',
    'C<sub>7</sub>H<sub>16</sub>O<sub>3</sub>',
    '',
    '',
    'MDRLNEUVCFZYIZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M2C65OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M2C65OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M2C65OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H2M4C65OOH',
    'C<sub>7</sub>H<sub>16</sub>O<sub>3</sub>',
    '',
    '',
    'HGFYTCXFDJYCQF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M4C65OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M4C65OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M4C65OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H2M5C65OOH',
    'C<sub>7</sub>H<sub>16</sub>O<sub>3</sub>',
    '',
    '',
    'NIKXNAUPHRWTEG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M5C65OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M5C65OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M5C65OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H3M3C5CO3H',
    'C<sub>7</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'DTTYYTHTMWEWDN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3M3C5CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3M3C5CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3M3C5CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H3M3C6OOH',
    'C<sub>7</sub>H<sub>16</sub>O<sub>3</sub>',
    '',
    '',
    'IWLJNMJTDMGLQI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3M3C6OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3M3C6OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3M3C6OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO3C76OOH',
    'C<sub>7</sub>H<sub>16</sub>O<sub>3</sub>',
    '',
    '',
    'YDKPOQVDDHNRNK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C76OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C76OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C76OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO5C6CO3H',
    'C<sub>7</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'KSOZMYOJLUVTBJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO5C6CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO5C6CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO5C6CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO6C7OOH',
    'C<sub>7</sub>H<sub>16</sub>O<sub>3</sub>',
    '',
    '',
    'YGTQIECBHSKCOV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO6C7OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO6C7OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO6C7OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TLBIPER2OH',
    'C<sub>7</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'CXEVRKZODGVABW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TLBIPER2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TLBIPER2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TLBIPER2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TLBIPEROOH',
    'C<sub>7</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'JAKOWCUSWIMTAF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TLBIPEROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TLBIPEROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TLBIPEROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EBENZOLOH',
    'C<sub>8</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'BUWSXDLGJSAPEF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBENZOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBENZOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBENZOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EBENZOLOOH',
    'C<sub>8</sub>H<sub>12</sub>O<sub>6</sub>',
    '',
    '',
    'RHHRSXIXEXUGSZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBENZOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBENZOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBENZOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EBZBPER2OH',
    'C<sub>8</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'AUMASFBINMOOAH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBZBPER2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBZBPER2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBZBPER2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EBZBPEROOH',
    'C<sub>8</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'SCDRKAWXSVOIOT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBZBPEROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBZBPEROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBZBPEROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO3C86OOH',
    'C<sub>8</sub>H<sub>18</sub>O<sub>3</sub>',
    '',
    '',
    'SPJZDLLIJATZHB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C86OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C86OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C86OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO6C7CO3H',
    'C<sub>8</sub>H<sub>16</sub>O<sub>4</sub>',
    '',
    '',
    'UKHVIUJOBBSNIJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO6C7CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO6C7CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO6C7CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO7C8OOH',
    'C<sub>8</sub>H<sub>18</sub>O<sub>3</sub>',
    '',
    '',
    'NDXYTTLTSMWWGD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO7C8OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO7C8OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO7C8OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MXYBPER2OH',
    'C<sub>8</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'HJWPGRMMUKJUOW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYBPER2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYBPER2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYBPER2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MXYBPEROOH',
    'C<sub>8</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'JLBHNTWNBASURB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYBPEROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYBPEROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYBPEROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MXYOLOH',
    'C<sub>8</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'HYWULKMMJLAVGS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MXYOLOOH',
    'C<sub>8</sub>H<sub>12</sub>O<sub>6</sub>',
    '',
    '',
    'GRFXDNYNQVBVKX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OXYBPER2OH',
    'C<sub>8</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'VCLGCGXZSIRZEA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYBPER2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYBPER2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYBPER2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OXYBPEROOH',
    'C<sub>8</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'AMPOFIFBYJNSOH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYBPEROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYBPEROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYBPEROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OXYOLOH',
    'C<sub>8</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'CAIZPBLFMULAII-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OXYOLOOH',
    'C<sub>8</sub>H<sub>12</sub>O<sub>6</sub>',
    '',
    '',
    'QYYRJAPHRBSJOE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PXYBPER2OH',
    'C<sub>8</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'IOEDFCIBQPWSMP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYBPER2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYBPER2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYBPER2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PXYBPEROOH',
    'C<sub>8</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'LZVOCZWDZPUJRQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYBPEROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYBPEROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYBPEROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PXYOLOH',
    'C<sub>8</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'YSBIHFSZRPVTOU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PXYOLOOH',
    'C<sub>8</sub>H<sub>12</sub>O<sub>6</sub>',
    '',
    '',
    'ROOFTVJQSDLVOJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO3C96OOH',
    'C<sub>9</sub>H<sub>20</sub>O<sub>3</sub>',
    '',
    '',
    'GGTTUTGCXALAOI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C96OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C96OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C96OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO7C8CO3H',
    'C<sub>9</sub>H<sub>18</sub>O<sub>4</sub>',
    '',
    '',
    'LZPDGAGYXQEGIA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO7C8CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO7C8CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO7C8CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO8C9OOH',
    'C<sub>9</sub>H<sub>20</sub>O<sub>3</sub>',
    '',
    '',
    'DDKPTZKAQLYQQK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO8C9OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO8C9OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO8C9OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPBENZOLOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>5</sub>',
    '',
    '',
    'MXOPSFWTSRHQGT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBENZOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBENZOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBENZOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPBZBPR2OH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'ZYFWWFFTFWUTQU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBZBPR2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBZBPR2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBZBPR2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPBZBPROOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>5</sub>',
    '',
    '',
    'PFZQQVVUSVRBJH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBZBPROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBZBPROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBZBPROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPBZOLOOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>6</sub>',
    '',
    '',
    'CHCZSTHNGRHXBM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBZOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBZOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBZOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:METLBPR2OH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'WBMKIPDFTCRXQQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METLBPR2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METLBPR2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METLBPR2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:METLBPROOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>5</sub>',
    '',
    '',
    'JDOROKVPYHJTEM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METLBPROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METLBPROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METLBPROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:METOLOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>5</sub>',
    '',
    '',
    'JGSZPUTWQXTPGZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:METOLOOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>6</sub>',
    '',
    '',
    'WHWNZVSDBMWGPT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OETLBPR2OH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'HUTNYAIOWRBWAA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OETLBPR2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OETLBPR2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OETLBPR2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OETLBPROOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>5</sub>',
    '',
    '',
    'JWHYGBDQJAPXFD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OETLBPROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OETLBPROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OETLBPROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OETOLOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>5</sub>',
    '',
    '',
    'RKSMHAQFVDQZCV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OETOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OETOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OETOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OETOLOOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>6</sub>',
    '',
    '',
    'HMIPOFAAVJMIHR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OETOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OETOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OETOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PBENZOLOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>5</sub>',
    '',
    '',
    'PPOCUJCGHLIXAB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBENZOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBENZOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBENZOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PBENZOLOOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>6</sub>',
    '',
    '',
    'YYEAFIOCCPRRFC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBENZOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBENZOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBENZOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PBZBPER2OH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'NXHGWQBANLWNAY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBZBPER2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBZBPER2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBZBPER2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PBZBPEROOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>5</sub>',
    '',
    '',
    'BDTBCPZZIFVKES-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBZBPEROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBZBPEROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBZBPEROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PETLBPR2OH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'ZJSMOJBPUXMKGO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PETLBPR2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PETLBPR2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PETLBPR2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PETLBPROOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>5</sub>',
    '',
    '',
    'HYHORQQVDRWXSH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PETLBPROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PETLBPROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PETLBPROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PETOLOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>5</sub>',
    '',
    '',
    'WWMQWQMHOYSCPT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PETOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PETOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PETOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PETOLOOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>6</sub>',
    '',
    '',
    'NWKQTACFFZGFMV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PETOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PETOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PETOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TM123BP2OH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'XELNTWYHIBVYRB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM123BP2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM123BP2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM123BP2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TM123BPOOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>5</sub>',
    '',
    '',
    'VYRKWTIFXGFOKI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM123BPOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM123BPOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM123BPOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TM123OLOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>5</sub>',
    '',
    '',
    'CUPCKHHMKYENPF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM123OLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM123OLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM123OLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TM123OLOOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>6</sub>',
    '',
    '',
    'QKUAZMPWBBDUFL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM123OLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM123OLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM123OLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TM124BP2OH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'ALTMQDHYGSUKTA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124BP2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124BP2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124BP2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TM124BPOOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>5</sub>',
    '',
    '',
    'WAGRVRZIKOHUQN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124BPOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124BPOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124BPOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TM124OLOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>5</sub>',
    '',
    '',
    'BDZMWXRIFUJLAS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124OLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124OLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124OLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TM124OLOOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>6</sub>',
    '',
    '',
    'BWEFFYCDYKVJMY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124OLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124OLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124OLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TM135BP2OH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'UOFFRVMQLZOQAS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM135BP2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM135BP2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM135BP2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TM135BPOOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>5</sub>',
    '',
    '',
    'JMJJTOHEWPZJQK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM135BPOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM135BPOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM135BPOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TM135OLOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>5</sub>',
    '',
    '',
    'QLKJHZCZIQIKHZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM135OLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM135OLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM135OLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TM135OLOOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>6</sub>',
    '',
    '',
    'BLJZZZVPECPSDH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM135OLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM135OLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM135OLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:APINAOOH',
    'C<sub>10</sub>H<sub>18</sub>O<sub>3</sub>',
    '',
    '',
    'RYIWEMFTAFVTLU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:APINAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:APINAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:APINAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:APINBOOH',
    'C<sub>10</sub>H<sub>18</sub>O<sub>3</sub>',
    '',
    '',
    'USRGRUOHOYDFID-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:APINBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:APINBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:APINBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:APINCOOH',
    'C<sub>10</sub>H<sub>18</sub>O<sub>3</sub>',
    '',
    '',
    'PONCTWLYBMTTOF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:APINCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:APINCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:APINCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BPINAOOH',
    'C<sub>10</sub>H<sub>18</sub>O<sub>3</sub>',
    '',
    '',
    'YIWAKBLZYMRLPO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BPINAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BPINAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BPINAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BPINBOOH',
    'C<sub>10</sub>H<sub>18</sub>O<sub>3</sub>',
    '',
    '',
    'LNOABRBKZGHYLB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BPINBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BPINBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BPINBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BPINCOOH',
    'C<sub>10</sub>H<sub>18</sub>O<sub>3</sub>',
    '',
    '',
    'ONJNLKNHLLSXIR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BPINCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BPINCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BPINCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C918CO3H',
    'C<sub>10</sub>H<sub>16</sub>O<sub>4</sub>',
    '',
    '',
    'NCSYYALRPIRWRM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C918CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C918CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C918CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DMEBPR2OH',
    'C<sub>10</sub>H<sub>16</sub>O<sub>4</sub>',
    '',
    '',
    'JNPNKLHEXQFLDW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMEBPR2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMEBPR2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMEBPR2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DMEBPROOH',
    'C<sub>10</sub>H<sub>16</sub>O<sub>5</sub>',
    '',
    '',
    'FGEXZPMCUOXGAY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMEBPROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMEBPROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMEBPROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DMEPHOLOH',
    'C<sub>10</sub>H<sub>16</sub>O<sub>5</sub>',
    '',
    '',
    'KIALIUKUKYONFN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMEPHOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMEPHOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMEPHOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DMEPHOLOOH',
    'C<sub>10</sub>H<sub>16</sub>O<sub>6</sub>',
    '',
    '',
    'NQWKUASPEMANIL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMEPHOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMEPHOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMEPHOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO3C106OOH',
    'C<sub>10</sub>H<sub>22</sub>O<sub>3</sub>',
    '',
    '',
    'FUGKCLXVXWNPCD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C106OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C106OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C106OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO8C9CO3H',
    'C<sub>10</sub>H<sub>20</sub>O<sub>4</sub>',
    '',
    '',
    'UIPJRQQFQSAZPI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO8C9CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO8C9CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO8C9CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:LIMAOOH',
    'C<sub>10</sub>H<sub>18</sub>O<sub>3</sub>',
    '',
    '',
    'FPMDSGWWEURSNO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>4</sup>',
    '13000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMAOOH'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:LIMBOOH',
    'C<sub>10</sub>H<sub>18</sub>O<sub>3</sub>',
    '',
    '',
    'KUZZIHAARVNWSI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:LIMCOOH',
    'C<sub>10</sub>H<sub>18</sub>O<sub>3</sub>',
    '',
    '',
    'VVHMRXSQYYKNLC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>4</sup>',
    '13000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMCOOH'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DEMPHOLOH',
    'C<sub>11</sub>H<sub>18</sub>O<sub>5</sub>',
    '',
    '',
    'ZTCJTCVANLKQAR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DEMPHOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DEMPHOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DEMPHOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DEMPHOLOOH',
    'C<sub>11</sub>H<sub>18</sub>O<sub>6</sub>',
    '',
    '',
    'MGZZNFCOXGVYJN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DEMPHOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DEMPHOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DEMPHOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DETLBPR2OH',
    'C<sub>11</sub>H<sub>18</sub>O<sub>4</sub>',
    '',
    '',
    'DLRWBBGTDDBDMY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DETLBPR2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DETLBPR2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DETLBPR2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DETLBPROOH',
    'C<sub>11</sub>H<sub>18</sub>O<sub>5</sub>',
    '',
    '',
    'XWTOJCWARUYVPA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DETLBPROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DETLBPROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DETLBPROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO3C116OOH',
    'C<sub>11</sub>H<sub>24</sub>O<sub>3</sub>',
    '',
    '',
    'XCBVDNPGCYSIMS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C116OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C116OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C116OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO3C126OOH',
    'C<sub>12</sub>H<sub>26</sub>O<sub>3</sub>',
    '',
    '',
    'FENUAUYSPLOZDX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C126OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C126OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C126OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BCAOOH',
    'C<sub>15</sub>H<sub>26</sub>O<sub>3</sub>',
    '',
    '',
    'UHQMVBPMTRQRFN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BCBOOH',
    'C<sub>15</sub>H<sub>26</sub>O<sub>3</sub>',
    '',
    '',
    'LZWWDZWHHIWFFS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BCCOOH',
    'C<sub>15</sub>H<sub>26</sub>O<sub>3</sub>',
    '',
    '',
    'LYZHLRDUTRINQK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CATEC1OOH',
    'C<sub>6</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '',
    'GQLFYNLDVCYDKN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CATEC1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CATEC1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CATEC1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MCATEC1OOH',
    'C<sub>7</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'XVDDPRZRYAGIKB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MCATEC1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MCATEC1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MCATEC1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ECATEC1OOH',
    'C<sub>8</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'WXEIAPGLSOOSMJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ECATEC1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ECATEC1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ECATEC1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MXCTEC1OOH',
    'C<sub>8</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'OTSRNDWSIFNBPX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXCTEC1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXCTEC1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXCTEC1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OCATEC1OOH',
    'C<sub>8</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'FFFASTPMSYAWLR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OCATEC1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OCATEC1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OCATEC1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PCATEC1OOH',
    'C<sub>8</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'XEPXMQBYFZNYBF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PCATEC1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PCATEC1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PCATEC1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:STYRENOOH',
    'C<sub>8</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'PRSNAZGJNCSLPW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:STYRENOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:STYRENOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:STYRENOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPCATC1OOH',
    'C<sub>9</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'LUGXJULPVOELPW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPCATC1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPCATC1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPCATC1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MTCTEC1OOH',
    'C<sub>9</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'RXVYKZMASOKYNM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTCTEC1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTCTEC1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTCTEC1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OTCTEC1OOH',
    'C<sub>9</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'BNYRTZAXTAHDLR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OTCTEC1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OTCTEC1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OTCTEC1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PRCATC1OOH',
    'C<sub>9</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'WDHGVTVSFNORIO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRCATC1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRCATC1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRCATC1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PTCTEC1OOH',
    'C<sub>9</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'SXYSFXQBYZNKPP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PTCTEC1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PTCTEC1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PTCTEC1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:T123CT1OOH',
    'C<sub>9</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'XFULZEJTRUOVEV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:T123CT1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:T123CT1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:T123CT1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:T124CT1OOH',
    'C<sub>9</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'XVSFIBYJDMNABQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:T124CT1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:T124CT1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:T124CT1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HCOCH2OOH',
    'C<sub>2</sub>H<sub>4</sub>O<sub>3</sub>',
    '',
    '',
    'TUJPSEFVDYHSJJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HCOCH2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HCOCH2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HCOCH2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HCOCO3H',
    'C<sub>2</sub>H<sub>2</sub>O<sub>4</sub>',
    '',
    '',
    'JOALXJIWVKUVBR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HCOCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HCOCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HCOCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C3DIALOOH',
    'C<sub>3</sub>H<sub>4</sub>O<sub>4</sub>',
    '',
    '',
    'VUPDPJIDXKCVGY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3DIALOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3DIALOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3DIALOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CHOC2H4OOH',
    'C<sub>3</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '',
    'XSASRUDTFFBDDK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Peroxides (ROOH) and peroxy radicals (ROO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOC2H4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOC2H4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOC2H4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Aldehydes (RCHO)',
    (SELECT id from categories WHERE catname='Organic species with oxygen (O)'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methanal',
    'HCHO',
    'formaldehyde',
    '50-00-0',
    'WSFSSNUMVMOOMR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>1</sup>',
    '7100',
    'L',
    (SELECT id from species WHERE iupac='methanal'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'HCHOdiol',
    '', 'Effective value that takes into account the hydration of HCHO: <br clear="all" /><table border="0" width="100%"><tr><td><table align="center" cellspacing="0"  cellpadding="2"><tr><td nowrap="nowrap" align="center">H<sub>s</sub>= ([HCHO]+[CH<sub>2</sub>(OH)<sub>2</sub>])/p(HCHO).</td></tr></table></td></tr></table>');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HCHOdiol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>1</sup>',
    '7100',
    'L',
    (SELECT id from species WHERE iupac='methanal'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HCHOdiol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>1</sup>',
    '6800',
    'L',
    (SELECT id from species WHERE iupac='methanal'),
    (SELECT id from literature WHERE bibtexkey='2828'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HCHOdiol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>1</sup>',
    '7100',
    'L',
    (SELECT id from species WHERE iupac='methanal'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HCHOdiol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>1</sup>',
    '7100',
    'L',
    (SELECT id from species WHERE iupac='methanal'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HCHOdiol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>1</sup>',
    '6800',
    'L',
    (SELECT id from species WHERE iupac='methanal'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HCHOdiol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>1</sup>',
    '6800',
    'L',
    (SELECT id from species WHERE iupac='methanal'),
    (SELECT id from literature WHERE bibtexkey='747'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HCHOdiol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>1</sup>',
    '5700',
    'M',
    (SELECT id from species WHERE iupac='methanal'),
    (SELECT id from literature WHERE bibtexkey='3111'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HCHOdiol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>1</sup>',
    '6400',
    'M',
    (SELECT id from species WHERE iupac='methanal'),
    (SELECT id from literature WHERE bibtexkey='2817'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HCHOdiol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>1</sup>',
    '1600',
    'M',
    (SELECT id from species WHERE iupac='methanal'),
    (SELECT id from literature WHERE bibtexkey='2829'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HCHOdiol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methanal'),
    (SELECT id from literature WHERE bibtexkey='2837'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HCHOdiol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>1</sup>',
    '6500',
    'M',
    (SELECT id from species WHERE iupac='methanal'),
    (SELECT id from literature WHERE bibtexkey='630'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '630',
    '630', 'Data from Table&nbsp;1 by Zhou and Mopper (1990) were used to redo the regression analysis. The data for acetone in their Table&nbsp;2 are incorrect.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='630'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HCHOdiol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>1</sup>',
    '7200',
    'M',
    (SELECT id from species WHERE iupac='methanal'),
    (SELECT id from literature WHERE bibtexkey='484'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HCHOdiol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'M',
    (SELECT id from species WHERE iupac='methanal'),
    (SELECT id from literature WHERE bibtexkey='485'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '485HCHO',
    '485', 'Dong and Dasgupta (1986) found that the Henry''s law constant for HCHO is not a true constant but that it increases with increasing concentration. Note that their expression does not converge asymptotically to a constant value at infinite dilution.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='485HCHO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'M',
    (SELECT id from species WHERE iupac='methanal'),
    (SELECT id from literature WHERE bibtexkey='481'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '481HCHO',
    '481,486,31,443,34', 'Ledbury and Blair (1925) (and also Blair and Ledbury (1925)) measured the solubility of HCHO at very high concentrations around 5 to 15&nbsp;M. Their value of H<sub>s</sub> increases with HCHO concentration. Lelieveld and Crutzen (1991), Hough (1991), and Pandis and Seinfeld (1989) all use these solubility data but do not specify how they extrapolated to lower concentrations. Since the concentration range is far from typical values in atmospheric chemistry, the value is not reproduced here.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='481HCHO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'M',
    (SELECT id from species WHERE iupac='methanal'),
    (SELECT id from literature WHERE bibtexkey='486'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='481HCHO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methanal'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HCHOdiol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'V',
    (SELECT id from species WHERE iupac='methanal'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HCHOdiol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>1</sup>',
    '6400',
    'T',
    (SELECT id from species WHERE iupac='methanal'),
    (SELECT id from literature WHERE bibtexkey='87'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HCHOdiol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>1</sup>',
    '7200',
    'X',
    (SELECT id from species WHERE iupac='methanal'),
    (SELECT id from literature WHERE bibtexkey='bell66'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'from507',
    '507', 'Value given here as quoted by Möller and Mauersberger (1992).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from507'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HCHOdiol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methanal'),
    (SELECT id from literature WHERE bibtexkey='gaffney84'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HCHOdiol'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from715'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='methanal'),
    (SELECT id from literature WHERE bibtexkey='2527'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HCHOdiol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'C',
    (SELECT id from species WHERE iupac='methanal'),
    (SELECT id from literature WHERE bibtexkey='443'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='481HCHO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='methanal'),
    (SELECT id from literature WHERE bibtexkey='67'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HCHOdiol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanal'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanal'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanal'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanal'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanal'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanal'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanal'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HCHOdiol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methanal'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methanal'),
    (SELECT id from literature WHERE bibtexkey='523'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HCHOdiol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='methanal'),
    (SELECT id from literature WHERE bibtexkey='31'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='481HCHO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='methanal'),
    (SELECT id from literature WHERE bibtexkey='34'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='481HCHO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethanal',
    'CH<sub>3</sub>CHO',
    'acetaldehyde',
    '75-07-0',
    'IKHGUXGNUITLKF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '5900',
    'L',
    (SELECT id from species WHERE iupac='ethanal'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'RCHOdiol',
    '', 'Effective value that takes into account the hydration of the aldehyde: <br clear="all" /><table border="0" width="100%"><tr><td><table align="center" cellspacing="0"  cellpadding="2"><tr><td nowrap="nowrap" align="center">H<sub>s</sub>= ([RCHO]+[RCH(OH)<sub>2</sub>])/p(RCHO).</td></tr></table></td></tr></table>');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='RCHOdiol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '5900',
    'L',
    (SELECT id from species WHERE iupac='ethanal'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='RCHOdiol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '5600',
    'L',
    (SELECT id from species WHERE iupac='ethanal'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '5900',
    'L',
    (SELECT id from species WHERE iupac='ethanal'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '5900',
    'L',
    (SELECT id from species WHERE iupac='ethanal'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '5700',
    'L',
    (SELECT id from species WHERE iupac='ethanal'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '5600',
    'L',
    (SELECT id from species WHERE iupac='ethanal'),
    (SELECT id from literature WHERE bibtexkey='747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '5600',
    'M',
    (SELECT id from species WHERE iupac='ethanal'),
    (SELECT id from literature WHERE bibtexkey='3215'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3215-75-07-0-ABC',
    '3215', 'The data from Wieland et&nbsp;al. (2015) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( 25.01220 +3596.11696/T &#8722;6.81730&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3215-75-07-0-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '6400',
    'M',
    (SELECT id from species WHERE iupac='ethanal'),
    (SELECT id from literature WHERE bibtexkey='2524'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethanal'),
    (SELECT id from literature WHERE bibtexkey='1937'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethanal'),
    (SELECT id from literature WHERE bibtexkey='2964'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '5700',
    'M',
    (SELECT id from species WHERE iupac='ethanal'),
    (SELECT id from literature WHERE bibtexkey='617'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '5000',
    'M',
    (SELECT id from species WHERE iupac='ethanal'),
    (SELECT id from literature WHERE bibtexkey='630'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='630'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethanal'),
    (SELECT id from literature WHERE bibtexkey='2924'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '6300',
    'M',
    (SELECT id from species WHERE iupac='ethanal'),
    (SELECT id from literature WHERE bibtexkey='484'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='RCHOdiol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '5800',
    'M',
    (SELECT id from species WHERE iupac='ethanal'),
    (SELECT id from literature WHERE bibtexkey='483'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethanal'),
    (SELECT id from literature WHERE bibtexkey='3635'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at303K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethanal'),
    (SELECT id from literature WHERE bibtexkey='3669'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethanal'),
    (SELECT id from literature WHERE bibtexkey='1492'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at283K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethanal'),
    (SELECT id from literature WHERE bibtexkey='754'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethanal'),
    (SELECT id from literature WHERE bibtexkey='2964'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethanal'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethanal'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '4500',
    'X',
    (SELECT id from species WHERE iupac='ethanal'),
    (SELECT id from literature WHERE bibtexkey='1154'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '4700',
    'X',
    (SELECT id from species WHERE iupac='ethanal'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethanal'),
    (SELECT id from literature WHERE bibtexkey='gaffney84'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from715'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethanal'),
    (SELECT id from literature WHERE bibtexkey='2223'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'from641',
    '641', 'Value given here as quoted by Bone et&nbsp;al. (1983).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from641'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanal'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanal'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanal'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanal'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanal'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanal'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanal'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanal'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanal'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5200',
    'Q',
    (SELECT id from species WHERE iupac='ethanal'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanal'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanal'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanal'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanal'),
    (SELECT id from literature WHERE bibtexkey='2964'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanal'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanal'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanal'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethanal'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethanal'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5800',
    '?',
    (SELECT id from species WHERE iupac='ethanal'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethanal'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethanal'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethanal'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethanedial',
    'OHCCHO',
    'glyoxal',
    '107-22-2',
    'LEQAOMBKQFMDFZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>3</sup>',
    '7500',
    'L',
    (SELECT id from species WHERE iupac='ethanedial'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='RCHOdiol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>3</sup>',
    '7500',
    'L',
    (SELECT id from species WHERE iupac='ethanedial'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='RCHOdiol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>3</sup>',
    '7500',
    'L',
    (SELECT id from species WHERE iupac='ethanedial'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='RCHOdiol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>5</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethanedial'),
    (SELECT id from literature WHERE bibtexkey='3010'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='RCHOdiol'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3010',
    '', 'Value suitable for the conditions of a case study in Mexico City.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3010'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>3</sup>',
    '7500',
    'M',
    (SELECT id from species WHERE iupac='ethanedial'),
    (SELECT id from literature WHERE bibtexkey='2401'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='RCHOdiol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethanedial'),
    (SELECT id from literature WHERE bibtexkey='3134'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3134-107-22-2-range',
    '3134', 'Volkamer et&nbsp;al. (2009) found average effective Henry''s law constants for CHOCHO in the range 1.6&times;10<sup>6</sup>&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>  &lt;  H<sub>s</sub><sup>cp</sup> &lt;  5.9&times;10<sup>6</sup>&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup> for solutions containing ammonium sulfate and/or fulvic acid. A salting-in effect by fulvic acid was observed even in the absence of sulfate.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3134-107-22-2-range'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>5</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethanedial'),
    (SELECT id from literature WHERE bibtexkey='2321'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='RCHOdiol'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2321',
    '', 'Solubility in sulfate aerosol.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2321'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethanedial'),
    (SELECT id from literature WHERE bibtexkey='630'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='RCHOdiol'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 3.0&times;10<sup>3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethanedial'),
    (SELECT id from literature WHERE bibtexkey='484'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='RCHOdiol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='ethanedial'),
    (SELECT id from literature WHERE bibtexkey='2527'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='RCHOdiol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanedial'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanedial'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanedial'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanedial'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanedial'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanedial'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanedial'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanedial'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethanedial'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethanedial'),
    (SELECT id from literature WHERE bibtexkey='3581'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3581',
    '3581,3098', 'Woo and McNeill (2015) say that the Henry''s law constant was updated based on advances in the literature since McNeill et&nbsp;al. (2012) but do not provide further details.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3581'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propanal',
    'C<sub>2</sub>H<sub>5</sub>CHO',
    'propionaldehyde',
    '123-38-6',
    'NBBJYMSMWIIQGU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '4300',
    'L',
    (SELECT id from species WHERE iupac='propanal'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '4300',
    'L',
    (SELECT id from species WHERE iupac='propanal'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '5500',
    'L',
    (SELECT id from species WHERE iupac='propanal'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '4300',
    'L',
    (SELECT id from species WHERE iupac='propanal'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '4300',
    'L',
    (SELECT id from species WHERE iupac='propanal'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='propanal'),
    (SELECT id from literature WHERE bibtexkey='3111'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at296K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='propanal'),
    (SELECT id from literature WHERE bibtexkey='3032'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '5800',
    'M',
    (SELECT id from species WHERE iupac='propanal'),
    (SELECT id from literature WHERE bibtexkey='2524'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '5700',
    'M',
    (SELECT id from species WHERE iupac='propanal'),
    (SELECT id from literature WHERE bibtexkey='630'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='630'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='propanal'),
    (SELECT id from literature WHERE bibtexkey='3635'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at303K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='propanal'),
    (SELECT id from literature WHERE bibtexkey='3669'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='propanal'),
    (SELECT id from literature WHERE bibtexkey='754'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='propanal'),
    (SELECT id from literature WHERE bibtexkey='3075'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propanal'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propanal'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '3200',
    'V',
    (SELECT id from species WHERE iupac='propanal'),
    (SELECT id from literature WHERE bibtexkey='3638'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propanal'),
    (SELECT id from literature WHERE bibtexkey='2388'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='propanal'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '5600',
    'X',
    (SELECT id from species WHERE iupac='propanal'),
    (SELECT id from literature WHERE bibtexkey='859'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '2400',
    'X',
    (SELECT id from species WHERE iupac='propanal'),
    (SELECT id from literature WHERE bibtexkey='1154'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanal'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanal'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanal'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanal'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanal'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanal'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanal'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanal'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanal'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5500',
    'Q',
    (SELECT id from species WHERE iupac='propanal'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanal'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanal'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanal'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanal'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanal'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanal'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propanal'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propanal'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5000',
    '?',
    (SELECT id from species WHERE iupac='propanal'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propanal'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propanal'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propanedial',
    'C<sub>3</sub>H<sub>4</sub>O<sub>2</sub>',
    'malonaldehyde',
    '542-78-9',
    'WSMYVTOQOOLQHP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanedial'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanedial'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanedial'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C32OH13CO',
    'C<sub>3</sub>H<sub>4</sub>O<sub>3</sub>',
    '',
    '',
    'NVXLIZQNSVLKPO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C32OH13CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C32OH13CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C32OH13CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CH3CHOHCHO',
    'C<sub>3</sub>H<sub>6</sub>O<sub>2</sub>',
    '',
    '',
    'BSABBBMNWQWLLU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3CHOHCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3CHOHCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3CHOHCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HOC2H4CHO',
    'C<sub>3</sub>H<sub>6</sub>O<sub>2</sub>',
    '',
    '',
    'AKXKFZDCRYJKTF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>1</sup>',
    '9900',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOC2H4CHO'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOC2H4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOC2H4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOC2H4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'butanal',
    'C<sub>3</sub>H<sub>7</sub>CHO',
    'butyraldehyde',
    '123-72-8',
    'ZTQSAGDEMFDKMZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;2</sup>',
    '6200',
    'L',
    (SELECT id from species WHERE iupac='butanal'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;2</sup>',
    '6200',
    'L',
    (SELECT id from species WHERE iupac='butanal'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;2</sup>',
    '6000',
    'L',
    (SELECT id from species WHERE iupac='butanal'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;2</sup>',
    '6200',
    'L',
    (SELECT id from species WHERE iupac='butanal'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;2</sup>',
    '6200',
    'L',
    (SELECT id from species WHERE iupac='butanal'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='butanal'),
    (SELECT id from literature WHERE bibtexkey='3032'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;2</sup>',
    '6200',
    'M',
    (SELECT id from species WHERE iupac='butanal'),
    (SELECT id from literature WHERE bibtexkey='2524'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;2</sup>',
    '6200',
    'M',
    (SELECT id from species WHERE iupac='butanal'),
    (SELECT id from literature WHERE bibtexkey='630'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='630'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='butanal'),
    (SELECT id from literature WHERE bibtexkey='754'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='butanal'),
    (SELECT id from literature WHERE bibtexkey='3075'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butanal'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butanal'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butanal'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;2</sup>',
    '3500',
    'V',
    (SELECT id from species WHERE iupac='butanal'),
    (SELECT id from literature WHERE bibtexkey='3638'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butanal'),
    (SELECT id from literature WHERE bibtexkey='2388'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='butanal'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='butanal'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;2</sup>',
    '4000',
    'X',
    (SELECT id from species WHERE iupac='butanal'),
    (SELECT id from literature WHERE bibtexkey='1154'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanal'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanal'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanal'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanal'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanal'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanal'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanal'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanal'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanal'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5900',
    'Q',
    (SELECT id from species WHERE iupac='butanal'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanal'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanal'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanal'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanal'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanal'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanal'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanal'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='butanal'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='butanal'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6400',
    '?',
    (SELECT id from species WHERE iupac='butanal'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='butanal'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='butanal'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methylpropanal',
    'C<sub>4</sub>H<sub>8</sub>O',
    'isobutyraldehyde',
    '78-84-2',
    'AMIMRNSIRUDHCM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2-methylpropanal'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2-methylpropanal'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '7600',
    'M',
    (SELECT id from species WHERE iupac='2-methylpropanal'),
    (SELECT id from literature WHERE bibtexkey='3508'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;3</sup>',
    '4500',
    'M',
    (SELECT id from species WHERE iupac='2-methylpropanal'),
    (SELECT id from literature WHERE bibtexkey='1571'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methylpropanal'),
    (SELECT id from literature WHERE bibtexkey='1922'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methylpropanal'),
    (SELECT id from literature WHERE bibtexkey='1923'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methylpropanal'),
    (SELECT id from literature WHERE bibtexkey='2388'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylpropanal'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylpropanal'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylpropanal'),
    (SELECT id from literature WHERE bibtexkey='2388'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methylpropanal'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropanal'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropanal'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropanal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropanal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropanal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropanal'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5000',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropanal'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropanal'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropanal'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropanal'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-Test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropanal'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropanal'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5100',
    '?',
    (SELECT id from species WHERE iupac='2-methylpropanal'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methylpropanal'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methylpropanal'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methylpropanedial',
    'C<sub>4</sub>H<sub>6</sub>O<sub>2</sub>',
    '',
    '16002-19-0',
    'VXYSFSCCSQAYJV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropanedial'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropanedial'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropanedial'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MALDIAL',
    'C<sub>4</sub>H<sub>4</sub>O<sub>2</sub>',
    '',
    '',
    'JGEMYUOFGVHXKV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MALDIAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MALDIAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MALDIAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C3MDIALOH',
    'C<sub>4</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '',
    'SQHUBVCIVAIUAB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3MDIALOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3MDIALOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3MDIALOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C41OH',
    'C<sub>4</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'YTBSYETUWUMLBZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C41OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C41OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C41OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C41OOH',
    'C<sub>4</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'ROHPNOOUQDXFHZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C41OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C41OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C41OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4OCCOHCOH',
    'C<sub>4</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'DFFAMJFPVBTTBX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4OCCOHCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4OCCOHCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4OCCOHCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CHOC3DIOL',
    'C<sub>4</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'CQSYGAZTCJHVFE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOC3DIOL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOC3DIOL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOC3DIOL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HC3CCHO',
    'C<sub>4</sub>H<sub>6</sub>O<sub>2</sub>',
    '',
    '',
    'PPNVQCFSKPIRKK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HC3CCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HC3CCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HC3CCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HC3CHO',
    'C<sub>4</sub>H<sub>6</sub>O<sub>2</sub>',
    '',
    '',
    'FXCMZPXXCRHRNK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HC3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HC3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HC3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HMACROH',
    'C<sub>4</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'OUEKYUKJSLEOIU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HMACROH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HMACROH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HMACROH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HMACR',
    'C<sub>4</sub>H<sub>6</sub>O<sub>2</sub>',
    '',
    '',
    'QVBICLGJAQXLSA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HMACR'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HMACR'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HMACR'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO13C3CHO',
    'C<sub>4</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'NKVLMFFGFYHDNE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO13C3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO13C3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO13C3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO2C3CHO',
    'C<sub>4</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '',
    'HSJKGGMUJITCBW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO3C3CHO',
    'C<sub>4</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '',
    'UIKQNMXWCYQNCS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HOC3H6CHO',
    'C<sub>4</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '',
    'PIAOXUVIBAKVSP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOC3H6CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOC3H6CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOC3H6CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HOHOC4DIAL',
    'C<sub>4</sub>H<sub>6</sub>O<sub>4</sub>',
    '',
    '',
    'UUWVJXZLAWXQBU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOHOC4DIAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOHOC4DIAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOHOC4DIAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HOIPRCHO',
    'C<sub>4</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '',
    'JTMCAHGCWBGWRV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOIPRCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOIPRCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOIPRCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IBUTALOH',
    'C<sub>4</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '',
    'HNVAGBIANFAIIL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IBUTALOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IBUTALOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IBUTALOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MACROH',
    'C<sub>4</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'JBCPUXACCOWZEB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MACROH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MACROH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MACROH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pentanal',
    'C<sub>4</sub>H<sub>9</sub>CHO',
    'valeraldehyde',
    '110-62-3',
    'HGBOYTHUEUWSSQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;2</sup>',
    '6500',
    'L',
    (SELECT id from species WHERE iupac='pentanal'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='pentanal'),
    (SELECT id from literature WHERE bibtexkey='3111'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at296K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='pentanal'),
    (SELECT id from literature WHERE bibtexkey='3032'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;2</sup>',
    '6100',
    'M',
    (SELECT id from species WHERE iupac='pentanal'),
    (SELECT id from literature WHERE bibtexkey='2524'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;2</sup>',
    '6300',
    'M',
    (SELECT id from species WHERE iupac='pentanal'),
    (SELECT id from literature WHERE bibtexkey='630'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='630'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='pentanal'),
    (SELECT id from literature WHERE bibtexkey='754'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='pentanal'),
    (SELECT id from literature WHERE bibtexkey='3075'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '3800',
    'V',
    (SELECT id from species WHERE iupac='pentanal'),
    (SELECT id from literature WHERE bibtexkey='3638'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pentanal'),
    (SELECT id from literature WHERE bibtexkey='2388'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='pentanal'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='pentanal'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentanal'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentanal'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentanal'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentanal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentanal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentanal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentanal'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentanal'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentanal'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentanal'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentanal'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentanal'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentanal'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6200',
    'Q',
    (SELECT id from species WHERE iupac='pentanal'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentanal'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentanal'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentanal'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentanal'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentanal'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentanal'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pentanal'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pentanal'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5500',
    '?',
    (SELECT id from species WHERE iupac='pentanal'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pentanal'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pentanal'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at303K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pentanal'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methylbutanal',
    'C<sub>5</sub>H<sub>10</sub>O',
    '',
    '96-17-3',
    'BYGQBDHUGHBGMD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '5600',
    'L',
    (SELECT id from species WHERE iupac='2-methylbutanal'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methylbutanal'),
    (SELECT id from literature WHERE bibtexkey='1923'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbutanal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbutanal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbutanal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbutanal'),
    (SELECT id from literature WHERE bibtexkey='2600'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'at372K',
    '', 'Value at T = 372&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at372K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methylbutanal',
    'C<sub>5</sub>H<sub>10</sub>O',
    'isovaleraldehyde',
    '590-86-3',
    'YGHRJJRRZDOVPD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '10000',
    'M',
    (SELECT id from species WHERE iupac='3-methylbutanal'),
    (SELECT id from literature WHERE bibtexkey='3508'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HTdep_r2_lessthan_0.9'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '6100',
    'M',
    (SELECT id from species WHERE iupac='3-methylbutanal'),
    (SELECT id from literature WHERE bibtexkey='3215'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3215-590-86-3-ABC',
    '3215', 'The data from Wieland et&nbsp;al. (2015) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;176.35942 +12895.73116/T +22.70566&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3215-590-86-3-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3-methylbutanal'),
    (SELECT id from literature WHERE bibtexkey='3032'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3-methylbutanal'),
    (SELECT id from literature WHERE bibtexkey='1923'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3-methylbutanal'),
    (SELECT id from literature WHERE bibtexkey='2387'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at301K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-methylbutanal'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-methylbutanal'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methylbutanal'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutanal'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutanal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutanal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutanal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutanal'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutanal'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutanal'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutanal'),
    (SELECT id from literature WHERE bibtexkey='2600'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at372K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4MDIAL',
    'C<sub>5</sub>H<sub>6</sub>O<sub>2</sub>',
    '',
    '',
    'USBJWIKCHJDWPF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4MDIAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4MDIAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4MDIAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO1M22CHO',
    'C<sub>5</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '',
    'WNBFTLCNQKKVHC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO1M22CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO1M22CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO1M22CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dimethylpropanal',
    'C<sub>5</sub>H<sub>10</sub>O',
    'pivaldehyde',
    '630-19-3',
    'FJJYHTVHBVXEEQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylpropanal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylpropanal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylpropanal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C3EDIALOH',
    'C<sub>5</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'QTDYRJFEJDMBDI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3EDIALOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3EDIALOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3EDIALOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C3M3OH2CHO',
    'C<sub>5</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'VKYKDJZVZBURQF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3M3OH2CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3M3OH2CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3M3OH2CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C42CHO',
    'C<sub>5</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'NGVSSTUGOBBIBC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C42CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C42CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C42CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4M2AL2OH',
    'C<sub>5</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'NUHRTSFMSDZSTE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4M2AL2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4M2AL2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4M2AL2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4OHCHO',
    'C<sub>5</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'SUTLBTHMXYSMSZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4OHCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4OHCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4OHCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C514OH',
    'C<sub>5</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'UIVALZXFWDRKKE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C514OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C514OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C514OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C57OH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'ZKDSJDSEVDWBAC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C57OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C57OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C57OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C58OH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'HTPZSALIZDTBIL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C58OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C58OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C58OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5DIALOH',
    'C<sub>5</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '',
    'KBKQEUDBRUGUIQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5DIALOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5DIALOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5DIALOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H13C43CHO',
    'C<sub>5</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'KJLUILOCNALPNM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H13C43CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H13C43CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H13C43CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H2M2C3CHO',
    'C<sub>5</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'FXFBPKDQLDOIRG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M2C3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M2C3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M2C3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HC4ACHO',
    'C<sub>5</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '',
    'BSHDRMLUCYMQOP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HC4ACHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HC4ACHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HC4ACHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HC4CCHO',
    'C<sub>5</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '',
    'GCHJBJOOADXJFT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '11000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HC4CCHO'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HC4CCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HC4CCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HC4CCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HM22CHO',
    'C<sub>5</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'JJMOMMLADQPZNY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM22CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM22CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM22CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO24C4CHO',
    'C<sub>5</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'WDKLWOBHKQJYSU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO24C4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO24C4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO24C4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO2C43CHO',
    'C<sub>5</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'ZURZPPULRFXVLF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C43CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C43CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C43CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO2C4CHO',
    'C<sub>5</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'HFZMJAMTNAAZQE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO3C4CHO',
    'C<sub>5</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'WRWLNLBWBJEUPI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HOBUT2CHO',
    'C<sub>5</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'PLBZJQQQFIOXRU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOBUT2CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOBUT2CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOBUT2CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HOIBUTCHO',
    'C<sub>5</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'RWXBAXNFTXQJAY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOIBUTCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOIBUTCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOIBUTCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MBOBCO',
    'C<sub>5</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'YDXYYBJRCIQQSF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MBOBCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MBOBCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MBOBCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PROL1MCHO',
    'C<sub>5</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'MEHIGMLPKIJWEA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PROL1MCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PROL1MCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PROL1MCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hexanal',
    'C<sub>5</sub>H<sub>11</sub>CHO',
    '',
    '66-25-1',
    'JARKCYVAAOWBJS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '6400',
    'L',
    (SELECT id from species WHERE iupac='hexanal'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '5200',
    'M',
    (SELECT id from species WHERE iupac='hexanal'),
    (SELECT id from literature WHERE bibtexkey='3507'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '8900',
    'M',
    (SELECT id from species WHERE iupac='hexanal'),
    (SELECT id from literature WHERE bibtexkey='3508'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='hexanal'),
    (SELECT id from literature WHERE bibtexkey='3671'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='hexanal'),
    (SELECT id from literature WHERE bibtexkey='1922'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '4900',
    'M',
    (SELECT id from species WHERE iupac='hexanal'),
    (SELECT id from literature WHERE bibtexkey='3650'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at303K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='hexanal'),
    (SELECT id from literature WHERE bibtexkey='3643'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='hexanal'),
    (SELECT id from literature WHERE bibtexkey='3670'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3670'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='hexanal'),
    (SELECT id from literature WHERE bibtexkey='3611'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '6500',
    'M',
    (SELECT id from species WHERE iupac='hexanal'),
    (SELECT id from literature WHERE bibtexkey='630'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='630'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='hexanal'),
    (SELECT id from literature WHERE bibtexkey='754'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='hexanal'),
    (SELECT id from literature WHERE bibtexkey='3075'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexanal'),
    (SELECT id from literature WHERE bibtexkey='2388'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='hexanal'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='hexanal'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at303K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='hexanal'),
    (SELECT id from literature WHERE bibtexkey='3135'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='hexanal'),
    (SELECT id from literature WHERE bibtexkey='3650'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='hexanal'),
    (SELECT id from literature WHERE bibtexkey='3644'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanal'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanal'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanal'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanal'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanal'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanal'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanal'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanal'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanal'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanal'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanal'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanal'),
    (SELECT id from literature WHERE bibtexkey='2600'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at372K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6600',
    'Q',
    (SELECT id from species WHERE iupac='hexanal'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanal'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanal'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanal'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanal'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanal'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanal'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='hexanal'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='hexanal'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6900',
    '?',
    (SELECT id from species WHERE iupac='hexanal'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='hexanal'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at303K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='hexanal'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at303K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='hexanal'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pentanedial',
    'OHC(CH<sub>2</sub>)<sub>3</sub>CHO',
    'glutaraldehyde',
    '111-30-8',
    'SXRSQZLOMIGNAQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>2</sup>',
    '9200',
    'M',
    (SELECT id from species WHERE iupac='pentanedial'),
    (SELECT id from literature WHERE bibtexkey='1110'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentanedial'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '8800',
    'Q',
    (SELECT id from species WHERE iupac='pentanedial'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '9100',
    '?',
    (SELECT id from species WHERE iupac='pentanedial'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methylpentanal',
    'C<sub>6</sub>H<sub>12</sub>O',
    '2-methylvaleraldehyde',
    '123-15-9',
    'FTZILAQGHINQQR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpentanal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpentanal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpentanal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpentanal'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5700',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpentanal'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5300',
    '?',
    (SELECT id from species WHERE iupac='2-methylpentanal'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hexanedial',
    'C<sub>6</sub>H<sub>10</sub>O<sub>2</sub>',
    'adipaldehyde',
    '1072-21-5',
    'UMHJEEQLYBKSAN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanedial'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanedial'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanedial'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:M22C3CHO',
    'C<sub>6</sub>H<sub>12</sub>O',
    '',
    '',
    'LTNUSYNQZJZUSY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M22C3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M22C3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M22C3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:M2C43CHO',
    'C<sub>6</sub>H<sub>12</sub>O',
    '',
    '',
    'AKUUEDVRXOZTBF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2C43CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2C43CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2C43CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:M33C3CHO',
    'C<sub>6</sub>H<sub>12</sub>O',
    '',
    '',
    'QYPLKDUOPJZROX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M33C3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M33C3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M33C3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methylpentanal',
    'C<sub>6</sub>H<sub>12</sub>O',
    '',
    '15877-57-3',
    'YJWJGLQYQJGEEP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methylpentanal'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylpentanal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylpentanal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylpentanal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylpentanal'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methylpentanal',
    'C<sub>6</sub>H<sub>12</sub>O',
    '',
    '1119-16-0',
    'JGEGJYXHCFUMJF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methylpentanal'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylpentanal'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-ethylbutanal',
    'C<sub>6</sub>H<sub>12</sub>O',
    '',
    '97-96-1',
    'UNNGUFMVYQJGTD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-ethylbutanal'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylbutanal'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C518CHO',
    'C<sub>6</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'XEAYIEUKFACAKS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C518CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C518CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C518CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C615OH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'LOUHJSYYTNSRBN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C615OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C615OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C615OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C623OH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'ASGSKBSLHTVURJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C623OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C623OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C623OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C67OH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'SIBVVDHXFPINCX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C67OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C67OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C67OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C68OH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'RJKLRJTWLKKQSE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C68OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C68OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C68OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6DIALOH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'GATFIJYWERJMGU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6DIALOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6DIALOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6DIALOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO1C6OH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'FPFTWHJPEMPAGE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO1C6OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO1C6OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO1C6OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO1H63OH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'TWSXDPXQZVBPJU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO1H63OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO1H63OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO1H63OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H2M2C4CHO',
    'C<sub>6</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'NEJZWIVQOAKZHY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M2C4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M2C4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M2C4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H2M3C4CHO',
    'C<sub>6</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'GUXDGBBNSMURMG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M3C4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M3C4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M3C4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H3M3C4CHO',
    'C<sub>6</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'HKXRCBUXVFAKDA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3M3C4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3M3C4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3M3C4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HM22C3CHO',
    'C<sub>6</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'VOISQCUJWIZDHK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM22C3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM22C3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM22C3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HM2C43CHO',
    'C<sub>6</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'QQZFDCJFBSAIBQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM2C43CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM2C43CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM2C43CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HM33C3CHO',
    'C<sub>6</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'YHMMFPKTSXQULG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM33C3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM33C3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM33C3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO2C54CHO',
    'C<sub>6</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'ZHZOUKIXPREHLS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C54CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C54CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C54CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO3C5CHO',
    'C<sub>6</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'HAPLZPWSLJPZBM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C5CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C5CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C5CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO5C5CHO',
    'C<sub>6</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'BRZMRZVKWQWYPJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO5C5CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO5C5CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO5C5CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'heptanal',
    'C<sub>6</sub>H<sub>13</sub>CHO',
    '',
    '111-71-7',
    'FXHGMKSSBGDXIY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '7500',
    'L',
    (SELECT id from species WHERE iupac='heptanal'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='heptanal'),
    (SELECT id from literature WHERE bibtexkey='3671'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='heptanal'),
    (SELECT id from literature WHERE bibtexkey='3643'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='heptanal'),
    (SELECT id from literature WHERE bibtexkey='3670'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3670'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='heptanal'),
    (SELECT id from literature WHERE bibtexkey='3611'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '7500',
    'M',
    (SELECT id from species WHERE iupac='heptanal'),
    (SELECT id from literature WHERE bibtexkey='630'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='630'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='heptanal'),
    (SELECT id from literature WHERE bibtexkey='754'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='heptanal'),
    (SELECT id from literature WHERE bibtexkey='3075'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='heptanal'),
    (SELECT id from literature WHERE bibtexkey='2388'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='heptanal'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='heptanal'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at303K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='heptanal'),
    (SELECT id from literature WHERE bibtexkey='3135'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptanal'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptanal'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptanal'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptanal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptanal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptanal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptanal'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptanal'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptanal'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptanal'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptanal'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptanal'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptanal'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptanal'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6900',
    'Q',
    (SELECT id from species WHERE iupac='heptanal'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptanal'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptanal'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptanal'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-Test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptanal'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptanal'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptanal'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='heptanal'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7100',
    '?',
    (SELECT id from species WHERE iupac='heptanal'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='heptanal'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at303K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='heptanal'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at303K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='heptanal'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C622CHO',
    'C<sub>7</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'JWVBPJJNIHELFZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>3</sup>',
    '11000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C622CHO'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C622CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C622CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C622CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C624CHO',
    'C<sub>7</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'AIMYSSDKEKDSEU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>3</sup>',
    '11000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C624CHO'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C624CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C624CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C624CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C728OH',
    'C<sub>7</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'RQDWEXZQVQBWBC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C728OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C728OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C728OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C730OH',
    'C<sub>7</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'ROYLBPWMPALPRM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C730OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C730OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C730OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H3M3C5CHO',
    'C<sub>7</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '',
    'PUMVOOYIPAYIQQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3M3C5CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3M3C5CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3M3C5CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'octanal',
    'C<sub>7</sub>H<sub>15</sub>CHO',
    '',
    '124-13-0',
    'NUJGJRNETVAIRJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '7300',
    'L',
    (SELECT id from species WHERE iupac='octanal'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='octanal'),
    (SELECT id from literature WHERE bibtexkey='3643'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='octanal'),
    (SELECT id from literature WHERE bibtexkey='3670'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3670'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='octanal'),
    (SELECT id from literature WHERE bibtexkey='3611'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='octanal'),
    (SELECT id from literature WHERE bibtexkey='2457'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '7400',
    'M',
    (SELECT id from species WHERE iupac='octanal'),
    (SELECT id from literature WHERE bibtexkey='630'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='630'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='octanal'),
    (SELECT id from literature WHERE bibtexkey='754'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='octanal'),
    (SELECT id from literature WHERE bibtexkey='3075'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='octanal'),
    (SELECT id from literature WHERE bibtexkey='2388'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='octanal'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='octanal'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at303K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='octanal'),
    (SELECT id from literature WHERE bibtexkey='3135'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='octanal'),
    (SELECT id from literature WHERE bibtexkey='3644'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octanal'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octanal'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octanal'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octanal'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octanal'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octanal'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octanal'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octanal'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octanal'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octanal'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7300',
    'Q',
    (SELECT id from species WHERE iupac='octanal'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octanal'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octanal'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octanal'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octanal'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octanal'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octanal'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='octanal'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6200',
    '?',
    (SELECT id from species WHERE iupac='octanal'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='octanal'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at303K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    '?',
    (SELECT id from species WHERE iupac='octanal'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at303K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='octanal'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-ethylhexanal',
    'C<sub>8</sub>H<sub>16</sub>O',
    '',
    '123-05-7',
    'LGYNIFWIKSEESD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '5400',
    'L',
    (SELECT id from species WHERE iupac='2-ethylhexanal'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-ethylhexanal'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-ethylhexanal'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-ethylhexanal'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-ethylhexanal'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylhexanal'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylhexanal'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylhexanal'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylhexanal'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylhexanal'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylhexanal'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylhexanal'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylhexanal'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C729CHO',
    'C<sub>8</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'MEGRLTONSLAOOM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>2</sup>',
    '10000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C729CHO'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C729CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C729CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C729CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C810OH',
    'C<sub>8</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'WBGXLUPQADVOIR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C810OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C810OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C810OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C822OH',
    'C<sub>8</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '',
    'CCTLWIOCAVSPLW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C822OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C822OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C822OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C824OH',
    'C<sub>8</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'RBBQERVBTKJTLF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C824OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C824OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C824OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C826OH',
    'C<sub>8</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'LLAUXDLXTPQIPI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C826OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C826OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C826OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C830OH',
    'C<sub>8</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '',
    'KODLEZWYEGWLGP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C830OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C830OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C830OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C831OH',
    'C<sub>8</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'YTEDFRLZFCPFBH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C831OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C831OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C831OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C89OH',
    'C<sub>8</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '',
    'KMZPPEYMMZMCIQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C89OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C89OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C89OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nonanal',
    'C<sub>8</sub>H<sub>17</sub>CHO',
    '',
    '124-19-6',
    'GYHFUZHODSMOHU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '6800',
    'L',
    (SELECT id from species WHERE iupac='nonanal'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '6700',
    'M',
    (SELECT id from species WHERE iupac='nonanal'),
    (SELECT id from literature WHERE bibtexkey='630'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='630'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='nonanal'),
    (SELECT id from literature WHERE bibtexkey='754'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='nonanal'),
    (SELECT id from literature WHERE bibtexkey='3075'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='nonanal'),
    (SELECT id from literature WHERE bibtexkey='2388'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='nonanal'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='nonanal'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at303K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='nonanal'),
    (SELECT id from literature WHERE bibtexkey='3135'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonanal'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonanal'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonanal'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonanal'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonanal'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonanal'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonanal'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonanal'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonanal'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonanal'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonanal'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonanal'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonanal'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonanal'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonanal'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonanal'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='nonanal'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='nonanal'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at303K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='nonanal'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at303K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='nonanal'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,5,5-trimethylhexanal',
    'C<sub>9</sub>H<sub>18</sub>O',
    '',
    '5435-64-3',
    'WTPYRCJDOZVZON-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5,5-trimethylhexanal'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'decanal',
    'C<sub>9</sub>H<sub>19</sub>CHO',
    '',
    '112-31-2',
    'KSMVZQYAVGTKIV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;3</sup>',
    '8900',
    'L',
    (SELECT id from species WHERE iupac='decanal'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='decanal'),
    (SELECT id from literature WHERE bibtexkey='2955'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;3</sup>',
    '8700',
    'M',
    (SELECT id from species WHERE iupac='decanal'),
    (SELECT id from literature WHERE bibtexkey='630'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='630'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='decanal'),
    (SELECT id from literature WHERE bibtexkey='3075'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='decanal'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='decanal'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='decanal'),
    (SELECT id from literature WHERE bibtexkey='3135'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decanal'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decanal'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decanal'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decanal'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decanal'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decanal'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decanal'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decanal'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decanal'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decanal'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7900',
    'Q',
    (SELECT id from species WHERE iupac='decanal'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decanal'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decanal'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='decanal'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '8500',
    '?',
    (SELECT id from species WHERE iupac='decanal'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C918CHO',
    'C<sub>10</sub>H<sub>16</sub>O<sub>2</sub>',
    '',
    '',
    'GWMMOZICECYZLL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C918CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C918CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C918CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hydroxycitronellal',
    'C<sub>10</sub>H<sub>20</sub>O<sub>2</sub>',
    '',
    '107-75-5',
    'WPFVBOQKRVRMJB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydroxycitronellal'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'undecanal',
    'C<sub>11</sub>H<sub>22</sub>O',
    '',
    '112-44-7',
    'KMPQYAYAQWNLME-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='undecanal'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='undecanal'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='undecanal'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='undecanal'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='undecanal'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '8300',
    'Q',
    (SELECT id from species WHERE iupac='undecanal'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '8300',
    '?',
    (SELECT id from species WHERE iupac='undecanal'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dodecanal',
    'C<sub>12</sub>H<sub>24</sub>O',
    '',
    '112-54-9',
    'HFJRKMMYBMWEAD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dodecanal'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dodecanal'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dodecanal'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dodecanal'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dodecanal'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-tridecanal',
    'C<sub>13</sub>H<sub>26</sub>O',
    '',
    '10486-19-8',
    'BGEHHAVMRVXCGR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-tridecanal'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-tridecanal'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-tridecanal'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-tridecanal'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-tridecanal'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-tetradecanal',
    'C<sub>14</sub>H<sub>28</sub>O',
    '',
    '124-25-4',
    'UHUFTBALEZWWIH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-tetradecanal'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-tetradecanal'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-tetradecanal'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'aquaflora',
    'C<sub>12</sub>H<sub>18</sub>O',
    '',
    '1339119-15-1',
    'BFTAXJRKNXWMMX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='aquaflora'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'starfleur',
    'C<sub>13</sub>H<sub>24</sub>O',
    '3-(4-isobutylcyclohexyl)propanal',
    '1254940-85-6',
    'XUTZHJNXAOHUTM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='starfleur'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C126CO',
    'C<sub>12</sub>H<sub>18</sub>O<sub>2</sub>',
    '',
    '',
    'IWMJDJFLMSAAES-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C126CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C126CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C126CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C126OH',
    'C<sub>12</sub>H<sub>20</sub>O<sub>2</sub>',
    '',
    '',
    'PQYIIYBUHROKIY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C126OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C126OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C126OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C127OH',
    'C<sub>12</sub>H<sub>20</sub>O<sub>3</sub>',
    '',
    '',
    'QHKXYVNBHFONML-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C127OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C127OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C127OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C126CHO',
    'C<sub>13</sub>H<sub>20</sub>O<sub>2</sub>',
    '',
    '',
    'ZDIXDRBTLRZYNM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C126CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C126CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C126CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1311OH',
    'C<sub>13</sub>H<sub>22</sub>O<sub>3</sub>',
    '',
    '',
    'CBUCUSJJCJUTML-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1311OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1311OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1311OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1313OH',
    'C<sub>13</sub>H<sub>22</sub>O<sub>4</sub>',
    '',
    '',
    'XIWFBNXBOAYHAJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1313OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1313OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1313OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C136OH',
    'C<sub>13</sub>H<sub>22</sub>O<sub>2</sub>',
    '',
    '',
    'GEHGNVSPJQGFQG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C136OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C136OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C136OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propenal',
    'CH<sub>2</sub>CHCHO',
    'acrolein',
    '107-02-8',
    'HGINCPLSRVDWNT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '5500',
    'L',
    (SELECT id from species WHERE iupac='propenal'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3500-107-02-8',
    '3500', 'The formula of propenal is incorrectly given as "CH<sub>2</sub>CHO" by Burkholder et&nbsp;al. (2019).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3500-107-02-8'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;2</sup>',
    '5100',
    'L',
    (SELECT id from species WHERE iupac='propenal'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;2</sup>',
    '5100',
    'M',
    (SELECT id from species WHERE iupac='propenal'),
    (SELECT id from literature WHERE bibtexkey='483'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propenal'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'V',
    (SELECT id from species WHERE iupac='propenal'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propenal'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propenal'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propenal'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '3800',
    'X',
    (SELECT id from species WHERE iupac='propenal'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'X',
    (SELECT id from species WHERE iupac='propenal'),
    (SELECT id from literature WHERE bibtexkey='howard89'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='propenal'),
    (SELECT id from literature WHERE bibtexkey='gaffney84'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from715'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='propenal'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='propenal'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propenal'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propenal'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propenal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propenal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propenal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propenal'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propenal'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propenal'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propenal'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propenal'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propenal'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4600',
    'Q',
    (SELECT id from species WHERE iupac='propenal'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propenal'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propenal'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3800',
    '?',
    (SELECT id from species WHERE iupac='propenal'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propenal'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methylpropenal',
    'C<sub>4</sub>H<sub>6</sub>O',
    'methacrolein',
    '78-85-3',
    'STNJBCKSHOAVAJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '4600',
    'L',
    (SELECT id from species WHERE iupac='2-methylpropenal'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2-methylpropenal'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '4600',
    'L',
    (SELECT id from species WHERE iupac='2-methylpropenal'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '4300',
    'M',
    (SELECT id from species WHERE iupac='2-methylpropenal'),
    (SELECT id from literature WHERE bibtexkey='2524'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methylpropenal'),
    (SELECT id from literature WHERE bibtexkey='1004'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '5300',
    'M',
    (SELECT id from species WHERE iupac='2-methylpropenal'),
    (SELECT id from literature WHERE bibtexkey='985'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylpropenal'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methylpropenal'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methylpropenal'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropenal'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropenal'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropenal'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropenal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropenal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropenal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropenal'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropenal'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropenal'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropenal'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropenal'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropenal'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropenal'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4000',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropenal'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methylpropenal'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4800',
    '?',
    (SELECT id from species WHERE iupac='2-methylpropenal'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methylpropenal'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-butenal',
    'CH<sub>3</sub>CHCHCHO',
    'crotonaldehyde',
    '4170-30-3',
    'MLUCVPSAIODCQM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;1</sup>',
    '3600',
    'X',
    (SELECT id from species WHERE iupac='2-butenal'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-butenal'),
    (SELECT id from literature WHERE bibtexkey='gaffney84'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from715'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butenal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butenal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butenal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butenal'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butenal'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='2-butenal'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3500-4170-30-3',
    '3500', 'The temperature dependence parameter C for 2-butenal is missing in Burkholder et&nbsp;al. (2019). The correct value is C = 24.42 (Robert E.&nbsp;Huie, personal communication, 2021).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3500-4170-30-3'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(E)-2-butenal',
    'CH<sub>3</sub>CHCHCHO',
    '<i>trans</i>-crotonaldehyde',
    '123-73-9',
    'MLUCVPSAIODCQM-NSCUHMNNSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;1</sup>',
    '5300',
    'L',
    (SELECT id from species WHERE iupac='(E)-2-butenal'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='(E)-2-butenal'),
    (SELECT id from literature WHERE bibtexkey='755'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(E)-2-butenal'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(E)-2-butenal'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='(E)-2-butenal'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(E)-2-butenal'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(E)-2-butenal'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(E)-2-butenal'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(E)-2-butenal'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5000',
    'Q',
    (SELECT id from species WHERE iupac='(E)-2-butenal'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(E)-2-butenal'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(E)-2-butenal'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(E)-2-butenal'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(E)-2-butenal'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4300',
    '?',
    (SELECT id from species WHERE iupac='(E)-2-butenal'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(E)-2-butenal'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(E)-2-butenal'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-hexenal',
    'C<sub>3</sub>H<sub>7</sub>CHCHCHO',
    '',
    '505-57-7',
    'MBDOYVRWFFCFHM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hexenal'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hexenal'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hexenal'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hexenal'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hexenal'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-hexenal'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(E)-2-hexenal',
    'C<sub>3</sub>H<sub>7</sub>CHCHCHO',
    '<i>trans</i>-2-hexenal',
    '6728-26-3',
    'MBDOYVRWFFCFHM-SNAWJCMRSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='(E)-2-hexenal'),
    (SELECT id from literature WHERE bibtexkey='1922'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;1</sup>',
    '5700',
    'M',
    (SELECT id from species WHERE iupac='(E)-2-hexenal'),
    (SELECT id from literature WHERE bibtexkey='3650'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at303K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='(E)-2-hexenal'),
    (SELECT id from literature WHERE bibtexkey='755'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='(E)-2-hexenal'),
    (SELECT id from literature WHERE bibtexkey='3650'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(E)-2-hexenal'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(E)-2-hexenal'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(E)-2-hexenal'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(E,E)-2,4-hexadienal',
    'CH<sub>3</sub>CHCHCHCHCHO',
    '<i>trans</i>-<i>trans</i>-2,4-hexadienal',
    '142-83-6',
    'BATOPAZDIZEVQF-MQQKCMAXSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'M',
    (SELECT id from species WHERE iupac='(E,E)-2,4-hexadienal'),
    (SELECT id from literature WHERE bibtexkey='755'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(E,E)-2,4-hexadienal'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(E,E)-2,4-hexadienal'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(E,E)-2,4-hexadienal'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(E,E)-2,4-hexadienal'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(E,E)-2,4-hexadienal'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    '?',
    (SELECT id from species WHERE iupac='(E,E)-2,4-hexadienal'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-heptenal',
    'C<sub>7</sub>H<sub>12</sub>O',
    '',
    '2463-63-0',
    'NDFKTBCGKNOHPJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-heptenal'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(E)-2-heptenal',
    'C<sub>7</sub>H<sub>12</sub>O',
    '<i>trans</i>-2-heptenal',
    '18829-55-5',
    'NDFKTBCGKNOHPJ-AATRIKPKSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(E)-2-heptenal'),
    (SELECT id from literature WHERE bibtexkey='3521'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(Z)-4-heptenal',
    'C<sub>7</sub>H<sub>12</sub>O',
    '<i>cis</i>-4-heptenal',
    '6728-31-0',
    'VVGOCOMZRGWHPI-ARJAWSKDSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='(Z)-4-heptenal'),
    (SELECT id from literature WHERE bibtexkey='1937'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-octenal',
    'C<sub>8</sub>H<sub>14</sub>O',
    '',
    '2363-89-5',
    'LVBXEMGDVWVTGY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-octenal'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-octenal'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-octenal'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-octenal'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-octenal'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-octenal'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(E)-2-octenal',
    'C<sub>8</sub>H<sub>14</sub>O',
    '<i>trans</i>-2-octenal',
    '2548-87-0',
    'LVBXEMGDVWVTGY-VOTSOKGWSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='(E)-2-octenal'),
    (SELECT id from literature WHERE bibtexkey='755'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(E)-2-octenal'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(E)-2-octenal'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(E)-2-octenal'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='(E)-2-octenal'),
    (SELECT id from literature WHERE bibtexkey='510'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '510-2548-87-0',
    '755,510', 'The data from Buttery et&nbsp;al. (1971) for <i>trans</i>-2-octenal are incorrectly cited by Betterton (1992).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='510-2548-87-0'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-ethyl-2-hexenal',
    'C<sub>8</sub>H<sub>14</sub>O',
    '',
    '645-62-5',
    'PYLMCYQHBRSDND-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '5800',
    'L',
    (SELECT id from species WHERE iupac='2-ethyl-2-hexenal'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(E)-2-nonenal',
    'C<sub>9</sub>H<sub>16</sub>O',
    '<i>trans</i>-2-nonenal',
    '18829-56-6',
    'BSAIUMLZVGUGKX-BQYQJAHWSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='(E)-2-nonenal'),
    (SELECT id from literature WHERE bibtexkey='2389'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>trans</i>-2,<i>cis</i>-6-nonadienal',
    'C<sub>9</sub>H<sub>14</sub>O',
    '',
    '557-48-2',
    'HZYHMHHBBBSGHB-ODYTWBPASA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;2</sup>',
    '7100',
    'M',
    (SELECT id from species WHERE iupac='<i>trans</i>-2,<i>cis</i>-6-nonadienal'),
    (SELECT id from literature WHERE bibtexkey='3303'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,7-dimethyl-6-octenal',
    'C<sub>10</sub>H<sub>18</sub>O',
    'citronellal',
    '106-23-0',
    'NEHNMFOYXAPHSD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '4500',
    'V',
    (SELECT id from species WHERE iupac='3,7-dimethyl-6-octenal'),
    (SELECT id from literature WHERE bibtexkey='2125'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,7-dimethyl-6-octenal'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,7-dimethyl-2,6-octadienal',
    'C<sub>10</sub>H<sub>16</sub>O',
    'citral',
    '5392-40-5',
    'WTEVQBCEXWBHNA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '6700',
    'M',
    (SELECT id from species WHERE iupac='3,7-dimethyl-2,6-octadienal'),
    (SELECT id from literature WHERE bibtexkey='3776'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,7-dimethyl-2,6-octadienal'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,7-dimethyl-2,6-octadienal'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tillenal',
    'C<sub>11</sub>H<sub>18</sub>O',
    '3-(4,4-dimethyl-1-cyclohexen-1-yl)propanal',
    '850997-10-3',
    'IHMKWBJKOWYASH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tillenal'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'lilybelle',
    'C<sub>12</sub>H<sub>20</sub>O',
    '',
    '1378867-81-2',
    'VZZSYXAVGYODQG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='lilybelle'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'mugoxal',
    'C<sub>13</sub>H<sub>22</sub>O',
    '3-(4-<i>tert</i>-butylcyclohexen-1-yl)propanal',
    '',
    'WGWWNPFQPHLSIM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='mugoxal'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'orange oil',
    'C<sub>15</sub>H<sub>22</sub>O',
    '',
    '8028-48-6',
    'NOPLRNXKHZRXHT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='orange oil'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benzaldehyde',
    'C<sub>6</sub>H<sub>5</sub>CHO',
    '',
    '100-52-7',
    'HUMNYLRZRPPJDN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '5200',
    'L',
    (SELECT id from species WHERE iupac='benzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3518-100-52-7-consicheck',
    '3518', 'Values at 298&nbsp;K in Tables&nbsp;C2 and C5 of Brockbank (2013) are inconsistent, with 6&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3518-100-52-7-consicheck'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '5500',
    'L',
    (SELECT id from species WHERE iupac='benzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '4800',
    'L',
    (SELECT id from species WHERE iupac='benzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '6300',
    'M',
    (SELECT id from species WHERE iupac='benzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='2817'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='benzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3671'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '7000',
    'M',
    (SELECT id from species WHERE iupac='benzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='985'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;1</sup>',
    '4600',
    'M',
    (SELECT id from species WHERE iupac='benzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='630'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='630'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '5100',
    'M',
    (SELECT id from species WHERE iupac='benzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='484'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='RCHOdiol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '5400',
    'T',
    (SELECT id from species WHERE iupac='benzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='2016'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2016',
    '', 'Calculated under the assumption that &#8710;G and &#8710;H are based on [mol&nbsp;L<sup>&#8722;1</sup>] and [atm] as the standard states.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2016'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='benzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='benzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='gaffney84'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from715'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='benzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='2165'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='2597'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at373K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='2599'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at373K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5800',
    'Q',
    (SELECT id from species WHERE iupac='benzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-Test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='benzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='benzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5400',
    '?',
    (SELECT id from species WHERE iupac='benzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='benzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='benzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phenylacetaldehyde',
    'C<sub>6</sub>H<sub>5</sub>CH<sub>2</sub>CHO',
    '',
    '122-78-1',
    'DTUQWGWMVIHBKE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenylacetaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenylacetaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenylacetaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenylacetaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenylacetaldehyde'),
    (SELECT id from literature WHERE bibtexkey='2597'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at373K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenylacetaldehyde'),
    (SELECT id from literature WHERE bibtexkey='2598'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at373K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methylbenzaldehyde',
    'C<sub>8</sub>H<sub>8</sub>O',
    'o-tolualdehyde',
    '529-20-4',
    'BTFQKIATRPGRBS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '6900',
    'M',
    (SELECT id from species WHERE iupac='2-methylbenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3724'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methylbenzaldehyde',
    'C<sub>8</sub>H<sub>8</sub>O',
    'm-tolualdehyde',
    '620-23-5',
    'OVWYEQOVUDKZNU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '7200',
    'L',
    (SELECT id from species WHERE iupac='3-methylbenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '5800',
    'M',
    (SELECT id from species WHERE iupac='3-methylbenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3776'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '7200',
    'M',
    (SELECT id from species WHERE iupac='3-methylbenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3724'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methylbenzaldehyde',
    'C<sub>8</sub>H<sub>8</sub>O',
    'p-tolualdehyde',
    '104-87-0',
    'FXLOVSHXALFLKQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;1</sup>',
    '7200',
    'L',
    (SELECT id from species WHERE iupac='4-methylbenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;1</sup>',
    '6400',
    'M',
    (SELECT id from species WHERE iupac='4-methylbenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3776'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;1</sup>',
    '7200',
    'M',
    (SELECT id from species WHERE iupac='4-methylbenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3724'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-methylbenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-methylbenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;1</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='4-methylbenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylbenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylbenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylbenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylbenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylbenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylbenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylbenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylbenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylbenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-methylbenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'terephthaldialdehyde',
    'C<sub>8</sub>H<sub>6</sub>O<sub>2</sub>',
    '',
    '623-27-8',
    'KUCOHFSKRZZVRO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='terephthaldialdehyde'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-hydroxybenzaldehyde',
    'C<sub>6</sub>H<sub>4</sub>(OH)CHO',
    '2-formylphenol; salicylaldehyde',
    '90-02-8',
    'SMQUZDBALVYZAC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '6200',
    'M',
    (SELECT id from species WHERE iupac='2-hydroxybenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3724'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-hydroxybenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxybenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxybenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3723'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3723',
    '3723', 'Calculated using the experimental value adjusted (EVA) method; see McFall et&nbsp;al. (2020) for details.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3723'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxybenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxybenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxybenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxybenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-hydroxybenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'at359K',
    '', 'Value at T = 359&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at359K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-hydroxybenzaldehyde',
    'C<sub>6</sub>H<sub>4</sub>(OH)CHO',
    '3-formylphenol',
    '100-83-4',
    'IAVREABSGIHHMO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-hydroxybenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='gaffney84'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from715'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hydroxybenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hydroxybenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hydroxybenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hydroxybenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hydroxybenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hydroxybenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hydroxybenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hydroxybenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hydroxybenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-hydroxybenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-hydroxybenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-hydroxybenzaldehyde',
    'C<sub>6</sub>H<sub>4</sub>(OH)CHO',
    '4-formylphenol',
    '123-08-0',
    'RGHHSNMVTDWUBI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>4</sup>',
    '8600',
    'T',
    (SELECT id from species WHERE iupac='4-hydroxybenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='724'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='assumedMatm'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-hydroxybenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-hydroxybenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-hydroxybenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-hydroxybenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-hydroxybenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-hydroxybenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-hydroxybenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-hydroxybenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-hydroxybenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-hydroxybenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-hydroxybenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methoxybenzaldehyde',
    'C<sub>8</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '135-02-4',
    'PKZJLOCLABXVMC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '8900',
    'M',
    (SELECT id from species WHERE iupac='2-methoxybenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3724'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methoxybenzaldehyde',
    'C<sub>8</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '591-31-1',
    'WMPDAIZRQDCGFH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1',
    '8800',
    'M',
    (SELECT id from species WHERE iupac='3-methoxybenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3724'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methoxybenzaldehyde',
    'C<sub>8</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '123-11-5',
    'ZRSNZINYAWTAHE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>1</sup>',
    '8700',
    'M',
    (SELECT id from species WHERE iupac='4-methoxybenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3724'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-phenyl-2-propenal',
    'C<sub>9</sub>H<sub>8</sub>O',
    'cinnamaldehyde',
    '104-55-2',
    'KJPRLNWUNMBNBZ-QPJJXVBHSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-phenyl-2-propenal'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '6300',
    'V',
    (SELECT id from species WHERE iupac='3-phenyl-2-propenal'),
    (SELECT id from literature WHERE bibtexkey='2125'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethylbenzaldehyde',
    'C<sub>9</sub>H<sub>10</sub>O',
    '',
    '5779-93-1',
    'UIFVCPMLQXKEEU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylbenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylbenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylbenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4-dimethylbenzaldehyde',
    'C<sub>9</sub>H<sub>10</sub>O',
    '',
    '5973-71-7',
    'POQJHLBMLVTHAU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethylbenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethylbenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethylbenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,5-dimethylbenzaldehyde',
    'C<sub>9</sub>H<sub>10</sub>O',
    '',
    '5779-95-3',
    'NBEFMISJJNGCIZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethylbenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethylbenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethylbenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-naphthaldehyde',
    'C<sub>11</sub>H<sub>8</sub>O',
    '',
    '66-99-9',
    'PJKVFARRVXDXAD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-naphthaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cyclemax',
    'C<sub>12</sub>H<sub>16</sub>O',
    '4-(1-methylethyl)-benzenepropanal',
    '7775-00-0',
    'RLEFOSDUWZYGOS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclemax'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bourgeonal',
    'C<sub>13</sub>H<sub>18</sub>O',
    '',
    '18127-01-0',
    'FZJUFJKVIYFBSY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bourgeonal'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'florhydral',
    'C<sub>13</sub>H<sub>18</sub>O',
    '',
    '125109-85-5',
    'OHRBQTOZYGEWCJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='florhydral'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cyclamen aldehyde',
    'C<sub>13</sub>H<sub>18</sub>O',
    '',
    '103-95-7',
    'ZFNVDHOSLNRHNN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclamen aldehyde'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'mimosal',
    'C<sub>13</sub>H<sub>16</sub>O',
    '4-methyl-5-(4-methylphenyl)pent-4-enal',
    '1226911-69-8',
    'LBKHGAIELUNYML-ZRDIBKRKSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='mimosal'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'lilial',
    'C<sub>14</sub>H<sub>20</sub>O',
    '',
    '80-54-6',
    'SDQFDHOLCGWZPU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='lilial'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hivernal',
    'C<sub>14</sub>H<sub>18</sub>O',
    '',
    '300371-33-9',
    'GEPCDOWRWODJEY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hivernal'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'silvial',
    'C<sub>14</sub>H<sub>20</sub>O',
    '',
    '6658-48-6',
    'YLIXVKUWWOQREC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='silvial'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'mefloral',
    'C<sub>14</sub>H<sub>20</sub>O',
    '',
    '62518-65-4',
    'GLZRHVTZLDNUQP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='mefloral'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nympheal',
    'C<sub>14</sub>H<sub>20</sub>O',
    '3-(4-isobutyl-2-methylphenyl)propanal',
    '1637294-12-2',
    'UKZXPOJABTXLMK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nympheal'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hexyl cinnamic aldehyde',
    'C<sub>15</sub>H<sub>20</sub>O',
    '',
    '101-86-0',
    'GUUHFMWKWLOQMM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexyl cinnamic aldehyde'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '&#945;-amyl cinnamaldehyde',
    'C<sub>14</sub>H<sub>18</sub>O',
    '',
    '122-40-7',
    'HMKKIXGYKWDQSV-KAMYIIQDSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#945;-amyl cinnamaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HCOCH2CO3H',
    'C<sub>3</sub>H<sub>4</sub>O<sub>4</sub>',
    '',
    '',
    'CFPRXLWZTODTLN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HCOCH2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HCOCH2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HCOCH2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PROPALOOH',
    'C<sub>3</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '',
    'UTLVMFCPERHVKU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PROPALOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PROPALOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PROPALOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BUTALAOOH',
    'C<sub>4</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'UBMPIIYSSVMXGT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BUTALAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BUTALAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BUTALAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BUTALO2H',
    'C<sub>4</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'HFNSAVKBHMZYBR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BUTALO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BUTALO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BUTALO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C3MDIALOOH',
    'C<sub>4</sub>H<sub>6</sub>O<sub>4</sub>',
    '',
    '',
    'WJWKLOFSCXWKQD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3MDIALOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3MDIALOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3MDIALOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CHOC2CO3H',
    'C<sub>4</sub>H<sub>6</sub>O<sub>4</sub>',
    '',
    '',
    'ZCKJJZIUFVHIST-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOC2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOC2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOC2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IBUTALBO2H',
    'C<sub>4</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'OSYMKIVGDGNGKG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IBUTALBO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IBUTALBO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IBUTALBO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IBUTALO2H',
    'C<sub>4</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'UINKREZTGVLFAU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IBUTALO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IBUTALO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IBUTALO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MALDALCO3H',
    'C<sub>4</sub>H<sub>4</sub>O<sub>4</sub>',
    '',
    '',
    'QFBRACYMKXGFRM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MALDALCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MALDALCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MALDALCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PRPAL2CO3H',
    'C<sub>4</sub>H<sub>6</sub>O<sub>4</sub>',
    '',
    '',
    'IGHWWGZEWMXWCB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRPAL2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRPAL2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRPAL2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C3EDIALOOH',
    'C<sub>5</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'IOKXWRCVGKGMQG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3EDIALOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3EDIALOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3EDIALOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C3M3CHOOOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'FJYKIGXUSFRBER-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3M3CHOOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3M3CHOOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3M3CHOOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4CHOAOOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'ZCMMOPXACREGKB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4CHOAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4CHOAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4CHOAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4CHOBOOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'JELNOURJPXUYRE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4CHOBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4CHOBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4CHOBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4CODBCO3H',
    'C<sub>5</sub>H<sub>6</sub>O<sub>4</sub>',
    '',
    '',
    'JLZDPUBRQDSTHL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4CODBCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4CODBCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4CODBCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C514OOH',
    'C<sub>5</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'PUFIIBDSTKVRQR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C514OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C514OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C514OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5DIALOOH',
    'C<sub>5</sub>H<sub>6</sub>O<sub>4</sub>',
    '',
    '',
    'MJFLAVCETRHPDB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5DIALOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5DIALOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5DIALOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CHOC4OOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'CTZAXNMAMSERLK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOC4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOC4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOC4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO1M22CO3H',
    'C<sub>5</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'HHOOHNHNSGMLRV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO1M22CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO1M22CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO1M22CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IC4CHOAOOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'MEJCTHPUJKQILI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IC4CHOAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IC4CHOAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IC4CHOAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MC3ODBCO3H',
    'C<sub>5</sub>H<sub>6</sub>O<sub>4</sub>',
    '',
    '',
    'UTZOYJZISPOIDM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MC3ODBCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MC3ODBCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MC3ODBCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C522CO3H',
    'C<sub>6</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'NCACXMVSAKPDND-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C522CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C522CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C522CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C615OOH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'XHCYBISQWAKVQU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C615OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C615OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C615OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6DIALOOH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'UGGYJIUZOSPDSO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6DIALOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6DIALOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6DIALOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CHOC4CO3H',
    'C<sub>6</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'RHHSYYPMFOTTRH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOC4CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOC4CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOC4CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO1C6OOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'HEPNQRDDKATRCQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO1C6OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO1C6OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO1C6OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C615CO3H',
    'C<sub>7</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'DXQJLRIPGQOCBO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C615CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C615CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C615CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C729OOH',
    'C<sub>7</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'PQESPNYRBXTFKD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C729OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C729OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C729OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C729CO3H',
    'C<sub>8</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'MJXLYBJUYDBXAC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C729CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C729CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C729CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C810OOH',
    'C<sub>8</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'YJCLQCSGAKCWEJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C810OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C810OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C810OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C822OOH',
    'C<sub>8</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'XWYULULFGKWPMD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>3</sup>',
    '11000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C822OOH'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C822OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C822OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C822OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C830OOH',
    'C<sub>8</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'QPQAMUJVCCDVQB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C830OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C830OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C830OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C831OOH',
    'C<sub>8</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'IGXVNESWPQHYEP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C831OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C831OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C831OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C89OOH',
    'C<sub>8</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'TYPKFPBYWMWINI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C89OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C89OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C89OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C822CO3H',
    'C<sub>9</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'DRDXOQWGQPPQFG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '14000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C822CO3H'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C822CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C822CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C822CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C830CO3H',
    'C<sub>9</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'YIGLTTCQERBPNX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C830CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C830CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C830CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C89CO3H',
    'C<sub>9</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'QJRQWHYQDGSSTJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C89CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C89CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C89CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C126OOH',
    'C<sub>12</sub>H<sub>20</sub>O<sub>3</sub>',
    '',
    '',
    'KEVCPNVRIXMZTI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C126OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C126OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C126OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C126CO3H',
    'C<sub>13</sub>H<sub>20</sub>O<sub>4</sub>',
    '',
    '',
    'OZAZBNTYEOZXRC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C126CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C126CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C126CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C136OOH',
    'C<sub>13</sub>H<sub>22</sub>O<sub>3</sub>',
    '',
    '',
    'MAMVWZJYPZZMSJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C136OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C136OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C136OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C136CO3H',
    'C<sub>14</sub>H<sub>22</sub>O<sub>4</sub>',
    '',
    '',
    'JKRMUSIUVDAEPW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C136CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C136CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C136CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HCOCOHCO3H',
    'C<sub>3</sub>H<sub>4</sub>O<sub>5</sub>',
    '',
    '',
    'DIZMXPJJIVKAJT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HCOCOHCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HCOCOHCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HCOCOHCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HOCHOCOOH',
    'C<sub>3</sub>H<sub>6</sub>O<sub>4</sub>',
    '',
    '',
    'GWWSSJVARZQKFN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOCHOCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOCHOCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOCHOCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OCCOHCOOH',
    'C<sub>3</sub>H<sub>6</sub>O<sub>4</sub>',
    '',
    '',
    'UFAXCNDNIIDPQE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OCCOHCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OCCOHCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OCCOHCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4OCCOHOOH',
    'C<sub>4</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'JJIHBDXOHFOUDV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4OCCOHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4OCCOHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4OCCOHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:COCCOHCOOH',
    'C<sub>4</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'XTEYRSCVGRLIOG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:COCCOHCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:COCCOHCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:COCCOHCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:COHM2CO3H',
    'C<sub>4</sub>H<sub>6</sub>O<sub>5</sub>',
    '',
    '',
    'AEAZUHMXWJBPCW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:COHM2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:COHM2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:COHM2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HMACROOH',
    'C<sub>4</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'AWITZWJPGUOCMB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HMACROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HMACROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HMACROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MACROHOOH',
    'C<sub>4</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'HWQXXVVDRNBYQB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MACROHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MACROHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MACROHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MACROOH',
    'C<sub>4</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'MOSGWPXPTZVSII-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MACROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MACROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MACROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MALDIALOOH',
    'C<sub>4</sub>H<sub>6</sub>O<sub>5</sub>',
    '',
    '',
    'MNYHDFHIZDEDLP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MALDIALOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MALDIALOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MALDIALOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ALC4DOLOOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'BTJWWKUWEVGVGA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ALC4DOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ALC4DOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ALC4DOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4MALOHOOH',
    'C<sub>5</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'NJMKFLHNNBFYIH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4MALOHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4MALOHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4MALOHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C57OOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'VJGRRPOTERGJKF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C57OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C57OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C57OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C58OOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'MTCQYLXAFMKVMT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C58OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C58OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C58OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CHOC4OHOOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'LTZYUHWRVSINRM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOC4OHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOC4OHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOC4OHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HIEB1OOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>6</sub>',
    '',
    '',
    'COFCBVJXHDFSHS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>13</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HIEB1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HIEB1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HIEB1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HIEB2OOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>6</sub>',
    '',
    '',
    'PKIUCWJPHHVKPZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>13</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HIEB2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HIEB2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HIEB2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HOC4CHOOOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'LRYOXTYJCQGVIC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOC4CHOOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOC4CHOOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOC4CHOOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IEB2OOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'MCOKLECUTPXNOW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IEB2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IEB2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IEB2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1H4C5CO3H',
    'C<sub>6</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'DOEHHISPDHWTCR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1H4C5CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1H4C5CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1H4C5CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C623OOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'OGBKQGQRAMSXTF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C623OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C623OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C623OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C67OOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'ONTGLCVTLGTTQS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C67OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C67OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C67OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C68OOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'ITDKDNQPTMKBIM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C68OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C68OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C68OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO1H63OOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'KJWILEAANBSBHN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO1H63OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO1H63OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO1H63OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C728OOH',
    'C<sub>7</sub>H<sub>14</sub>O<sub>5</sub>',
    '',
    '',
    'WJYXJQPIZCIBJO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>10</sup>',
    '18000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C728OOH'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C728OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C728OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C728OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C730OOH',
    'C<sub>7</sub>H<sub>14</sub>O<sub>5</sub>',
    '',
    '',
    'YXKHJQXHKYJCPI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>10</sup>',
    '18000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C730OOH'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C730OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C730OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C730OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C824OOH',
    'C<sub>8</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'FGEKWAMEWUMQIL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>6</sup>',
    '15000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C824OOH'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C824OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C824OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C824OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C826OOH',
    'C<sub>8</sub>H<sub>14</sub>O<sub>5</sub>',
    '',
    '',
    'MATCTRFTDTXPPO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C826OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C826OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C826OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C127OOH',
    'C<sub>12</sub>H<sub>20</sub>O<sub>4</sub>',
    '',
    '',
    'CZSOPCQUOGQYQQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C127OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C127OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C127OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1311OOH',
    'C<sub>13</sub>H<sub>22</sub>O<sub>4</sub>',
    '',
    '',
    'GNGYVQPBVCXXTM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1311OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1311OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1311OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1313OOH',
    'C<sub>13</sub>H<sub>22</sub>O<sub>5</sub>',
    '',
    '',
    'ALNYAIDMJTUDIF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Aldehydes (RCHO)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1313OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1313OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1313OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Ketones (RCOR)',
    (SELECT id from categories WHERE catname='Organic species with oxygen (O)'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propanone',
    'CH<sub>3</sub>COCH<sub>3</sub>',
    'acetone',
    '67-64-1',
    'CSCPPACGZOOCGX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '5500',
    'L',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '5500',
    'L',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '5300',
    'L',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3518-67-64-1-consicheck',
    '3518', 'Values at 298&nbsp;K in Tables&nbsp;C2 and C5 of Brockbank (2013) are inconsistent, with 5&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3518-67-64-1-consicheck'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '5500',
    'L',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '5300',
    'L',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='2822'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '5100',
    'L',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '5700',
    'L',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '4800',
    'L',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '5000',
    'L',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='3617'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '4600',
    'L',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '5100',
    'M',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='2822'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '4500',
    'M',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='3526'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '5400',
    'M',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='2524'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '4200',
    'M',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='3112'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='alsosalt'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '6400',
    'M',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='1571'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='1937'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '4300',
    'M',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='2825'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='3532'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at297K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='2969'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2969epics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='2969'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2969linear'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='2969'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2969direct'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='3646'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '5300',
    'M',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='617'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='637'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='3675'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '5800',
    'M',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='495'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '3800',
    'M',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='630'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='630'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='2924'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='2448'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '4800',
    'M',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='483'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '5400',
    'M',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='1331'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='3635'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at303K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '5100',
    'M',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='3667'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3667',
    '3667', 'Calculated from the slope of y<sub><span class="roman">ac</span></sub>P vs x<sub><span class="roman">ac</span></sub>, using data from Table&nbsp;VIII in Lichtenbelt and Schram (1985).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3667'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '7800',
    'M',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='3640'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='2917'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='1492'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='1492'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='754'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='2387'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at301K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='496'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='2580'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '3100',
    'V',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='3638'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='2234'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='714'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='713'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '4900',
    'T',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='2016'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2016'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '5000',
    'X',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='859'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '3300',
    'X',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='1154'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='gaffney84'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from715'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='1910'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5500',
    'Q',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='2531'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5100',
    '?',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='3091'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propanone'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propanone-2-13C',
    'CH<sub>3</sub>COCH<sub>3</sub>',
    'acetone-2-13C',
    '3881-06-9',
    'CSCPPACGZOOCGX-LBPDFUHNSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '5300',
    'M',
    (SELECT id from species WHERE iupac='propanone-2-13C'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-hydroxypropanone',
    'CH<sub>3</sub>COCH<sub>2</sub>OH',
    'hydroxyacetone',
    '116-09-6',
    'XLSMFKSTNGKWQX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1-hydroxypropanone'),
    (SELECT id from literature WHERE bibtexkey='2527'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxypropanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxypropanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxypropanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'butanone',
    'C<sub>2</sub>H<sub>5</sub>COCH<sub>3</sub>',
    'methyl ethyl ketone; MEK',
    '78-93-3',
    'ZWEHNKRNPOVVGH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '5700',
    'L',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '5700',
    'L',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '5600',
    'L',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '5700',
    'L',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '5700',
    'L',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '4600',
    'L',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '5400',
    'L',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '5500',
    'L',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='3617'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '5000',
    'L',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='3032'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='2955'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '5200',
    'M',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='2524'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '4400',
    'M',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='3112'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='alsosalt'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '12000',
    'M',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='1571'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='1937'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '4500',
    'M',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='2825'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'M',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='2483'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='cdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'M',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='1856'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='cdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='1922'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '4300',
    'M',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='3609'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='3643'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='3670'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3670'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='3611'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='2837'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='3646'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='1073'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '4700',
    'M',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='858'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '5000',
    'M',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='630'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='630'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;2</sup>',
    '-5100',
    'M',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='1156'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HTdep_r2_lessthan_0.9'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1156'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='2448'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='2449'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '5700',
    'M',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='483'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='2232'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='3635'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at303K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='3640'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at303K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='2917'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='1492'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='792'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='754'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='2580'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;2</sup>',
    '3700',
    'V',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='3638'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='2234'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;2</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='714'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '5500',
    'T',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='2016'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2016'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5500',
    'T',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='2220'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;2</sup>',
    '5800',
    'X',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='1154'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='1912'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='1910'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5900',
    'Q',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5300',
    '?',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='3091'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='495'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='butanone'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'butanone-1,1,1,3,3-d5',
    'C<sub>2</sub>H<sub>5</sub>COCH<sub>3</sub>',
    'methyl ethyl ketone-d5; MEK-d5',
    '24313-50-6',
    'ZWEHNKRNPOVVGH-PDWRLMEDSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '8200',
    'M',
    (SELECT id from species WHERE iupac='butanone-1,1,1,3,3-d5'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-pentanone',
    'C<sub>3</sub>H<sub>7</sub>COCH<sub>3</sub>',
    '',
    '107-87-9',
    'XNLICIUVMPYHGG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '6000',
    'L',
    (SELECT id from species WHERE iupac='2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '5900',
    'L',
    (SELECT id from species WHERE iupac='2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3617'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '5900',
    'M',
    (SELECT id from species WHERE iupac='2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3632'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '5700',
    'M',
    (SELECT id from species WHERE iupac='2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2524'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '4600',
    'M',
    (SELECT id from species WHERE iupac='2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3112'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='alsosalt'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='1937'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '4800',
    'M',
    (SELECT id from species WHERE iupac='2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2825'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2837'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2339'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2232'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2917'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='1492'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='1492'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'at313K',
    '', 'Value at T = 313&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at313K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='754'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2387'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at301K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3642'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2339'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '4300',
    'V',
    (SELECT id from species WHERE iupac='2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3638'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2234'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2388'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5900',
    'T',
    (SELECT id from species WHERE iupac='2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2220'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;2</sup>',
    '4600',
    'X',
    (SELECT id from species WHERE iupac='2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='1154'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6200',
    'Q',
    (SELECT id from species WHERE iupac='2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6500',
    '?',
    (SELECT id from species WHERE iupac='2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3091'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2233'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-pentanone',
    'C<sub>2</sub>H<sub>5</sub>COC<sub>2</sub>H<sub>5</sub>',
    'diethyl ketone',
    '96-22-0',
    'FDPIMTJIUBPUKL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;2</sup>',
    '5800',
    'L',
    (SELECT id from species WHERE iupac='3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3518-96-22-0-consicheck',
    '3518', 'Values at 298&nbsp;K in Tables&nbsp;C2 and C5 of Brockbank (2013) are inconsistent, with 6&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3518-96-22-0-consicheck'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '6000',
    'L',
    (SELECT id from species WHERE iupac='3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3617'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '5900',
    'M',
    (SELECT id from species WHERE iupac='3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3632'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3526'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '5600',
    'M',
    (SELECT id from species WHERE iupac='3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2524'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2917'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;5</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2491'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at303K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2234'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '6000',
    'T',
    (SELECT id from species WHERE iupac='3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2016'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2016'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6000',
    'T',
    (SELECT id from species WHERE iupac='3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2220'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '9200',
    'X',
    (SELECT id from species WHERE iupac='3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='1154'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='howard93'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='1910'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6200',
    'Q',
    (SELECT id from species WHERE iupac='3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-Test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6800',
    '?',
    (SELECT id from species WHERE iupac='3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3091'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-cyclopropyl-ethanone',
    'C<sub>5</sub>H<sub>8</sub>O',
    'cyclopropyl methyl ketone',
    '765-43-5',
    'HVCFCNAITDHQFX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;1</sup>',
    '5900',
    'T',
    (SELECT id from species WHERE iupac='1-cyclopropyl-ethanone'),
    (SELECT id from literature WHERE bibtexkey='2016'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2016'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5900',
    'T',
    (SELECT id from species WHERE iupac='1-cyclopropyl-ethanone'),
    (SELECT id from literature WHERE bibtexkey='2220'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-cyclopropyl-ethanone'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-cyclopropyl-ethanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-cyclopropyl-ethanone'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-cyclopropyl-ethanone'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-cyclopropyl-ethanone'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-Test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-cyclopropyl-ethanone'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-cyclopropyl-ethanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-2-butanone',
    'C<sub>5</sub>H<sub>10</sub>O',
    'isopropyl methyl ketone',
    '563-80-4',
    'SYBYTAAJFKOIEJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '5800',
    'L',
    (SELECT id from species WHERE iupac='3-methyl-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;2</sup>',
    '5700',
    'L',
    (SELECT id from species WHERE iupac='3-methyl-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='3617'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;2</sup>',
    '5600',
    'M',
    (SELECT id from species WHERE iupac='3-methyl-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='3632'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-methyl-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-methyl-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-methyl-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='1910'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;2</sup>',
    '5700',
    'T',
    (SELECT id from species WHERE iupac='3-methyl-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='2016'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2016'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5700',
    'T',
    (SELECT id from species WHERE iupac='3-methyl-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='2220'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5300',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7200',
    '?',
    (SELECT id from species WHERE iupac='3-methyl-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-methyl-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-methyl-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='3091'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-methyl-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cyclopentanone',
    'C<sub>5</sub>H<sub>8</sub>O',
    '',
    '120-92-3',
    'BGTOWKSIORTVQH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '5800',
    'L',
    (SELECT id from species WHERE iupac='cyclopentanone'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '',
    'M',
    (SELECT id from species WHERE iupac='cyclopentanone'),
    (SELECT id from literature WHERE bibtexkey='3526'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;1</sup>',
    '4900',
    'M',
    (SELECT id from species WHERE iupac='cyclopentanone'),
    (SELECT id from literature WHERE bibtexkey='3609'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='cyclopentanone'),
    (SELECT id from literature WHERE bibtexkey='2232'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopentanone'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopentanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopentanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopentanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopentanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopentanone'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopentanone'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5800',
    'Q',
    (SELECT id from species WHERE iupac='cyclopentanone'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopentanone'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopentanone'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopentanone'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopentanone'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cyclopentanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5600',
    '?',
    (SELECT id from species WHERE iupac='cyclopentanone'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    '?',
    (SELECT id from species WHERE iupac='cyclopentanone'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-hexanone',
    'C<sub>6</sub>H<sub>12</sub>O',
    '',
    '591-78-6',
    'QQZOPKMRPOGIEB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '6500',
    'L',
    (SELECT id from species WHERE iupac='2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;2</sup>',
    '6300',
    'L',
    (SELECT id from species WHERE iupac='2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='3617'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '6300',
    'M',
    (SELECT id from species WHERE iupac='2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='3632'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '8600',
    'M',
    (SELECT id from species WHERE iupac='2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;2</sup>',
    '4800',
    'M',
    (SELECT id from species WHERE iupac='2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='3112'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='alsosalt'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='1937'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;2</sup>',
    '5100',
    'M',
    (SELECT id from species WHERE iupac='2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='2825'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='2917'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;1</sup>',
    '4900',
    'V',
    (SELECT id from species WHERE iupac='2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='3638'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='1910'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6200',
    'T',
    (SELECT id from species WHERE iupac='2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='2220'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='howard93'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6600',
    'Q',
    (SELECT id from species WHERE iupac='2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6200',
    '?',
    (SELECT id from species WHERE iupac='2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='3091'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-hexanone-1,1,1,3,3-d5',
    'C<sub>6</sub>H<sub>12</sub>O',
    '',
    '4840-82-8',
    'QQZOPKMRPOGIEB-ZTIZGVCASA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '9000',
    'M',
    (SELECT id from species WHERE iupac='2-hexanone-1,1,1,3,3-d5'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-hexanone',
    'C<sub>6</sub>H<sub>12</sub>O',
    '',
    '589-38-8',
    'PFCHFHIRKBAQGU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;2</sup>',
    '7100',
    'L',
    (SELECT id from species WHERE iupac='3-hexanone'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='3-hexanone'),
    (SELECT id from literature WHERE bibtexkey='3617'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;2</sup>',
    '6400',
    'M',
    (SELECT id from species WHERE iupac='3-hexanone'),
    (SELECT id from literature WHERE bibtexkey='3632'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'M',
    (SELECT id from species WHERE iupac='3-hexanone'),
    (SELECT id from literature WHERE bibtexkey='1107'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1107notused'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-hexanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-hexanone'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hexanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hexanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hexanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hexanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hexanone'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hexanone'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hexanone'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6600',
    'Q',
    (SELECT id from species WHERE iupac='3-hexanone'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hexanone'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hexanone'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5800',
    '?',
    (SELECT id from species WHERE iupac='3-hexanone'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-hexanone'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-hexanone'),
    (SELECT id from literature WHERE bibtexkey='3091'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-2-pentanone',
    'C<sub>6</sub>H<sub>12</sub>O',
    '',
    '565-61-7',
    'UIHCLUNTQKBZGK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='3-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3617'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;2</sup>',
    '6000',
    'M',
    (SELECT id from species WHERE iupac='3-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3632'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3091'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-2-pentanone',
    '(CH<sub>3</sub>)<sub>2</sub>CHCH<sub>2</sub>COCH<sub>3</sub>',
    'methyl isobutyl ketone; MIBK',
    '108-10-1',
    'NTIZESTWPVYFNL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;2</sup>',
    '6200',
    'L',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;2</sup>',
    '6000',
    'L',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3617'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;2</sup>',
    '6000',
    'M',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3632'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3032'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '8700',
    'M',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2837'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3646'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '4600',
    'M',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='857'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='857'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '110',
    'M',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='1156'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HTdep_r2_lessthan_0.5'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1156'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2448'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2917'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2234'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='1910'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='howard90'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6600',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5700',
    '?',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3091'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='495'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-3-pentanone',
    'C<sub>6</sub>H<sub>12</sub>O',
    '',
    '565-69-5',
    'HYTRYEXINDDXJK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2-methyl-3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3617'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '6100',
    'M',
    (SELECT id from species WHERE iupac='2-methyl-3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3632'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methyl-3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3091'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3-dimethyl-2-butanone',
    'C<sub>6</sub>H<sub>12</sub>O',
    '<i>tert</i>-butyl methyl ketone',
    '75-97-8',
    'PJGSXYOJTGTZAV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '5800',
    'L',
    (SELECT id from species WHERE iupac='3,3-dimethyl-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '5700',
    'L',
    (SELECT id from species WHERE iupac='3,3-dimethyl-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='3617'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '5700',
    'M',
    (SELECT id from species WHERE iupac='3,3-dimethyl-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='3632'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,3-dimethyl-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,3-dimethyl-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;2</sup>',
    '6000',
    'T',
    (SELECT id from species WHERE iupac='3,3-dimethyl-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='2016'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2016'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6000',
    'T',
    (SELECT id from species WHERE iupac='3,3-dimethyl-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='2220'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5700',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5400',
    '?',
    (SELECT id from species WHERE iupac='3,3-dimethyl-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,3-dimethyl-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='3091'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cyclohexanone',
    'C<sub>6</sub>H<sub>10</sub>O',
    '',
    '108-94-1',
    'JHIVVAPYMSGYDF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '6400',
    'L',
    (SELECT id from species WHERE iupac='cyclohexanone'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;1</sup>',
    '5100',
    'M',
    (SELECT id from species WHERE iupac='cyclohexanone'),
    (SELECT id from literature WHERE bibtexkey='3609'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='cyclohexanone'),
    (SELECT id from literature WHERE bibtexkey='2232'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='cyclohexanone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cyclohexanone'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cyclohexanone'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cyclohexanone'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'X',
    (SELECT id from species WHERE iupac='cyclohexanone'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexanone'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexanone'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexanone'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexanone'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6200',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexanone'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexanone'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexanone'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexanone'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexanone'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexanone'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    '?',
    (SELECT id from species WHERE iupac='cyclohexanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6300',
    '?',
    (SELECT id from species WHERE iupac='cyclohexanone'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    '?',
    (SELECT id from species WHERE iupac='cyclohexanone'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    '?',
    (SELECT id from species WHERE iupac='cyclohexanone'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-heptanone',
    'C<sub>7</sub>H<sub>14</sub>O',
    '',
    '110-43-0',
    'CATSNJVOTSVZJV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;2</sup>',
    '6800',
    'L',
    (SELECT id from species WHERE iupac='2-heptanone'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;2</sup>',
    '6800',
    'L',
    (SELECT id from species WHERE iupac='2-heptanone'),
    (SELECT id from literature WHERE bibtexkey='3617'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;2</sup>',
    '5300',
    'M',
    (SELECT id from species WHERE iupac='2-heptanone'),
    (SELECT id from literature WHERE bibtexkey='3112'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='alsosalt'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;2</sup>',
    '5700',
    'M',
    (SELECT id from species WHERE iupac='2-heptanone'),
    (SELECT id from literature WHERE bibtexkey='2825'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-heptanone'),
    (SELECT id from literature WHERE bibtexkey='3643'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-heptanone'),
    (SELECT id from literature WHERE bibtexkey='3670'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3670'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-heptanone'),
    (SELECT id from literature WHERE bibtexkey='3611'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-heptanone'),
    (SELECT id from literature WHERE bibtexkey='2837'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-heptanone'),
    (SELECT id from literature WHERE bibtexkey='2339'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-heptanone'),
    (SELECT id from literature WHERE bibtexkey='2917'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-heptanone'),
    (SELECT id from literature WHERE bibtexkey='754'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-heptanone'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-heptanone'),
    (SELECT id from literature WHERE bibtexkey='2339'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-heptanone'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '5600',
    'V',
    (SELECT id from species WHERE iupac='2-heptanone'),
    (SELECT id from literature WHERE bibtexkey='3638'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-heptanone'),
    (SELECT id from literature WHERE bibtexkey='2234'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-heptanone'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-heptanone'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '4500',
    'X',
    (SELECT id from species WHERE iupac='2-heptanone'),
    (SELECT id from literature WHERE bibtexkey='1154'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-heptanone'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-heptanone'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-heptanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-heptanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-heptanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-heptanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-heptanone'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-heptanone'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-heptanone'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6900',
    'Q',
    (SELECT id from species WHERE iupac='2-heptanone'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-heptanone'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-heptanone'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-Test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-heptanone'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-heptanone'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-heptanone'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-heptanone'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-heptanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-heptanone'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6900',
    '?',
    (SELECT id from species WHERE iupac='2-heptanone'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-heptanone'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-heptanone'),
    (SELECT id from literature WHERE bibtexkey='3091'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-heptanone'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-heptanone'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-heptanone'),
    (SELECT id from literature WHERE bibtexkey='2233'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-heptanone',
    'C<sub>7</sub>H<sub>14</sub>O',
    '',
    '106-35-4',
    'NGAZZOYFWWSOGK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;2</sup>',
    '7000',
    'L',
    (SELECT id from species WHERE iupac='3-heptanone'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-heptanone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-heptanone'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-heptanone'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-heptanone'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-heptanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-heptanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-heptanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-heptanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-heptanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-heptanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-heptanone'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-heptanone'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6900',
    'Q',
    (SELECT id from species WHERE iupac='3-heptanone'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-heptanone'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-heptanone'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6000',
    '?',
    (SELECT id from species WHERE iupac='3-heptanone'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-heptanone'),
    (SELECT id from literature WHERE bibtexkey='3091'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-heptanone',
    'C<sub>7</sub>H<sub>14</sub>O',
    '',
    '123-19-3',
    'HCFAJYNVAYBARA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;2</sup>',
    '6800',
    'L',
    (SELECT id from species WHERE iupac='4-heptanone'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3518-123-19-3-consicheck',
    '3518', 'Values at 298&nbsp;K in Tables&nbsp;C2 and C5 of Brockbank (2013) are inconsistent, with 7&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3518-123-19-3-consicheck'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;2</sup>',
    '7000',
    'L',
    (SELECT id from species WHERE iupac='4-heptanone'),
    (SELECT id from literature WHERE bibtexkey='3617'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-heptanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-heptanone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-heptanone'),
    (SELECT id from literature WHERE bibtexkey='1910'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-heptanone'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-heptanone'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-heptanone'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-heptanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-heptanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-heptanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-heptanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-heptanone'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-heptanone'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-heptanone'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6900',
    'Q',
    (SELECT id from species WHERE iupac='4-heptanone'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-heptanone'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-heptanone'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-heptanone'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-heptanone'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7800',
    '?',
    (SELECT id from species WHERE iupac='4-heptanone'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-heptanone'),
    (SELECT id from literature WHERE bibtexkey='3091'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at303K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-heptanone'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-2-hexanone',
    'C<sub>7</sub>H<sub>14</sub>O',
    '',
    '2550-21-2',
    'GYWYASONLSQZBB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-methyl-2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='3091'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-2-hexanone',
    'C<sub>7</sub>H<sub>14</sub>O',
    '',
    '105-42-0',
    'XUPXMIAWKPTZLZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-methyl-2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='3091'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-methyl-2-hexanone',
    'C<sub>7</sub>H<sub>14</sub>O',
    '',
    '110-12-3',
    'FFWSICBKRCICMR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;2</sup>',
    '6800',
    'L',
    (SELECT id from species WHERE iupac='5-methyl-2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='5-methyl-2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='5-methyl-2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='5-methyl-2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6900',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7600',
    '?',
    (SELECT id from species WHERE iupac='5-methyl-2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='5-methyl-2-hexanone'),
    (SELECT id from literature WHERE bibtexkey='3091'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-3-hexanone',
    'C<sub>7</sub>H<sub>14</sub>O',
    '',
    '7379-12-6',
    'HIGGFWFRAWSMBR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-3-hexanone'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-hexanone'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methyl-3-hexanone'),
    (SELECT id from literature WHERE bibtexkey='3091'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-3-hexanone',
    'C<sub>7</sub>H<sub>14</sub>O',
    '',
    '17042-16-9',
    'ULPMRIXXHGUZFA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-3-hexanone'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-3-hexanone'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-methyl-3-hexanone'),
    (SELECT id from literature WHERE bibtexkey='3091'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-methyl-3-hexanone',
    'C<sub>7</sub>H<sub>14</sub>O',
    '',
    '623-56-3',
    'DXVYLFHTJZWTRF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='5-methyl-3-hexanone'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-3-hexanone'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='5-methyl-3-hexanone'),
    (SELECT id from literature WHERE bibtexkey='3091'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-2-pentanone',
    'C<sub>7</sub>H<sub>14</sub>O',
    '',
    '6137-03-7',
    'GSNKRSKIWFBWEG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-ethyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3091'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3-dimethyl-2-pentanone',
    'C<sub>7</sub>H<sub>14</sub>O',
    '',
    '20669-04-9',
    'QSHJLBQLQVSEFV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3-dimethyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,3-dimethyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3091'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4-dimethyl-2-pentanone',
    'C<sub>7</sub>H<sub>14</sub>O',
    '',
    '565-78-6',
    'QXHRQZNDMYRDPA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4-dimethyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,4-dimethyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3091'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,4-dimethyl-2-pentanone',
    'C<sub>7</sub>H<sub>14</sub>O',
    '',
    '590-50-1',
    'AZASWMGVGQEVCS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,4-dimethyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4,4-dimethyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3091'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dimethyl-3-pentanone',
    'C<sub>7</sub>H<sub>14</sub>O',
    '',
    '564-04-5',
    'VLNUTKMHYLQCQB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2-dimethyl-3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2-dimethyl-3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3091'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dimethyl-3-pentanone',
    'C<sub>7</sub>H<sub>14</sub>O',
    'diisopropyl ketone',
    '565-80-0',
    'HXVNBWAKAOHACI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '6100',
    'L',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '6500',
    'L',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3617'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='1910'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;1</sup>',
    '6400',
    'T',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2016'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2016'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6400',
    'T',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2220'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6000',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4900',
    '?',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,4-dimethyl-3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3091'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cycloheptanone',
    'C<sub>7</sub>H<sub>12</sub>O',
    '',
    '502-42-1',
    'CGZZMOTZOONQIA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cycloheptanone'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methylcyclohexanone',
    'C<sub>7</sub>H<sub>12</sub>O',
    '',
    '583-60-8',
    'LFSAPCRASZRSKS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5600',
    'Q',
    (SELECT id from species WHERE iupac='2-methylcyclohexanone'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4600',
    '?',
    (SELECT id from species WHERE iupac='2-methylcyclohexanone'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methylcyclohexanone',
    'C<sub>7</sub>H<sub>12</sub>O',
    '',
    '591-24-2',
    'UJBOOUHRTQVGRU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-methylcyclohexanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylcyclohexanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methylcyclohexanone',
    'C<sub>7</sub>H<sub>12</sub>O',
    '',
    '589-92-4',
    'VGVHNLRUAMRIEW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6500',
    'Q',
    (SELECT id from species WHERE iupac='4-methylcyclohexanone'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6100',
    '?',
    (SELECT id from species WHERE iupac='4-methylcyclohexanone'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dicyclopropylmethanone',
    'C<sub>7</sub>H<sub>10</sub>O',
    'dicyclopropyl ketone',
    '1121-37-5',
    'BIPUHAHGLJKIPK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '7300',
    'T',
    (SELECT id from species WHERE iupac='dicyclopropylmethanone'),
    (SELECT id from literature WHERE bibtexkey='2016'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2016'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7300',
    'T',
    (SELECT id from species WHERE iupac='dicyclopropylmethanone'),
    (SELECT id from literature WHERE bibtexkey='2220'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-octanone',
    'C<sub>6</sub>H<sub>13</sub>COCH<sub>3</sub>',
    '',
    '111-13-7',
    'ZPVFWPFBNIEHGJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '7500',
    'L',
    (SELECT id from species WHERE iupac='2-octanone'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3518-111-13-7-consicheck',
    '3518', 'Values at 298&nbsp;K in Tables&nbsp;C2 and C5 of Brockbank (2013) are inconsistent, with 6&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3518-111-13-7-consicheck'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2-octanone'),
    (SELECT id from literature WHERE bibtexkey='3617'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-octanone'),
    (SELECT id from literature WHERE bibtexkey='3643'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-octanone'),
    (SELECT id from literature WHERE bibtexkey='3670'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3670'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-octanone'),
    (SELECT id from literature WHERE bibtexkey='3611'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-octanone'),
    (SELECT id from literature WHERE bibtexkey='754'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-octanone'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-octanone'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-octanone'),
    (SELECT id from literature WHERE bibtexkey='2234'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-octanone'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-octanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-octanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-octanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-octanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-octanone'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-octanone'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7300',
    'Q',
    (SELECT id from species WHERE iupac='2-octanone'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-octanone'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-octanone'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-octanone'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-octanone'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-octanone'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-octanone'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-octanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-octanone'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7300',
    '?',
    (SELECT id from species WHERE iupac='2-octanone'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-octanone'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-octanone'),
    (SELECT id from literature WHERE bibtexkey='3091'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-octanone'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-octanone',
    'C<sub>8</sub>H<sub>16</sub>O',
    '',
    '106-68-3',
    'RHLVCLIPMVJYKS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '6900',
    'L',
    (SELECT id from species WHERE iupac='3-octanone'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '5800',
    'M',
    (SELECT id from species WHERE iupac='3-octanone'),
    (SELECT id from literature WHERE bibtexkey='3719'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3719-3-octanone',
    '3719', 'Table&nbsp;S2 in the supplement of Wu et&nbsp;al. (2022a) contains incorrect data for 3-octanone. Here, the corrected data (Shuang Wu, personal communication, 2022) were used: 2.88&times;10<sup>&#8722;2</sup> and 1.52&times;10<sup>&#8722;2</sup> at 25&nbsp;<sup>&#176;</sup>C and 35&nbsp;<sup>&#176;</sup>C, respectively.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3719-3-octanone'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-octanone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-octanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-octanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-octanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-octanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-octanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-octanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-octanone'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-octanone',
    'C<sub>8</sub>H<sub>16</sub>O',
    '',
    '589-63-9',
    'YWXLSHOWXZUMSR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-octanone'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-methyl-3-heptanone',
    'C<sub>8</sub>H<sub>16</sub>O',
    '',
    '541-85-5',
    'PSBKJPTZCVYXSD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='5-methyl-3-heptanone'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '6-methyl-3-heptanone',
    'C<sub>8</sub>H<sub>16</sub>O',
    '',
    '624-42-0',
    'CCCIYAQYQZQDIZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-methyl-3-heptanone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cyclohexyl methyl ketone',
    'C<sub>6</sub>H<sub>11</sub>COCH<sub>3</sub>',
    '',
    '823-76-7',
    'RIFKADJTWUGDOV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '7200',
    'T',
    (SELECT id from species WHERE iupac='cyclohexyl methyl ketone'),
    (SELECT id from literature WHERE bibtexkey='2016'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2016'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexyl methyl ketone'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexyl methyl ketone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexyl methyl ketone'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexyl methyl ketone'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexyl methyl ketone'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexyl methyl ketone'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cyclohexyl methyl ketone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-nonanone',
    'C<sub>9</sub>H<sub>18</sub>O',
    '',
    '821-55-6',
    'VKCYHJWLYTUGCC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '7400',
    'L',
    (SELECT id from species WHERE iupac='2-nonanone'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3518-821-55-6-consicheck',
    '3518', 'Values at 298&nbsp;K in Tables&nbsp;C2 and C5 of Brockbank (2013) are inconsistent, with 7&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3518-821-55-6-consicheck'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '7500',
    'L',
    (SELECT id from species WHERE iupac='2-nonanone'),
    (SELECT id from literature WHERE bibtexkey='3617'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-nonanone'),
    (SELECT id from literature WHERE bibtexkey='2457'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-nonanone'),
    (SELECT id from literature WHERE bibtexkey='754'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7600',
    'V',
    (SELECT id from species WHERE iupac='2-nonanone'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-nonanone'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nonanone'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nonanone'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nonanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nonanone'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nonanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nonanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nonanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nonanone'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nonanone'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7600',
    'Q',
    (SELECT id from species WHERE iupac='2-nonanone'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nonanone'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nonanone'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nonanone'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nonanone'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nonanone'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-nonanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '8100',
    '?',
    (SELECT id from species WHERE iupac='2-nonanone'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-nonanone'),
    (SELECT id from literature WHERE bibtexkey='3091'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-nonanone'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-nonanone',
    'C<sub>9</sub>H<sub>18</sub>O',
    '',
    '925-78-0',
    'IYTXKIXETAELAV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;2</sup>',
    '6600',
    'L',
    (SELECT id from species WHERE iupac='3-nonanone'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-nonanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-nonanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-nonanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-nonanone',
    'C<sub>9</sub>H<sub>18</sub>O',
    'dibutyl ketone',
    '502-56-7',
    'WSGCRAOTEDLMFQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '8000',
    'L',
    (SELECT id from species WHERE iupac='5-nonanone'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='5-nonanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='5-nonanone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='5-nonanone'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='5-nonanone'),
    (SELECT id from literature WHERE bibtexkey='1910'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-nonanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-nonanone'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-nonanone'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7600',
    'Q',
    (SELECT id from species WHERE iupac='5-nonanone'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-nonanone'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-nonanone'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-nonanone'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-nonanone'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7900',
    '?',
    (SELECT id from species WHERE iupac='5-nonanone'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='5-nonanone'),
    (SELECT id from literature WHERE bibtexkey='3091'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at303K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='5-nonanone'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6-dimethyl-4-heptanone',
    'C<sub>9</sub>H<sub>18</sub>O',
    'diisobutyl ketone',
    '108-83-8',
    'PTTPXKJBFFKCEK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '7500',
    'L',
    (SELECT id from species WHERE iupac='2,6-dimethyl-4-heptanone'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2,6-dimethyl-4-heptanone'),
    (SELECT id from literature WHERE bibtexkey='3617'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,6-dimethyl-4-heptanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,6-dimethyl-4-heptanone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethyl-4-heptanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethyl-4-heptanone'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethyl-4-heptanone'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7600',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethyl-4-heptanone'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethyl-4-heptanone'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethyl-4-heptanone'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5500',
    '?',
    (SELECT id from species WHERE iupac='2,6-dimethyl-4-heptanone'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,6-dimethyl-4-heptanone'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at297K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,6-dimethyl-4-heptanone'),
    (SELECT id from literature WHERE bibtexkey='3091'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at297K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,4,4-tetramethyl-3-pentanone',
    'C<sub>9</sub>H<sub>18</sub>O',
    'di-(<i>tert</i>-butyl) ketone',
    '815-24-7',
    'UIQGEWJEWJMQSL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='2,2,4,4-tetramethyl-3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2016'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2016'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-decanone',
    'C<sub>8</sub>H<sub>17</sub>COCH<sub>3</sub>',
    '',
    '693-54-9',
    'ZAJNGDIORYACQU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-decanone'),
    (SELECT id from literature WHERE bibtexkey='3643'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-decanone'),
    (SELECT id from literature WHERE bibtexkey='3670'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3670'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-decanone'),
    (SELECT id from literature WHERE bibtexkey='3611'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-decanone'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-decanone'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-decanone'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-decanone'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-decanone'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-decanone'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-decanone'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-decanone'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-decanone'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-decanone'),
    (SELECT id from literature WHERE bibtexkey='3091'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-decanone'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-undecanone',
    'C<sub>9</sub>H<sub>19</sub>COCH<sub>3</sub>',
    '',
    '112-12-9',
    'KYWIYKKSMDLRDC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2-undecanone'),
    (SELECT id from literature WHERE bibtexkey='3617'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-undecanone'),
    (SELECT id from literature WHERE bibtexkey='754'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-undecanone'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-undecanone'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-undecanone'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-undecanone'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-undecanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-undecanone'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-undecanone'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-undecanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-undecanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-undecanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-undecanone'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-undecanone'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-undecanone'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-undecanone'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-undecanone'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-undecanone'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-undecanone'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-undecanone'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-undecanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-undecanone'),
    (SELECT id from literature WHERE bibtexkey='3091'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-undecanone'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '6-undecanone',
    'C<sub>11</sub>H<sub>22</sub>O',
    '',
    '927-49-1',
    'ZPQAKYPOZRXKFA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-undecanone'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-undecanone'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-dodecanone',
    'C<sub>12</sub>H<sub>24</sub>O',
    '',
    '6175-49-1',
    'LSKONYYRONEBKA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-dodecanone'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-dodecanone'),
    (SELECT id from literature WHERE bibtexkey='3091'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6,8-trimethyl-4-nonanone',
    'C<sub>12</sub>H<sub>24</sub>O',
    '',
    '123-18-2',
    'GFWVDQCGGDBTBS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='2,6,8-trimethyl-4-nonanone'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3518-123-18-2',
    '', 'The value listed as A for 2,6,8-trimethyl-4-nonanone is probably not A but the Henry''s law volatility constant H<sub>v</sub><sup>px</sup> at 298&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3518-123-18-2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-tridecanone',
    'C<sub>13</sub>H<sub>26</sub>O',
    '',
    '593-08-8',
    'CYIFVRUOHKNECG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-tridecanone'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-tridecanone'),
    (SELECT id from literature WHERE bibtexkey='3091'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-tetradecanone',
    'C<sub>14</sub>H<sub>28</sub>O',
    '',
    '2345-27-9',
    'POQLVOYRGNFGRM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-tetradecanone'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-tetradecanone'),
    (SELECT id from literature WHERE bibtexkey='3091'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-pentadecanone',
    'C<sub>15</sub>H<sub>30</sub>O',
    '',
    '2345-28-0',
    'CJPNOLIZCWDHJK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-pentadecanone'),
    (SELECT id from literature WHERE bibtexkey='3091'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-hexadecanone',
    'C<sub>16</sub>H<sub>32</sub>O',
    '',
    '18787-63-8',
    'XCXKZBWAKKPFCJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-hexadecanone'),
    (SELECT id from literature WHERE bibtexkey='3091'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-heptadecanone',
    'C<sub>17</sub>H<sub>34</sub>O',
    '',
    '2922-51-2',
    'TVTCXPXLRKTHAU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-heptadecanone'),
    (SELECT id from literature WHERE bibtexkey='3091'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'menthone',
    'C<sub>10</sub>H<sub>18</sub>O',
    '',
    '89-80-5',
    'NFLGAXVYCFJBMK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='menthone'),
    (SELECT id from literature WHERE bibtexkey='2964'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='menthone'),
    (SELECT id from literature WHERE bibtexkey='2964'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='menthone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='menthone'),
    (SELECT id from literature WHERE bibtexkey='2964'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tricyclo[3.3.1.1(3,7)]decanone',
    'C<sub>10</sub>H<sub>14</sub>O',
    '2-adamantanone',
    '700-58-3',
    'IYKFYARMMIESOX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '5800',
    'V',
    (SELECT id from species WHERE iupac='tricyclo[3.3.1.1(3,7)]decanone'),
    (SELECT id from literature WHERE bibtexkey='2125'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tricyclo[3.3.1.1(3,7)]decanone'),
    (SELECT id from literature WHERE bibtexkey='1910'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl cedryl ketone',
    'C<sub>17</sub>H<sub>26</sub>O',
    '',
    '32388-55-9',
    'YBUIAJZFOGJGLJ-SWRJLBSHSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl cedryl ketone'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-buten-2-one',
    'C<sub>4</sub>H<sub>6</sub>O',
    'methyl vinyl ketone; MVK',
    '78-94-4',
    'FUSUHKVFWTUUBE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='3-buten-2-one'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='3-buten-2-one'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '4800',
    'M',
    (SELECT id from species WHERE iupac='3-buten-2-one'),
    (SELECT id from literature WHERE bibtexkey='2524'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3-buten-2-one'),
    (SELECT id from literature WHERE bibtexkey='1004'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '7800',
    'M',
    (SELECT id from species WHERE iupac='3-buten-2-one'),
    (SELECT id from literature WHERE bibtexkey='985'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-buten-2-one'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-buten-2-one'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-buten-2-one'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-buten-2-one'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-buten-2-one'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-buten-2-one'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-buten-2-one'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-buten-2-one'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-buten-2-one'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-buten-2-one'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6000',
    'Q',
    (SELECT id from species WHERE iupac='3-buten-2-one'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-buten-2-one'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7800',
    '?',
    (SELECT id from species WHERE iupac='3-buten-2-one'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-buten-2-one'),
    (SELECT id from literature WHERE bibtexkey='495'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl isopropenyl ketone',
    'C<sub>5</sub>H<sub>8</sub>O',
    '',
    '814-78-8',
    'ZGHFDIIVVIFNPS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methyl isopropenyl ketone'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl isopropenyl ketone'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl isopropenyl ketone'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl isopropenyl ketone'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methyl isopropenyl ketone'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-3-penten-2-one',
    'C<sub>6</sub>H<sub>10</sub>O',
    'mesityl oxide',
    '141-79-7',
    'SHOJXDKTYKFBRD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-methyl-3-penten-2-one'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-3-penten-2-one'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-3-penten-2-one'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-3-penten-2-one'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-3-penten-2-one'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-3-penten-2-one'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-methyl-3-penten-2-one'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-phenylethanone',
    'C<sub>6</sub>H<sub>5</sub>COCH<sub>3</sub>',
    'acetophenone',
    '98-86-2',
    'KWOLFJPFCHCOCG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '7900',
    'L',
    (SELECT id from species WHERE iupac='1-phenylethanone'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '7700',
    'L',
    (SELECT id from species WHERE iupac='1-phenylethanone'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;1</sup>',
    '6800',
    'M',
    (SELECT id from species WHERE iupac='1-phenylethanone'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '7800',
    'M',
    (SELECT id from species WHERE iupac='1-phenylethanone'),
    (SELECT id from literature WHERE bibtexkey='3724'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;1</sup>',
    '12000',
    'M',
    (SELECT id from species WHERE iupac='1-phenylethanone'),
    (SELECT id from literature WHERE bibtexkey='985'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-phenylethanone'),
    (SELECT id from literature WHERE bibtexkey='2339'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '6000',
    'M',
    (SELECT id from species WHERE iupac='1-phenylethanone'),
    (SELECT id from literature WHERE bibtexkey='495'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-phenylethanone'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-phenylethanone'),
    (SELECT id from literature WHERE bibtexkey='2339'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-phenylethanone'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-phenylethanone'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;1</sup>',
    '6400',
    'T',
    (SELECT id from species WHERE iupac='1-phenylethanone'),
    (SELECT id from literature WHERE bibtexkey='2016'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2016'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-phenylethanone'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1-phenylethanone'),
    (SELECT id from literature WHERE bibtexkey='2165'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-phenylethanone'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-phenylethanone'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-phenylethanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-phenylethanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-phenylethanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-phenylethanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-phenylethanone'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-phenylethanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-phenylethanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-phenylethanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-phenylethanone'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-phenylethanone'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6100',
    'Q',
    (SELECT id from species WHERE iupac='1-phenylethanone'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-phenylethanone'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-phenylethanone'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-phenylethanone'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-phenylethanone'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-phenylethanone'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-phenylethanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6700',
    '?',
    (SELECT id from species WHERE iupac='1-phenylethanone'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-phenylethanone'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-phenylethanone'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-phenylethanone-d5',
    'C<sub>6</sub>D<sub>5</sub>COCH<sub>3</sub>',
    'acetophenone-d5',
    '28077-64-7',
    'KWOLFJPFCHCOCG-VIQYUKPQSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '10000',
    'M',
    (SELECT id from species WHERE iupac='1-phenylethanone-d5'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methoxy-4-methyl-2-pentanone',
    'C<sub>7</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '107-70-0',
    'KOKPBCHLPVDQTK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-methoxy-4-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-methoxy-4-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methoxy-4-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methoxy-4-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methoxy-4-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methoxy-4-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methoxy-4-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methoxy-4-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2′-hydroxyacetophenone',
    'C<sub>8</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '118-93-4',
    'JECYUBVRTQDVAT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '8400',
    'M',
    (SELECT id from species WHERE iupac='2′-hydroxyacetophenone'),
    (SELECT id from literature WHERE bibtexkey='3724'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '6-methyl-5-hepten-2-one',
    'C<sub>8</sub>H<sub>14</sub>O',
    '',
    '110-93-0',
    'UHEPJGULSIKKTP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '6200',
    'M',
    (SELECT id from species WHERE iupac='6-methyl-5-hepten-2-one'),
    (SELECT id from literature WHERE bibtexkey='3776'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-methyl-5-hepten-2-one'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phenyl ethyl ketone',
    'C<sub>9</sub>H<sub>10</sub>O',
    'propiophenone',
    '93-55-0',
    'KRIOVPPHQSLHCZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '7900',
    'M',
    (SELECT id from species WHERE iupac='phenyl ethyl ketone'),
    (SELECT id from literature WHERE bibtexkey='3724'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='phenyl ethyl ketone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='phenyl ethyl ketone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenyl ethyl ketone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenyl ethyl ketone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenyl ethyl ketone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenyl ethyl ketone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenyl ethyl ketone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenyl ethyl ketone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenyl ethyl ketone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenyl ethyl ketone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenyl ethyl ketone'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenyl ethyl ketone'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6400',
    'Q',
    (SELECT id from species WHERE iupac='phenyl ethyl ketone'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenyl ethyl ketone'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenyl ethyl ketone'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7700',
    '?',
    (SELECT id from species WHERE iupac='phenyl ethyl ketone'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2′-methylacetophenone',
    'C<sub>9</sub>H<sub>10</sub>O',
    '',
    '577-16-2',
    'YXWWHNCQZBVZPV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;1</sup>',
    '7600',
    'M',
    (SELECT id from species WHERE iupac='2′-methylacetophenone'),
    (SELECT id from literature WHERE bibtexkey='3724'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2′-methylacetophenone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2′-methylacetophenone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2′-methylacetophenone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3′-methylacetophenone',
    'C<sub>9</sub>H<sub>10</sub>O',
    '',
    '585-74-0',
    'FSPSELPMWGWDRY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '7600',
    'M',
    (SELECT id from species WHERE iupac='3′-methylacetophenone'),
    (SELECT id from literature WHERE bibtexkey='3724'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4''-methylacetophenone',
    'C<sub>9</sub>H<sub>10</sub>O',
    '',
    '122-00-9',
    'GNKZMNRKLCTJAY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '8400',
    'M',
    (SELECT id from species WHERE iupac='4''-methylacetophenone'),
    (SELECT id from literature WHERE bibtexkey='3724'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'R',
    (SELECT id from species WHERE iupac='4''-methylacetophenone'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4''-methylacetophenone'),
    (SELECT id from literature WHERE bibtexkey='3521'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4''-methylacetophenone'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4''-methylacetophenone'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4''-methylacetophenone'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4''-methylacetophenone'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2′-methoxyacetophenone',
    'C<sub>9</sub>H<sub>10</sub>O<sub>2</sub>',
    '2-methoxyphenyl methyl ketone',
    '579-74-8',
    'DWPLEOPKBWNPQV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '9500',
    'M',
    (SELECT id from species WHERE iupac='2′-methoxyacetophenone'),
    (SELECT id from literature WHERE bibtexkey='3724'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3′-methoxyacetophenone',
    'C<sub>9</sub>H<sub>10</sub>O<sub>2</sub>',
    '3-methoxyphenyl methyl ketone',
    '586-37-8',
    'BAYUSCHCCGXLAY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '9400',
    'M',
    (SELECT id from species WHERE iupac='3′-methoxyacetophenone'),
    (SELECT id from literature WHERE bibtexkey='3724'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4′-methoxyacetophenone',
    'C<sub>9</sub>H<sub>10</sub>O<sub>2</sub>',
    '4-methoxyphenyl methyl ketone',
    '100-06-1',
    'NTPLXRHDUXRPNE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;1</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='4′-methoxyacetophenone'),
    (SELECT id from literature WHERE bibtexkey='2016'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2016'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4′-methoxyacetophenone'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4′-methoxyacetophenone'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4′-methoxyacetophenone'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-5-(1-methylethenyl)-2-cyclohexen-1-one',
    'C<sub>10</sub>H<sub>14</sub>O',
    'carvone',
    '6485-40-1',
    'ULDHMXUKGWMISQ-SECBINFHSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methyl-5-(1-methylethenyl)-2-cyclohexen-1-one'),
    (SELECT id from literature WHERE bibtexkey='2388'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-5-(1-methylethenyl)-2-cyclohexen-1-one'),
    (SELECT id from literature WHERE bibtexkey='2388'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-5-(1-methylethenyl)-2-cyclohexen-1-one'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benzophenone',
    'C<sub>13</sub>H<sub>10</sub>O',
    'diphenyl ketone',
    '119-61-9',
    'RWCCWEUUXYIKHB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzophenone'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1',
    '9400',
    'T',
    (SELECT id from species WHERE iupac='benzophenone'),
    (SELECT id from literature WHERE bibtexkey='2016'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2016'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'X',
    (SELECT id from species WHERE iupac='benzophenone'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzophenone'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzophenone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzophenone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzophenone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzophenone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzophenone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    '?',
    (SELECT id from species WHERE iupac='benzophenone'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dihydroxybenzophenone',
    'C<sub>13</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '131-56-6',
    'ZXDDPOHVAMWLBH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dihydroxybenzophenone'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,5,5-trimethyl-2-cyclohexen-1-one',
    'C<sub>9</sub>H<sub>14</sub>O',
    'isophorone',
    '78-59-1',
    'HJOVHMDZYOCNQW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,5,5-trimethyl-2-cyclohexen-1-one'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,5,5-trimethyl-2-cyclohexen-1-one'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,5,5-trimethyl-2-cyclohexen-1-one'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,5,5-trimethyl-2-cyclohexen-1-one'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,5,5-trimethyl-2-cyclohexen-1-one'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '3900',
    'X',
    (SELECT id from species WHERE iupac='3,5,5-trimethyl-2-cyclohexen-1-one'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'C',
    (SELECT id from species WHERE iupac='3,5,5-trimethyl-2-cyclohexen-1-one'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5,5-trimethyl-2-cyclohexen-1-one'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5,5-trimethyl-2-cyclohexen-1-one'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5,5-trimethyl-2-cyclohexen-1-one'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5,5-trimethyl-2-cyclohexen-1-one'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5,5-trimethyl-2-cyclohexen-1-one'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5,5-trimethyl-2-cyclohexen-1-one'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7300',
    'Q',
    (SELECT id from species WHERE iupac='3,5,5-trimethyl-2-cyclohexen-1-one'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5,5-trimethyl-2-cyclohexen-1-one'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5,5-trimethyl-2-cyclohexen-1-one'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7400',
    '?',
    (SELECT id from species WHERE iupac='3,5,5-trimethyl-2-cyclohexen-1-one'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,5,5-trimethyl-2-cyclohexen-1-one'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bicyclo[2.2.1]heptan-2-one',
    'C<sub>7</sub>H<sub>10</sub>O',
    'norcamphor; 2-norbornanone',
    '497-38-1',
    'KPMKEVXVVHNIEY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;1</sup>',
    '5100',
    'V',
    (SELECT id from species WHERE iupac='bicyclo[2.2.1]heptan-2-one'),
    (SELECT id from literature WHERE bibtexkey='2125'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-1-(1-methylethyl)-bicyclo[3.1.0]hexan-3-one',
    'C<sub>10</sub>H<sub>16</sub>O',
    'thujone',
    '1125-12-8',
    'USMNOWBWPHYOEA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '4700',
    'V',
    (SELECT id from species WHERE iupac='4-methyl-1-(1-methylethyl)-bicyclo[3.1.0]hexan-3-one'),
    (SELECT id from literature WHERE bibtexkey='2125'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'isopropyl phenyl ketone',
    'C<sub>10</sub>H<sub>12</sub>O',
    '',
    '611-70-1',
    'BSMGLVDZZMBWQB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isopropyl phenyl ketone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isopropyl phenyl ketone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isopropyl phenyl ketone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isopropyl phenyl ketone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'carvone',
    'C<sub>10</sub>H<sub>14</sub>O',
    '',
    '99-49-0',
    'ULDHMXUKGWMISQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='carvone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'thujone',
    'C<sub>10</sub>H<sub>16</sub>O',
    '',
    '76231-76-0',
    'USMNOWBWPHYOEA-VWHDNNRLSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='thujone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>cis</i>-jasmone',
    'C<sub>11</sub>H<sub>16</sub>O',
    '',
    '488-10-8',
    'XMLSXPIVAXONDL-PLNGDYQASA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-jasmone'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '&#945;-damascone',
    'C<sub>13</sub>H<sub>20</sub>O',
    '',
    '24720-09-0',
    'CRIGTVCBMUKRSL-FNORWQNLSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#945;-damascone'),
    (SELECT id from literature WHERE bibtexkey='3521'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(E)-&#946;-damascenone',
    'C<sub>13</sub>H<sub>18</sub>O',
    '',
    '23726-93-4',
    'POIARNZEYGURDG-FNORWQNLSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '4600',
    'M',
    (SELECT id from species WHERE iupac='(E)-&#946;-damascenone'),
    (SELECT id from literature WHERE bibtexkey='3215'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3215-23726-93-4-ABC',
    '3215', 'The data from Wieland et&nbsp;al. (2015) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( 116.85779 &#8722;1341.05519/T &#8722;19.91967&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3215-23726-93-4-ABC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '9H-fluoren-9-one',
    'C<sub>13</sub>H<sub>8</sub>O',
    '',
    '486-25-9',
    'YLQWCDOCJODRMT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='9H-fluoren-9-one'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='9H-fluoren-9-one'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='9H-fluoren-9-one'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'anthrone',
    'C<sub>14</sub>H<sub>10</sub>O',
    '',
    '90-44-8',
    'RJGDLRCDCYRQOQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='anthrone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,5,6,7-hexahydro-1,1,2,3,3-pentamethyl-4H-inden-4-one',
    'C<sub>14</sub>H<sub>22</sub>O',
    '',
    '33704-61-9',
    'MIZGSAALSYARKU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,5,6,7-hexahydro-1,1,2,3,3-pentamethyl-4H-inden-4-one'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,5,6,7-hexahydro-1,1,2,3,3-pentamethyl-4H-inden-4-one'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,5,6,7-hexahydro-1,1,2,3,3-pentamethyl-4H-inden-4-one'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,5,6,7-hexahydro-1,1,2,3,3-pentamethyl-4H-inden-4-one'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benzoin',
    'C<sub>14</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '119-53-9',
    'ISAOCJYIOMOJEB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzoin'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl-alpha-ionone',
    'C<sub>14</sub>H<sub>22</sub>O',
    '',
    '93302-56-8',
    'VPKMGDRERYMTJX-XEHSLEBBSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl-alpha-ionone'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'iso-e super',
    'C<sub>16</sub>H<sub>26</sub>O',
    '',
    '54464-57-2',
    'FVUGZKDGWGKCFE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='iso-e super'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,6-trimethylbenzophenone',
    'C<sub>16</sub>H<sub>16</sub>O',
    '',
    '954-16-5',
    'HPAFOABSQZMTHE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trimethylbenzophenone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trimethylbenzophenone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trimethylbenzophenone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trimethylbenzophenone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-(1,2,3,5,6,7,8,8a-octahydro-2,3,8,8-tetramethyl-2-naphthyl)ethan-1-one',
    'C<sub>16</sub>H<sub>26</sub>O',
    '',
    '68155-66-8',
    'NOMWSTMYQKABST-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-(1,2,3,5,6,7,8,8a-octahydro-2,3,8,8-tetramethyl-2-naphthyl)ethan-1-one'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-(1,2,3,5,6,7,8,8a-octahydro-2,3,8,8-tetramethyl-2-naphthyl)ethan-1-one'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-(1,2,3,5,6,7,8,8a-octahydro-2,3,8,8-tetramethyl-2-naphthyl)ethan-1-one'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-(1,2,3,5,6,7,8,8a-octahydro-2,3,8,8-tetramethyl-2-naphthyl)ethan-1-one'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'civetone',
    'C<sub>17</sub>H<sub>30</sub>O',
    '',
    '542-46-1',
    'ZKVZSBSZTMPBQR-UPHRSURJSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='civetone'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-(2,3-dihydro-1,1,2,3,3,6-hexamethyl-1H-inden-5-yl)ethanone',
    'C<sub>17</sub>H<sub>24</sub>O',
    '',
    '15323-35-0',
    'VDBHOHJWUDKDRW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-(2,3-dihydro-1,1,2,3,3,6-hexamethyl-1H-inden-5-yl)ethanone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-(2,3-dihydro-1,1,2,3,3,6-hexamethyl-1H-inden-5-yl)ethanone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-(2,3-dihydro-1,1,2,3,3,6-hexamethyl-1H-inden-5-yl)ethanone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-(2,3-dihydro-1,1,2,3,3,6-hexamethyl-1H-inden-5-yl)ethanone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'celestolide',
    'C<sub>17</sub>H<sub>24</sub>O',
    '',
    '13171-00-1',
    'IKTHMQYJOWTSJO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='celestolide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='celestolide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='celestolide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='celestolide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '7H-benz[de]anthracen-7-one',
    'C<sub>17</sub>H<sub>10</sub>O',
    'benzanthrone',
    '82-05-3',
    'HUKPVYBUJRAUAG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='7H-benz[de]anthracen-7-one'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='7H-benz[de]anthracen-7-one'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '11H-benzo[a]fluoren-11-one',
    'C<sub>17</sub>H<sub>10</sub>O',
    '',
    '479-79-8',
    'RNICURKFVSAHLQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='11H-benzo[a]fluoren-11-one'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '11H-benzo[b]fluoren-11-one',
    'C<sub>17</sub>H<sub>10</sub>O',
    '',
    '3074-03-1',
    'MLMNDNOSVOKYMT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='11H-benzo[b]fluoren-11-one'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benz[a]anthracene-7,12-dione',
    'C<sub>18</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '2498-66-0',
    'LHMRXAIRPKSGDE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benz[a]anthracene-7,12-dione'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-[2,3-dihydro-1,1,2,6-tetramethyl-3-(1-methylethyl)-1H-inden-5-yl]ethanone',
    'C<sub>18</sub>H<sub>26</sub>O',
    '',
    '68140-48-7',
    'IMRYETFJNLKUHK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-[2,3-dihydro-1,1,2,6-tetramethyl-3-(1-methylethyl)-1H-inden-5-yl]ethanone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-[2,3-dihydro-1,1,2,6-tetramethyl-3-(1-methylethyl)-1H-inden-5-yl]ethanone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-[2,3-dihydro-1,1,2,6-tetramethyl-3-(1-methylethyl)-1H-inden-5-yl]ethanone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-[2,3-dihydro-1,1,2,6-tetramethyl-3-(1-methylethyl)-1H-inden-5-yl]ethanone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tonalide',
    'C<sub>18</sub>H<sub>26</sub>O',
    '',
    '21145-77-7',
    'DNRJTBAOUJJKDY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tonalide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tonalide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tonalide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tonalide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tonalide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-butanedione',
    'CH<sub>3</sub>COCOCH<sub>3</sub>',
    'diacetyl; dimethylglyoxal',
    '431-03-8',
    'QSJXEFYPDANLFS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;1</sup>',
    '5700',
    'L',
    (SELECT id from species WHERE iupac='2,3-butanedione'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;1</sup>',
    '5700',
    'L',
    (SELECT id from species WHERE iupac='2,3-butanedione'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;1</sup>',
    '5700',
    'L',
    (SELECT id from species WHERE iupac='2,3-butanedione'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '4900',
    'M',
    (SELECT id from species WHERE iupac='2,3-butanedione'),
    (SELECT id from literature WHERE bibtexkey='3776'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;1</sup>',
    '7200',
    'M',
    (SELECT id from species WHERE iupac='2,3-butanedione'),
    (SELECT id from literature WHERE bibtexkey='3215'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3215-431-03-8-ABC',
    '3215', 'The data from Wieland et&nbsp;al. (2015) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;74.84087 +9452.88617/T +7.41865&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3215-431-03-8-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '6700',
    'M',
    (SELECT id from species WHERE iupac='2,3-butanedione'),
    (SELECT id from literature WHERE bibtexkey='1571'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3-butanedione'),
    (SELECT id from literature WHERE bibtexkey='1937'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3-butanedione'),
    (SELECT id from literature WHERE bibtexkey='3643'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3-butanedione'),
    (SELECT id from literature WHERE bibtexkey='3670'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3670'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3-butanedione'),
    (SELECT id from literature WHERE bibtexkey='3611'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3-butanedione'),
    (SELECT id from literature WHERE bibtexkey='2964'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3-butanedione'),
    (SELECT id from literature WHERE bibtexkey='2389'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3-butanedione'),
    (SELECT id from literature WHERE bibtexkey='3647'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;1</sup>',
    '5700',
    'M',
    (SELECT id from species WHERE iupac='2,3-butanedione'),
    (SELECT id from literature WHERE bibtexkey='495'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3-butanedione'),
    (SELECT id from literature WHERE bibtexkey='483'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3-butanedione'),
    (SELECT id from literature WHERE bibtexkey='2964'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3-butanedione'),
    (SELECT id from literature WHERE bibtexkey='gaffney84'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3-butanedione'),
    (SELECT id from literature WHERE bibtexkey='gaffney84'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from715'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-butanedione'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-butanedione'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-butanedione'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-butanedione'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-butanedione'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-butanedione'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-butanedione'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-butanedione'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-butanedione'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-butanedione'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6500',
    'Q',
    (SELECT id from species WHERE iupac='2,3-butanedione'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-butanedione'),
    (SELECT id from literature WHERE bibtexkey='2964'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3-butanedione'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6000',
    '?',
    (SELECT id from species WHERE iupac='2,3-butanedione'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-pentanedione',
    'C<sub>5</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '600-14-6',
    'TZMFJUDUGYTVRY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '6200',
    'M',
    (SELECT id from species WHERE iupac='2,3-pentanedione'),
    (SELECT id from literature WHERE bibtexkey='3776'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-pentanedione'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-pentanedione'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-pentanedione'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-pentanedione',
    'C<sub>5</sub>H<sub>8</sub>O<sub>2</sub>',
    'acetylacetone',
    '123-54-6',
    'YRKCREAYFQTBPV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;1</sup>',
    '3800',
    'L',
    (SELECT id from species WHERE iupac='2,4-pentanedione'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,4-pentanedione'),
    (SELECT id from literature WHERE bibtexkey='3532'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at297K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '4400',
    'M',
    (SELECT id from species WHERE iupac='2,4-pentanedione'),
    (SELECT id from literature WHERE bibtexkey='3609'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,4-pentanedione'),
    (SELECT id from literature WHERE bibtexkey='2448'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4-pentanedione'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4-pentanedione'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-pentanedione'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-pentanedione'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-pentanedione'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-pentanedione'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-pentanedione'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-pentanedione'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-pentanedione'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-pentanedione'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-pentanedione'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7300',
    'Q',
    (SELECT id from species WHERE iupac='2,4-pentanedione'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-pentanedione'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4400',
    '?',
    (SELECT id from species WHERE iupac='2,4-pentanedione'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,4-pentanedione'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-naphthalenedione',
    'C<sub>10</sub>H<sub>6</sub>O<sub>2</sub>',
    '',
    '524-42-5',
    'KETQAJRQOHHATG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-naphthalenedione'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4-naphthalenedione',
    'C<sub>10</sub>H<sub>6</sub>O<sub>2</sub>',
    '1,4-naphthoquinone',
    '130-15-4',
    'FRASJONUBLZVQX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-naphthalenedione'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-naphthalenedione'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'menadione',
    'C<sub>11</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '58-27-5',
    'MJVAVZPDRWSRRC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='menadione'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6-di-<i>tert</i>-butyl-p-benzoquinone',
    'C<sub>14</sub>H<sub>20</sub>O<sub>2</sub>',
    '',
    '719-22-2',
    'RDQSIADLBQFVMY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-di-<i>tert</i>-butyl-p-benzoquinone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '9,10-phenanthrenedione',
    'C<sub>14</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '84-11-7',
    'YYVYAPXYZVYDHN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='9,10-phenanthrenedione'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '9,10-anthracenedione',
    'C<sub>14</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '84-65-1',
    'RZVHIXYEVGDQDX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='9,10-anthracenedione'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='9,10-anthracenedione'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='9,10-anthracenedione'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='9,10-anthracenedione'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='9,10-anthracenedione'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='9,10-anthracenedione'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='9,10-anthracenedione'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='9,10-anthracenedione'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='9,10-anthracenedione'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='9,10-anthracenedione'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-hydroxy-9,10-anthracenedione',
    'C<sub>14</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '605-32-3',
    'GCDBEYOJCZLKMC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-hydroxy-9,10-anthracenedione'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxy-9,10-anthracenedione'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4-dihydroxy-9,10-anthracenedione',
    'C<sub>14</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '81-64-1',
    'GUEIZVNYDFNHJU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-dihydroxy-9,10-anthracenedione'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dihydroxy-9,10-anthracenedione'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benzil',
    'C<sub>14</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '134-81-6',
    'WURBFLDFSFBTLW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzil'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dibenzoylmethane',
    'C<sub>15</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '120-46-7',
    'NZZIMKJIVMHWJC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibenzoylmethane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibenzoylmethane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibenzoylmethane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibenzoylmethane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-9,10-anthracenedione',
    'C<sub>15</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '84-54-8',
    'NJWGQARXZDRHCD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-9,10-anthracenedione'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-ethyl-9,10-anthracenedione',
    'C<sub>16</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '84-51-5',
    'SJEBAWHUJDUKQK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-9,10-anthracenedione'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-9,10-anthracenedione'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-9,10-anthracenedione'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-9,10-anthracenedione'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-9,10-anthracenedione'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diphenadione',
    'C<sub>23</sub>H<sub>16</sub>O<sub>3</sub>',
    '',
    '82-66-6',
    'JYGLAHSAISAEAL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diphenadione'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diphenadione'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CH3COCO3H',
    'C<sub>3</sub>H<sub>4</sub>O<sub>4</sub>',
    '',
    '',
    'BXASKOSTAOGNPV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3COCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3COCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3COCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HYPERACET',
    'C<sub>3</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '',
    'LSIGHSKIPNHVEN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HYPERACET'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HYPERACET'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HYPERACET'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BIACETOOH',
    'C<sub>4</sub>H<sub>6</sub>O<sub>4</sub>',
    '',
    '',
    'JYWVDPVJSGSFMT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BIACETOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BIACETOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BIACETOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO2C3CO3H',
    'C<sub>4</sub>H<sub>6</sub>O<sub>4</sub>',
    '',
    '',
    'SJOPHMGAZWPERQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2C3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2C3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2C3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MEKAOOH',
    'C<sub>4</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'VEPDQRPXKSSVPR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MEKAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MEKAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MEKAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MEKBOOH',
    'C<sub>4</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'ISENHDUDKGYVAU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MEKBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MEKBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MEKBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MEKCOOH',
    'C<sub>4</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'PSPWSCBXMKHAFW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MEKCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MEKCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MEKCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MVKOOH',
    'C<sub>4</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '',
    'PRFKYXWFQJOCGY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MVKOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MVKOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MVKOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C41CO3H',
    'C<sub>5</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'FAYQBJFLFGEPOW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C41CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C41CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C41CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5CO14OOH',
    'C<sub>5</sub>H<sub>6</sub>O<sub>4</sub>',
    '',
    '',
    'FKGAAIITVQJZMS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5CO14OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5CO14OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5CO14OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5CO234',
    'C<sub>5</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '',
    'MVDYEFQVZNBPPH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5CO234'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5CO234'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5CO234'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5CO234OOH',
    'C<sub>5</sub>H<sub>6</sub>O<sub>5</sub>',
    '',
    '',
    'XNGUZQHZGCMOHY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5CO234OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5CO234OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5CO234OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5CO23OOH',
    'C<sub>5</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'BRUGMCFWMGXRAP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5CO23OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5CO23OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5CO23OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO23C4CO3H',
    'C<sub>5</sub>H<sub>6</sub>O<sub>5</sub>',
    '',
    '',
    'BRGQKBIYWSYIOL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO23C4CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO23C4CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO23C4CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO23C54OOH',
    'C<sub>5</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'QASRSSCEZIIDDC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO23C54OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO23C54OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO23C54OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO24C53OOH',
    'C<sub>5</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'AULGAHCEUUOLTF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO24C53OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO24C53OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO24C53OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO2C4CO3H',
    'C<sub>5</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'COVHHGSUFOHLBW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>4</sup>',
    '12000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2C4CO3H'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2C4CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2C4CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2C4CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO3C4CO3H',
    'C<sub>5</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'HMOQHHYQXPCOJD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO3C4CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO3C4CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO3C4CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DIEKAOOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'GVIFMISHBUBLQF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DIEKAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DIEKAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DIEKAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DIEKBOOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'PNIUWVGTVWVIRO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DIEKBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DIEKBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DIEKBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MIPKAOOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'UWVYZAHMDOAIIN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIPKAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIPKAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIPKAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MIPKBOOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'OWEKNVKRJSTQCB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIPKBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIPKBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIPKBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MPRKAOOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'RFXMBEJILJIJHO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MPRKAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MPRKAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MPRKAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MPRKBOOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'BOKMIGXVNYNOOE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MPRKBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MPRKBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MPRKBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PE2ONE1OOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'NFPIZNOAHNBIPJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PE2ONE1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PE2ONE1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PE2ONE1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C23C54CO3H',
    'C<sub>6</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'FOQTZZGGVXWRDJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23C54CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23C54CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23C54CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C3COCCO3H',
    'C<sub>6</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'NQEGAXBMSWAEEJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3COCCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3COCCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3COCCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4DBDIKET',
    'C<sub>6</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '',
    'OTSKZNVDZOOHRX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4DBDIKET'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4DBDIKET'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4DBDIKET'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C51CO3H',
    'C<sub>6</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'JNOOBNCRVAKFDO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C51CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C51CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C51CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5CODBCO3H',
    'C<sub>6</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'DSQMAYIDJPXZOY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5CODBCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5CODBCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5CODBCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5DBCOCO3H',
    'C<sub>6</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'NVTHKHSWEWVMOZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5DBCOCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5DBCOCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5DBCOCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C611OOH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'YTLUYDMGHZZGIK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C611OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C611OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C611OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C619OOH',
    'C<sub>6</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'CLPCTPYJHZPKKC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C619OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C619OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C619OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C627OOH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'BKNNHKNGGIDPKB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C627OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C627OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C627OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C62OOH',
    'C<sub>6</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'NRJLAAIGKSDANL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C62OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C62OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C62OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6CO134OOH',
    'C<sub>6</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'KXHHBNOARBHHNQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO134OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO134OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO134OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6CO34',
    'C<sub>6</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'KVFQMAZOBTXCAZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO34'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO34'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO34'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6CO34OOH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'GOPKJUXJYMJAQC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO34OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO34OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO34OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6CYTONOOH',
    'C<sub>6</sub>H<sub>6</sub>O<sub>5</sub>',
    '',
    '',
    'JAWAIWJCDBIXQU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CYTONOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CYTONOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CYTONOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6DCRBBOOH',
    'C<sub>6</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'JRENYXREJDINFO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6DCRBBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6DCRBBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6DCRBBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO234C6',
    'C<sub>6</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'FYLKBSXPBXZFJV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO234C6'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO234C6'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO234C6'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO234C6OOH',
    'C<sub>6</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'RXZSKHWIVPRCNE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO234C6OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO234C6OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO234C6OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO235C6',
    'C<sub>6</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'POASQEFMMPWSLD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO235C6'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO235C6'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO235C6'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO235C6OOH',
    'C<sub>6</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'OFEOQWJKJVUBKA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO235C6OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO235C6OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO235C6OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO23C65OOH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'QKJDOFMXAZMTSN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO23C65OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO23C65OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO23C65OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO23C6',
    'C<sub>6</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'MWVFCEVNXHTDNF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO23C6'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO23C6'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO23C6'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO24C63OOH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'BCTNDVKHSPOTQH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO24C63OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO24C63OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO24C63OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO24C6',
    'C<sub>6</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'NDOGLIPWGGRQCO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO24C6'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO24C6'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO24C6'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO24C6OOH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'SLWLMHWJPVVUSV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO24C6OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO24C6OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO24C6OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO24M3C5',
    'C<sub>6</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'GSOHKPVFCOWKPU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO24M3C5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO24M3C5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO24M3C5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO25C6',
    'C<sub>6</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'OJVAMHKKJGICOG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO25C6'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO25C6'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO25C6'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO25C6OOH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'JXALTZPWVLRWQW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO25C6OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO25C6OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO25C6OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO2C54CO3H',
    'C<sub>6</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'CNZIZHTUCKWXKF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2C54CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2C54CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2C54CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO2M33CO3H',
    'C<sub>6</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'NINAOMADVJMMOS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2M33CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2M33CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2M33CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO3C54CO3H',
    'C<sub>6</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'VXADHVSNPNTBLA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO3C54CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO3C54CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO3C54CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO3C5CO3H',
    'C<sub>6</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'NEAYDZAAQZUWAX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO3C5CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO3C5CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO3C5CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CY6COCOOOH',
    'C<sub>6</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'PCNCBCRTMCKUHD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CY6COCOOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CY6COCOOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CY6COCOOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CY6DIONOOH',
    'C<sub>6</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'WZMMYHNHRXLTAA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CY6DIONOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CY6DIONOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CY6DIONOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CYC613DION',
    'C<sub>6</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '',
    'HJSLFCCWAKVHIW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CYC613DION'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CYC613DION'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CYC613DION'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CYC6DIONE',
    'C<sub>6</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '',
    'OILAIQUEIWYQPH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CYC6DIONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CYC6DIONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CYC6DIONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CYHXONAOOH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'YLRYKXGGQIKRPE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CYHXONAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CYHXONAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CYHXONAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ECO3CO3H',
    'C<sub>6</sub>H<sub>6</sub>O<sub>6</sub>',
    '',
    '',
    'LOIDTPBEOYVNRI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ECO3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ECO3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ECO3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EIPKAOOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'UUAGRKYHKVSONO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EIPKAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EIPKAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EIPKAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EIPKBOOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'GSVDUVPILFIVQC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EIPKBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EIPKBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EIPKBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HEX2ONAOOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'BPODHSIMBCVMGL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEX2ONAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEX2ONAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEX2ONAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HEX2ONBOOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'XXENGSKOCXRCDY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEX2ONBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEX2ONBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEX2ONBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HEX2ONCOOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'UIIPZQPVNWMUDI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEX2ONCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEX2ONCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEX2ONCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HEX3ONAOOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'ZKBVMKAKXKAOJC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEX3ONAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEX3ONAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEX3ONAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HEX3ONBOOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'CFZVDJFTDOASSJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEX3ONBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEX3ONBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEX3ONBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HEX3ONCOOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'RCWXBCITQMXQRJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEX3ONCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEX3ONCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEX3ONCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HEX3ONDOOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'GTTLVNDFVPDHBU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEX3ONDOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEX3ONDOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEX3ONDOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:M2BKAOOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'UYZBTKCJJDJNOE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2BKAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2BKAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2BKAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:M2BKBOOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'HXTZBJMRLHBTDT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2BKBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2BKBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2BKBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MIBK3CO',
    'C<sub>6</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'JENYBWHRLYZSSZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIBK3CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIBK3CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIBK3CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MIBK3COOOH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'REESTLWXXTVHDK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIBK3COOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIBK3COOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIBK3COOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MIBKAOOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'TVLYPTZVJFAYSU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIBKAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIBKAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIBKAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MIBKBOOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'NTAUGUQNNYBRPR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIBKBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIBKBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIBKBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MTBKOOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'FSDVGLADHCPPED-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBKOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBKOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBKOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C235C6CO3H',
    'C<sub>7</sub>H<sub>8</sub>O<sub>6</sub>',
    '',
    '',
    'MCULIRAVDBAPRO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C235C6CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C235C6CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C235C6CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C710OOH',
    'C<sub>7</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'WMYMHSKADBIKCY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C710OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C710OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C710OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C713OOH',
    'C<sub>7</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'BVAIBJLRLSWCNT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C713OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C713OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C713OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C714OOH',
    'C<sub>7</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'FQLJODGQMVISEK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C714OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C714OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C714OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C715OOH',
    'C<sub>7</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'IFAJGMRYFBSYLP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C715OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C715OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C715OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7236CO',
    'C<sub>7</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'ZXGNNLLPQXKXPQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7236CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7236CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7236CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C726CO5OOH',
    'C<sub>7</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'DRGOPDAWFSWANX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C726CO5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C726CO5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C726CO5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C727CO',
    'C<sub>7</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'XDJAUXXWCBLXGT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C727CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C727CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C727CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C727OOH',
    'C<sub>7</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'IMCLYNFQESJQRO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>5</sup>',
    '13000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C727OOH'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C727OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C727OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C727OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C73OOH',
    'C<sub>7</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'QFXLTANEYKLVBH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C73OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C73OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C73OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C74OOH',
    'C<sub>7</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'ZLQFKUKGFNRBMM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C74OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C74OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C74OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C75OOH',
    'C<sub>7</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'YNKFHYFADYHYPZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C75OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C75OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C75OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7ADCCO3H',
    'C<sub>7</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'KFHCVBUEDOHUEG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7ADCCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7ADCCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7ADCCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7BDICARB',
    'C<sub>7</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'SGWFXGZCQBUONH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7BDICARB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7BDICARB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7BDICARB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7DCCO3H',
    'C<sub>7</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'VBFDFNFUMYAFQG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7DCCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7DCCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7DCCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7DDCCO3H',
    'C<sub>7</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'ITRURPAVBUVUCD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7DDCCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7DDCCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7DDCCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7EDICARB',
    'C<sub>7</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'YTVSAHBJOWKZHT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7EDICARB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7EDICARB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7EDICARB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C821OOH',
    'C<sub>7</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'VNKKTGYQOPWEKF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C821OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C821OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C821OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO235C7',
    'C<sub>7</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'PLNIROICNOROEN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO235C7'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO235C7'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO235C7'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO245C7',
    'C<sub>7</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'SOSHREJUCDQQIR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO245C7'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO245C7'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO245C7'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO25C6CO3H',
    'C<sub>7</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'NZAOVWOYFADSGM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO25C6CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO25C6CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO25C6CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO25C73OOH',
    'C<sub>7</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'NWTMJMDPQCUZCE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO25C73OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO25C73OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO25C73OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO25C74OOH',
    'C<sub>7</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'VDRXHYKLZSMLBZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO25C74OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO25C74OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO25C74OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO25C7',
    'C<sub>7</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'HGRGPAAXHOTBAM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO25C7'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO25C7'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO25C7'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO3C75OOH',
    'C<sub>7</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'TVVPPVSOZMPRIM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO3C75OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO3C75OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO3C75OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IC7DCCO3H',
    'C<sub>7</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'JFPQYVJBAXIOAT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IC7DCCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IC7DCCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IC7DCCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:M3CO245C6',
    'C<sub>7</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'FMABCBYNHKBBEH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M3CO245C6'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M3CO245C6'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M3CO245C6'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:M3CO25C6',
    'C<sub>7</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'NLLILAUVOOREKR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M3CO25C6'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M3CO25C6'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M3CO25C6'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5DBECO3H',
    'C<sub>8</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'QHSWUEYXPZRIAH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5DBECO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5DBECO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5DBECO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5EDBCO3H',
    'C<sub>8</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'YXJCVNQUVAHMKT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5EDBCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5EDBCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5EDBCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C727CO3H',
    'C<sub>8</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'FJTLPXSURBYIDW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C727CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C727CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C727CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7CO2M5OOH',
    'C<sub>8</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'GOMWBXPFFZKXIF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7CO2M5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7CO2M5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7CO2M5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7M2CO5OOH',
    'C<sub>8</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'BVDWDBGMQXZSJX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7M2CO5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7M2CO5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7M2CO5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7M3CO',
    'C<sub>8</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'WFGYJTNUNWJHJN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7M3CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7M3CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7M3CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7ODLBCO3H',
    'C<sub>8</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'NMESNSUDSMNPLZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7ODLBCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7ODLBCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7ODLBCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C816CO',
    'C<sub>8</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'FXXXYZSMIIVJDG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>2</sup>',
    '10000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C816CO'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C816CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C816CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C816CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C816OOH',
    'C<sub>8</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'GWYFGLCLLKWWIQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C816OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C816OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C816OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C817OOH',
    'C<sub>8</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'WQMXPSRLZZCZTO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>6</sup>',
    '13000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C817OOH'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C817OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C817OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C817OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C8236CO',
    'C<sub>8</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'IOHUPZZTKNTURH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8236CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8236CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8236CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C826CO3OOH',
    'C<sub>8</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'JGDMXPACXAYITG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C826CO3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C826CO3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C826CO3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C827OOH',
    'C<sub>8</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'MYZHYUNBFYQPIX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C827OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C827OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C827OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C828OOH',
    'C<sub>8</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'IPIPKWBUGMDLTO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C828OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C828OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C828OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C83OOH',
    'C<sub>8</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'MTDHYROWVQXAOV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C83OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C83OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C83OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C84OOH',
    'C<sub>8</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'HQUQRVBRCVTTSE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C84OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C84OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C84OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C85OOH',
    'C<sub>8</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'MGHQHHXZPXRHRQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C85OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C85OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C85OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C88CO',
    'C<sub>8</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'KYJUTSWXKQCOOZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C88CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C88CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C88CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C88OOH',
    'C<sub>8</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'LSPOECQNSUKNPK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C88OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C88OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C88OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C8BCCO',
    'C<sub>8</sub>H<sub>12</sub>O',
    '',
    '',
    'BYOKRVKHSHTAOM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8BCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8BCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8BCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO346C8',
    'C<sub>8</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'YUHNMHTZZXLCQZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO346C8'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO346C8'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO346C8'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO36C8',
    'C<sub>8</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '',
    'CVZGUJMLZZTPKH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO36C8'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO36C8'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO36C8'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO3C85OOH',
    'C<sub>8</sub>H<sub>16</sub>O<sub>3</sub>',
    '',
    '',
    'RPACFUNWVVDXHA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO3C85OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO3C85OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO3C85OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MXYQONE',
    'C<sub>8</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '',
    'SENUUPBBLQWHMF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYQONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYQONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYQONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OXYQONE',
    'C<sub>8</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '',
    'AIACLXROWHONEE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYQONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYQONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYQONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PEBQONE',
    'C<sub>8</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '',
    'IGRSQEOIAAGSGS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PEBQONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PEBQONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PEBQONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PXYQONE',
    'C<sub>8</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '',
    'MYKLQMNSFPAPLZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYQONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYQONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYQONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C816CO3H',
    'C<sub>9</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'IXOBJDNIWKDFSA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C816CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C816CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C816CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C817CO3H',
    'C<sub>9</sub>H<sub>14</sub>O<sub>5</sub>',
    '',
    '',
    'NVOUBBWYYUIRJW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>7</sup>',
    '16000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C817CO3H'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C817CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C817CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C817CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C827CO3H',
    'C<sub>9</sub>H<sub>14</sub>O<sub>5</sub>',
    '',
    '',
    'DZJUGPICXPPSEN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C827CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C827CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C827CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C828CO3H',
    'C<sub>9</sub>H<sub>12</sub>O<sub>6</sub>',
    '',
    '',
    'XCCOWFUPSKLDCA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C828CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C828CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C828CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C85CO3H',
    'C<sub>9</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'DAYKQISVSRMABH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C85CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C85CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C85CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C88CO3H',
    'C<sub>9</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'KOEDWBONHQRVNE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C88CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C88CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C88CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C8M2CO6OOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'LMHVWEUXUKAUEE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8M2CO6OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8M2CO6OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8M2CO6OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C8M3CO',
    'C<sub>9</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'VNKKGGMTAOGJCS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8M3CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8M3CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8M3CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C917OOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'USPARXGTYFQAAO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C917OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C917OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C917OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C91OOH',
    'C<sub>9</sub>H<sub>18</sub>O<sub>3</sub>',
    '',
    '',
    'LTHHCRGMHVQJHW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C91OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C91OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C91OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C923OOH',
    'C<sub>9</sub>H<sub>16</sub>O<sub>3</sub>',
    '',
    '',
    'ZSCOJLRNNZZYOH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '12000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C923OOH'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C923OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C923OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C923OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C928OOH',
    'C<sub>9</sub>H<sub>16</sub>O<sub>4</sub>',
    '',
    '',
    'NVMDAOHKHIQTQS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C928OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C928OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C928OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C94OOH',
    'C<sub>9</sub>H<sub>16</sub>O<sub>4</sub>',
    '',
    '',
    'ZEMHBLLRPWJDGD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C94OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C94OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C94OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C95OOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>5</sub>',
    '',
    '',
    'OKPNQXXXVOPUSS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C95OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C95OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C95OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C96OOH',
    'C<sub>9</sub>H<sub>16</sub>O<sub>3</sub>',
    '',
    '',
    'UOSOYGOFRNBVGT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C96OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C96OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C96OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C9DC',
    'C<sub>9</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'MRLMBLCAGJIZHM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C9DC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C9DC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C9DC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C9DCCO',
    'C<sub>9</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'CNGBBXSWKSNDLL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C9DCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C9DCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C9DCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C9DCOOH',
    'C<sub>9</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'LVYPIBNFNZWAIN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C9DCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C9DCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C9DCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO356C9',
    'C<sub>9</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'UAWDJSGDSYOWDW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO356C9'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO356C9'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO356C9'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO36C9',
    'C<sub>9</sub>H<sub>16</sub>O<sub>2</sub>',
    '',
    '',
    'NTESOQURXNMSRF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO36C9'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO36C9'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO36C9'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPRBQONE',
    'C<sub>9</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'XLTSBDOZTUSCMX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRBQONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRBQONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRBQONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:LIMKET',
    'C<sub>9</sub>H<sub>14</sub>O',
    '',
    '',
    'HOBBEYSRFFJETF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;1</sup>',
    '8000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMKET'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMKET'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMKET'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMKET'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:METLQONE',
    'C<sub>9</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'FBVFNJVAQSWLOP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METLQONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METLQONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METLQONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NOPINAOOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'AGOGLNHOAIUZEO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOPINAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOPINAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOPINAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NOPINBCO',
    'C<sub>9</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'AQDJLLQBBRXMBZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOPINBCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOPINBCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOPINBCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NOPINBOOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'ICIAOEDGJQUKIV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOPINBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOPINBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOPINBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NOPINCOOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'YDBPVAMAGOPNKC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOPINCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOPINCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOPINCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NOPINDCO',
    'C<sub>9</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'QEZVNLZLSDOZRT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOPINDCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOPINDCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOPINDCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NOPINDOOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'MUTHAEIFCDWSQQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOPINDOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOPINDOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOPINDOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NOPINONE',
    'C<sub>9</sub>H<sub>14</sub>O',
    '',
    '',
    'XZFDKWMYCUEKSS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOPINONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOPINONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOPINONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OETLQONE',
    'C<sub>9</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'CMBANAGVBLPIPT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OETLQONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OETLQONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OETLQONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PETLQONE',
    'C<sub>9</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'JUIQOKRNPGGIPV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PETLQONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PETLQONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PETLQONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PPRBQONE',
    'C<sub>9</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'NBHAZVWKRHTWRW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PPRBQONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PPRBQONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PPRBQONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TM124QONE',
    'C<sub>9</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'QIXDHVDGPXBRRD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124QONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124QONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124QONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1011CO',
    'C<sub>10</sub>H<sub>16</sub>O<sub>2</sub>',
    '',
    '',
    'HCTKOTXYXFZDNL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1011CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1011CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1011CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1011OOH',
    'C<sub>10</sub>H<sub>18</sub>O<sub>3</sub>',
    '',
    '',
    'SNMQVMGNQAVOQP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1011OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1011OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1011OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C101OOH',
    'C<sub>10</sub>H<sub>20</sub>O<sub>3</sub>',
    '',
    '',
    'SFSDJTUNVGVIHA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C101OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C101OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C101OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C104OOH',
    'C<sub>10</sub>H<sub>18</sub>O<sub>4</sub>',
    '',
    '',
    'NAKDXHBWPFMZPE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C104OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C104OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C104OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C105OOH',
    'C<sub>10</sub>H<sub>16</sub>O<sub>5</sub>',
    '',
    '',
    'SMUSKFONQIUMCM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C105OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C105OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C105OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C923CO3H',
    'C<sub>10</sub>H<sub>16</sub>O<sub>4</sub>',
    '',
    '',
    'JSHGCXGTVADTAK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>4</sup>',
    '15000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C923CO3H'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C923CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C923CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C923CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C928CO3H',
    'C<sub>10</sub>H<sub>16</sub>O<sub>5</sub>',
    '',
    '',
    'LCMHUZKVXFPENZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C928CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C928CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C928CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C9M2CO6OOH',
    'C<sub>10</sub>H<sub>16</sub>O<sub>4</sub>',
    '',
    '',
    'ACPAJMUJFSDSAX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C9M2CO6OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C9M2CO6OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C9M2CO6OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C9M3CO',
    'C<sub>10</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'DYAPBQRZCBYWEA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C9M3CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C9M3CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C9M3CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO356C10',
    'C<sub>10</sub>H<sub>16</sub>O<sub>3</sub>',
    '',
    '',
    'OKXFSYMNZFSQOL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO356C10'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO356C10'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO356C10'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO36C10',
    'C<sub>10</sub>H<sub>18</sub>O<sub>2</sub>',
    '',
    '',
    'WYDYPTCJLWEFAY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO36C10'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO36C10'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO36C10'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DEC3ONE',
    'C<sub>10</sub>H<sub>20</sub>O',
    '',
    '',
    'XJLDYKIEURAVBW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DEC3ONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DEC3ONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DEC3ONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PERPINONIC',
    'C<sub>10</sub>H<sub>16</sub>O<sub>4</sub>',
    '',
    '',
    'VFMYUIAYOIIENK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PERPINONIC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PERPINONIC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PERPINONIC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1011CO3H',
    'C<sub>11</sub>H<sub>18</sub>O<sub>4</sub>',
    '',
    '',
    'MDKPIQZZHUIYJQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1011CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1011CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1011CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C111OOH',
    'C<sub>11</sub>H<sub>22</sub>O<sub>3</sub>',
    '',
    '',
    'AMIJEMPORNLGBW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C111OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C111OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C111OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C114OOH',
    'C<sub>11</sub>H<sub>20</sub>O<sub>4</sub>',
    '',
    '',
    'YQNGKLISCMALPY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C114OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C114OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C114OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C115OOH',
    'C<sub>11</sub>H<sub>18</sub>O<sub>5</sub>',
    '',
    '',
    'VPBZYPGTLQIJKG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C115OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C115OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C115OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO356C11',
    'C<sub>11</sub>H<sub>18</sub>O<sub>3</sub>',
    '',
    '',
    'YADKKYWEPSBFCL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO356C11'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO356C11'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO356C11'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO36C11',
    'C<sub>11</sub>H<sub>20</sub>O<sub>2</sub>',
    '',
    '',
    'KWHQQLQVDJMZTG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO36C11'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO36C11'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO36C11'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:UDEC3ONE',
    'C<sub>11</sub>H<sub>22</sub>O',
    '',
    '',
    'YNMZZHPSYMOGCI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:UDEC3ONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:UDEC3ONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:UDEC3ONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C121OOH',
    'C<sub>12</sub>H<sub>24</sub>O<sub>3</sub>',
    '',
    '',
    'NWJGDRGQGOZUDJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C121OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C121OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C121OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C124OOH',
    'C<sub>12</sub>H<sub>22</sub>O<sub>4</sub>',
    '',
    '',
    'DCPRRPHGFZBUMW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C124OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C124OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C124OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C125OOH',
    'C<sub>12</sub>H<sub>20</sub>O<sub>5</sub>',
    '',
    '',
    'FTFXETPWXOMYNK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C125OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C125OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C125OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO356C12',
    'C<sub>12</sub>H<sub>20</sub>O<sub>3</sub>',
    '',
    '',
    'FQYVJQVZHPFSKC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO356C12'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO356C12'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO356C12'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO36C12',
    'C<sub>12</sub>H<sub>22</sub>O<sub>2</sub>',
    '',
    '',
    'RUTQSYKISNASLK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO36C12'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO36C12'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO36C12'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DDEC3ONE',
    'C<sub>12</sub>H<sub>24</sub>O',
    '',
    '',
    'PERIHWAPLOBAJM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DDEC3ONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DDEC3ONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DDEC3ONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C131OOH',
    'C<sub>13</sub>H<sub>22</sub>O<sub>4</sub>',
    '',
    '',
    'HPZPYFVEAXAGHY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C131OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C131OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C131OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BCKET',
    'C<sub>14</sub>H<sub>22</sub>O',
    '',
    '',
    'MBZBBVTYLUNZPJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCKET'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCKET'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCKET'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C131CO3H',
    'C<sub>14</sub>H<sub>22</sub>O<sub>5</sub>',
    '',
    '',
    'LLSRBTGTUZNRQT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C131CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C131CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C131CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C141OOH',
    'C<sub>14</sub>H<sub>24</sub>O<sub>3</sub>',
    '',
    '',
    'HKWHMEKBBPOBSQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C141OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C141OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C141OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C141CO3H',
    'C<sub>15</sub>H<sub>24</sub>O<sub>4</sub>',
    '',
    '',
    'ADRMPTUALHKSOU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C141CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C141CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C141CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C619CO',
    'C<sub>6</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '',
    'NGHVTTBOPYXCFB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C619CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C619CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C619CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CY6TRION',
    'C<sub>6</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '',
    'GKSCYYCYSPXQFY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CY6TRION'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CY6TRION'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CY6TRION'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PHCOMEOOH',
    'C<sub>8</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'BXVCLOREWFXMNM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PHCOMEOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PHCOMEOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PHCOMEOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MPHCOMEOOH',
    'C<sub>9</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'NJDRUBYBGCJLGU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MPHCOMEOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MPHCOMEOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MPHCOMEOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PHCOCOCOOH',
    'C<sub>9</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'XMJMKOZGMVOAIC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PHCOCOCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PHCOCOCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PHCOCOCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PHCOCOME',
    'C<sub>9</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '',
    'BVQVLAIMHVDZEL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PHCOCOME'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PHCOCOME'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PHCOCOME'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PHCOETOOH',
    'C<sub>9</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'RYQHVKZCKUBIFL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PHCOETOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PHCOETOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PHCOETOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DMPHCOME',
    'C<sub>10</sub>H<sub>12</sub>O',
    '',
    '',
    'BKIHFZLJJUNKMZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMPHCOME'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMPHCOME'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMPHCOME'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DMPHCOMOOH',
    'C<sub>10</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'SEDWELDPOZYWLL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMPHCOMOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMPHCOMOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMPHCOMOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EMPHCOME',
    'C<sub>11</sub>H<sub>14</sub>O',
    '',
    '',
    'CZNQKVDFQIGBEW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EMPHCOME'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EMPHCOME'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EMPHCOME'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EMPHCOMOOH',
    'C<sub>11</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'OJNDCDHAKIGFTB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EMPHCOMOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EMPHCOMOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EMPHCOMOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BIACETOH',
    'C<sub>4</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '',
    'NXIVQSJQXMAXJR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BIACETOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BIACETOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BIACETOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO2H3CO3H',
    'C<sub>4</sub>H<sub>6</sub>O<sub>5</sub>',
    '',
    '',
    'WNDCXKJVOGKFRM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2H3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2H3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2H3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H13CO2CO3H',
    'C<sub>4</sub>H<sub>6</sub>O<sub>6</sub>',
    '',
    '',
    'RXVYYLAFXUAZCR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H13CO2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H13CO2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H13CO2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H14CO23C4',
    'C<sub>4</sub>H<sub>6</sub>O<sub>4</sub>',
    '',
    '',
    'GJCZUCLKDGABDS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>6</sup>',
    '17000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H14CO23C4'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H14CO23C4'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H14CO23C4'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H14CO23C4'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H1C23C4OOH',
    'C<sub>4</sub>H<sub>6</sub>O<sub>5</sub>',
    '',
    '',
    'FQXHRCVOGVCTSR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H1C23C4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H1C23C4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H1C23C4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HMVKAOOH',
    'C<sub>4</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'XTELZFGIGJBUGR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HMVKAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HMVKAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HMVKAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HMVKBOOH',
    'C<sub>4</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'NGLQGLCPXKPDMS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HMVKBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HMVKBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HMVKBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO12CO3C4',
    'C<sub>4</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'SEYLPRWNVFCVRQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO12CO3C4'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO12CO3C4'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO12CO3C4'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO14CO2C4',
    'C<sub>4</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'XBJODPUPYBBDEM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO14CO2C4'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO14CO2C4'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO14CO2C4'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HOCO3C4OOH',
    'C<sub>4</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'GQXQZBROPOTXJQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOCO3C4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOCO3C4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOCO3C4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MEKAOH',
    'C<sub>4</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '',
    'LVSQXDHWDCMMRJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MEKAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MEKAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MEKAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MEKCOH',
    'C<sub>4</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '',
    'GFAZHVHNLUBROE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MEKCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MEKCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MEKCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MVKOHAOH',
    'C<sub>4</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'UQPHVQVXLPRNCX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MVKOHAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MVKOHAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MVKOHAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MVKOHAOOH',
    'C<sub>4</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'MOVXURHCNUWOQO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MVKOHAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MVKOHAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MVKOHAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MVKOHBOOH',
    'C<sub>4</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'WSMWIMXDHMPHIN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MVKOHBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MVKOHBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MVKOHBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MVKOH',
    'C<sub>4</sub>H<sub>6</sub>O<sub>2</sub>',
    '',
    '',
    'LHBQGXZUVXFJRH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MVKOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MVKOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MVKOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C517OH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'NQMZUMSFJBKHAU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C517OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C517OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C517OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C517OOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'OAFCGFSFCVGKSH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '13000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C517OOH'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C517OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C517OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C517OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C519OOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'RDSFTYTWLRHJGZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>5</sup>',
    '13000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C519OOH'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C519OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C519OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C519OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C51OH2CO',
    'C<sub>5</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'WOVLKKLXYZJMSN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C51OH2CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C51OH2CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C51OH2CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C51OH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'NJUQBPDKVORANW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C51OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C51OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C51OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C51OOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'IZBMMNKBXWVQLB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C51OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C51OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C51OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C521OH',
    'C<sub>5</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'UOGQGBWLBZOULD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C521OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C521OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C521OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C521OOH',
    'C<sub>5</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'INSNYERMNWOCIO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C521OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C521OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C521OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C524CO',
    'C<sub>5</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'JVFYSLPFISVGRS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C524CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C524CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C524CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C525OOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>6</sub>',
    '',
    '',
    'KYXSOONCNSTMJK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>12</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C525OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C525OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C525OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C53OH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'PLVCXNLHUHTLCR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C53OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C53OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C53OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C53OOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'VCGFNBZCPLQTJR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C53OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C53OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C53OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C55OOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'IEXMEMALQGQSKE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C55OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C55OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C55OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C59OOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'JWNCLQLBUYGJMN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C59OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C59OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C59OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5CO243OH',
    'C<sub>5</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'SLKPFOVYRYRNBA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5CO243OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5CO243OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5CO243OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5OHCO4OOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'DSLVXKSJLFFUGE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5OHCO4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5OHCO4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5OHCO4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO2C5OH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'JSHPTIGHEWEXRW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>3</sup>',
    '9800',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2C5OH'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2C5OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2C5OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2C5OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO2H3MCO3H',
    'C<sub>5</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'LZACDMRRAOGIBF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2H3MCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2H3MCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2H3MCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO3H4CO3H',
    'C<sub>5</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'LAOPLCWFGWEKGR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO3H4CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO3H4CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO3H4CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DIEKAOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'QMXCHEVUAIPIRM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DIEKAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DIEKAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DIEKAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H3C2C4CO3H',
    'C<sub>5</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'NYZNEBYYPQANOB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3C2C4CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3C2C4CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3C2C4CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HC23C4CO3H',
    'C<sub>5</sub>H<sub>6</sub>O<sub>6</sub>',
    '',
    '',
    'UQNPRLJBDVQJQC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HC23C4CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HC23C4CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HC23C4CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HCOC5',
    'C<sub>5</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '',
    'LSMLKPXBSFFBNR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HCOC5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HCOC5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HCOC5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HMVKBCO3H',
    'C<sub>5</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'VFNFGUWSZFHBRW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HMVKBCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HMVKBCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HMVKBCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO13CO4C5',
    'C<sub>5</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'CGPIPFJOMJUWGK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO13CO4C5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO13CO4C5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO13CO4C5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO14CO2C5',
    'C<sub>5</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'XLDKDOKPMNKVMP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO14CO2C5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO14CO2C5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO14CO2C5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO14CO3C5',
    'C<sub>5</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'YMIRTILUDYUWGY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO14CO3C5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO14CO3C5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO14CO3C5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO1CO24C5',
    'C<sub>5</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'VBUBLWCIADYRMB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO1CO24C5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO1CO24C5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO1CO24C5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO1CO34C5',
    'C<sub>5</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'LKLKMCUVBQDYFU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO1CO34C5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO1CO34C5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO1CO34C5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO1CO3C5',
    'C<sub>5</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'TYXULUBCBKMSSK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO1CO3C5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO1CO3C5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO1CO3C5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO2CO4C5',
    'C<sub>5</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'PCYZZYAEGNVNMH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2CO4C5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2CO4C5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2CO4C5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HOCO3C5OOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'ZLPJDXTYGYNOQK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOCO3C5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOCO3C5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOCO3C5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HOCO4C5OOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'MYGJVQXASPJPCS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOCO4C5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOCO4C5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOCO4C5OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MBOACO',
    'C<sub>5</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'FEIUXLCYYBVUGD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MBOACO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MBOACO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MBOACO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ME3CO2BUOL',
    'C<sub>5</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'NBEGXSQMVJTIAR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ME3CO2BUOL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ME3CO2BUOL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ME3CO2BUOL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MIPKAOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'BNDRWEVUODOUDW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIPKAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIPKAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIPKAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MIPKBOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'VVSRECWZBBJOTG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIPKBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIPKBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIPKBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MPRKAOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'HDKKRASBPHFULQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MPRKAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MPRKAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MPRKAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BZOBIPEROH',
    'C<sub>6</sub>H<sub>6</sub>O<sub>4</sub>',
    '',
    '',
    'OGRXSIBGKCRBOL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BZOBIPEROH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BZOBIPEROH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BZOBIPEROH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4COMEOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'FDJJNIXWMAWMBP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4COMEOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4COMEOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4COMEOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4COMOH3OH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'NCEURKGQTPCVEC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4COMOH3OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4COMOH3OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4COMOH3OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4COMOHOOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'JZGTXIGKACACHL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4COMOHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4COMOHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4COMOHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4MOHOCO3H',
    'C<sub>6</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'BJXKNHIKUQDPQL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4MOHOCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4MOHOCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4MOHOCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C517CO3H',
    'C<sub>6</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'HTNOTPIWPYZOLN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C517CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C517CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C517CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C519CO3H',
    'C<sub>6</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'OBKQTPZEBCGGJT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C519CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C519CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C519CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5COHOCO3H',
    'C<sub>6</sub>H<sub>8</sub>O<sub>6</sub>',
    '',
    '',
    'BPYCYKKOURHNJX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5COHOCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5COHOCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5COHOCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5O5OHCO3H',
    'C<sub>6</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'GCQMJNYHSPBFDA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5O5OHCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5O5OHCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5O5OHCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C610OH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'YFEDHAOQJOZUIL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C610OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C610OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C610OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C610OOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'VBEFRWQFSDXQDV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C610OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C610OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C610OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C611OH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'PYRMISJRKRVNPG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C611OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C611OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C611OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C612OH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'VCLSUNMNDIKRMY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C612OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C612OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C612OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C612OOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'OANIXDZJWBEQCD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C612OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C612OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C612OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C613OOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'MBLADDFAKVGAFO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C613OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C613OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C613OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C614CO',
    'C<sub>6</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'DFWHGSVPVJPYJZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C614CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C614CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C614CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C614OH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'WLPHOQAEOJPJID-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C614OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C614OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C614OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C614OOH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'AZSLPKKGLPCKMI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C614OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C614OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C614OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C619OH',
    'C<sub>6</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'WEYIBABPZCYASX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C619OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C619OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C619OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C61CO',
    'C<sub>6</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'MGEAAKFVOQZVFH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C61CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C61CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C61CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C61OH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'JOVKXRBMZIPRBZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C61OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C61OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C61OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C61OOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'ZUQHNOSGBJLTRH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C61OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C61OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C61OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C621OOH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>6</sub>',
    '',
    '',
    'OMSKVAAPFLCUBC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C621OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C621OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C621OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C624CO',
    'C<sub>6</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'SAJQFIMRYKQCMA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C624CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C624CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C624CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C625OH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'UHZLCNNVPSWLBR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C625OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C625OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C625OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C625OOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'RLEQEEKQTRHVBK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C625OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C625OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C625OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C627OH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'YXADPHVQSSNJLB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C627OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C627OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C627OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C630OH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'LTOZVYXSZHIEKZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C630OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C630OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C630OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C630OOH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'FPSNWVZQINIJKM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C630OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C630OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C630OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C63OH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'YEHSOHVSOJHCML-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C63OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C63OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C63OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C63OOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'RYUSCYCDUHZJRL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C63OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C63OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C63OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C64OH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'DWHFPVYPGLVOER-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C64OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C64OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C64OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C64OOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'WKWKMZOJIHCBFC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C64OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C64OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C64OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C66CO',
    'C<sub>6</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'PQXOVUFKUOIXAY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C66CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C66CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C66CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C66OH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'YKCRSYHGTATDJD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C66OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C66OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C66OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C66OOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'ZIMKSIUZUDHWGV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C66OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C66OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C66OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C67CO3H',
    'C<sub>6</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'BGZGHPIMJSIBNB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C67CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C67CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C67CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C69OH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'UAFCVHAXODPLTF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C69OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C69OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C69OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C69OOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'IBTXITPBBCYNLS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C69OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C69OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C69OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6CO23HO5',
    'C<sub>6</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'ZFXUWHPHUNDYBV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO23HO5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO23HO5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO23HO5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6CO243OH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'YZRCADLLOAXRLD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO243OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO243OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO243OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6CO34HO1',
    'C<sub>6</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'LBGWMVXVPMPEID-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO34HO1'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO34HO1'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO34HO1'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6CO3HO14',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'AEYYIRCLAOJEMX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO3HO14'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO3HO14'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO3HO14'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6CO3HO25',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'AQJAHIKLRWQRAX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO3HO25'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO3HO25'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO3HO25'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6CO3HO4',
    'C<sub>6</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'SKCYVGUCBRYGTE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO3HO4'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO3HO4'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO3HO4'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6CO3OHOOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'VJHRZIUXRMRGDC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO3OHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO3OHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO3OHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6HOCOOOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'DEHZHOWOLMWYLS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6HOCOOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6HOCOOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6HOCOOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO24M3C5OH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'JUTFYFRULBWUNH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO24M3C5OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO24M3C5OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO24M3C5OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO25C6OH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'MXGSILCFPNVDMX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO25C6OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO25C6OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO25C6OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO2HO3C6',
    'C<sub>6</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'UHSBCAJZDUQTHH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2HO3C6'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2HO3C6'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2HO3C6'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO2HO4C6',
    'C<sub>6</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'ODWYTDVNWFBCLV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2HO4C6'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2HO4C6'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2HO4C6'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO2HOC6OOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'DONIGPAOCGSEHJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2HOC6OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2HOC6OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2HOC6OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO2M3C5OH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'YJCMJVMCCJIPRV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2M3C5OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2M3C5OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2M3C5OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO2MC5OH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'NZBRXFKHZBOFBW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2MC5OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2MC5OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2MC5OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CY6DIONOH',
    'C<sub>6</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'ACRUCDPQQCIOID-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CY6DIONOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CY6DIONOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CY6DIONOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CYHXOLACO',
    'C<sub>6</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'ODZTXUXIYGJLMC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CYHXOLACO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CYHXOLACO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CYHXOLACO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CYHXONAOH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'TWEVQGUWCLBRMJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CYHXONAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CYHXONAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CYHXONAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DMK2OH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'RQDWELNLPMBYMA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMK2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMK2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMK2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DMKCOOH',
    'C<sub>6</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'OKDWWGVTKQPUTM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMKCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMKCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMKCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DMKOHOOH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'WAHPQVAXIMVNLL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMKOHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMKOHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMKOHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EIPKAOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'SYAVYWAMVZKGTF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EIPKAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EIPKAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EIPKAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EIPKBOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'JYEMLYGXHDIVRA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EIPKBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EIPKBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EIPKBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H13M3CO4C5',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'NBNMOYHUQSLZCQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H13M3CO4C5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H13M3CO4C5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H13M3CO4C5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H3C25C6OH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'XLUGOLRJPRATMY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3C25C6OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3C25C6OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3C25C6OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H3C25C6OOH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'XIJKANBCMKWKRM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3C25C6OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3C25C6OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3C25C6OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HEX3ONAOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'XHYXKWWFNRBCGE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEX3ONAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEX3ONAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEX3ONAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HEX3ONCOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'ZWBUSAWJHMPOEJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEX3ONCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEX3ONCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEX3ONCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HEX3ONDOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'ITHSWIXXHGKFJW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEX3ONDOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEX3ONDOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEX3ONDOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO1CO24C6',
    'C<sub>6</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'NUDMYLMVZRZHHU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO1CO24C6'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO1CO24C6'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO1CO24C6'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO1CO4C6',
    'C<sub>6</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'APQMHEQLBDXGMP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO1CO4C6'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO1CO4C6'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO1CO4C6'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO2CO5C6',
    'C<sub>6</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'ZSDLLTJVENEIDW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>3</sup>',
    '10000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2CO5C6'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2CO5C6'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2CO5C6'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2CO5C6'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:M2BKAOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'ZXZUCILLTLHIBZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2BKAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2BKAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2BKAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:M2BKBOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'KHCUSEDRQWYNDS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2BKBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2BKBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2BKBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MBKCOOHOOH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'VGLNQNYMXFMHPV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MBKCOOHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MBKCOOHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MBKCOOHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MIBKAOH3CO',
    'C<sub>6</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'NARMPYMUEZMSEV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIBKAOH3CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIBKAOH3CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIBKAOH3CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MIBKBOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'IGPIDYBTABPKQT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIBKBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIBKBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIBKBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MIBKHO14',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'UZSRJTNVDUYOLE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIBKHO14'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIBKHO14'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIBKHO14'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MIBKHO4OOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'FGHCAVJLMYVGOV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIBKHO4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIBKHO4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIBKHO4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MIBKOH34',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'OSPIOFUQWMUWOI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIBKOH34'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIBKOH34'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIBKOH34'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MIBKOHAOOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'WIXFQYMFSUQGGT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIBKOHAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIBKOHAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIBKOHAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MIBKOHBOOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'NCKNZQNPSVRYAP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIBKOHBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIBKOHBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIBKOHBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MTBKOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'DYAWMXSWDGPGOI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBKOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBKOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBKOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PBZQCO',
    'C<sub>6</sub>H<sub>4</sub>O<sub>4</sub>',
    '',
    '',
    'LTWQMQDFZHUKCN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBZQCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBZQCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBZQCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PBZQOH',
    'C<sub>6</sub>H<sub>6</sub>O<sub>4</sub>',
    '',
    '',
    'KGAUAKJVBKFEJK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBZQOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBZQOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBZQOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PBZQOOH',
    'C<sub>6</sub>H<sub>6</sub>O<sub>5</sub>',
    '',
    '',
    'GWWKDNIKIVTFLV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBZQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBZQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBZQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C61CO3H',
    'C<sub>7</sub>H<sub>10</sub>O<sub>6</sub>',
    '',
    '',
    'LNQZNTUCDYUQNY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C61CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C61CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C61CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C62CO3H',
    'C<sub>7</sub>H<sub>10</sub>O<sub>6</sub>',
    '',
    '',
    'OTMFEIRKQNFPTO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C62CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C62CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C62CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C711OOH',
    'C<sub>7</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'CHMPWQJFRSDBMP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C711OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C711OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C711OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C712OH',
    'C<sub>7</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'XKQDJNZCXUTPAB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C712OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C712OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C712OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C712OOH',
    'C<sub>7</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'ISDXEEIPAJYQKS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C712OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C712OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C712OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C713OH',
    'C<sub>7</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'KKMPMNHIJNYFMY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C713OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C713OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C713OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C714OH',
    'C<sub>7</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'BDJIDAHXOAZMLT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C714OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C714OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C714OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C719OH',
    'C<sub>7</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'SNLGDBZBHBGDGF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C719OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C719OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C719OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C719OOH',
    'C<sub>7</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'RIQZESWBZQGTOF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C719OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C719OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C719OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C71OOH',
    'C<sub>7</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'NBQALOYIKVIATH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C71OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C71OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C71OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C726CO3OH',
    'C<sub>7</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'KXKCGTAVIRFZLI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C726CO3OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C726CO3OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C726CO3OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C72OH',
    'C<sub>7</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'NSVUCXUEJIZYCX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C72OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C72OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C72OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C72OOH',
    'C<sub>7</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'HOCRXLJRXJDOAI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C72OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C72OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C72OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C76OOH',
    'C<sub>7</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'RNKPJWWQPAQZAU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C76OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C76OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C76OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C77CO',
    'C<sub>7</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'LRWMVVHMPWURQP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C77CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C77CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C77CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C77OH',
    'C<sub>7</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'BWFQHNYIFKCYIN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C77OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C77OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C77OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C77OOH',
    'C<sub>7</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'VLZZBCPZVYCEGU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C77OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C77OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C77OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C78CO',
    'C<sub>7</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'XZDSUXRHWGXGLP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C78CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C78CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C78CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C78OH',
    'C<sub>7</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'RHPFPSWJNNLJIH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C78OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C78OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C78OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C78OOH',
    'C<sub>7</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'CHSMMMZNDOATLZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C78OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C78OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C78OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C79OOH',
    'C<sub>7</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'PAASZTKJDWJXEO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C79OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C79OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C79OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7BDCOH',
    'C<sub>7</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'IQLAANIUQOXZGT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7BDCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7BDCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7BDCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7BDCOOH',
    'C<sub>7</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'YSGKLAZJXASOJQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7BDCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7BDCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7BDCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7EDCCO',
    'C<sub>7</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'ZZJOBVIMQADRSG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7EDCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7EDCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7EDCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7EDCOH',
    'C<sub>7</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'ILHMXLYATWSMQV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7EDCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7EDCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7EDCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7EDCOOH',
    'C<sub>7</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'GFYCWCYSZRNKIC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7EDCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7EDCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7EDCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO25C73OH',
    'C<sub>7</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'SUAOXERUOLNODJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO25C73OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO25C73OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO25C73OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO25C74OH',
    'C<sub>7</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'WVDVIEDFZYMNAI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO25C74OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO25C74OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO25C74OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H2M2CO5C6',
    'C<sub>7</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '',
    'GNNBSAPGFGNCCT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M2CO5C6'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M2CO5C6'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M2CO5C6'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H2M3CO5C6',
    'C<sub>7</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '',
    'JXXNGUYHZPNXHL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M3CO5C6'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M3CO5C6'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M3CO5C6'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H2M4CO5C6',
    'C<sub>7</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '',
    'ZIVAMUMQDXZFCR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M4CO5C6'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M4CO5C6'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M4CO5C6'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H3C25CCO3H',
    'C<sub>7</sub>H<sub>10</sub>O<sub>6</sub>',
    '',
    '',
    'ARDZNQBCJILRHG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3C25CCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3C25CCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3C25CCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HCC7CO',
    'C<sub>7</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'WVMVYBISUAVCBD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HCC7CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HCC7CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HCC7CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO2CO35C7',
    'C<sub>7</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'LULWLYVLBHVZLB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2CO35C7'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2CO35C7'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2CO35C7'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO2CO5C7',
    'C<sub>7</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '',
    'DWMNUVZLRBCGOL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2CO5C7'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2CO5C7'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2CO5C7'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO3CO6C7',
    'C<sub>7</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '',
    'MQRALIJAASQPNT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '11000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3CO6C7'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3CO6C7'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3CO6C7'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3CO6C7'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PTLQCO',
    'C<sub>7</sub>H<sub>6</sub>O<sub>4</sub>',
    '',
    '',
    'QCLUMLMJJNMFFX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PTLQCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PTLQCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PTLQCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PTLQOH',
    'C<sub>7</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'FWCZASAULMADEU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PTLQOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PTLQOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PTLQOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PTLQOOH',
    'C<sub>7</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'ULCYCDVSDDOIBS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PTLQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PTLQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PTLQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TLCOBIPEOH',
    'C<sub>7</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'BTRXIMYXFXXDNL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TLCOBIPEOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TLCOBIPEOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TLCOBIPEOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TLOBIPEROH',
    'C<sub>7</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'OGIZZGFCOPEREO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TLOBIPEROH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TLOBIPEROH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TLOBIPEROH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6MOCOCO3H',
    'C<sub>8</sub>H<sub>10</sub>O<sub>6</sub>',
    '',
    '',
    'UAMJQIWVNIVSAA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6MOCOCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6MOCOCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6MOCOCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7CO2M5OH',
    'C<sub>8</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'VIGCXZSBZQABDL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7CO2M5OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7CO2M5OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7CO2M5OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7CO2OCO3H',
    'C<sub>8</sub>H<sub>10</sub>O<sub>6</sub>',
    '',
    '',
    'PYNUJNZYCLWJPS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7CO2OCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7CO2OCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7CO2OCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7M2CO5OH',
    'C<sub>8</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'IWFVDGADKJRMAI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7M2CO5OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7M2CO5OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7M2CO5OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C817OH',
    'C<sub>8</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'HXKXVESDDNIBIQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C817OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C817OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C817OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C818CO',
    'C<sub>8</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'CRQAGKNTHDNGEW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>6</sup>',
    '16000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C818CO'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C818CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C818CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C818CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C818OH',
    'C<sub>8</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'GYBDPSWJEGVQPC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C818OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C818OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C818OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C818OOH',
    'C<sub>8</sub>H<sub>14</sub>O<sub>5</sub>',
    '',
    '',
    'DLMBPALZQHFDOH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>8</sup>',
    '17000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C818OOH'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C818OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C818OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C818OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C819OOH',
    'C<sub>8</sub>H<sub>14</sub>O<sub>5</sub>',
    '',
    '',
    'JRXMSSDNDAZISI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>7</sup>',
    '17000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C819OOH'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C819OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C819OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C819OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C81OOH',
    'C<sub>8</sub>H<sub>16</sub>O<sub>4</sub>',
    '',
    '',
    'SFFBCYBCCUXGLX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C81OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C81OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C81OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C820OOH',
    'C<sub>8</sub>H<sub>12</sub>O<sub>6</sub>',
    '',
    '',
    'MPCACGHSMGOFNV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>12</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C820OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C820OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C820OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C826CO3OH',
    'C<sub>8</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'GGSZUEZFMJTLBX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C826CO3OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C826CO3OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C826CO3OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C827OH',
    'C<sub>8</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'VYHQZXLAUHJBAB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C827OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C827OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C827OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C829OH',
    'C<sub>8</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'ZFRREEXTYBESJX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C829OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C829OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C829OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C829OOH',
    'C<sub>8</sub>H<sub>14</sub>O<sub>5</sub>',
    '',
    '',
    'PFFZQAOPEABNHW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C829OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C829OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C829OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C82OOH',
    'C<sub>8</sub>H<sub>16</sub>O<sub>4</sub>',
    '',
    '',
    'AQECYOJQUIJAFS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C82OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C82OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C82OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C84OH',
    'C<sub>8</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'HXKSWDLNZPICFQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C84OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C84OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C84OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C88OH',
    'C<sub>8</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'DCTATDQRTQNXHW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C88OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C88OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C88OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EBZOBPEROH',
    'C<sub>8</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'YDVGTQTYIBCIQC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBZOBPEROH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBZOBPEROH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBZOBPEROH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO34CO6C8',
    'C<sub>8</sub>H<sub>16</sub>O<sub>3</sub>',
    '',
    '',
    'GQDVWZAGWHUXKX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO34CO6C8'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO34CO6C8'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO34CO6C8'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO3CO46C8',
    'C<sub>8</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'LLYUJOAMIUBKSA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3CO46C8'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3CO46C8'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3CO46C8'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO3CO6C8',
    'C<sub>8</sub>H<sub>16</sub>O<sub>2</sub>',
    '',
    '',
    'VJDZJBNTVLGPEM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3CO6C8'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3CO6C8'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3CO6C8'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MXYOBPEROH',
    'C<sub>8</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'BQJOHFWATKFGAQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYOBPEROH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYOBPEROH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYOBPEROH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MXYQOH',
    'C<sub>8</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'DNSXSYZLXRHYTM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYQOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYQOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYQOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MXYQOOH',
    'C<sub>8</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'UAWVAAITGKOKNW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OXYQCO',
    'C<sub>8</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'QSCBEAAIZXLBQA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYQCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYQCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYQCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OXYQOH',
    'C<sub>8</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'LJMMKZLQFVIDLQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYQOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYQOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYQOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OXYQOOH',
    'C<sub>8</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'NOWQTCYBLCRAEJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PXYQOH',
    'C<sub>8</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'RORXCXPFLRGHQV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYQOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYQOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYQOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PXYQOOH',
    'C<sub>8</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'FYDHRLZPZZTRLJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6EO2HCO3H',
    'C<sub>9</sub>H<sub>12</sub>O<sub>6</sub>',
    '',
    '',
    'KMUWHHLOUXRZEC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6EO2HCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6EO2HCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6EO2HCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7MJPCO3H',
    'C<sub>9</sub>H<sub>12</sub>O<sub>6</sub>',
    '',
    '',
    'HVGFJXMJLWNDQT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7MJPCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7MJPCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7MJPCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7MOCOCO3H',
    'C<sub>9</sub>H<sub>12</sub>O<sub>6</sub>',
    '',
    '',
    'UXMGGYROBLVMKA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7MOCOCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7MOCOCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7MOCOCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C8M2CO6OH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'AUYUFIFJEJTOMG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8M2CO6OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8M2CO6OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8M2CO6OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C917OH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'DVAQWOBQFULNSX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C917OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C917OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C917OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C920OOH',
    'C<sub>9</sub>H<sub>16</sub>O<sub>4</sub>',
    '',
    '',
    'CXKZGZZGALDRTB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C920OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C920OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C920OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C921OOH',
    'C<sub>9</sub>H<sub>16</sub>O<sub>5</sub>',
    '',
    '',
    'MIFQELLQXZRDIQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C921OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C921OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C921OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C922OOH',
    'C<sub>9</sub>H<sub>16</sub>O<sub>6</sub>',
    '',
    '',
    'IOTRHTNOHNKLJT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C922OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C922OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C922OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C923OH',
    'C<sub>9</sub>H<sub>16</sub>O<sub>2</sub>',
    '',
    '',
    'VZYSLJNPEGILSI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>3</sup>',
    '12000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C923OH'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C923OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C923OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C923OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C924CO',
    'C<sub>9</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'IEIWFPIZSBHOOD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C924CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C924CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C924CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C924OH',
    'C<sub>9</sub>H<sub>16</sub>O<sub>3</sub>',
    '',
    '',
    'OXSRPARPRXNCEH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>5</sup>',
    '16000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C924OH'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C924OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C924OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C924OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C924OOH',
    'C<sub>9</sub>H<sub>16</sub>O<sub>4</sub>',
    '',
    '',
    'BVODBOGLMHSHGK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>6</sup>',
    '16000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C924OOH'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C924OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C924OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C924OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C925OOH',
    'C<sub>9</sub>H<sub>16</sub>O<sub>6</sub>',
    '',
    '',
    'BGVLBDREANINMN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>12</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C925OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C925OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C925OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C927OH',
    'C<sub>9</sub>H<sub>16</sub>O<sub>3</sub>',
    '',
    '',
    'JILOVKBSEAXPMT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C927OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C927OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C927OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C927OOH',
    'C<sub>9</sub>H<sub>16</sub>O<sub>4</sub>',
    '',
    '',
    'UVVCFFCMOUIWEJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C927OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C927OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C927OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C928OH',
    'C<sub>9</sub>H<sub>16</sub>O<sub>3</sub>',
    '',
    '',
    'QGCNXROUFNWXOO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C928OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C928OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C928OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C929CO',
    'C<sub>9</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'BWILLNTUIBCKIM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C929CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C929CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C929CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C929OH',
    'C<sub>9</sub>H<sub>16</sub>O<sub>4</sub>',
    '',
    '',
    'PMWQIXWFMSCXRH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C929OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C929OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C929OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C929OOH',
    'C<sub>9</sub>H<sub>16</sub>O<sub>5</sub>',
    '',
    '',
    'IKUORCWWMOEDGL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C929OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C929OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C929OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C92OOH',
    'C<sub>9</sub>H<sub>18</sub>O<sub>4</sub>',
    '',
    '',
    'MOTPUWPPGZYDTM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C92OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C92OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C92OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C93CO',
    'C<sub>9</sub>H<sub>16</sub>O<sub>3</sub>',
    '',
    '',
    'NCWLHDSPZIENNF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C93CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C93CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C93CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C93OH',
    'C<sub>9</sub>H<sub>18</sub>O<sub>3</sub>',
    '',
    '',
    'XOZZRVPGLURXSY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C93OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C93OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C93OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C93OOH',
    'C<sub>9</sub>H<sub>18</sub>O<sub>4</sub>',
    '',
    '',
    'DSWUVSMVGXSNEV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C93OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C93OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C93OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C94OH',
    'C<sub>9</sub>H<sub>16</sub>O<sub>3</sub>',
    '',
    '',
    'RCWXDPYULCSTKX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C94OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C94OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C94OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C96OH',
    'C<sub>9</sub>H<sub>16</sub>O<sub>2</sub>',
    '',
    '',
    'RRFQMYCDTHUGSU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C96OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C96OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C96OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C97OH',
    'C<sub>9</sub>H<sub>16</sub>O<sub>3</sub>',
    '',
    '',
    'QWYKJUJQBVIHQW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C97OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C97OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C97OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C97OOH',
    'C<sub>9</sub>H<sub>16</sub>O<sub>4</sub>',
    '',
    '',
    'AXRJNDGSGFVBSX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C97OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C97OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C97OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C98OH',
    'C<sub>9</sub>H<sub>16</sub>O<sub>4</sub>',
    '',
    '',
    'BWKWRXKCGJAJAO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C98OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C98OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C98OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C98OOH',
    'C<sub>9</sub>H<sub>16</sub>O<sub>5</sub>',
    '',
    '',
    'MEUGYCLQCHCPCY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C98OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C98OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C98OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C9DCOH',
    'C<sub>9</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'DIFRJFLUSYQBJM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C9DCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C9DCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C9DCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO4CO7C9',
    'C<sub>9</sub>H<sub>18</sub>O<sub>2</sub>',
    '',
    '',
    'BPRAKHMXALGYKO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO4CO7C9'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO4CO7C9'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO4CO7C9'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPBZOBPROH',
    'C<sub>9</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'WRQNGVASMLSOGA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBZOBPROH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBZOBPROH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBZOBPROH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPRBQCO',
    'C<sub>9</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'UYSSVGYDANWBFJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRBQCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRBQCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRBQCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPRBQOH',
    'C<sub>9</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'BQKYQBQGKYWJSQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRBQOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRBQOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRBQOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPRBQOOH',
    'C<sub>9</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'CCPBRYDTGCPJNX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRBQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRBQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRBQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:LMKAOH',
    'C<sub>9</sub>H<sub>16</sub>O<sub>3</sub>',
    '',
    '',
    'RDFFVUMNEKCADL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LMKAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LMKAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LMKAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:LMKAOOH',
    'C<sub>9</sub>H<sub>16</sub>O<sub>4</sub>',
    '',
    '',
    'ZYSXBTHWQDNLBX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LMKAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LMKAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LMKAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:LMKBCO',
    'C<sub>9</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'QJYRJOZGIVJKQK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LMKBCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LMKBCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LMKBCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:LMKBOOH',
    'C<sub>9</sub>H<sub>16</sub>O<sub>4</sub>',
    '',
    '',
    'PMLHMEIQMSUJKR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LMKBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LMKBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LMKBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:METLOBPROH',
    'C<sub>9</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'ZSTYNOBMCJBFRA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METLOBPROH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METLOBPROH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METLOBPROH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:METLQOH',
    'C<sub>9</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'YIUSRNITCRMQJW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METLQOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METLQOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METLQOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:METLQOOH',
    'C<sub>9</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'JBNOKZJMGKNXDA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METLQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METLQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METLQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NOPINAOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '',
    'CVWGOJDPALGYKB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOPINAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOPINAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOPINAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NOPINBOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '',
    'FPBMXOVOMRHDTB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOPINBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOPINBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOPINBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NOPINCOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '',
    'OXRZVROAQQDWAA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOPINCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOPINCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOPINCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NOPINDOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '',
    'MLOBETUCFXAOOL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOPINDOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOPINDOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOPINDOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OETLQCO',
    'C<sub>9</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'WOEKXHYIEUECKR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OETLQCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OETLQCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OETLQCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OETLQOH',
    'C<sub>9</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'DZHQWTGZQAKVBN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OETLQOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OETLQOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OETLQOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OETLQOOH',
    'C<sub>9</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'KKWSBZSFLIKUTL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OETLQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OETLQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OETLQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PBZOBPEROH',
    'C<sub>9</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'JGNLEXNHGWFGHL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBZOBPEROH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBZOBPEROH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBZOBPEROH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PETLQOH',
    'C<sub>9</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'KZOAJFYPECZGSC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PETLQOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PETLQOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PETLQOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PETLQOOH',
    'C<sub>9</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'BJRXYYOXPIRVAX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PETLQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PETLQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PETLQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TM123OBPOH',
    'C<sub>9</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'WQSRSICCLTUNRX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM123OBPOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM123OBPOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM123OBPOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TM124QOH',
    'C<sub>9</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'GVKLCWOTVYVOTB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124QOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124QOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124QOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TM124QOOH',
    'C<sub>9</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'SLEWHRYFRSXVOQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124QOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124QOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124QOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TM135OBPOH',
    'C<sub>9</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'MWFXWFJYOSXFGA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM135OBPOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM135OBPOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM135OBPOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:APINBCO',
    'C<sub>10</sub>H<sub>16</sub>O<sub>2</sub>',
    '',
    '',
    'VZRRCQOUNSHSGB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:APINBCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:APINBCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:APINBCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1011OH',
    'C<sub>10</sub>H<sub>18</sub>O<sub>2</sub>',
    '',
    '',
    'FSFKNSSBELMLGT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1011OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1011OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1011OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C102OOH',
    'C<sub>10</sub>H<sub>20</sub>O<sub>4</sub>',
    '',
    '',
    'QHLMVJFPSLBXKZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C102OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C102OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C102OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C103CO',
    'C<sub>10</sub>H<sub>18</sub>O<sub>3</sub>',
    '',
    '',
    'QIIAZEBRWZSMOM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C103CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C103CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C103CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C103OH',
    'C<sub>10</sub>H<sub>20</sub>O<sub>3</sub>',
    '',
    '',
    'SXEGIXJYQPFAQK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C103OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C103OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C103OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C103OOH',
    'C<sub>10</sub>H<sub>20</sub>O<sub>4</sub>',
    '',
    '',
    'DOFXWCNTKGZWNU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C103OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C103OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C103OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C104OH',
    'C<sub>10</sub>H<sub>18</sub>O<sub>3</sub>',
    '',
    '',
    'FHITZQAABUJLCH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C104OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C104OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C104OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C920CO3H',
    'C<sub>10</sub>H<sub>16</sub>O<sub>5</sub>',
    '',
    '',
    'OFVMBWQGLFFRLM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C920CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C920CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C920CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C9M2CO6OH',
    'C<sub>10</sub>H<sub>16</sub>O<sub>3</sub>',
    '',
    '',
    'SLPXKTFAPIGCFF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C9M2CO6OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C9M2CO6OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C9M2CO6OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DMEOBPROH',
    'C<sub>10</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'ZCTKJUASOMJGQC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMEOBPROH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMEOBPROH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMEOBPROH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO5CO8C10',
    'C<sub>10</sub>H<sub>20</sub>O<sub>2</sub>',
    '',
    '',
    'GDOWVFFRHQHNBZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO5CO8C10'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO5CO8C10'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO5CO8C10'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:LIMBCO',
    'C<sub>10</sub>H<sub>16</sub>O<sub>2</sub>',
    '',
    '',
    'JEQLRDRDFLXSHY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMBCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMBCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMBCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C112OOH',
    'C<sub>11</sub>H<sub>22</sub>O<sub>4</sub>',
    '',
    '',
    'IFXOTQISYXBGBQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C112OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C112OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C112OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C113CO',
    'C<sub>11</sub>H<sub>20</sub>O<sub>3</sub>',
    '',
    '',
    'VJVDGYIYRBYKOQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C113CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C113CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C113CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C113OH',
    'C<sub>11</sub>H<sub>22</sub>O<sub>3</sub>',
    '',
    '',
    'IBMABDXBRFZEGO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C113OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C113OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C113OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C113OOH',
    'C<sub>11</sub>H<sub>22</sub>O<sub>4</sub>',
    '',
    '',
    'PBWNXGFXFCLKSE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C113OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C113OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C113OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C114OH',
    'C<sub>11</sub>H<sub>20</sub>O<sub>3</sub>',
    '',
    '',
    'UGVQLPIEIICAJP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C114OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C114OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C114OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DETLOBPROH',
    'C<sub>11</sub>H<sub>16</sub>O<sub>4</sub>',
    '',
    '',
    'QNKVJNYVFVQVHN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DETLOBPROH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DETLOBPROH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DETLOBPROH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO6CO9C11',
    'C<sub>11</sub>H<sub>22</sub>O<sub>2</sub>',
    '',
    '',
    'HEIFQPPUFKWMSE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO6CO9C11'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO6CO9C11'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO6CO9C11'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C122OOH',
    'C<sub>12</sub>H<sub>24</sub>O<sub>4</sub>',
    '',
    '',
    'PWTYXUGOJRDLPW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C122OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C122OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C122OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C123CO',
    'C<sub>12</sub>H<sub>22</sub>O<sub>3</sub>',
    '',
    '',
    'IVLDSNPYDYHHKW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C123CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C123CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C123CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C123OH',
    'C<sub>12</sub>H<sub>24</sub>O<sub>3</sub>',
    '',
    '',
    'FTSJAGYKUWYWCN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C123OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C123OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C123OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C123OOH',
    'C<sub>12</sub>H<sub>24</sub>O<sub>4</sub>',
    '',
    '',
    'YANZHJXFRFYAEY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C123OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C123OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C123OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C124OH',
    'C<sub>12</sub>H<sub>22</sub>O<sub>3</sub>',
    '',
    '',
    'ABVYFIKKAQHKSN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C124OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C124OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C124OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO7CO10C12',
    'C<sub>12</sub>H<sub>24</sub>O<sub>2</sub>',
    '',
    '',
    'AJDNADCNQXGLCC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO7CO10C12'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO7CO10C12'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO7CO10C12'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C131OH',
    'C<sub>13</sub>H<sub>22</sub>O<sub>3</sub>',
    '',
    '',
    'AONUZHGLRYBQFR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C131OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C131OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C131OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C132OH',
    'C<sub>13</sub>H<sub>22</sub>O<sub>4</sub>',
    '',
    '',
    'FIXMRMMYQTVSPU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C132OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C132OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C132OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C132OOH',
    'C<sub>13</sub>H<sub>22</sub>O<sub>5</sub>',
    '',
    '',
    'VUANIPKMYHABIK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C132OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C132OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C132OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C133CO',
    'C<sub>13</sub>H<sub>20</sub>O<sub>5</sub>',
    '',
    '',
    'NSPNCPQPMIIWRH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C133CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C133CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C133CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C133OH',
    'C<sub>13</sub>H<sub>22</sub>O<sub>5</sub>',
    '',
    '',
    'PJPMMZIOBGUFRQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C133OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C133OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C133OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C133OOH',
    'C<sub>13</sub>H<sub>22</sub>O<sub>6</sub>',
    '',
    '',
    'TWNMHUJEMNHLMV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C133OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C133OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C133OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C134CO',
    'C<sub>13</sub>H<sub>18</sub>O<sub>6</sub>',
    '',
    '',
    'XVPKZNMZKWIEGC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>12</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C134CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C134CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C134CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C134OH',
    'C<sub>13</sub>H<sub>20</sub>O<sub>6</sub>',
    '',
    '',
    'CKMYGJKMMJWXII-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>12</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C134OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>13</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C134OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C134OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C134OOH',
    'C<sub>13</sub>H<sub>20</sub>O<sub>7</sub>',
    '',
    '',
    'RYVAPXIZXOQMSU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>14</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C134OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>12</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C134OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C134OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C135OOH',
    'C<sub>13</sub>H<sub>18</sub>O<sub>8</sub>',
    '',
    '',
    'VAECXYXKQRKKGE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>17</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C135OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>13</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C135OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C135OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BCKAOH',
    'C<sub>14</sub>H<sub>24</sub>O<sub>3</sub>',
    '',
    '',
    'ARSAOHGCYSGONM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCKAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCKAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCKAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BCKAOOH',
    'C<sub>14</sub>H<sub>24</sub>O<sub>4</sub>',
    '',
    '',
    'OXLVMLPVWDEZIL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCKAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCKAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCKAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BCKBCO',
    'C<sub>14</sub>H<sub>22</sub>O<sub>3</sub>',
    '',
    '',
    'IWYBCVOMQFEOMA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCKBCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCKBCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCKBCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BCKBOOH',
    'C<sub>14</sub>H<sub>24</sub>O<sub>4</sub>',
    '',
    '',
    'SISQWITWYDFXLW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCKBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCKBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCKBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C141OH',
    'C<sub>14</sub>H<sub>24</sub>O<sub>2</sub>',
    '',
    '',
    'OMNNANPOKVZFEY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C141OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C141OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C141OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C142OH',
    'C<sub>14</sub>H<sub>24</sub>O<sub>3</sub>',
    '',
    '',
    'TZIWCZUVZZOIAP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C142OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C142OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C142OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C142OOH',
    'C<sub>14</sub>H<sub>24</sub>O<sub>4</sub>',
    '',
    '',
    'OJVOLXXWTGQGEJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C142OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C142OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C142OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C143CO',
    'C<sub>14</sub>H<sub>22</sub>O<sub>4</sub>',
    '',
    '',
    'IPHIBGAHOYIGTO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C143CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C143CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C143CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C143OH',
    'C<sub>14</sub>H<sub>24</sub>O<sub>4</sub>',
    '',
    '',
    'PUMKKTACSBJGTI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C143OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C143OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C143OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C143OOH',
    'C<sub>14</sub>H<sub>24</sub>O<sub>5</sub>',
    '',
    '',
    'FMXAUTXFPHKMFA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C143OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C143OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C143OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C145OH',
    'C<sub>14</sub>H<sub>24</sub>O<sub>6</sub>',
    '',
    '',
    'CADDZNHIARUDOF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>12</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C145OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>13</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C145OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C145OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C145OOH',
    'C<sub>14</sub>H<sub>24</sub>O<sub>7</sub>',
    '',
    '',
    'CEBXMSFHIDLJKH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>15</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C145OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>13</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C145OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C145OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BCBCO',
    'C<sub>15</sub>H<sub>24</sub>O<sub>2</sub>',
    '',
    '',
    'VLNGGDKMXDHPMK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCBCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCBCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCBCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PHCOMEOH',
    'C<sub>8</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '',
    'ZWVHTXAYIKBMEE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PHCOMEOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PHCOMEOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PHCOMEOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MPHCOMEOH',
    'C<sub>9</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'CEJINNSYZFLSCS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MPHCOMEOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MPHCOMEOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MPHCOMEOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PHCOETOH',
    'C<sub>9</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'WLVPRARCUSRDNI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PHCOETOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PHCOETOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PHCOETOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DMPHCOMOH',
    'C<sub>10</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'DBYMZNOFJHQFFD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMPHCOMOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMPHCOMOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMPHCOMOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EMPHCOMOH',
    'C<sub>11</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '',
    'MHJXTDDYZBYNEF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EMPHCOMOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EMPHCOMOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EMPHCOMOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ALCOCH2OOH',
    'C<sub>3</sub>H<sub>4</sub>O<sub>4</sub>',
    '',
    '',
    'RQBGWFCHIWSUOK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ALCOCH2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ALCOCH2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ALCOCH2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C33CO',
    'C<sub>3</sub>H<sub>2</sub>O<sub>3</sub>',
    '',
    '',
    'ICQNCHSXWNQIHC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C33CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C33CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C33CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C312COCO3H',
    'C<sub>4</sub>H<sub>4</sub>O<sub>5</sub>',
    '',
    '',
    'GUGBJTDAGNLAJO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C312COCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C312COCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C312COCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C413COOOH',
    'C<sub>4</sub>H<sub>6</sub>O<sub>4</sub>',
    '',
    '',
    'XUKQQLOKOLCMAI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C413COOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C413COOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C413COOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4CO2OOH',
    'C<sub>4</sub>H<sub>6</sub>O<sub>4</sub>',
    '',
    '',
    'NOBUEMWCPQFCCN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4CO2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4CO2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4CO2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4CODIAL',
    'C<sub>4</sub>H<sub>4</sub>O<sub>3</sub>',
    '',
    '',
    'OWIMZZMOFXSCLT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4CODIAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4CODIAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4CODIAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO23C3CHO',
    'C<sub>4</sub>H<sub>4</sub>O<sub>3</sub>',
    '',
    '',
    'LVZOZHOAAHWEOQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO23C3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO23C3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO23C3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO2C3CHO',
    'C<sub>4</sub>H<sub>6</sub>O<sub>2</sub>',
    '',
    '',
    'PKQIDSVLSKFZQC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2C3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2C3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2C3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO2C4DIAL',
    'C<sub>4</sub>H<sub>2</sub>O<sub>4</sub>',
    '',
    '',
    'OURVMEXCDVXLPR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2C4DIAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2C4DIAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2C4DIAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EGLYOX',
    'C<sub>4</sub>H<sub>6</sub>O<sub>2</sub>',
    '',
    '',
    'RWHQMRRVZJSKGX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EGLYOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EGLYOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EGLYOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:VGLYOX',
    'C<sub>4</sub>H<sub>4</sub>O<sub>2</sub>',
    '',
    '',
    'SDQVYUNYDAWYIK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:VGLYOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:VGLYOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:VGLYOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4CO2DCO3H',
    'C<sub>5</sub>H<sub>4</sub>O<sub>5</sub>',
    '',
    '',
    'AXIVSVGHKYPZBE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4CO2DCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4CO2DCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4CO2DCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4MCO2OOH',
    'C<sub>5</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'RKGLOUQDKXPRQL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4MCO2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4MCO2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4MCO2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C511OOH',
    'C<sub>5</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'NBNOBTZXOPWFTP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C511OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C511OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C511OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5124COOOH',
    'C<sub>5</sub>H<sub>6</sub>O<sub>5</sub>',
    '',
    '',
    'BXDCDQOWFJMSCY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5124COOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5124COOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5124COOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C512OOH',
    'C<sub>5</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'UGOJGQBYBBLKDX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C512OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C512OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C512OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C515CO',
    'C<sub>5</sub>H<sub>4</sub>O<sub>4</sub>',
    '',
    '',
    'OONLUXUUWPUJOU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C515CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C515CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C515CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C515OOH',
    'C<sub>5</sub>H<sub>6</sub>O<sub>5</sub>',
    '',
    '',
    'KCJJHAINVUWKSI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C515OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C515OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C515OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C54CO',
    'C<sub>5</sub>H<sub>4</sub>O<sub>4</sub>',
    '',
    '',
    'KDLDWLXQVYMIBX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C54CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C54CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C54CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5CO23CHO',
    'C<sub>5</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '',
    'IPHREVVCPNNUEQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5CO23CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5CO23CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5CO23CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5COCHOOOH',
    'C<sub>5</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'QJMOTDLHJFXUFN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5COCHOOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5COCHOOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5COCHOOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5DIALCO',
    'C<sub>5</sub>H<sub>4</sub>O<sub>3</sub>',
    '',
    '',
    'SFSCHQJUYKUKJM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5DIALCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5DIALCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5DIALCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5DICARB',
    'C<sub>5</sub>H<sub>6</sub>O<sub>2</sub>',
    '',
    '',
    'GBLMMVFQENXAFZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5DICARB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5DICARB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5DICARB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CHOC3COOOH',
    'C<sub>5</sub>H<sub>6</sub>O<sub>5</sub>',
    '',
    '',
    'KFSMXRNQWYDJRM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOC3COOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOC3COOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOC3COOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO12C4CHO',
    'C<sub>5</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '',
    'VUSMENNBCBGZQI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO12C4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO12C4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO12C4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO13C4CHO',
    'C<sub>5</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '',
    'SSMCSEDSANTCBB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO13C4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO13C4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO13C4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO23C4CHO',
    'C<sub>5</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '',
    'QGGCMCHYJIPQCE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO23C4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO23C4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO23C4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO24C4CHO',
    'C<sub>5</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '',
    'XHTYNUBGBUBFOA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO24C4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO24C4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO24C4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO2C43CHO',
    'C<sub>5</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '',
    'KNTLTMLEQPLVDA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2C43CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2C43CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2C43CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO2C4CHO',
    'C<sub>5</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '',
    'KEHNRUNQZGRQHU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>2</sup>',
    '8400',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2C4CHO'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2C4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2C4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2C4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO3C4CHO',
    'C<sub>5</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '',
    'ZNNXJRURXWWGLN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO3C4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO3C4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO3C4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPRGLYOX',
    'C<sub>5</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '',
    'FTDZDHIBENIBKZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRGLYOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRGLYOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRGLYOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PGLYOX',
    'C<sub>5</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '',
    'GDTHVMAIBQVUMV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PGLYOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PGLYOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PGLYOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C23C54CHO',
    'C<sub>6</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'CBIOWOAHGWGTSI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23C54CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23C54CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23C54CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C3COCCHO',
    'C<sub>6</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'PVLKSJIUOKAUMV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3COCCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3COCCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3COCCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C45IC5CHO',
    'C<sub>6</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'WETHXHAOPNKQLZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C45IC5CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C45IC5CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C45IC5CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4ECO2OOH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'CMRDMVGIWXQQFX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4ECO2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4ECO2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4ECO2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C511CHO',
    'C<sub>6</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'SLKPDJWOVVFRFW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C511CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C511CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C511CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C511CO3H',
    'C<sub>6</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'PKVJBWZRBQBAMT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C511CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C511CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C511CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C512CO3H',
    'C<sub>6</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'OPLKNVAQLNTMAR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C512CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C512CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C512CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C515CHO',
    'C<sub>6</sub>H<sub>6</sub>O<sub>4</sub>',
    '',
    '',
    'JHVNJBQABGTRPH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C515CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C515CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C515CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C515CO3H',
    'C<sub>6</sub>H<sub>6</sub>O<sub>6</sub>',
    '',
    '',
    'XPLLKUAMAYNXAT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C515CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C515CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C515CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5CO2DCO3H',
    'C<sub>6</sub>H<sub>6</sub>O<sub>5</sub>',
    '',
    '',
    'DHHXAZIZMIZDQV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5CO2DCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5CO2DCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5CO2DCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5DCO2CO3H',
    'C<sub>6</sub>H<sub>6</sub>O<sub>5</sub>',
    '',
    '',
    'GJOWGOOSLUXRQO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5DCO2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5DCO2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5DCO2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5MDICARB',
    'C<sub>6</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '',
    'PFLPZDBOPDYOJU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5MDICARB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5MDICARB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5MDICARB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5TRONCO3H',
    'C<sub>6</sub>H<sub>6</sub>O<sub>6</sub>',
    '',
    '',
    'GGHLQXKHXYQGCE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5TRONCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5TRONCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5TRONCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6125CO',
    'C<sub>6</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '',
    'RFTMILUWMDIPHH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6125CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6125CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6125CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6135COOOH',
    'C<sub>6</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'HGYTXVUJMUREIP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6135COOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6135COOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6135COOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6145COOOH',
    'C<sub>6</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'DSJLQKNTJKMXRQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6145COOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6145COOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6145COOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C615CO2OOH',
    'C<sub>6</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'MOFLPBJDWVVKPL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C615CO2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C615CO2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C615CO2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C615CO',
    'C<sub>6</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'BRRWJVYIMRBLKB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C615CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C615CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C615CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C616OOH',
    'C<sub>6</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'RZNSBZRPHHAABM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C616OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C616OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C616OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C617OOH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'VPKXUGZDYIOAPR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C617OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C617OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C617OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C618OOH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'AMQFKFSLRYYJMS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C618OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C618OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C618OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C620OOH',
    'C<sub>6</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'UWWRYJPKFSIPFS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C620OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C620OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C620OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C626OOH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'DHTMLHKAZOWLFT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C626OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C626OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C626OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C65OOH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'LHKMAYQHAYSMQO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C65OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C65OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C65OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6CO134',
    'C<sub>6</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'VIOZHXSHLWOADQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO134'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO134'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO134'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6CO4DB',
    'C<sub>6</sub>H<sub>4</sub>O<sub>4</sub>',
    '',
    '',
    'OGFBTMOHTIWBJU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO4DB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO4DB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO4DB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6COALCO3H',
    'C<sub>6</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'WRLXIVUJPLXKIG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6COALCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6COALCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6COALCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6COCHOOOH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'DQAWORJSQGOPLV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6COCHOOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6COCHOOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6COCHOOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6CODIAL',
    'C<sub>6</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'PAXFMQWEAJBIJB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CODIAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CODIAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CODIAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6DICARB',
    'C<sub>6</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '',
    'GVKYFODEMNCLGS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6DICARB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6DICARB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6DICARB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO123C5CHO',
    'C<sub>6</sub>H<sub>6</sub>O<sub>4</sub>',
    '',
    '',
    'GLSSGXNNMIEKBR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO123C5CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO123C5CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO123C5CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO235C5CHO',
    'C<sub>6</sub>H<sub>6</sub>O<sub>4</sub>',
    '',
    '',
    'GPIFCHFPYCMSRY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO235C5CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO235C5CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO235C5CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO24M3CHO',
    'C<sub>6</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'OQYGUGGUHGKPLC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO24M3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO24M3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO24M3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO2C4GLYOX',
    'C<sub>6</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'YEJDUVJLIVLCFZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2C4GLYOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2C4GLYOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2C4GLYOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO2C54CHO',
    'C<sub>6</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'IDAHIBMEKOEBRG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2C54CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2C54CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2C54CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO2M33CHO',
    'C<sub>6</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'HOOWKSPRVCRTJK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2M33CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2M33CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2M33CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO2M3C4CHO',
    'C<sub>6</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'GQHWESFTVGVFIA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2M3C4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2M3C4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2M3C4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO35C5CHO',
    'C<sub>6</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'KXLMWINKDVAJKB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO35C5CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO35C5CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO35C5CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO3C54CHO',
    'C<sub>6</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'HFHZCESKBNQESK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO3C54CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO3C54CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO3C54CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO3C5CHO',
    'C<sub>6</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'KKOFYQBBUSZDKJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO3C5CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO3C5CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO3C5CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO45C5CHO',
    'C<sub>6</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'WXTRRXXKCNKUIA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO45C5CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO45C5CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO45C5CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ECO4',
    'C<sub>6</sub>H<sub>6</sub>O<sub>4</sub>',
    '',
    '',
    'RGMUISDTMIPFQK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ECO4'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ECO4'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ECO4'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MC5DICARB',
    'C<sub>6</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '',
    'PEBMIJGMJUFNQE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MC5DICARB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MC5DICARB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MC5DICARB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4DBM2CO3H',
    'C<sub>7</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'OAFSDIWBIPMWQP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4DBM2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4DBM2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4DBM2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C617CHO',
    'C<sub>7</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'NFXFJRVNKKYMOX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C617CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C617CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C617CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C617CO3H',
    'C<sub>7</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'GEJLCFNTSCJUHB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C617CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C617CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C617CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C618CO3H',
    'C<sub>7</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'BCVYZYXNMFZMHQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C618CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C618CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C618CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C626CHO',
    'C<sub>7</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'HBIBDTOPQGUCOQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C626CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C626CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C626CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C626CO3H',
    'C<sub>7</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'XXGYBOYKTQFTKB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C626CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C626CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C626CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6M5CO2OOH',
    'C<sub>7</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'BPEPZMFTCHTDHQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6M5CO2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6M5CO2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6M5CO2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C715CO2OOH',
    'C<sub>7</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'MXRQCKDWMJYUGS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C715CO2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C715CO2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C715CO2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C716OOH',
    'C<sub>7</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'PDOSKCUHLZEIAA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C716OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C716OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C716OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C717OOH',
    'C<sub>7</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'PIJZITIWWOWVNF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C717OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C717OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C717OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C718OOH',
    'C<sub>7</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'IUOFUPZPJIEECL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C718OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C718OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C718OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C731OOH',
    'C<sub>7</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'GGMJSZWHPXYNJN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C731OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C731OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C731OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C735OOH',
    'C<sub>7</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'FKXMDVIITUJJPH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C735OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C735OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C735OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C736CO',
    'C<sub>7</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'XIQVOMVDKSOEBZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C736CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C736CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C736CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C736OOH',
    'C<sub>7</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'FLZNSMFAMOSJOT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C736OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C736OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C736OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7ADICARB',
    'C<sub>7</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'JOIPXRIQHWMPFU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7ADICARB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7ADICARB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7ADICARB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7CO2DBAL',
    'C<sub>7</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'YGMUVGSOGISXBZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7CO2DBAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7CO2DBAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7CO2DBAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7CO2DCO3H',
    'C<sub>7</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'GSEZJGCNNFTSDI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7CO2DCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7CO2DCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7CO2DCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7CO4DB',
    'C<sub>7</sub>H<sub>6</sub>O<sub>4</sub>',
    '',
    '',
    'RYPSCZRULGRFHH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7CO4DB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7CO4DB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7CO4DB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7DDICARB',
    'C<sub>7</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'SRVPSCZJUZZLCY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7DDICARB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7DDICARB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7DDICARB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7DICARB',
    'C<sub>7</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'GLRVVKVYRCSDLF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7DICARB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7DICARB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7DICARB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO235C6CHO',
    'C<sub>7</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'DKBJFPXQZAZJBK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO235C6CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO235C6CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO235C6CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO25C6CHO',
    'C<sub>7</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'ZTMYUKBUAYLBJN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO25C6CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO25C6CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO25C6CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IC7DICARB',
    'C<sub>7</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'XQQMMKHYZYQABV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IC7DICARB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IC7DICARB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IC7DICARB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MC6CO2OOH',
    'C<sub>7</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'HBFXSTFRJMUUSF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MC6CO2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MC6CO2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MC6CO2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4DBMECO3H',
    'C<sub>8</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'MRKOFGXLZVJMLJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4DBMECO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4DBMECO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4DBMECO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6CO4M2DB',
    'C<sub>8</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'XSTUBABFSAZOJC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO4M2DB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO4M2DB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO4M2DB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6ETCO4DB',
    'C<sub>8</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'OAQBTICOMUFUNE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6ETCO4DB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6ETCO4DB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6ETCO4DB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C718CO3H',
    'C<sub>8</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'TVOCFMMHLDKVAZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C718CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C718CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C718CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C731CO3H',
    'C<sub>8</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'NTZMYPVPFVPPPF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C731CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C731CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C731CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7M6CO2OOH',
    'C<sub>8</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'SYXNCLOQMRSNCQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7M6CO2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7M6CO2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7M6CO2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7MCO2DBAL',
    'C<sub>8</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'PDQBXAJOXSGWHJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7MCO2DBAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7MCO2DBAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7MCO2DBAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7MCO2OOH',
    'C<sub>8</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'IVJZKSXAPVTQOQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7MCO2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7MCO2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7MCO2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C815CO2OOH',
    'C<sub>8</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'BDUHFTDKOJODDX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C815CO2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C815CO2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C815CO2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C817CO',
    'C<sub>8</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'WSCYQCAMZDXSLH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>5</sup>',
    '12000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C817CO'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C817CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C817CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C817CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C830CO',
    'C<sub>8</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'MHDCXCKIQVLVLU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C830CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C830CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C830CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C831CO',
    'C<sub>8</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'ZUSGUVUFJOBUST-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C831CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C831CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C831CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C86OOH',
    'C<sub>8</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'DHFNMJQLYJIWHS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C86OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C86OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C86OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C87CO',
    'C<sub>8</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'ZGSYEZWRFTZRGE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C87CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C87CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C87CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C87OOH',
    'C<sub>8</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'ZOZQVMIZJFBYCH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C87OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C87OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C87OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C8CO2DBAL',
    'C<sub>8</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'WFUAEUZWLUGFPU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8CO2DBAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8CO2DBAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8CO2DBAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C8CO2DCO3H',
    'C<sub>8</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'AFZRTBPBEHNFPV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8CO2DCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8CO2DCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8CO2DCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C8CO4DB',
    'C<sub>8</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'XMBXSFIUGNBAMW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8CO4DB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8CO4DB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8CO4DB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C8DCO2CO3H',
    'C<sub>8</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'LSJULIYFTAQYGE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8DCO2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8DCO2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8DCO2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO4DBC8',
    'C<sub>8</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'UUVQUVHMBIAKFN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO4DBC8'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO4DBC8'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO4DBC8'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MC7CO2OOH',
    'C<sub>8</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'XEFYLFAPQOHXQI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MC7CO2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MC7CO2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MC7CO2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6CO4MEDB',
    'C<sub>9</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'KWNUZJFJQSMOTR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO4MEDB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO4MEDB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO4MEDB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6IPRCO4DB',
    'C<sub>9</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'PHOIWTKCTUWXFI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6IPRCO4DB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6IPRCO4DB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6IPRCO4DB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6PRCO4DB',
    'C<sub>9</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'ZAOQHXFQWRKJIE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PRCO4DB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PRCO4DB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PRCO4DB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7CO4EDB',
    'C<sub>9</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'ZLFZFHOVUMHREF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7CO4EDB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7CO4EDB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7CO4EDB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7ECO4DB',
    'C<sub>9</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'AWHQTSPUFRSDOO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7ECO4DB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7ECO4DB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7ECO4DB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C827CHO',
    'C<sub>9</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'WRGXNTJIWBXAOX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C827CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C827CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C827CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C828CHO',
    'C<sub>9</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'YZUHPZZEPOWVFM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C828CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C828CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C828CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C87CO3H',
    'C<sub>9</sub>H<sub>12</sub>O<sub>6</sub>',
    '',
    '',
    'AJHPLULEOIFIGV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C87CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C87CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C87CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C88CHO',
    'C<sub>9</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'NXCXUGLKKPDWEC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C88CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C88CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C88CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C914CO',
    'C<sub>9</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'RDBINALOBQAVHT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C914CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C914CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C914CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C914OOH',
    'C<sub>9</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'ZERYOMDBUHTQAV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C914OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C914OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C914OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C915OOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'IHUGTHJLMVJZBZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C915OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C915OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C915OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C916OOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>5</sub>',
    '',
    '',
    'FURCCROLNKVFJP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C916OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C916OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C916OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C918OOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'RVRGXPTVZZTPQO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C918OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C918OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C918OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C919OOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>5</sub>',
    '',
    '',
    'HGDKSMVLGYFVMB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C919OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C919OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C919OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C926OOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>5</sub>',
    '',
    '',
    'YGLJXDYJGXWZRQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C926OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C926OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C926OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C930OOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>5</sub>',
    '',
    '',
    'UQPOFUKCKANZIY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C930OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C930OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C930OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO4DBC9',
    'C<sub>9</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'KCIAXTRCVKQJBW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO4DBC9'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO4DBC9'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO4DBC9'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:LMLKACO',
    'C<sub>9</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'JZUAMOXWRDMCCH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LMLKACO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LMLKACO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LMLKACO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:LMLKAOOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>5</sub>',
    '',
    '',
    'VTXNRXDJNZTEJV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LMLKAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LMLKAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LMLKAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:LMLKBCO',
    'C<sub>9</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'UMGHNOQMPCKCSD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LMLKBCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LMLKBCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LMLKBCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:LMLKBOOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>5</sub>',
    '',
    '',
    'YVDVZIZUYUAKKJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LMLKBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LMLKBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LMLKBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:LMLKET',
    'C<sub>9</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'CWEQHJLFCKMWEE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '13000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LMLKET'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LMLKET'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LMLKET'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LMLKET'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NORLIMAL',
    'C<sub>9</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '',
    'WPNOYHDEEVPEJH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>2</sup>',
    '11000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NORLIMAL'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NORLIMAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NORLIMAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NORLIMAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NORPINAL',
    'C<sub>9</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '',
    'CRBGTXDFEDFKSU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NORPINAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NORPINAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NORPINAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1010OOH',
    'C<sub>10</sub>H<sub>16</sub>O<sub>4</sub>',
    '',
    '',
    'PQCOZMUQYGSZBV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1010OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1010OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1010OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1012CO',
    'C<sub>10</sub>H<sub>16</sub>O<sub>3</sub>',
    '',
    '',
    'ZTXNVHZVZBDWRG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1012CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1012CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1012CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1012OOH',
    'C<sub>10</sub>H<sub>18</sub>O<sub>4</sub>',
    '',
    '',
    'NQAGNHJKHGEOIP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1012OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1012OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1012OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C106OOH',
    'C<sub>10</sub>H<sub>16</sub>O<sub>5</sub>',
    '',
    '',
    'QENSMPURVPBEBQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C106OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C106OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C106OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C107OOH',
    'C<sub>10</sub>H<sub>16</sub>O<sub>4</sub>',
    '',
    '',
    'JYIMELQJWXRSLA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C107OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C107OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C107OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C108OOH',
    'C<sub>10</sub>H<sub>16</sub>O<sub>5</sub>',
    '',
    '',
    'AIXQDYAMZUITKH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C108OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C108OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C108OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C109CO',
    'C<sub>10</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'GPWOGFGLGKGEOT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C109CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C109CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C109CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C109OOH',
    'C<sub>10</sub>H<sub>16</sub>O<sub>4</sub>',
    '',
    '',
    'ODTCGEGBAGAWAJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C109OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C109OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C109OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:LIMALACO',
    'C<sub>10</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'OXUPJDFJWCMZMO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>4</sup>',
    '13000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMALACO'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMALACO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMALACO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMALACO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:LIMALAOOH',
    'C<sub>10</sub>H<sub>16</sub>O<sub>4</sub>',
    '',
    '',
    'DVORBFWFCUOYLW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>5</sup>',
    '15000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMALAOOH'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMALAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMALAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMALAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:LIMALBCO',
    'C<sub>10</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'OFCYPGCYWHDSNB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMALBCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMALBCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMALBCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:LIMALBOOH',
    'C<sub>10</sub>H<sub>16</sub>O<sub>4</sub>',
    '',
    '',
    'DCWLKDSHBWMMQU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>5</sup>',
    '15000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMALBOOH'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMALBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMALBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMALBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:LIMAL',
    'C<sub>10</sub>H<sub>16</sub>O<sub>2</sub>',
    '',
    '',
    'OGCGCISRMFSLTC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>2</sup>',
    '11000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMAL'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PINAL',
    'C<sub>10</sub>H<sub>16</sub>O<sub>2</sub>',
    '',
    '',
    'GCHDWVBHKDJOKU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PINAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PINAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PINAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PINALOOH',
    'C<sub>10</sub>H<sub>16</sub>O<sub>4</sub>',
    '',
    '',
    'IKYOAMQPSDRUHL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PINALOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PINALOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PINALOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C116CO',
    'C<sub>11</sub>H<sub>16</sub>O<sub>3</sub>',
    '',
    '',
    'XGVKCXDPIYHMTH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C116CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C116CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C116CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C116OOH',
    'C<sub>11</sub>H<sub>18</sub>O<sub>4</sub>',
    '',
    '',
    'GLQKGYMROFUHSE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C116OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C116OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C116OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C116CHO',
    'C<sub>12</sub>H<sub>18</sub>O<sub>3</sub>',
    '',
    '',
    'LCDZSXGLJAAQMI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C116CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C116CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C116CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C116CO3H',
    'C<sub>12</sub>H<sub>18</sub>O<sub>5</sub>',
    '',
    '',
    'DYOBAPPYFCSOAS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C116CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C116CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C116CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1210OOH',
    'C<sub>12</sub>H<sub>20</sub>O<sub>4</sub>',
    '',
    '',
    'KZRFFJDVJJJBDC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1210OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1210OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1210OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C129CO',
    'C<sub>12</sub>H<sub>16</sub>O<sub>4</sub>',
    '',
    '',
    'RGVZWLUABXGGBI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C129CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C129CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C129CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C129OOH',
    'C<sub>12</sub>H<sub>18</sub>O<sub>5</sub>',
    '',
    '',
    'OVAMHHASBHCMIZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C129OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C129OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C129OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1210CO3H',
    'C<sub>13</sub>H<sub>20</sub>O<sub>5</sub>',
    '',
    '',
    'BXGKTBFSJURUHS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1210CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1210CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1210CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C131CO',
    'C<sub>13</sub>H<sub>20</sub>O<sub>3</sub>',
    '',
    '',
    'FDPPFMUIMWYEIX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C131CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C131CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C131CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BCLKACO',
    'C<sub>14</sub>H<sub>20</sub>O<sub>4</sub>',
    '',
    '',
    'ARRZIWJBJSIOKE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCLKACO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCLKACO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCLKACO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BCLKAOOH',
    'C<sub>14</sub>H<sub>22</sub>O<sub>5</sub>',
    '',
    '',
    'CKBNEDHFWOQWQD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCLKAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCLKAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCLKAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BCLKBCO',
    'C<sub>14</sub>H<sub>20</sub>O<sub>4</sub>',
    '',
    '',
    'NZHCLRCYZNBCMK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCLKBCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCLKBCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCLKBCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BCLKBOOH',
    'C<sub>14</sub>H<sub>22</sub>O<sub>5</sub>',
    '',
    '',
    'CNYMBWKCKYTSRZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCLKBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCLKBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCLKBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BCLKCCO',
    'C<sub>14</sub>H<sub>20</sub>O<sub>4</sub>',
    '',
    '',
    'RVZWWCAHYGTHHX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCLKCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCLKCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCLKCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BCLKCOOH',
    'C<sub>14</sub>H<sub>22</sub>O<sub>5</sub>',
    '',
    '',
    'OVPKMRRDRUAGIL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCLKCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCLKCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCLKCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BCLKET',
    'C<sub>14</sub>H<sub>22</sub>O<sub>3</sub>',
    '',
    '',
    'UGDRYISIDBCIAI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCLKET'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCLKET'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCLKET'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C141CO',
    'C<sub>14</sub>H<sub>22</sub>O<sub>2</sub>',
    '',
    '',
    'LUPUYUXNGLIEMW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C141CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C141CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C141CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C146CO',
    'C<sub>14</sub>H<sub>20</sub>O<sub>4</sub>',
    '',
    '',
    'ODTZTSYYOIXMEF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C146CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C146CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C146CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C146OOH',
    'C<sub>14</sub>H<sub>22</sub>O<sub>5</sub>',
    '',
    '',
    'SPXXDEIFDYFSMG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C146OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C146OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C146OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BCALACO',
    'C<sub>15</sub>H<sub>22</sub>O<sub>3</sub>',
    '',
    '',
    'ULXUQSOGQJAAAV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCALACO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCALACO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCALACO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BCALAOOH',
    'C<sub>15</sub>H<sub>24</sub>O<sub>4</sub>',
    '',
    '',
    'CATQWYAHYHBBFL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCALAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCALAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCALAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BCALBCO',
    'C<sub>15</sub>H<sub>22</sub>O<sub>3</sub>',
    '',
    '',
    'DVBAGSYXLVWTHM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCALBCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCALBCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCALBCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BCALBOOH',
    'C<sub>15</sub>H<sub>24</sub>O<sub>4</sub>',
    '',
    '',
    'BXDTVEFUTYSWEH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCALBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCALBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCALBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BCAL',
    'C<sub>15</sub>H<sub>24</sub>O<sub>2</sub>',
    '',
    '',
    'PJJCDGMFEIUQRZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BCALCCO',
    'C<sub>15</sub>H<sub>22</sub>O<sub>3</sub>',
    '',
    '',
    'RMGPJKLPPRXORI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCALCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCALCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCALCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BCALCOOH',
    'C<sub>15</sub>H<sub>24</sub>O<sub>4</sub>',
    '',
    '',
    'WQOUANLPJNTVBV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCALCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCALCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCALCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PHGLYOX',
    'C<sub>8</sub>H<sub>6</sub>O<sub>2</sub>',
    '',
    '',
    'OJUGVDODNPJEEC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PHGLYOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PHGLYOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PHGLYOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MPHGLYOX',
    'C<sub>9</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '',
    'ILRFLXHICGHRIN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MPHGLYOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MPHGLYOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MPHGLYOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DMPHGLYOX',
    'C<sub>10</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'COKLAMNWIKZGIN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMPHGLYOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMPHGLYOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMPHGLYOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EMPHGLYOX',
    'C<sub>11</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'LRURTQBJFCJOFP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EMPHGLYOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EMPHGLYOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EMPHGLYOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HOCH2COCHO',
    'C<sub>3</sub>H<sub>4</sub>O<sub>3</sub>',
    '',
    '',
    'JLPAWRLRMTZCSF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOCH2COCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOCH2COCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOCH2COCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CCOCOCOH',
    'C<sub>4</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '',
    'AWMGPEHDHJUMEN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CCOCOCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CCOCOCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CCOCOCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO13C4OH',
    'C<sub>4</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '',
    'KATSYVMPKZTIRW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO13C4OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO13C4OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO13C4OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO2H3CHO',
    'C<sub>4</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '',
    'GTYVZUSWKGYETP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2H3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2H3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2H3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H13CO2CHO',
    'C<sub>4</sub>H<sub>6</sub>O<sub>4</sub>',
    '',
    '',
    'RAPYKXPBVBNJGC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H13CO2CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H13CO2CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H13CO2CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H1CO23CHO',
    'C<sub>4</sub>H<sub>4</sub>O<sub>4</sub>',
    '',
    '',
    'XSEYITBSKRUSNL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H1CO23CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H1CO23CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H1CO23CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO1CO3CHO',
    'C<sub>4</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '',
    'CUSSNCHZLYDUPJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO1CO3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO1CO3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO1CO3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HOCOC4DIAL',
    'C<sub>4</sub>H<sub>4</sub>O<sub>4</sub>',
    '',
    '',
    'JWBVDBDNUQOADG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOCOC4DIAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOCOC4DIAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOCOC4DIAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4MCO2OH',
    'C<sub>5</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'YKNUMNAVGAMCFT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4MCO2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4MCO2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4MCO2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C512OH',
    'C<sub>5</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'ZSJOVUGBPPFONP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C512OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C512OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C512OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5134CO2OH',
    'C<sub>5</sub>H<sub>6</sub>O<sub>4</sub>',
    '',
    '',
    'UFXCMYYHMGNRSQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5134CO2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5134CO2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5134CO2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C513CO',
    'C<sub>5</sub>H<sub>6</sub>O<sub>4</sub>',
    '',
    '',
    'GBFAZHBQOBSKET-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C513CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C513CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C513CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C513OH',
    'C<sub>5</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'VLANIYKAIBIISW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C513OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C513OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C513OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C513OOH',
    'C<sub>5</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'FJRVRXOZJCMNIT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C513OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C513OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C513OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C514CO23OH',
    'C<sub>5</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'JLVNMCMGUWUGCO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C514CO23OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C514CO23OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C514CO23OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C520OH',
    'C<sub>5</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'BXHDMMHJHUOSNS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C520OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C520OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C520OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C520OOH',
    'C<sub>5</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'BCWSZSNCYSGOQJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C520OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C520OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C520OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5CO3OH',
    'C<sub>5</sub>H<sub>6</sub>O<sub>4</sub>',
    '',
    '',
    'UUUQEQKLOQQXBA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5CO3OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5CO3OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5CO3OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5DICAROOH',
    'C<sub>5</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'SXCXUVJXNGWYKY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5DICAROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5DICAROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5DICAROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO3H4CHO',
    'C<sub>5</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'GHHQRUFNLVFZPQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO3H4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO3H4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO3H4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H1C23C4CHO',
    'C<sub>5</sub>H<sub>6</sub>O<sub>4</sub>',
    '',
    '',
    'VBLXHDGHHJBCMK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H1C23C4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H1C23C4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H1C23C4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HMVKBCHO',
    'C<sub>5</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'XYGGNMZYIGPNCC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>5</sup>',
    '11000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HMVKBCHO'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HMVKBCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HMVKBCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HMVKBCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO2CO4CHO',
    'C<sub>5</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'NSUJYXKDWVMPFQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2CO4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2CO4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2CO4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HOIPRGLYOX',
    'C<sub>5</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'ROKGRLJNHSUEOC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOIPRGLYOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOIPRGLYOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOIPRGLYOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IEC2OOH',
    'C<sub>5</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'KGZJHQJCDPZOFG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IEC2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IEC2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IEC2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MBOCOCO',
    'C<sub>5</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'OCAJTNNCRSVJNU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MBOCOCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MBOCOCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MBOCOCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C43OHCOCHO',
    'C<sub>6</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'NMZPCKZSNUOBSC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C43OHCOCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C43OHCOCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C43OHCOCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C517CHO',
    'C<sub>6</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'JGHPNZFTVGSLKF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>2</sup>',
    '13000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C517CHO'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C517CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C517CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C517CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C519CHO',
    'C<sub>6</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'PVAHQKAVPKMXGV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>6</sup>',
    '11000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C519CHO'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C519CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C519CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C519CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5COOHCO3H',
    'C<sub>6</sub>H<sub>6</sub>O<sub>6</sub>',
    '',
    '',
    'DETDOHNNOYOALO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5COOHCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5COOHCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5COOHCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5MO132OH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'YVTXQDAOLHXGGS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5MO132OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5MO132OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5MO132OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6134CO2OH',
    'C<sub>6</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'ZUSWTYLGBZLTMD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6134CO2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6134CO2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6134CO2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C614CO23OH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'FTHGMBBEYTXWQT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C614CO23OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C614CO23OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C614CO23OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C615CO2OH',
    'C<sub>6</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'AEWAJJBQFQHEAB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C615CO2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C615CO2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C615CO2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C616OH',
    'C<sub>6</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'VJOSQGBCXQMKDE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C616OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C616OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C616OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C617OH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'GSQCYSIEWGMUPC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C617OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C617OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C617OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C620OH',
    'C<sub>6</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'SMLWDBHBBFROKP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C620OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C620OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C620OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C628OH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'XRZKKMNIWXFNJQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C628OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C628OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C628OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C628OOH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'BGLCDSUTRBZUMD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C628OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C628OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C628OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C629OH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'MIXLBBAGKJLCSO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C629OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C629OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C629OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C629OOH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'PARGUUHBZPMBOS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C629OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C629OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C629OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C630CO',
    'C<sub>6</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'AUMGTZPDEFNUMP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C630CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C630CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C630CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C65OH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'ZWRMEYSYDMGCIE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C65OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C65OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C65OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C67CHO',
    'C<sub>6</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'BZFZPOBVGBFEBG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C67CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C67CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C67CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6CO2M2OH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'ZFPKEBYORKZJID-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO2M2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO2M2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO2M2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6CO2OHOOH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'LMEOLDNWXYVMAA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO2OHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO2OHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO2OHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6CO3MOH',
    'C<sub>6</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'WBLLHOUAAGAGCV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO3MOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO3MOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO3MOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6COHOCHO',
    'C<sub>6</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'HJNIDOQIVMJXHS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6COHOCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6COHOCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6COHOCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6DICAROOH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'HIILQMKIFXFEHC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6DICAROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6DICAROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6DICAROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6O132OH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'GIDOBZXUXDNRDY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6O132OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6O132OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6O132OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6TONOHOOH',
    'C<sub>6</sub>H<sub>8</sub>O<sub>6</sub>',
    '',
    '',
    'CIXJOARRJVNUNZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6TONOHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6TONOHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6TONOHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H2M3CO4CHO',
    'C<sub>6</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'MIIVJRGFVJVTGE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M3CO4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M3CO4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M3CO4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H3C25C5CHO',
    'C<sub>6</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'CLPDOVMSDUESLY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3C25C5CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3C25C5CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3C25C5CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HM22COCHO',
    'C<sub>6</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'UTYMQWKKMYQTHJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM22COCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM22COCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM22COCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MC52CO2OH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'LGFUKTGFFSPNKZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MC52CO2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MC52CO2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MC52CO2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MC5COOHOOH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'XFHCIPDXRRXAPB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MC5COOHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MC5COOHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MC5COOHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MIBKHO4CHO',
    'C<sub>6</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'OYDFBAKICJVUQJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIBKHO4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIBKHO4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIBKHO4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C61CHO',
    'C<sub>7</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'BDFRSVKDVGXKLG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C61CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C61CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C61CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C62CHO',
    'C<sub>7</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'QCTBGQUOJXZEIH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C62CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C62CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C62CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6COOHCO3H',
    'C<sub>7</sub>H<sub>8</sub>O<sub>6</sub>',
    '',
    '',
    'BNWBZUAKPODUMK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6COOHCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6COOHCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6COOHCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6M5CO2OH',
    'C<sub>7</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'YAAUSHWRBSRFSJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6M5CO2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6M5CO2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6M5CO2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C715CO2OH',
    'C<sub>7</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'KBBGTWJMXYAKIO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C715CO2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C715CO2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C715CO2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C716OH',
    'C<sub>7</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'QFGSQPDLKNLDDS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C716OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C716OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C716OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C717OH',
    'C<sub>7</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'SEENFYUXRUQNHQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C717OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C717OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C717OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C718OH',
    'C<sub>7</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'ALYGFZDZOCWXMF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C718OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C718OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C718OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C731OH',
    'C<sub>7</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'KHEBQEUBDOAJRG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C731OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C731OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C731OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C733CO',
    'C<sub>7</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'IRSIMXCKMCQRGW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C733CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C733CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C733CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C733OH',
    'C<sub>7</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'WRHSSXYTISGZIA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C733OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C733OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C733OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C733OOH',
    'C<sub>7</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'OWEUBRYSVXGVIC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C733OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C733OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C733OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C735OH',
    'C<sub>7</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'PHOAHMZZKPNPAM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C735OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C735OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C735OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C736OH',
    'C<sub>7</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'QWXLVLIZAXRZBR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C736OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C736OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C736OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7ADCOH',
    'C<sub>7</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'SVQINHOHTZDOCH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7ADCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7ADCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7ADCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7ADCOOH',
    'C<sub>7</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'COQUITHNSRNVBJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7ADCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7ADCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7ADCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7CO3OHOOH',
    'C<sub>7</sub>H<sub>10</sub>O<sub>6</sub>',
    '',
    '',
    'YAEIVOJGWQGWPS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7CO3OHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7CO3OHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7CO3OHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7DCOH',
    'C<sub>7</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'VIPBNCDHLKDPDM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7DCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7DCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7DCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7DCOOH',
    'C<sub>7</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'AVRZSWZUKXCJRK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7DCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7DCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7DCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7DDCOH',
    'C<sub>7</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'HYCGRSOMYJQICU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7DDCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7DDCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7DDCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7DDCOOH',
    'C<sub>7</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'VSEOFSAKNXJKSZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7DDCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7DDCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7DDCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IC7DCOH',
    'C<sub>7</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'DEDFQTYPJDABTI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IC7DCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IC7DCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IC7DCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IC7DCOOH',
    'C<sub>7</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'ZVFWDEWSMKAAIM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IC7DCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IC7DCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IC7DCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MC6CO2OH',
    'C<sub>7</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'BNJUZVCUVNAPOM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MC6CO2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MC6CO2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MC6CO2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5M2OHCO3H',
    'C<sub>8</sub>H<sub>10</sub>O<sub>6</sub>',
    '',
    '',
    'BRIBGOXGRALVGI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5M2OHCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5M2OHCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5M2OHCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7M15CO2OH',
    'C<sub>8</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'OEJDBFGEAKTZGI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7M15CO2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7M15CO2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7M15CO2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7M6CO2OH',
    'C<sub>8</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'WXVOVBAGQNBDEE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7M6CO2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7M6CO2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7M6CO2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7MO3OHOOH',
    'C<sub>8</sub>H<sub>12</sub>O<sub>6</sub>',
    '',
    '',
    'UOUKTGYLQYQUAO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7MO3OHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7MO3OHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7MO3OHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7OHO2CO3H',
    'C<sub>8</sub>H<sub>10</sub>O<sub>6</sub>',
    '',
    '',
    'AOHPTSIBUCEZIY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7OHO2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7OHO2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7OHO2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C815CO2OH',
    'C<sub>8</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'IPCSMQASRIZASM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C815CO2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C815CO2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C815CO2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C824CO',
    'C<sub>8</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'BQDQKENHFIFOJZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C824CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C824CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C824CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C83COOHOOH',
    'C<sub>8</sub>H<sub>12</sub>O<sub>6</sub>',
    '',
    '',
    'LBBMWNQOJHPRLQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C83COOHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C83COOHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C83COOHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C87OH',
    'C<sub>8</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'DFOLUFIWIMPWQH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C87OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C87OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C87OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MC7CO2OH',
    'C<sub>8</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'BSMWBPAKWVVEKL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MC7CO2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MC7CO2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MC7CO2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5MEJCO3H',
    'C<sub>9</sub>H<sub>12</sub>O<sub>6</sub>',
    '',
    '',
    'IZKMPGKTEBWFPK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5MEJCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5MEJCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5MEJCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C8O2OHCO3H',
    'C<sub>9</sub>H<sub>12</sub>O<sub>6</sub>',
    '',
    '',
    'MBOWYQZNYXRQRC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8O2OHCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8O2OHCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8O2OHCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C8OHO2CO3H',
    'C<sub>9</sub>H<sub>12</sub>O<sub>6</sub>',
    '',
    '',
    'CJLPRBWVJFSMFP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8OHO2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8OHO2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8OHO2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C914OH',
    'C<sub>9</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'LFDXAZOJHXEEGS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C914OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C914OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C914OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C915OH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'FAAQZCMVHKUUSB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C915OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C915OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C915OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C916OH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'MXDMOPCDPNEDIT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C916OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C916OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C916OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C918OH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'NFJZVEFTUBPOLY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C918OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C918OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C918OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C919OH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'ULXJXURNPDAXQL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C919OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C919OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C919OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C926OH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'DBPGQZSZWKEZHT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C926OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C926OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C926OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C930OH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'LNIVXHBNNGOOPM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C930OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C930OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C930OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:LMLKAOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'XDMVMFNHBSPJDJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LMLKAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LMLKAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LMLKAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:LMLKBOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'JSAHIYWZESQWRA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LMLKBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LMLKBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LMLKBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NORLIMOOH',
    'C<sub>9</sub>H<sub>16</sub>O<sub>5</sub>',
    '',
    '',
    'CUMGKBRSRBORIJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NORLIMOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NORLIMOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NORLIMOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1010OH',
    'C<sub>10</sub>H<sub>16</sub>O<sub>3</sub>',
    '',
    '',
    'NQWGZMQLCPYJCB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1010OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1010OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1010OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1012OH',
    'C<sub>10</sub>H<sub>18</sub>O<sub>3</sub>',
    '',
    '',
    'ZSBQFHQMMVQAKS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1012OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1012OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1012OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C106OH',
    'C<sub>10</sub>H<sub>16</sub>O<sub>4</sub>',
    '',
    '',
    'LWIDJJPVYZTGLI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C106OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C106OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C106OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C107OH',
    'C<sub>10</sub>H<sub>16</sub>O<sub>3</sub>',
    '',
    '',
    'DUMRJPIWTJFZCT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C107OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C107OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C107OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C108OH',
    'C<sub>10</sub>H<sub>16</sub>O<sub>4</sub>',
    '',
    '',
    'ZDBVABFEYYIFLR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C108OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C108OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C108OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C109OH',
    'C<sub>10</sub>H<sub>16</sub>O<sub>3</sub>',
    '',
    '',
    'PUENXTSKKXKPMK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C109OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C109OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C109OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:LIMALAOH',
    'C<sub>10</sub>H<sub>16</sub>O<sub>3</sub>',
    '',
    '',
    'VNYSFQVUCPNMDZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>4</sup>',
    '15000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMALAOH'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMALAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMALAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMALAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:LIMALBOH',
    'C<sub>10</sub>H<sub>16</sub>O<sub>3</sub>',
    '',
    '',
    'SMXSHIIAZMJGAE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMALBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMALBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMALBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:LIMALOH',
    'C<sub>10</sub>H<sub>18</sub>O<sub>4</sub>',
    '',
    '',
    'ISUQULRVPDSRIP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>10</sup>',
    '18000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMALOH'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMALOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMALOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMALOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:LIMALOOH',
    'C<sub>10</sub>H<sub>18</sub>O<sub>5</sub>',
    '',
    '',
    'OQLBLHLZVAPRGN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>10</sup>',
    '18000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMALOOH'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMALOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMALOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMALOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PINALOH',
    'C<sub>10</sub>H<sub>16</sub>O<sub>3</sub>',
    '',
    '',
    'NGFXWFWSYUSJMH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PINALOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PINALOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PINALOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C116OH',
    'C<sub>11</sub>H<sub>18</sub>O<sub>3</sub>',
    '',
    '',
    'JMGXHRKVWURTTA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C116OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C116OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C116OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C117OH',
    'C<sub>11</sub>H<sub>18</sub>O<sub>4</sub>',
    '',
    '',
    'XYBUENVNXDXQKB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C117OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C117OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C117OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C117OOH',
    'C<sub>11</sub>H<sub>18</sub>O<sub>5</sub>',
    '',
    '',
    'NUIUIELMTMWFAB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C117OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C117OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C117OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C118CO',
    'C<sub>11</sub>H<sub>16</sub>O<sub>5</sub>',
    '',
    '',
    'QFBAMJSHDLKQRE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C118CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C118CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C118CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C118OH',
    'C<sub>11</sub>H<sub>18</sub>O<sub>5</sub>',
    '',
    '',
    'GQNPBTACCNTXDZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C118OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C118OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C118OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C118OOH',
    'C<sub>11</sub>H<sub>18</sub>O<sub>6</sub>',
    '',
    '',
    'DZELKNYJHUANPY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>12</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C118OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C118OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C118OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1210OH',
    'C<sub>12</sub>H<sub>20</sub>O<sub>3</sub>',
    '',
    '',
    'RDCPBXUNBHOYIW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1210OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1210OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1210OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1214OH',
    'C<sub>12</sub>H<sub>20</sub>O<sub>4</sub>',
    '',
    '',
    'LBONAAUBRWCFLP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1214OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1214OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1214OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1214OOH',
    'C<sub>12</sub>H<sub>20</sub>O<sub>5</sub>',
    '',
    '',
    'RDWLNWMMPUJYPV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1214OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1214OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1214OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1215CO',
    'C<sub>12</sub>H<sub>18</sub>O<sub>5</sub>',
    '',
    '',
    'MFAMPSJMWGSBSP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1215CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1215CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1215CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1215OH',
    'C<sub>12</sub>H<sub>20</sub>O<sub>5</sub>',
    '',
    '',
    'ICTVPTJMPURCGE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1215OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1215OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1215OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1215OOH',
    'C<sub>12</sub>H<sub>20</sub>O<sub>6</sub>',
    '',
    '',
    'PWIVJRAMQXZVCR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>12</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1215OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1215OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1215OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C128CO',
    'C<sub>12</sub>H<sub>18</sub>O<sub>4</sub>',
    '',
    '',
    'UGSIBTFJEGNWKQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C128CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C128CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C128CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C128OH',
    'C<sub>12</sub>H<sub>20</sub>O<sub>4</sub>',
    '',
    '',
    'CFXREDIWINSYMD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C128OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C128OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C128OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C128OOH',
    'C<sub>12</sub>H<sub>20</sub>O<sub>5</sub>',
    '',
    '',
    'UJLXMZVGYRRHNB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C128OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C128OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C128OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C129OH',
    'C<sub>12</sub>H<sub>18</sub>O<sub>4</sub>',
    '',
    '',
    'LZLVFWPHHNPPPO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C129OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C129OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C129OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1312CO',
    'C<sub>13</sub>H<sub>20</sub>O<sub>4</sub>',
    '',
    '',
    'OXGUTNXNCKSGQJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1312CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1312CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1312CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1312OH',
    'C<sub>13</sub>H<sub>22</sub>O<sub>4</sub>',
    '',
    '',
    'IOOAKPNHTHIGJB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1312OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1312OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1312OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1312OOH',
    'C<sub>13</sub>H<sub>22</sub>O<sub>5</sub>',
    '',
    '',
    'IMCVJRKOQRMDFG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1312OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1312OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1312OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BCLKAOH',
    'C<sub>14</sub>H<sub>22</sub>O<sub>4</sub>',
    '',
    '',
    'OIHLYIMTKSRRQE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCLKAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCLKAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCLKAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BCLKBOH',
    'C<sub>14</sub>H<sub>22</sub>O<sub>4</sub>',
    '',
    '',
    'LFMWXXSOGPOZAN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCLKBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCLKBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCLKBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BCLKCOH',
    'C<sub>14</sub>H<sub>22</sub>O<sub>4</sub>',
    '',
    '',
    'WUCWLUFQNHHRAC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCLKCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCLKCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCLKCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C144OOH',
    'C<sub>14</sub>H<sub>24</sub>O<sub>5</sub>',
    '',
    '',
    'GLUIAMUUMIPXJY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C144OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C144OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C144OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C146OH',
    'C<sub>14</sub>H<sub>22</sub>O<sub>4</sub>',
    '',
    '',
    'MRXVSIMJFRVVPA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C146OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C146OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C146OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BCALAOH',
    'C<sub>15</sub>H<sub>24</sub>O<sub>3</sub>',
    '',
    '',
    'SOIICZPFVOBBSJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCALAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCALAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCALAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BCALBOH',
    'C<sub>15</sub>H<sub>24</sub>O<sub>3</sub>',
    '',
    '',
    'WYNIZHBHTSXQQC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCALBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCALBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCALBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BCALCOH',
    'C<sub>15</sub>H<sub>24</sub>O<sub>3</sub>',
    '',
    '',
    'NQPQIVDLCLYNNZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCALCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCALCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCALCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BCALOH',
    'C<sub>15</sub>H<sub>26</sub>O<sub>4</sub>',
    '',
    '',
    'MPEWUZJEETZOEB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCALOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCALOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCALOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BCALOOH',
    'C<sub>15</sub>H<sub>26</sub>O<sub>5</sub>',
    '',
    '',
    'HSCKVTFOUFPNNB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ketones (RCOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCALOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCALOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCALOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)',
    (SELECT id from categories WHERE catname='Organic species with oxygen (O)'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methanoic acid',
    'HCOOH',
    'formic acid',
    '64-18-6',
    'BDAGIHXWWSANSR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>1</sup>',
    '6100',
    'L',
    (SELECT id from species WHERE iupac='methanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>1</sup>',
    '6100',
    'L',
    (SELECT id from species WHERE iupac='methanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>1</sup>',
    '6100',
    'L',
    (SELECT id from species WHERE iupac='methanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>1</sup>',
    '6100',
    'L',
    (SELECT id from species WHERE iupac='methanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>1</sup>',
    '5900',
    'L',
    (SELECT id from species WHERE iupac='methanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>1</sup>',
    '6100',
    'M',
    (SELECT id from species WHERE iupac='methanoic acid'),
    (SELECT id from literature WHERE bibtexkey='511'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methanoic acid'),
    (SELECT id from literature WHERE bibtexkey='493'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>1</sup>',
    '5600',
    'M',
    (SELECT id from species WHERE iupac='methanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2230'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methanoic acid'),
    (SELECT id from literature WHERE bibtexkey='520'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '520',
    '520', 'The value given here was measured at a liquid-phase mixing ratio of 1&nbsp;&#956;mol&nbsp;mol<sup>&#8722;1</sup>. Servant et&nbsp;al. (1991) found that the Henry''s law constant changes at higher concentrations.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='520'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methanoic acid'),
    (SELECT id from literature WHERE bibtexkey='4023'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at297K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5700',
    'V',
    (SELECT id from species WHERE iupac='methanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5600',
    'R',
    (SELECT id from species WHERE iupac='methanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '1497smoothed',
    '1497', 'Abraham (1984) smoothed the values from a plot of enthalpy against carbon number.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1497smoothed'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5700',
    'T',
    (SELECT id from species WHERE iupac='methanoic acid'),
    (SELECT id from literature WHERE bibtexkey='160'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '160',
    '508', 'The value of H<sub>s</sub><sup>&ominus;</sup> was taken from Keene and Galloway (1986).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='160'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>1</sup>',
    '5700',
    'T',
    (SELECT id from species WHERE iupac='methanoic acid'),
    (SELECT id from literature WHERE bibtexkey='46'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '46HCOOH',
    '499', 'Calculated using thermodynamic data from Latimer (1952).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='46HCOOH'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>1</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='methanoic acid'),
    (SELECT id from literature WHERE bibtexkey='508'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methanoic acid'),
    (SELECT id from literature WHERE bibtexkey='gaffney84'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from715'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '715pH4',
    '', 'Value at pH = 4.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='715pH4'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='methanoic acid'),
    (SELECT id from literature WHERE bibtexkey='511'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='methanoic acid'),
    (SELECT id from literature WHERE bibtexkey='538'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='methanoic acid'),
    (SELECT id from literature WHERE bibtexkey='538'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>1</sup>',
    '5700',
    'C',
    (SELECT id from species WHERE iupac='methanoic acid'),
    (SELECT id from literature WHERE bibtexkey='31'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>1</sup>',
    '5700',
    'C',
    (SELECT id from species WHERE iupac='methanoic acid'),
    (SELECT id from literature WHERE bibtexkey='34'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5800',
    'Q',
    (SELECT id from species WHERE iupac='methanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6500',
    '?',
    (SELECT id from species WHERE iupac='methanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9',
    '',
    '?',
    (SELECT id from species WHERE iupac='methanoic acid'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethanoic acid',
    'CH<sub>3</sub>COOH',
    'acetic acid',
    '64-19-7',
    'QTBSBXVTEAMEQO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>1</sup>',
    '6200',
    'L',
    (SELECT id from species WHERE iupac='ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>1</sup>',
    '6200',
    'L',
    (SELECT id from species WHERE iupac='ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>1</sup>',
    '6200',
    'L',
    (SELECT id from species WHERE iupac='ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>1</sup>',
    '6200',
    'L',
    (SELECT id from species WHERE iupac='ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>1</sup>',
    '6300',
    'L',
    (SELECT id from species WHERE iupac='ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1721'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>1</sup>',
    '6300',
    'M',
    (SELECT id from species WHERE iupac='ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='511'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='493'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>1</sup>',
    '8300',
    'M',
    (SELECT id from species WHERE iupac='ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2230'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='520'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='520'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1913'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='cdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6300',
    'V',
    (SELECT id from species WHERE iupac='ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6200',
    'R',
    (SELECT id from species WHERE iupac='ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1497smoothed'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>1</sup>',
    '6400',
    'T',
    (SELECT id from species WHERE iupac='ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3674'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>1</sup>',
    '6400',
    'T',
    (SELECT id from species WHERE iupac='ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='76'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6400',
    'T',
    (SELECT id from species WHERE iupac='ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='160'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='160'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>1</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='508'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7',
    '4900',
    'X',
    (SELECT id from species WHERE iupac='ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='gaffney84'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from715'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='715pH4'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='511'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='538'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='538'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6100',
    'Q',
    (SELECT id from species WHERE iupac='ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6200',
    '?',
    (SELECT id from species WHERE iupac='ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'acetic anhydride',
    'C<sub>4</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '108-24-7',
    'WFDIJRYMOXRFFG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'V',
    (SELECT id from species WHERE iupac='acetic anhydride'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6',
    '',
    'X',
    (SELECT id from species WHERE iupac='acetic anhydride'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='acetic anhydride'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='acetic anhydride'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='acetic anhydride'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='acetic anhydride'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='acetic anhydride'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='acetic anhydride'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='acetic anhydride'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='acetic anhydride'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='acetic anhydride'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    '?',
    (SELECT id from species WHERE iupac='acetic anhydride'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propanoic acid',
    'C<sub>2</sub>H<sub>5</sub>COOH',
    'propionic acid',
    '79-09-4',
    'XBDQKXXYIPTUBI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='propanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3684'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='propanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1721'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='propanoic acid'),
    (SELECT id from literature WHERE bibtexkey='493'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='propanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2230'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='propanoic acid'),
    (SELECT id from literature WHERE bibtexkey='520'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='520'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='propanoic acid'),
    (SELECT id from literature WHERE bibtexkey='713'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6800',
    'V',
    (SELECT id from species WHERE iupac='propanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6800',
    'R',
    (SELECT id from species WHERE iupac='propanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1497smoothed'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>1</sup>',
    '6800',
    'T',
    (SELECT id from species WHERE iupac='propanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3674'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanoic acid'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-P'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propanoic acid'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methoxyacetic acid',
    'C<sub>3</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '625-45-6',
    'RMIODHQZRUFFFF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methoxyacetic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methoxyacetic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methoxyacetic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methoxyacetic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methoxyacetic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'butanoic acid',
    'C<sub>3</sub>H<sub>7</sub>COOH',
    'butyric acid',
    '107-92-6',
    'FERIUCNNQQJTOY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='butanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3684'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7',
    '',
    'M',
    (SELECT id from species WHERE iupac='butanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1721'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='butanoic acid'),
    (SELECT id from literature WHERE bibtexkey='493'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='butanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2230'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='butanoic acid'),
    (SELECT id from literature WHERE bibtexkey='713'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4',
    '',
    'V',
    (SELECT id from species WHERE iupac='butanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7100',
    'V',
    (SELECT id from species WHERE iupac='butanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7300',
    'R',
    (SELECT id from species WHERE iupac='butanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1497smoothed'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-Test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanoic acid'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='butanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='butanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='butanoic acid'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methylpropanoic acid',
    '(CH<sub>3</sub>)<sub>2</sub>CHCOOH',
    'isobutyric acid',
    '79-31-2',
    'KQNPFQTWMSNSAP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methylpropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3684'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methylpropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1721'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methylpropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='493'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methylpropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2230'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methylpropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='520'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='520'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylpropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methylpropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methylpropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pentanoic acid',
    'C<sub>4</sub>H<sub>9</sub>COOH',
    'valeric acid',
    '109-52-4',
    'NQPDZGIKBAWPEJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '6900',
    'L',
    (SELECT id from species WHERE iupac='pentanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='pentanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3684'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='pentanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1721'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '6600',
    'M',
    (SELECT id from species WHERE iupac='pentanoic acid'),
    (SELECT id from literature WHERE bibtexkey='493'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '6900',
    'M',
    (SELECT id from species WHERE iupac='pentanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2230'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pentanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pentanoic acid'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pentanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2231'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7500',
    'V',
    (SELECT id from species WHERE iupac='pentanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pentanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2388'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7700',
    'R',
    (SELECT id from species WHERE iupac='pentanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1497smoothed'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7',
    '',
    'X',
    (SELECT id from species WHERE iupac='pentanoic acid'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7200',
    'Q',
    (SELECT id from species WHERE iupac='pentanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentanoic acid'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pentanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6900',
    '?',
    (SELECT id from species WHERE iupac='pentanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4',
    '',
    '?',
    (SELECT id from species WHERE iupac='pentanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pentanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methylbutanoic acid',
    'C<sub>5</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '116-53-0',
    'WLAMNBDJUVNPJU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylbutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methylbutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methylbutanoic acid',
    '(CH<sub>3</sub>)<sub>2</sub>CHCH<sub>2</sub>COOH',
    'isovaleric acid',
    '503-74-2',
    'GWYFCOCPABKNJV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3-methylbutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3684'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3-methylbutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1721'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3-methylbutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='493'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3-methylbutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2230'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3-methylbutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2388'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-methylbutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-methylbutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-methylbutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2388'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methylbutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-methylbutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-methylbutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-methylbutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dimethylpropanoic acid',
    '(CH<sub>3</sub>)<sub>3</sub>CCOOH',
    'pivalic acid',
    '75-98-9',
    'IUGYQRQAERSCNH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2-dimethylpropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='493'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2-dimethylpropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2230'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2-dimethylpropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylpropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylpropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylpropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylpropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylpropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylpropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylpropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylpropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylpropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylpropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2-dimethylpropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hexanoic acid',
    'C<sub>5</sub>H<sub>11</sub>COOH',
    'caproic acid',
    '142-62-1',
    'FUZZWVXGSFPDMH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '6100',
    'L',
    (SELECT id from species WHERE iupac='hexanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9',
    '',
    'M',
    (SELECT id from species WHERE iupac='hexanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3684'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5',
    '',
    'M',
    (SELECT id from species WHERE iupac='hexanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1721'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '6300',
    'M',
    (SELECT id from species WHERE iupac='hexanoic acid'),
    (SELECT id from literature WHERE bibtexkey='493'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '5900',
    'M',
    (SELECT id from species WHERE iupac='hexanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2230'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexanoic acid'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2231'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '8700',
    'V',
    (SELECT id from species WHERE iupac='hexanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '8100',
    'R',
    (SELECT id from species WHERE iupac='hexanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1497smoothed'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='hexanoic acid'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7500',
    'Q',
    (SELECT id from species WHERE iupac='hexanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanoic acid'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='hexanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7200',
    '?',
    (SELECT id from species WHERE iupac='hexanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='hexanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='hexanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methylpentanoic acid',
    'C<sub>6</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '97-61-0',
    'OVBFMEVBMNZIBR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpentanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpentanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-ethylbutanoic acid',
    'C<sub>6</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '88-09-5',
    'OXQGTIUCKGYOAA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-ethylbutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-ethylbutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylbutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylbutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylbutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylbutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylbutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylbutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylbutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylbutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylbutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylbutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'heptanoic acid',
    'C<sub>7</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '111-14-8',
    'MNWFXJYAOYHMED-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='heptanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3684'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='heptanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6',
    '',
    'V',
    (SELECT id from species WHERE iupac='heptanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2231'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '8500',
    'V',
    (SELECT id from species WHERE iupac='heptanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '8500',
    'R',
    (SELECT id from species WHERE iupac='heptanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1497smoothed'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7800',
    'Q',
    (SELECT id from species WHERE iupac='heptanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7900',
    '?',
    (SELECT id from species WHERE iupac='heptanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='heptanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='heptanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,4-dimethylpentanoic acid',
    'C<sub>7</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '95823-36-2',
    'HMMSZUQCCUWXRA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethylpentanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethylpentanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethylpentanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethylpentanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-ethyl-2-methylbutanoic acid',
    'C<sub>7</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '19889-37-3',
    'LHJPKLWGGMAUAN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-2-methylbutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-2-methylbutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-2-methylbutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-2-methylbutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'octanoic acid',
    'C<sub>8</sub>H<sub>16</sub>O<sub>2</sub>',
    'caprylic acid',
    '124-07-2',
    'WWZKQHOCKIZLMA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='octanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='octanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='octanoic acid'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6',
    '',
    'V',
    (SELECT id from species WHERE iupac='octanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2231'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '9600',
    'V',
    (SELECT id from species WHERE iupac='octanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '8900',
    'R',
    (SELECT id from species WHERE iupac='octanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1497smoothed'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='octanoic acid'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '8200',
    'Q',
    (SELECT id from species WHERE iupac='octanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '8400',
    '?',
    (SELECT id from species WHERE iupac='octanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='octanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='octanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-ethylhexanoic acid',
    'C<sub>8</sub>H<sub>16</sub>O<sub>2</sub>',
    '',
    '149-57-5',
    'OBETXYAYXDNJHR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-ethylhexanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylhexanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylhexanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'endothal',
    'C<sub>8</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '145-73-3',
    'GXEKYRXVRROBEV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>10</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='endothal'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='endothal'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nonanoic acid',
    'C<sub>9</sub>H<sub>18</sub>O<sub>2</sub>',
    'pelargic acid',
    '112-05-0',
    'FBUKVWPVBMHYJY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='nonanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8',
    '',
    'V',
    (SELECT id from species WHERE iupac='nonanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2231'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='nonanoic acid'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9',
    '',
    'C',
    (SELECT id from species WHERE iupac='nonanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '',
    '?',
    (SELECT id from species WHERE iupac='nonanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='nonanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'decanoic acid',
    'C<sub>10</sub>H<sub>20</sub>O<sub>2</sub>',
    '',
    '334-48-5',
    'GHVNFZFCNZKVNT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4',
    '',
    'V',
    (SELECT id from species WHERE iupac='decanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5',
    '',
    'C',
    (SELECT id from species WHERE iupac='decanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='decanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3,5,5-tetramethylhexanoic acid',
    'C<sub>10</sub>H<sub>20</sub>O<sub>2</sub>',
    '',
    '1135681-77-4',
    'WRPPDRMFGQJMAR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,5,5-tetramethylhexanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,5,5-tetramethylhexanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,5,5-tetramethylhexanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,5,5-tetramethylhexanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pinonic acid',
    'C<sub>10</sub>H<sub>16</sub>O<sub>3</sub>',
    '',
    '473-72-3',
    'SIZDUQQDBXJXLQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pinonic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pinonic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pinonic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pinonic acid'),
    (SELECT id from literature WHERE bibtexkey='3413'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3413SPARC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'undecanoic acid',
    'C<sub>11</sub>H<sub>22</sub>O<sub>2</sub>',
    '',
    '112-37-8',
    'ZDPHROOEEOARMN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7',
    '',
    'X',
    (SELECT id from species WHERE iupac='undecanoic acid'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='undecanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='undecanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='undecanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3613'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dodecanoic acid',
    'C<sub>12</sub>H<sub>24</sub>O<sub>2</sub>',
    '',
    '143-07-7',
    'POULHZVOKOAJMA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dodecanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dodecanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dodecanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dodecanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tridecanoic acid',
    'C<sub>13</sub>H<sub>26</sub>O<sub>2</sub>',
    '',
    '638-53-9',
    'SZHOJFHSIKHZHA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0',
    '',
    'X',
    (SELECT id from species WHERE iupac='tridecanoic acid'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tridecanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tridecanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3613'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tetradecanoic acid',
    'C<sub>14</sub>H<sub>28</sub>O<sub>2</sub>',
    '',
    '544-63-8',
    'TUNFSRHWOTWDNC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tetradecanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetradecanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetradecanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3613'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pentadecanoic acid',
    'C<sub>15</sub>H<sub>30</sub>O<sub>2</sub>',
    '',
    '1002-84-2',
    'WQEPLUUGTLDZJY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentadecanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3613'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hexadecanoic acid',
    'C<sub>16</sub>H<sub>32</sub>O<sub>2</sub>',
    'palmitic acid',
    '57-10-3',
    'IPCSVZSSVZVIGE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexadecanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexadecanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexadecanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexadecanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3613'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'heptadecanoic acid',
    'C<sub>17</sub>H<sub>34</sub>O<sub>2</sub>',
    'margaric acid',
    '506-12-7',
    'KEMQGTRYUADPNZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptadecanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3613'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'octadecanoic acid',
    'C<sub>18</sub>H<sub>36</sub>O<sub>2</sub>',
    'stearic acid',
    '57-11-4',
    'QIQXTHQIDYTFRH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='octadecanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='octadecanoic acid'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octadecanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octadecanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octadecanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octadecanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3613'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nonadecanoic acid',
    'C<sub>19</sub>H<sub>38</sub>O<sub>2</sub>',
    '',
    '646-30-0',
    'ISYWECDDZWTKFF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonadecanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3613'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'eicosanoic acid',
    'C<sub>20</sub>H<sub>40</sub>O<sub>2</sub>',
    'arachidic acid',
    '506-30-9',
    'VKOBVWXKNCXXDE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='eicosanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3613'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'heneicosanoic acid',
    'C<sub>21</sub>H<sub>42</sub>O<sub>2</sub>',
    '',
    '2363-71-5',
    'CKDDRHZIAZRDBW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heneicosanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3613'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'docosanoic acid',
    'C<sub>22</sub>H<sub>44</sub>O<sub>2</sub>',
    'behenic acid',
    '112-85-6',
    'UKMSUNONTOPOIO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='docosanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3613'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tricosanoic acid',
    'C<sub>23</sub>H<sub>46</sub>O<sub>2</sub>',
    '',
    '2433-96-7',
    'XEZVDURJDFGERA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tricosanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3613'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tetracosanoic acid',
    'C<sub>24</sub>H<sub>48</sub>O<sub>2</sub>',
    'lignoceric acid',
    '557-59-5',
    'QZZGJDVWLFXDLK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetracosanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3613'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propenoic acid',
    'C<sub>3</sub>H<sub>4</sub>O<sub>2</sub>',
    'acrylic acid',
    '79-10-7',
    'NIXOWILDQLNWCW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propenoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propenoic acid'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propenoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propenoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propenoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propenoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propenoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propenoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propenoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propenoic acid'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propenoic acid'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propenoic acid'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propenoic acid'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-butenoic acid',
    'C<sub>4</sub>H<sub>6</sub>O<sub>2</sub>',
    'crotonic acid',
    '3724-65-0',
    'LDHQCZJRKDOVOX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-butenoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butenoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butenoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butenoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butenoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butenoic acid'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butenoic acid'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(E)-2-butenoic acid',
    'C<sub>4</sub>H<sub>6</sub>O<sub>2</sub>',
    '<i>trans</i>-crotonic acid',
    '107-93-7',
    'LDHQCZJRKDOVOX-NSCUHMNNSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(E)-2-butenoic acid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(Z)-2-butenoic acid',
    'C<sub>4</sub>H<sub>6</sub>O<sub>2</sub>',
    'isocrotonic acid',
    '503-64-0',
    'LDHQCZJRKDOVOX-IHWYPQMZSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(Z)-2-butenoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(Z)-2-butenoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(Z)-2-butenoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(Z)-2-butenoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(Z)-2-butenoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(Z)-2-butenoic acid'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(Z)-2-butenoic acid'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-2-propenoic acid',
    'C<sub>4</sub>H<sub>6</sub>O<sub>2</sub>',
    'methacrylic acid',
    '79-41-4',
    'CERQOIWHTDAKMF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methyl-2-propenoic acid'),
    (SELECT id from literature WHERE bibtexkey='1063'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-2-propenoic acid'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propenoic acid'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propenoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propenoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propenoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propenoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propenoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propenoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propenoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propenoic acid'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propenoic acid'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methyl-2-propenoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methacrylic acid epoxide',
    'C<sub>4</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '',
    'CSEUSVYSDPXJAP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methacrylic acid epoxide'),
    (SELECT id from literature WHERE bibtexkey='3583'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3583',
    '', 'Calculated using HENRYWIN 3.2 (bond contribution method).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3583'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benzenecarboxylic acid',
    'C<sub>6</sub>H<sub>5</sub>COOH',
    'benzoic acid',
    '65-85-0',
    'WPYMKLBDIGXBTP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='benzenecarboxylic acid'),
    (SELECT id from literature WHERE bibtexkey='2566'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzenecarboxylic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzenecarboxylic acid'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzenecarboxylic acid'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzenecarboxylic acid'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzenecarboxylic acid'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '6500',
    'X',
    (SELECT id from species WHERE iupac='benzenecarboxylic acid'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='benzenecarboxylic acid'),
    (SELECT id from literature WHERE bibtexkey='howard89'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzenecarboxylic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzenecarboxylic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzenecarboxylic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzenecarboxylic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzenecarboxylic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzenecarboxylic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzenecarboxylic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzenecarboxylic acid'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6700',
    'Q',
    (SELECT id from species WHERE iupac='benzenecarboxylic acid'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzenecarboxylic acid'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='benzenecarboxylic acid'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6200',
    '?',
    (SELECT id from species WHERE iupac='benzenecarboxylic acid'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='benzenecarboxylic acid'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'sorbic acid',
    'C<sub>6</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '110-44-1',
    'WSWCOQWTEOXDQX-MQQKCMAXSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='sorbic acid'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='sorbic acid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'D(-)-isoascorbic acid',
    'C<sub>6</sub>H<sub>8</sub>O<sub>6</sub>',
    'erythorbic acid',
    '89-65-6',
    'CIWBSHSKHKDKBQ-DUZGATOHSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D(-)-isoascorbic acid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'shikimic acid',
    'C<sub>7</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '138-59-0',
    'JXOHGGNKMLTUBP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='shikimic acid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-hydroxybenzoic acid',
    'C<sub>7</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '99-96-7',
    'FJKROLUGYXJWQN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-hydroxybenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-hydroxybenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-hydroxybenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4,5-trihydroxybenzoic acid',
    'C<sub>7</sub>H<sub>6</sub>O<sub>5</sub>',
    'gallic acid',
    '149-91-7',
    'LNTHITQWFMADLM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>14</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,5-trihydroxybenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methylbenzoic acid',
    'C<sub>8</sub>H<sub>8</sub>O<sub>2</sub>',
    'o-toluic acid',
    '118-90-1',
    'ZWLPBLYKEWSWPD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methylbenzoic acid',
    'C<sub>8</sub>H<sub>8</sub>O<sub>2</sub>',
    'm-toluic acid',
    '99-04-7',
    'GPSDUZXPYCFOSQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-methylbenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-methylbenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methylbenzoic acid',
    'C<sub>8</sub>H<sub>8</sub>O<sub>2</sub>',
    'p-toluic acid',
    '99-94-5',
    'LPNBBFKOUUSUDB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylbenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylbenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylbenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylbenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylbenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylbenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylbenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7000',
    'Q',
    (SELECT id from species WHERE iupac='4-methylbenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7500',
    '?',
    (SELECT id from species WHERE iupac='4-methylbenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-hydroxy-benzoic acid',
    'C<sub>7</sub>H<sub>6</sub>O<sub>3</sub>',
    'salicylic acid',
    '69-72-7',
    'YGSDEFSMJLZEOE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-hydroxy-benzoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-hydroxy-benzoic acid'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-hydroxy-benzoic acid'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-hydroxy-benzoic acid'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-hydroxy-benzoic acid'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxy-benzoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxy-benzoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxy-benzoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxy-benzoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxy-benzoic acid'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benzeneethanoic acid',
    'C<sub>8</sub>H<sub>8</sub>O<sub>2</sub>',
    'phenylacetic acid',
    '103-82-2',
    'WLJVXDMOQOGPHL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzeneethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzeneethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzeneethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzeneethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzeneethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzeneethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzeneethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzeneethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzeneethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzeneethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzeneethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzeneethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzeneethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzeneethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzeneethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phthalic anhydride',
    'C<sub>8</sub>H<sub>4</sub>O<sub>3</sub>',
    '',
    '85-44-9',
    'LGRFSURHDFAFJT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='phthalic anhydride'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='phthalic anhydride'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='phthalic anhydride'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phthalic anhydride'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phthalic anhydride'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-benzenedicarboxylic acid',
    'C<sub>8</sub>H<sub>6</sub>O<sub>4</sub>',
    'phthalic acid',
    '88-99-3',
    'XNGIFLGASWRNHJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-benzenedicarboxylic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-benzenedicarboxylic acid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-benzenedicarboxylic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'terephthalic acid',
    'C<sub>8</sub>H<sub>6</sub>O<sub>4</sub>',
    '',
    '100-21-0',
    'KKEYFWRCBNTPAC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='terephthalic acid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='terephthalic acid'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'isophthalic acid',
    'C<sub>8</sub>H<sub>6</sub>O<sub>4</sub>',
    '',
    '121-91-5',
    'QQVIHTHCMHWDBS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>9</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='isophthalic acid'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isophthalic acid'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isophthalic acid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isophthalic acid'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isophthalic acid'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dehydroacetic acid',
    'C<sub>8</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '520-45-6',
    'PGRHXDWITVMQBC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dehydroacetic acid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methoxybenzoic acid',
    'C<sub>8</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '579-75-9',
    'ILUJQPXNXACGAN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methoxybenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methoxybenzoic acid',
    'C<sub>8</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '100-09-4',
    'ZEYHEAKUIGZSGI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methoxybenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'caffeic acid',
    'C<sub>9</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '331-39-5',
    'QAIPRVGONGVQAS-DUXPYHPUSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='caffeic acid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methylphthalic anhydride',
    'C<sub>9</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '19438-61-0',
    'ZOXBWJMCXHTKNU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylphthalic anhydride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylphthalic anhydride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylphthalic anhydride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylphthalic anhydride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-phenyl-2-propenoic acid',
    'C<sub>9</sub>H<sub>8</sub>O<sub>2</sub>',
    'cinnamic acid',
    '621-82-9',
    'WBYWAXJHAXSJNI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-phenyl-2-propenoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-phenyl-2-propenoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-phenyl-2-propenoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-phenyl-2-propenoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-phenyl-2-propenoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>trans</i>-cinnamic acid',
    'C<sub>9</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '140-10-3',
    'WBYWAXJHAXSJNI-VOTSOKGWSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-cinnamic acid'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'p-coumaric acid',
    'C<sub>9</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '501-98-4',
    'NGSWKAQJJWESNS-ZZXKWVIFSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='p-coumaric acid'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4-dimethoxybenzoic acid',
    'C<sub>9</sub>H<sub>10</sub>O<sub>4</sub>',
    'veratric acid',
    '93-07-2',
    'DAUAQNGYDSHRET-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethoxybenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4,5-trimethoxybenzoic acid',
    'C<sub>10</sub>H<sub>12</sub>O<sub>5</sub>',
    'eudesmic acid',
    '118-41-2',
    'SJSOFNCYXJUNBT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,5-trimethoxybenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-naphthaleneacetic acid',
    'C<sub>12</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '86-87-3',
    'PRPINYUDVPFIRX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-naphthaleneacetic acid'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3549-pH7',
    '', 'At pH = 7.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH7'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-naphthaleneacetic acid'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3549-pH10.8',
    '', 'At pH = 10.8.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH10.8'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-naphthoxyacetic acid',
    'C<sub>12</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '120-23-0',
    'RZCJYMOBWVJQGV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-naphthoxyacetic acid'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'p-<i>tert</i>-butylbenzoic acid',
    'C<sub>11</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '98-73-7',
    'KDVYCTOWXSLNNI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='p-<i>tert</i>-butylbenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='p-<i>tert</i>-butylbenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='p-<i>tert</i>-butylbenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='p-<i>tert</i>-butylbenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'trinexapac',
    'C<sub>11</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '104273-73-6',
    'DFFWZNDCNBOKDI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='trinexapac'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trinexapac'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benzoic acid, anhydride',
    'C<sub>14</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '93-97-0',
    'CHIHQLCVLOXUJW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzoic acid, anhydride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzoic acid, anhydride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzoic acid, anhydride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzoic acid, anhydride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pyromellitic acid',
    'C<sub>10</sub>H<sub>6</sub>O<sub>8</sub>',
    '',
    '89-05-4',
    'CYIDZMCFTVVTJO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>13</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='pyromellitic acid'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'at289K',
    '', 'Value at T = 289&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at289K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>13</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pyromellitic acid'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>13</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pyromellitic acid'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pyromellitic dianhydride',
    'C<sub>10</sub>H<sub>2</sub>O<sub>6</sub>',
    '',
    '89-32-7',
    'ANSXAPJVJOKRDJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pyromellitic dianhydride'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pyromellitic dianhydride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pyromellitic dianhydride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pyromellitic dianhydride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pyromellitic dianhydride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'naproxen',
    'C<sub>14</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '22204-53-1',
    'CMWTZPSULFXXJA-VIFPVBQESA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='naproxen'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(Z,Z)-9,12-octadecadienoic acid',
    'C<sub>18</sub>H<sub>32</sub>O<sub>2</sub>',
    'linoleic acid',
    '60-33-3',
    'OYHQOLUKZRVURQ-HZJYTTRNSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(Z,Z)-9,12-octadecadienoic acid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'rosmarinic acid',
    'C<sub>18</sub>H<sub>16</sub>O<sub>8</sub>',
    '',
    '537-15-5',
    'DOUMFZQKYFQNTF-WUTVXBCWSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>21</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='rosmarinic acid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'abietic acid',
    'C<sub>20</sub>H<sub>30</sub>O<sub>2</sub>',
    '',
    '514-10-3',
    'RSWGJHLUYNHPMX-ONCXSQPRSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='abietic acid'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='abietic acid'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethanedioic acid',
    'HOOCCOOH',
    'oxalic acid',
    '144-62-7',
    'MUBZPKHOEPUJKR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='ethanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>6</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='ethanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3022'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>6</sup>',
    '9800',
    'V',
    (SELECT id from species WHERE iupac='ethanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='1925'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>4</sup>',
    '7300',
    'V',
    (SELECT id from species WHERE iupac='ethanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='2231'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='gaffney84'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from715'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='715pH4'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>6</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='ethanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propanedioic acid',
    'HOOCCH<sub>2</sub>COOH',
    'malonic acid',
    '141-82-2',
    'OFOBLEOULBTSOW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>8</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='propanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>8</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='propanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>8</sup>',
    '11000',
    'V',
    (SELECT id from species WHERE iupac='propanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3022'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>7</sup>',
    '14000',
    'V',
    (SELECT id from species WHERE iupac='propanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3022'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>6</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='propanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'butanedioic acid',
    'HOOC(CH<sub>2</sub>)<sub>2</sub>COOH',
    'succinic acid',
    '110-15-6',
    'KDYFGRWQOYBRFD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>7</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='butanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>7</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='butanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>7</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>7</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>7</sup>',
    '11000',
    'V',
    (SELECT id from species WHERE iupac='butanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3022'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>7</sup>',
    '12000',
    'V',
    (SELECT id from species WHERE iupac='butanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3022'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='butanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>6</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='butanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pentanedioic acid',
    'HOOC(CH<sub>2</sub>)<sub>3</sub>COOH',
    'glutaric acid',
    '110-94-1',
    'JFCQEDHGNNZCLN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>7</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='pentanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>7</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='pentanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>7</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='pentanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='1658'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>7</sup>',
    '12000',
    'V',
    (SELECT id from species WHERE iupac='pentanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3022'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>7</sup>',
    '13000',
    'V',
    (SELECT id from species WHERE iupac='pentanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3022'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='pentanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'at338K',
    '', 'Value at T = 338&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at338K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>6</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='pentanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-hydroxy glutaric acid',
    'C<sub>5</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '638-18-6',
    'ZQHYXNSQOIDNTL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hydroxy glutaric acid'),
    (SELECT id from literature WHERE bibtexkey='3413'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3413SPARC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hexanedioic acid',
    'HOOC(CH<sub>2</sub>)<sub>4</sub>COOH',
    'adipic acid',
    '124-04-9',
    'WNLRTRBMVRJNCN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>7</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='hexanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>7</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='hexanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>7</sup>',
    '13000',
    'V',
    (SELECT id from species WHERE iupac='hexanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3022'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>5</sup>',
    '11000',
    'X',
    (SELECT id from species WHERE iupac='hexanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>6</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='hexanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tricarballylic acid',
    'C<sub>6</sub>H<sub>8</sub>O<sub>6</sub>',
    '',
    '99-14-9',
    'KQTIIICEAUMSDG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tricarballylic acid'),
    (SELECT id from literature WHERE bibtexkey='3413'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3413SPARC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'heptanedioic acid',
    'C<sub>7</sub>H<sub>12</sub>O<sub>4</sub>',
    'pimelic acid',
    '111-16-0',
    'WLJVNTCWHIRURA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>7</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='heptanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>7</sup>',
    '15000',
    'V',
    (SELECT id from species WHERE iupac='heptanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3022'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-acetyl pentanedioic acid',
    'C<sub>7</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '149474-71-5',
    'TZPGYCKKEMNHRS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-acetyl pentanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3413'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3413SPARC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'octanedioic acid',
    'C<sub>8</sub>H<sub>14</sub>O<sub>4</sub>',
    'suberic acid',
    '505-48-6',
    'TYFQFVWCELRYAO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='octanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>7</sup>',
    '14000',
    'V',
    (SELECT id from species WHERE iupac='octanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3022'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-1,2,3-butanetricarboxylic acid',
    'C<sub>8</sub>H<sub>12</sub>O<sub>6</sub>',
    '',
    '77370-41-3',
    'VMWJGTKDJFMTFZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1,2,3-butanetricarboxylic acid'),
    (SELECT id from literature WHERE bibtexkey='3413'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3413SPARC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nonanedioic acid',
    'C<sub>9</sub>H<sub>16</sub>O<sub>4</sub>',
    'azelaic acid',
    '123-99-9',
    'BDJRBEYXGGNYIS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>7</sup>',
    '17000',
    'V',
    (SELECT id from species WHERE iupac='nonanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3022'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='nonanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'decanedioic acid',
    'C<sub>10</sub>H<sub>18</sub>O<sub>4</sub>',
    'sebacic acid',
    '111-20-6',
    'CXMXRPHRNRROMY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>7</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='decanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3022'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='decanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dodecanedioic acid',
    'C<sub>12</sub>H<sub>22</sub>O<sub>4</sub>',
    '',
    '693-23-2',
    'TVIDDXQYHWJXFK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dodecanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>cis</i>-butenedioic acid',
    'HOOC(CH)<sub>2</sub>COOH',
    'maleic acid',
    '110-16-7',
    'VZCYOOQTPOCHFL-UPHRSURJSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>8</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='<i>cis</i>-butenedioic acid'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>cis</i>-butenedioic acid'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-butenedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-butenedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>6</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='<i>cis</i>-butenedioic acid'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'citraconic acid',
    'C<sub>5</sub>H<sub>6</sub>O<sub>4</sub>',
    '',
    '498-23-7',
    'HNEGQIOMVPPMNR-IHWYPQMZSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='citraconic acid'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='citraconic acid'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='citraconic acid'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'itaconic acid',
    'C<sub>5</sub>H<sub>6</sub>O<sub>4</sub>',
    '',
    '97-65-4',
    'LVHBHZANLOWSRM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='itaconic acid'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='itaconic acid'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='itaconic acid'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4-cyclohexanedicarboxylic acid',
    'C<sub>8</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '619-82-9',
    'PXGZQGDTEZPERC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,4-cyclohexanedicarboxylic acid'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at290K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-cyclohexanedicarboxylic acid'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-cyclohexanedicarboxylic acid'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pinic acid',
    'C<sub>9</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '473-73-4',
    'LEVONNIFUFSRKZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pinic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pinic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pinic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pinic acid'),
    (SELECT id from literature WHERE bibtexkey='3413'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3413SPARC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methanoic peroxyacid',
    'HCOOOH',
    'peroxyformic acid',
    '107-32-4',
    'SCKXCAADGDQQCS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methanoic peroxyacid'),
    (SELECT id from literature WHERE bibtexkey='1200'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at278K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanoic peroxyacid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethanoic peroxyacid',
    'CH<sub>3</sub>COOOH',
    'peroxyacetic acid',
    '79-21-0',
    'KFSLWBXXFJQRDL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3',
    '5300',
    'L',
    (SELECT id from species WHERE iupac='ethanoic peroxyacid'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3',
    '5300',
    'L',
    (SELECT id from species WHERE iupac='ethanoic peroxyacid'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3',
    '5300',
    'L',
    (SELECT id from species WHERE iupac='ethanoic peroxyacid'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3',
    '5600',
    'L',
    (SELECT id from species WHERE iupac='ethanoic peroxyacid'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethanoic peroxyacid'),
    (SELECT id from literature WHERE bibtexkey='1200'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at278K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3',
    '5300',
    'M',
    (SELECT id from species WHERE iupac='ethanoic peroxyacid'),
    (SELECT id from literature WHERE bibtexkey='516'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5',
    '5900',
    'M',
    (SELECT id from species WHERE iupac='ethanoic peroxyacid'),
    (SELECT id from literature WHERE bibtexkey='311'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='311'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanoic peroxyacid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanoic peroxyacid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanoic peroxyacid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanoic peroxyacid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanoic peroxyacid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanoic peroxyacid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanoic peroxyacid'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanoic peroxyacid'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6100',
    'Q',
    (SELECT id from species WHERE iupac='ethanoic peroxyacid'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5300',
    '?',
    (SELECT id from species WHERE iupac='ethanoic peroxyacid'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:M2C43CO2H',
    'C<sub>6</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'XFOASZQZPWEJAA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2C43CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2C43CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2C43CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:M33C3CO2H',
    'C<sub>6</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'VUAXHMVRKOTJKP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M33C3CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M33C3CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M33C3CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C721OOH',
    'C<sub>7</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'ZLURETBBUKLNQX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C721OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C721OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C721OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C721CO3H',
    'C<sub>8</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'HYEGRGIGVZWWFM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C721CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C721CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C721CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C811OOH',
    'C<sub>8</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'RYDSGVCXHLRTGT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C811OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C811OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C811OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C823OOH',
    'C<sub>8</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'KIIRSRLFRXTUMU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C823OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C823OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C823OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NORPINIC',
    'C<sub>8</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'KLGKVMMWRDYKJM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NORPINIC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NORPINIC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NORPINIC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C811CO3H',
    'C<sub>9</sub>H<sub>14</sub>O<sub>5</sub>',
    '',
    '',
    'ZVOGBTSHONFRIW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C811CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C811CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C811CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C823CO3H',
    'C<sub>9</sub>H<sub>14</sub>O<sub>5</sub>',
    '',
    '',
    'IESQFENJEQJSTC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C823CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C823CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C823CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:LIMONIC',
    'C<sub>9</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'JUCWCJYNDRRZKR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMONIC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMONIC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMONIC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C137OOH',
    'C<sub>13</sub>H<sub>22</sub>O<sub>4</sub>',
    '',
    '',
    'RDYPCLKIKFUKHY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C137OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C137OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C137OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C137CO2H',
    'C<sub>14</sub>H<sub>22</sub>O<sub>4</sub>',
    '',
    '',
    'IYTMEDMFNUDFPT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C137CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C137CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C137CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C137CO3H',
    'C<sub>14</sub>H<sub>22</sub>O<sub>5</sub>',
    '',
    '',
    'WIBVBPZGNYNCKK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C137CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C137CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C137CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TM123BCO2H',
    'C<sub>9</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'RIZUCYSQUWMQLX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM123BCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM123BCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM123BCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TM124BCO2H',
    'C<sub>9</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'OPVAJFQBSDUNQA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124BCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124BCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124BCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TMBCO2H',
    'C<sub>9</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'UMVOQQDNEYOJOK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TMBCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TMBCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TMBCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C2OHOCO2H',
    'C<sub>3</sub>H<sub>6</sub>O<sub>4</sub>',
    '',
    '',
    'RBNPOMFGQQGHHO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C2OHOCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C2OHOCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C2OHOCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HOC2H4CO2H',
    'C<sub>3</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '',
    'ALRHLSYJTWAHJZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOC2H4CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOC2H4CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOC2H4CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HC3CO2H',
    'C<sub>4</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '',
    'RMQJECWPWQIIPW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HC3CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HC3CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HC3CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HMACO2H',
    'C<sub>4</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '',
    'AAMTXHVZOHPPQR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HMACO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HMACO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HMACO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO2C3CO2H',
    'C<sub>4</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'WHBMMWSBFZVSSR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C3CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C3CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C3CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HOC3H6CO2H',
    'C<sub>4</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'SJZRECIVHVDYJC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOC3H6CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOC3H6CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOC3H6CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HOIPRCO2H',
    'C<sub>4</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'DBXBTMSZEOQQDU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOIPRCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOIPRCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOIPRCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPRHOCO2H',
    'C<sub>4</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'BWLBGMIXKSTLSX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRHOCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRHOCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRHOCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C46CO2H',
    'C<sub>5</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'NJMYQRVWBCSLEU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C46CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C46CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C46CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HC4ACO2H',
    'C<sub>5</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'BERUOTKXCOOJJM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HC4ACO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HC4ACO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HC4ACO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HC4CCO2H',
    'C<sub>5</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'NCQCQZXQBYAHBZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HC4CCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HC4CCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HC4CCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HM22CO2H',
    'C<sub>5</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'RDFQSFOGKVZWKF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM22CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM22CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM22CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO2C43CO2H',
    'C<sub>5</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'VEXDRERIMPLZLU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C43CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C43CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C43CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO2C4CO2H',
    'C<sub>5</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'FMHKPLXYWVCLME-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C4CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C4CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C4CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HOBUT2CO2H',
    'C<sub>5</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'JYTYEGKJKIXWOJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOBUT2CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOBUT2CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOBUT2CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C518CO2H',
    'C<sub>6</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'COPVWTGWHHSRKU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C518CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C518CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C518CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H2M2C4CO2H',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'PQJUMPXLDAZULJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M2C4CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M2C4CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M2C4CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H2M3C4CO2H',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'BNTHHYUWQILHSA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M3C4CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M3C4CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M3C4CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HM22C3CO2H',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'WLKUATLKPJGHKX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM22C3CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM22C3CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM22C3CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HM2C43CO2H',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'QSMSJHRQUBQMKD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM2C43CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM2C43CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM2C43CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HM33C3CO2H',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'NGRPJOQCQYDOJX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM33C3CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM33C3CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM33C3CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO2C54CO2H',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'IOXPMKQXROCYFL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C54CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C54CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C54CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO3C5CO2H',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'ABIKNKURIGPIRJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C5CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C5CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C5CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C622CO2H',
    'C<sub>7</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'PHVXTLWKDLVJPT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C622CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C622CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C622CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C624CO2H',
    'C<sub>7</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'IOGKLHPXZHQWIC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C624CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C624CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C624CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H3M3C5CO2H',
    'C<sub>7</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'BHWOTLCMMUBASI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3M3C5CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3M3C5CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3M3C5CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C811OH',
    'C<sub>8</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'UVNHICQQCWWSMK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C811OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C811OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C811OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C812OH',
    'C<sub>8</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'VFUDATRQVLCLSF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C812OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C812OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C812OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C812OOH',
    'C<sub>8</sub>H<sub>14</sub>O<sub>5</sub>',
    '',
    '',
    'TXANCYYWZQZPGK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C812OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C812OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C812OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C823OH',
    'C<sub>8</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'HTVBHPNLYICQSI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C823OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C823OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C823OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C825OH',
    'C<sub>8</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'GZVYHBJSBFFFII-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C825OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C825OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C825OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C825OOH',
    'C<sub>8</sub>H<sub>14</sub>O<sub>5</sub>',
    '',
    '',
    'XYVJCWMMBMHSFM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C825OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C825OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C825OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C137OH',
    'C<sub>13</sub>H<sub>22</sub>O<sub>3</sub>',
    '',
    '',
    'GRQGZSRLPJOOBF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C137OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C137OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C137OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C139OH',
    'C<sub>13</sub>H<sub>22</sub>O<sub>4</sub>',
    '',
    '',
    'RQGWJIBQKQBFEC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C139OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C139OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C139OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C139OOH',
    'C<sub>13</sub>H<sub>22</sub>O<sub>5</sub>',
    '',
    '',
    'MQHLLQIJDGKDCT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C139OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C139OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C139OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C44OOH',
    'C<sub>4</sub>H<sub>6</sub>O<sub>5</sub>',
    '',
    '',
    'RIVXGQNQRYOWAN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C44OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C44OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C44OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MALDALCO2H',
    'C<sub>4</sub>H<sub>4</sub>O<sub>3</sub>',
    '',
    '',
    'ZOIRMVZWDRLJPI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MALDALCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MALDALCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MALDALCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PRPAL2CO2H',
    'C<sub>4</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '',
    'VOKUMXABRRXHAR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRPAL2CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRPAL2CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRPAL2CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C3MCOCO2H',
    'C<sub>5</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '',
    'VXAWORVMCLXEKH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3MCOCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3MCOCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3MCOCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO1M22CO2H',
    'C<sub>5</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'SUMZWDXUXLTFFX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO1M22CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO1M22CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO1M22CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MC3ODBCO2H',
    'C<sub>5</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '',
    'QPFVAKLVWFPTSX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MC3ODBCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MC3ODBCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MC3ODBCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C3EODBCO2H',
    'C<sub>6</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'XIZBOUDCWHEQCF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3EODBCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3EODBCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3EODBCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C3M2COCO2H',
    'C<sub>6</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'HLFIROOBCUFLFC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3M2COCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3M2COCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3M2COCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C522CO2H',
    'C<sub>6</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'NSMTVDIDRFOALU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C522CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C522CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C522CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:RGDCO2H',
    'C<sub>6</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'HNXWTHGWCGDLKB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:RGDCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:RGDCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:RGDCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C615CO2H',
    'C<sub>7</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'BRDQYLNZHVUNQF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C615CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C615CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C615CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C722OOH',
    'C<sub>7</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'XJSSOLXEKAZFKL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C722OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C722OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C722OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IP3ODBCO2H',
    'C<sub>7</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'HLXOYOZOZOGAJW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IP3ODBCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IP3ODBCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IP3ODBCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PC3ODBCO2H',
    'C<sub>7</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'SHOOYBDWMZRRKO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PC3ODBCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PC3ODBCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PC3ODBCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C721CHO',
    'C<sub>8</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'MQTHUXQLMJSVGN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C721CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C721CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C721CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C729CO2H',
    'C<sub>8</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'NHNJUKWYLMFOQP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C729CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C729CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C729CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C823CO',
    'C<sub>8</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'KUOQBJGRIDTXEZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C823CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C823CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C823CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C822CO2H',
    'C<sub>9</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'ADULCIYKWVJSFE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>4</sup>',
    '15000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C822CO2H'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C822CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C822CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C822CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C830CO2H',
    'C<sub>9</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'NWNQYPOMHUZLML-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C830CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C830CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C830CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C89CO2H',
    'C<sub>9</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'RFGXRYLTPBBFIG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C89CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C89CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C89CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C126CO2H',
    'C<sub>13</sub>H<sub>20</sub>O<sub>3</sub>',
    '',
    '',
    'FRZAETYQWIEERW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C126CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C126CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C126CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C137CO',
    'C<sub>13</sub>H<sub>20</sub>O<sub>3</sub>',
    '',
    '',
    'FQUQDHNCRLRZNB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C137CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C137CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C137CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C136CO2H',
    'C<sub>14</sub>H<sub>22</sub>O<sub>3</sub>',
    '',
    '',
    'MUFZWTUKICSBHZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C136CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C136CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C136CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:COHM2CO2H',
    'C<sub>4</sub>H<sub>6</sub>O<sub>4</sub>',
    '',
    '',
    'DDNPKLYNPFAIEE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:COHM2CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:COHM2CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:COHM2CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1H4C5CO2H',
    'C<sub>6</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'NIVGPRREFKECGM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1H4C5CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1H4C5CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1H4C5CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ECOCO2H',
    'C<sub>4</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '',
    'TYEYBOSBBBHJIV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ECOCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ECOCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ECOCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C41CO2H',
    'C<sub>5</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'GCXJINGJZAOJHR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C41CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C41CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C41CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5CO14OH',
    'C<sub>5</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '',
    'XGTKSWVCNVUVHG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5CO14OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5CO14OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5CO14OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO2C4CO2H',
    'C<sub>5</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'JOOXCMJARBKPKM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2C4CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2C4CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2C4CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO3C4CO2H',
    'C<sub>5</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'FHSUFDYFOHSYHI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO3C4CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO3C4CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO3C4CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPGLYOXOH',
    'C<sub>5</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'QHKABHOOEWYVLI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPGLYOXOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPGLYOXOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPGLYOXOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PGLYOXOH',
    'C<sub>5</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'KDVFRMMRZOCFLS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PGLYOXOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PGLYOXOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PGLYOXOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C51CO2H',
    'C<sub>6</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'NFIWUVRBASXMGK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C51CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C51CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C51CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5CODBCO2H',
    'C<sub>6</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'YUICRCSHEOZHST-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5CODBCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5CODBCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5CODBCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5DBCOCO2H',
    'C<sub>6</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'LRRPKULXSOVRRZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5DBCOCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5DBCOCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5DBCOCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6DCRBBOH',
    'C<sub>6</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'VUZJJUOKMOGBDH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6DCRBBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6DCRBBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6DCRBBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO2C54CO2H',
    'C<sub>6</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'UZTJTTKEYGHTNM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2C54CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2C54CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2C54CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO2M33CO2H',
    'C<sub>6</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'CBZZWRQRPKSEQI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2M33CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2M33CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2M33CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO3C5CO2H',
    'C<sub>6</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'CLJBDOUIEHLLEN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO3C5CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO3C5CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO3C5CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C732OOH',
    'C<sub>7</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'ASSSOSHEUJWVOL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C732OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C732OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C732OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7ADCCO2H',
    'C<sub>7</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'GJIWJSZYGQVZNC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7ADCCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7ADCCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7ADCCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7CDCCO2H',
    'C<sub>7</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'OAGXHOMWGVMDLP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7CDCCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7CDCCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7CDCCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7DCCO2H',
    'C<sub>7</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'LUXOYEZTEWTGMD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7DCCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7DCCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7DCCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7DDCCO2H',
    'C<sub>7</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'MDDQAVHYGMRQBB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7DDCCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7DDCCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7DDCCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO25C6CO2H',
    'C<sub>7</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'WUQQVFQGWWMQLD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO25C6CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO25C6CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO25C6CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IC7DCCO2H',
    'C<sub>7</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'TZKNMZPMBZQSMV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IC7DCCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IC7DCCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IC7DCCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C732CO3H',
    'C<sub>8</sub>H<sub>12</sub>O<sub>6</sub>',
    '',
    '',
    'IARLEAITRRLVEZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C732CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C732CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C732CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:KLIMONIC',
    'C<sub>8</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'POLIOAJLCGOOTJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:KLIMONIC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:KLIMONIC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:KLIMONIC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C827CO2H',
    'C<sub>9</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'UOMMGFNPUVSKTE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C827CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C827CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C827CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C88CO2H',
    'C<sub>9</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'LOFCXTWTTIFNLN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C88CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C88CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C88CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:KLIMONONIC',
    'C<sub>9</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'RRLLKTDJWPIWHS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:KLIMONONIC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:KLIMONONIC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:KLIMONONIC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C928CO2H',
    'C<sub>10</sub>H<sub>16</sub>O<sub>4</sub>',
    '',
    '',
    'SANKOOWGNYBKOU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C928CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C928CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C928CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:LIMONONIC',
    'C<sub>10</sub>H<sub>16</sub>O<sub>3</sub>',
    '',
    '',
    'NJOIWWRMLFSDTM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>4</sup>',
    '15000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMONONIC'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMONONIC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMONONIC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMONONIC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1011CO2H',
    'C<sub>11</sub>H<sub>18</sub>O<sub>3</sub>',
    '',
    '',
    'IUOPXZCJHJMHNP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1011CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1011CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1011CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1211OOH',
    'C<sub>12</sub>H<sub>20</sub>O<sub>5</sub>',
    '',
    '',
    'PTZJPBFCCQIPAZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1211OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1211OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1211OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1211CO2H',
    'C<sub>13</sub>H<sub>20</sub>O<sub>5</sub>',
    '',
    '',
    'QUEDJGCZCJPFDA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1211CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1211CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1211CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1211CO3H',
    'C<sub>13</sub>H<sub>20</sub>O<sub>6</sub>',
    '',
    '',
    'DVDQWECWXWLOQZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1211CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1211CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1211CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C131CO2H',
    'C<sub>14</sub>H<sub>22</sub>O<sub>4</sub>',
    '',
    '',
    'QDUXHZZYSCMHPK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C131CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C131CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C131CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C147CO',
    'C<sub>14</sub>H<sub>20</sub>O<sub>5</sub>',
    '',
    '',
    'MMRJODLWTRWNRH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C147CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C147CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C147CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C147OOH',
    'C<sub>14</sub>H<sub>22</sub>O<sub>6</sub>',
    '',
    '',
    'MOUQEZQXHGSYER-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C147OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C147OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C147OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C141CO2H',
    'C<sub>15</sub>H<sub>24</sub>O<sub>3</sub>',
    '',
    '',
    'VGNFSHPHIKPNED-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C141CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C141CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C141CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HOCH2COCO2H',
    'C<sub>3</sub>H<sub>4</sub>O<sub>4</sub>',
    '',
    '',
    'HHDDCCUIIUWNGJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOCH2COCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOCH2COCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOCH2COCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H3C2C4CO2H',
    'C<sub>5</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'IQZHXDCQZNRIRW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3C2C4CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3C2C4CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3C2C4CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HMVKBCO2H',
    'C<sub>5</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'ISMQTZHDOHOVBT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HMVKBCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HMVKBCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HMVKBCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C517CO2H',
    'C<sub>6</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'APPVMSIJNZFGHP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C517CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C517CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C517CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C519CO2H',
    'C<sub>6</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'ULHNCRHSCMPZGW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C519CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C519CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C519CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C732OH',
    'C<sub>7</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'PKQMWBHBXJKPID-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C732OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C732OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C732OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C734CO',
    'C<sub>7</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'CPJVKYXUMUTCGW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C734CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C734CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C734CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C734OH',
    'C<sub>7</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'RDRUHSRUZHRAFB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C734OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C734OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C734OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C734OOH',
    'C<sub>7</sub>H<sub>12</sub>O<sub>6</sub>',
    '',
    '',
    'ABEMFUWOTMEDPB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>12</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C734OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C734OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C734OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H3C25CCO2H',
    'C<sub>7</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'FMZPEVNVWACALO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3C25CCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3C25CCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3C25CCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C813OH',
    'C<sub>8</sub>H<sub>14</sub>O<sub>5</sub>',
    '',
    '',
    'UHMOZKUUXAVADP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C813OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C813OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C813OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C813OOH',
    'C<sub>8</sub>H<sub>14</sub>O<sub>6</sub>',
    '',
    '',
    'FNGYAHKKJFMZCA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C813OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C813OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C813OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C825CO',
    'C<sub>8</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'PGSQVIJDIYGHPF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C825CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C825CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C825CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HOPINONIC',
    'C<sub>10</sub>H<sub>16</sub>O<sub>4</sub>',
    '',
    '',
    'MZHKOIVHCBFXJV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOPINONIC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOPINONIC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOPINONIC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1211OH',
    'C<sub>12</sub>H<sub>20</sub>O<sub>4</sub>',
    '',
    '',
    'JNTJQAWMLAKHDW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1211OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1211OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1211OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1212OH',
    'C<sub>12</sub>H<sub>20</sub>O<sub>5</sub>',
    '',
    '',
    'OINCQTVJDDDYTJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1212OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1212OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1212OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1212OOH',
    'C<sub>12</sub>H<sub>20</sub>O<sub>6</sub>',
    '',
    '',
    'KZNQDAPBLSOIIR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1212OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1212OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1212OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1213CO',
    'C<sub>12</sub>H<sub>18</sub>O<sub>6</sub>',
    '',
    '',
    'IKFUCIVDZJUENZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>12</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1213CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>12</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1213CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1213CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1213OH',
    'C<sub>12</sub>H<sub>20</sub>O<sub>6</sub>',
    '',
    '',
    'DPGLQQDGNMDAAZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>12</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1213OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1213OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1213OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1213OOH',
    'C<sub>12</sub>H<sub>20</sub>O<sub>7</sub>',
    '',
    '',
    'ZUGVXCQEOPRNFT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>14</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1213OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>13</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1213OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1213OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1310CO',
    'C<sub>13</sub>H<sub>20</sub>O<sub>5</sub>',
    '',
    '',
    'NHYXXXJOGAKHPV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1310CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1310CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1310CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1310OH',
    'C<sub>13</sub>H<sub>22</sub>O<sub>5</sub>',
    '',
    '',
    'PXEJSKZGVMTSCR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1310OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1310OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1310OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1310OOH',
    'C<sub>13</sub>H<sub>22</sub>O<sub>6</sub>',
    '',
    '',
    'HXUMLFGRLLCICH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1310OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>12</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1310OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1310OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C147OH',
    'C<sub>14</sub>H<sub>22</sub>O<sub>5</sub>',
    '',
    '',
    'IPYASLZXSQHCRG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C147OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C147OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C147OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C151OH',
    'C<sub>15</sub>H<sub>26</sub>O<sub>5</sub>',
    '',
    '',
    'RRTATIWWWPYIIC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C151OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C151OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C151OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C151OOH',
    'C<sub>15</sub>H<sub>26</sub>O<sub>6</sub>',
    '',
    '',
    'FDHNLWUJMDRLQD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C151OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C151OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C151OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO13C3CO2H',
    'C<sub>4</sub>H<sub>4</sub>O<sub>4</sub>',
    '',
    '',
    'YEZSWHPLZBZVLH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO13C3CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO13C3CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO13C3CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C512CO2H',
    'C<sub>6</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'CGRSCFNOTZUXCX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C512CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C512CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C512CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6COALCO2H',
    'C<sub>6</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'TWNJAPRLIZAXHA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6COALCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6COALCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6COALCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C617CO2H',
    'C<sub>7</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'ZXMACHDUAJJJBQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C617CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C617CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C617CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C618CO2H',
    'C<sub>7</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'MXMJWVQRGMMLRI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C618CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C618CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C618CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C626CO2H',
    'C<sub>7</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'JCTYMUINHXVDEP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C626CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C626CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C626CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C732CO',
    'C<sub>7</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'ATXVRLJHWCSFDB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C732CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C732CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C732CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C718CO2H',
    'C<sub>8</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'OBYKYHDGLQUNDK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C718CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C718CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C718CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C731CO2H',
    'C<sub>8</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'URWVDUFOGQNELZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C731CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C731CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C731CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C87CO2H',
    'C<sub>9</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'GZPOIVSRXTZTQZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C87CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C87CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C87CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C116CO2H',
    'C<sub>12</sub>H<sub>18</sub>O<sub>4</sub>',
    '',
    '',
    'HWWVGCXKFWUOCT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C116CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C116CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C116CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1211CO',
    'C<sub>12</sub>H<sub>18</sub>O<sub>4</sub>',
    '',
    '',
    'VVPUYBXPESADLR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1211CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1211CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1211CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1210CO2H',
    'C<sub>13</sub>H<sub>20</sub>O<sub>4</sub>',
    '',
    '',
    'MERIWEKKXYNSHZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Carboxylic acids (RCOOH) and peroxy carboxylic acids (RCOOOH)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1210CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1210CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1210CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Esters (RCOOR)',
    (SELECT id from categories WHERE catname='Organic species with oxygen (O)'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3-dioxolan-2-one',
    'C<sub>3</sub>H<sub>4</sub>O<sub>3</sub>',
    'ethylene carbonate',
    '96-49-1',
    'KMTRUDSVKNLOMY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dioxolan-2-one'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'carbonic acid, dimethyl ester',
    'C<sub>3</sub>H<sub>6</sub>O<sub>3</sub>',
    'dimethyl carbonate',
    '616-38-6',
    'IEJIGPNLZYLLBP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '4900',
    'L',
    (SELECT id from species WHERE iupac='carbonic acid, dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '4900',
    'L',
    (SELECT id from species WHERE iupac='carbonic acid, dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '5000',
    'L',
    (SELECT id from species WHERE iupac='carbonic acid, dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '4900',
    'M',
    (SELECT id from species WHERE iupac='carbonic acid, dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3302'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '5000',
    'V',
    (SELECT id from species WHERE iupac='carbonic acid, dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3523'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='carbonic acid, dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='carbonic acid, dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='carbonic acid, dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='carbonic acid, dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimethyl dicarbonate',
    'C<sub>4</sub>H<sub>6</sub>O<sub>5</sub>',
    '',
    '4525-33-1',
    'GZDFHIJNHHMENY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl dicarbonate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'carbonic acid, diethyl ester',
    'C<sub>5</sub>H<sub>10</sub>O<sub>3</sub>',
    'diethyl carbonate',
    '105-58-8',
    'OIFBSDVPJOWBCH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '6000',
    'L',
    (SELECT id from species WHERE iupac='carbonic acid, diethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '6000',
    'L',
    (SELECT id from species WHERE iupac='carbonic acid, diethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '6400',
    'L',
    (SELECT id from species WHERE iupac='carbonic acid, diethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '6100',
    'M',
    (SELECT id from species WHERE iupac='carbonic acid, diethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3302'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='carbonic acid, diethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='carbonic acid, diethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '6100',
    'V',
    (SELECT id from species WHERE iupac='carbonic acid, diethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3523'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='carbonic acid, diethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='carbonic acid, diethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='carbonic acid, diethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='carbonic acid, diethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='carbonic acid, diethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='carbonic acid, diethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='carbonic acid, diethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='carbonic acid, diethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl methanoate',
    'HCOOCH<sub>3</sub>',
    'methyl formate',
    '107-31-3',
    'TZIHFWKZFHZASV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '4000',
    'L',
    (SELECT id from species WHERE iupac='methyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '4000',
    'L',
    (SELECT id from species WHERE iupac='methyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '3800',
    'L',
    (SELECT id from species WHERE iupac='methyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '4000',
    'L',
    (SELECT id from species WHERE iupac='methyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '3900',
    'L',
    (SELECT id from species WHERE iupac='methyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3616'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '4000',
    'M',
    (SELECT id from species WHERE iupac='methyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2802'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='637'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '4100',
    'M',
    (SELECT id from species WHERE iupac='methyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='640'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4100',
    'Q',
    (SELECT id from species WHERE iupac='methyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4200',
    '?',
    (SELECT id from species WHERE iupac='methyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='510'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'from720',
    '720', 'Pecsar and Martin (1966) are quoted as the source. However, only activity coefficients and no vapor pressures are listed there.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from720'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from720'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyl methanoate',
    'HCOOC<sub>2</sub>H<sub>5</sub>',
    'ethyl formate',
    '109-94-4',
    'WBJINCZRORDGAQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '4600',
    'L',
    (SELECT id from species WHERE iupac='ethyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '4600',
    'L',
    (SELECT id from species WHERE iupac='ethyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '4000',
    'L',
    (SELECT id from species WHERE iupac='ethyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '4600',
    'L',
    (SELECT id from species WHERE iupac='ethyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '4600',
    'L',
    (SELECT id from species WHERE iupac='ethyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3616'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '4600',
    'M',
    (SELECT id from species WHERE iupac='ethyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2802'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3635'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at303K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '4600',
    'M',
    (SELECT id from species WHERE iupac='ethyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='640'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at291K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='637'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propyl methanoate',
    'HCOOC<sub>3</sub>H<sub>7</sub>',
    'propyl formate',
    '110-74-7',
    'KFNNIILCVOLYIR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '5100',
    'L',
    (SELECT id from species WHERE iupac='propyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '5100',
    'L',
    (SELECT id from species WHERE iupac='propyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '4800',
    'L',
    (SELECT id from species WHERE iupac='propyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '5100',
    'L',
    (SELECT id from species WHERE iupac='propyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '4900',
    'L',
    (SELECT id from species WHERE iupac='propyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3616'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '5100',
    'M',
    (SELECT id from species WHERE iupac='propyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2802'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='propyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'isopropyl methanoate',
    'HCOOC<sub>3</sub>H<sub>7</sub>',
    'isopropyl formate',
    '625-55-8',
    'RMOUBSOVHSONPZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='isopropyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3616'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='isopropyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='isopropyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isopropyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isopropyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isopropyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isopropyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isopropyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isopropyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isopropyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isopropyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-Test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isopropyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isopropyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isopropyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='isopropyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'butyl methanoate',
    'HCOOC<sub>4</sub>H<sub>9</sub>',
    'butyl formate',
    '592-84-7',
    'NMJJFJNHVMGPGM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '3700',
    'L',
    (SELECT id from species WHERE iupac='butyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='butyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3616'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='butyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='butyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at300K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='butyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at300K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(1-methylpropyl)-methanoate',
    'C<sub>5</sub>H<sub>10</sub>O<sub>2</sub>',
    '<i>sec</i>-butyl formate',
    '589-40-2',
    'OAEQYDZVVPONKW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(1-methylpropyl)-methanoate'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(2-methylpropyl)-methanoate',
    'HCOOC<sub>4</sub>H<sub>9</sub>',
    'isobutyl formate',
    '542-55-2',
    'AVMSWPWPYJVYKY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '5200',
    'L',
    (SELECT id from species WHERE iupac='(2-methylpropyl)-methanoate'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '5200',
    'L',
    (SELECT id from species WHERE iupac='(2-methylpropyl)-methanoate'),
    (SELECT id from literature WHERE bibtexkey='3616'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(2-methylpropyl)-methanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(2-methylpropyl)-methanoate'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(2-methylpropyl)-methanoate'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(2-methylpropyl)-methanoate'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='(2-methylpropyl)-methanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2-methylpropyl)-methanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2-methylpropyl)-methanoate'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2-methylpropyl)-methanoate'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2-methylpropyl)-methanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2-methylpropyl)-methanoate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2-methylpropyl)-methanoate'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2-methylpropyl)-methanoate'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2-methylpropyl)-methanoate'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2-methylpropyl)-methanoate'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2-methylpropyl)-methanoate'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(2-methylpropyl)-methanoate'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(2-methylpropyl)-methanoate'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(1,1-dimethylethyl)-methanoate',
    'HCOOC<sub>4</sub>H<sub>9</sub>',
    '<i>tert</i>-butyl formate; TBF',
    '762-75-4',
    'RUPAXCPQAAOIPB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '3600',
    'L',
    (SELECT id from species WHERE iupac='(1,1-dimethylethyl)-methanoate'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '3600',
    'M',
    (SELECT id from species WHERE iupac='(1,1-dimethylethyl)-methanoate'),
    (SELECT id from literature WHERE bibtexkey='2646'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='(1,1-dimethylethyl)-methanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='(1,1-dimethylethyl)-methanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(1,1-dimethylethyl)-methanoate'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(1,1-dimethylethyl)-methanoate'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(1,1-dimethylethyl)-methanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(1,1-dimethylethyl)-methanoate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(1,1-dimethylethyl)-methanoate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(1,1-dimethylethyl)-methanoate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(1,1-dimethylethyl)-methanoate'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(1,1-dimethylethyl)-methanoate'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(1,1-dimethylethyl)-methanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pentyl methanoate',
    'C<sub>6</sub>H<sub>12</sub>O<sub>2</sub>',
    'pentyl formate',
    '638-49-3',
    'DIQMPQMYFZXDAX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '6000',
    'L',
    (SELECT id from species WHERE iupac='pentyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '5800',
    'L',
    (SELECT id from species WHERE iupac='pentyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3616'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='pentyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pentyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-pentyl methanoate',
    'C<sub>6</sub>H<sub>12</sub>O<sub>2</sub>',
    '3-pentyl formate',
    '58368-67-5',
    'YMJOAYHERILFIM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-pentyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1-dimethylpropyl methanoate',
    'C<sub>6</sub>H<sub>12</sub>O<sub>2</sub>',
    '1,1-dimethylpropyl formate',
    '757-88-0',
    'SVZIJXUUTNJSEJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,1-dimethylpropyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dimethylpropyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dimethylpropyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-dimethylpropyl methanoate',
    'C<sub>6</sub>H<sub>12</sub>O<sub>2</sub>',
    '1,2-dimethylpropyl formate',
    '66794-46-5',
    'XEQSPMCNFJQDHU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,2-dimethylpropyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethylpropyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethylpropyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methylbutyl methanoate',
    'C<sub>6</sub>H<sub>12</sub>O<sub>2</sub>',
    '1-methylbutyl formate',
    '58368-66-4',
    'JNRQSKFTIYCDIP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-methylbutyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methylbutyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methylbutyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dimethylpropyl methanoate',
    'C<sub>6</sub>H<sub>12</sub>O<sub>2</sub>',
    '2,2-dimethylpropyl formate',
    '23361-67-3',
    'DGMIPKNXUDSQGI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2-dimethylpropyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylpropyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylpropyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methylbutyl methanoate',
    'C<sub>6</sub>H<sub>12</sub>O<sub>2</sub>',
    '2-methylbutyl formate',
    '35073-27-9',
    'DWORILFBIRYUDC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methylbutyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbutyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbutyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methylbutyl methanoate',
    'HCOOC<sub>5</sub>H<sub>11</sub>',
    'isoamyl formate',
    '110-45-2',
    'XKYICAQFSCFURC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '5700',
    'L',
    (SELECT id from species WHERE iupac='3-methylbutyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3616'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-methylbutyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methylbutyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-methylbutyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-methylbutyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hexyl methanoate',
    'C<sub>7</sub>H<sub>14</sub>O<sub>2</sub>',
    'hexyl formate',
    '629-33-4',
    'OUGPMNMLWKSBRI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='hexyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3616'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='hexyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'heptyl methanoate',
    'C<sub>8</sub>H<sub>16</sub>O<sub>2</sub>',
    'heptyl formate',
    '112-23-2',
    'XEAMDSXSXYAICO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='heptyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'octyl methanoate',
    'C<sub>9</sub>H<sub>18</sub>O<sub>2</sub>',
    'octyl formate',
    '112-32-3',
    'AVBRYQRTMPHARE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='octyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='octyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nonyl methanoate',
    'C<sub>10</sub>H<sub>20</sub>O<sub>2</sub>',
    'nonyl formate',
    '5451-92-3',
    'MOGJOLMSQWGXPA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='nonyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'decyl methanoate',
    'C<sub>11</sub>H<sub>22</sub>O<sub>2</sub>',
    'decyl formate',
    '5451-52-5',
    'BCLJZFLDSCTULJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='decyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'undecyl methanoate',
    'C<sub>12</sub>H<sub>24</sub>O<sub>2</sub>',
    'undecyl formate',
    '5454-24-0',
    'OASFNORBKVGDRW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='undecyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='undecyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='undecyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dodecyl methanoate',
    'C<sub>13</sub>H<sub>26</sub>O<sub>2</sub>',
    'dodecyl formate',
    '28303-42-6',
    'WPSGFSPBRBRLIQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dodecyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dodecyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'vinyl methanoate',
    'C<sub>3</sub>H<sub>4</sub>O<sub>2</sub>',
    'vinyl formate',
    '692-45-5',
    'GFJVXXWOPWLRNU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='vinyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='vinyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='vinyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='vinyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benzyl methanoate',
    'C<sub>8</sub>H<sub>8</sub>O<sub>2</sub>',
    'benzyl formate',
    '104-57-4',
    'UYWQUFXKFGHYNT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '7100',
    'L',
    (SELECT id from species WHERE iupac='benzyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl ethanoate',
    'CH<sub>3</sub>COOCH<sub>3</sub>',
    'methyl acetate',
    '79-20-9',
    'KXKVLQRXCPHEJC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;2</sup>',
    '5900',
    'L',
    (SELECT id from species WHERE iupac='methyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3500-79-20-9-consicheck',
    '3500', 'The H298 and A, B, C data listed in Table&nbsp;5-4 of Burkholder et&nbsp;al. (2019) are inconsistent, with 6&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3500-79-20-9-consicheck'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '5000',
    'L',
    (SELECT id from species WHERE iupac='methyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3245-79-20-9',
    '3245', 'The formula of methyl ethanoate is incorrectly given as "CH<sub>3</sub>C(O)CH<sub>3</sub>" by Burkholder et&nbsp;al. (2015).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3245-79-20-9'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3245-79-20-9-consicheck',
    '3245', 'The H298 and A, B data listed in Table&nbsp;5-4 of Burkholder et&nbsp;al. (2015) are inconsistent, with 74&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3245-79-20-9-consicheck'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;2</sup>',
    '5900',
    'L',
    (SELECT id from species WHERE iupac='methyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;2</sup>',
    '4800',
    'L',
    (SELECT id from species WHERE iupac='methyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3616'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;2</sup>',
    '4900',
    'M',
    (SELECT id from species WHERE iupac='methyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3093'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '7500',
    'M',
    (SELECT id from species WHERE iupac='methyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;2</sup>',
    '4500',
    'M',
    (SELECT id from species WHERE iupac='methyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2646'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;2</sup>',
    '4900',
    'M',
    (SELECT id from species WHERE iupac='methyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3609'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3631'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3640'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;2</sup>',
    '5000',
    'M',
    (SELECT id from species WHERE iupac='methyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='628'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '628',
    '3588', 'The same data were also published in Kieckbusch and King (1979a).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='628'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='754'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='713'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;2</sup>',
    '4800',
    'M',
    (SELECT id from species WHERE iupac='methyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3641'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '3300',
    'V',
    (SELECT id from species WHERE iupac='methyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3638'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '4800',
    'T',
    (SELECT id from species WHERE iupac='methyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2016'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2016'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4500',
    'Q',
    (SELECT id from species WHERE iupac='methyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4900',
    '?',
    (SELECT id from species WHERE iupac='methyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyl ethanoate',
    'CH<sub>3</sub>COOC<sub>2</sub>H<sub>5</sub>',
    'ethyl acetate',
    '141-78-6',
    'XEKOWRVHYACXOJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;2</sup>',
    '5600',
    'L',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3500-141-78-6-consicheck',
    '3500', 'The H298 and A, B, C data listed in Table&nbsp;5-4 of Burkholder et&nbsp;al. (2019) are inconsistent, with 7&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3500-141-78-6-consicheck'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;2</sup>',
    '5900',
    'L',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;2</sup>',
    '5600',
    'L',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;2</sup>',
    '5900',
    'L',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;2</sup>',
    '5500',
    'L',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3616'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;2</sup>',
    '5200',
    'M',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3507'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '4800',
    'M',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3788'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '5500',
    'M',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3093'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2371'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;2</sup>',
    '5900',
    'M',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2802'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3643'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3670'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3670'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3611'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='1107'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1107notused'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3645'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3646'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3647'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3631'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '3900',
    'M',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='857'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='857'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3648'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2924'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3649'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3635'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at303K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3640'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '5300',
    'M',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='628'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='628'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2387'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at301K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='713'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3642'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '5700',
    'X',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='1154'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3644'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4800',
    'Q',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5200',
    '?',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='637'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyl ethanoate-1-13C',
    'CH<sub>3</sub>COOC<sub>2</sub>H<sub>5</sub>',
    'ethyl acetate-1-13C',
    '3424-59-7',
    'XEKOWRVHYACXOJ-AZXPZELESA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;2</sup>',
    '6500',
    'M',
    (SELECT id from species WHERE iupac='ethyl ethanoate-1-13C'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propyl ethanoate',
    'CH<sub>3</sub>COOC<sub>3</sub>H<sub>7</sub>',
    'propyl acetate',
    '109-60-4',
    'YKYONYBAUNKHLG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '6100',
    'L',
    (SELECT id from species WHERE iupac='propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3500-109-60-4',
    '3500', 'The formula of propyl ethanoate is incorrectly given as "CH<sub>3</sub>C(O)C<sub>3</sub>H<sub>8</sub>" by Burkholder et&nbsp;al. (2019).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3500-109-60-4'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '6000',
    'L',
    (SELECT id from species WHERE iupac='propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '5900',
    'L',
    (SELECT id from species WHERE iupac='propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3616'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '5900',
    'M',
    (SELECT id from species WHERE iupac='propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3093'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3643'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3670'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3670'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3611'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3646'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3631'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3635'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at303K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '5500',
    'M',
    (SELECT id from species WHERE iupac='propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='628'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='628'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='713'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '6000',
    'X',
    (SELECT id from species WHERE iupac='propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='1154'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl methoxyacetate',
    'C<sub>4</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '6290-49-9',
    'QRMHDGWGLNLHMN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'M',
    (SELECT id from species WHERE iupac='methyl methoxyacetate'),
    (SELECT id from literature WHERE bibtexkey='3609'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at303K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-propenyl ethanoate',
    'C<sub>5</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '591-87-7',
    'FWZUNOYOVVKUNF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-propenyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propenyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propenyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propenyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propenyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propenyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-propyl ethanoate',
    'CH<sub>3</sub>COOC<sub>3</sub>H<sub>7</sub>',
    'isopropyl acetate',
    '108-21-4',
    'JMMWKPVZQRWMSS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '6100',
    'L',
    (SELECT id from species WHERE iupac='2-propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '5600',
    'L',
    (SELECT id from species WHERE iupac='2-propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3616'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3631'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '5500',
    'X',
    (SELECT id from species WHERE iupac='2-propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='1154'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-Test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methoxyethyl ethanoate',
    'C<sub>5</sub>H<sub>10</sub>O<sub>3</sub>',
    'methyl cellosolve acetate',
    '110-49-6',
    'XLLIQLLCWZCATF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methoxyethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3609'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at303K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methoxyethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'glycerol monoacetate',
    'C<sub>5</sub>H<sub>10</sub>O<sub>4</sub>',
    'acetin',
    '26446-35-5',
    'KMZHZAAOEWVPSE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='glycerol monoacetate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-propen-2-ol, acetate',
    'C<sub>5</sub>H<sub>8</sub>O<sub>2</sub>',
    'isopropenyl acetate',
    '108-22-5',
    'HETCEOQFVDFGSY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-propen-2-ol, acetate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'butyl ethanoate',
    'CH<sub>3</sub>COOC<sub>4</sub>H<sub>9</sub>',
    'butyl acetate',
    '123-86-4',
    'DKPFZGUDAPQIHT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '6300',
    'L',
    (SELECT id from species WHERE iupac='butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '6300',
    'L',
    (SELECT id from species WHERE iupac='butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3616'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3032'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '6300',
    'M',
    (SELECT id from species WHERE iupac='butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3093'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2955'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3643'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3670'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3670'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3611'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3646'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3631'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '4300',
    'M',
    (SELECT id from species WHERE iupac='butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='857'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='857'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '7100',
    'M',
    (SELECT id from species WHERE iupac='butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3640'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '6000',
    'M',
    (SELECT id from species WHERE iupac='butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='628'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='628'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '7500',
    'X',
    (SELECT id from species WHERE iupac='butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='1154'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '3200',
    'X',
    (SELECT id from species WHERE iupac='butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5500',
    'Q',
    (SELECT id from species WHERE iupac='butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-P'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5300',
    '?',
    (SELECT id from species WHERE iupac='butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-butyl ethanoate',
    'C<sub>6</sub>H<sub>12</sub>O<sub>2</sub>',
    '<i>sec</i>-butyl acetate',
    '105-46-4',
    'DCKVNWZUADLDEH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '6000',
    'L',
    (SELECT id from species WHERE iupac='2-butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '6200',
    'L',
    (SELECT id from species WHERE iupac='2-butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3616'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3764dupl',
    '3764', 'Katritzky et&nbsp;al. (1998) list this species twice in their table, with different values. As it is unclear which of them is correct, the data are not reproduced here.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3764dupl'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-butyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1-dimethylethyl ethanoate',
    'C<sub>6</sub>H<sub>12</sub>O<sub>2</sub>',
    '<i>tert</i>-butyl acetate',
    '540-88-5',
    'WMOVHXAZOJBABW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '6100',
    'L',
    (SELECT id from species WHERE iupac='1,1-dimethylethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '5600',
    'L',
    (SELECT id from species WHERE iupac='1,1-dimethylethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3616'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1-dimethylethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,1-dimethylethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,1-dimethylethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dimethylethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dimethylethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dimethylethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dimethylethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dimethylethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dimethylethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dimethylethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dimethylethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dimethylethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dimethylethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1-dimethylethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methylpropyl ethanoate',
    'CH<sub>3</sub>COOC<sub>4</sub>H<sub>9</sub>',
    'isobutyl acetate',
    '110-19-0',
    'GJRQTCIYDGXPES-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '6000',
    'L',
    (SELECT id from species WHERE iupac='2-methylpropyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '6200',
    'L',
    (SELECT id from species WHERE iupac='2-methylpropyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3616'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methylpropyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3631'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylpropyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylpropyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylpropyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methylpropyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methylpropyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5500',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methylpropyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4600',
    '?',
    (SELECT id from species WHERE iupac='2-methylpropyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methylpropyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methylpropyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pentyl ethanoate',
    'CH<sub>3</sub>COOC<sub>5</sub>H<sub>11</sub>',
    'amyl acetate',
    '628-63-7',
    'PGMYKACGEOXYJE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '7200',
    'L',
    (SELECT id from species WHERE iupac='pentyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '6700',
    'L',
    (SELECT id from species WHERE iupac='pentyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3616'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '5000',
    'M',
    (SELECT id from species WHERE iupac='pentyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3650'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at303K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='pentyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3631'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='pentyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2448'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '6500',
    'M',
    (SELECT id from species WHERE iupac='pentyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='628'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='628'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pentyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pentyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pentyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='pentyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='pentyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='pentyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3650'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2531'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pentyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pentyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pentyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methylbutyl ethanoate',
    'C<sub>7</sub>H<sub>14</sub>O<sub>2</sub>',
    '2-methylbutyl acetate',
    '624-41-9',
    'XHIUFYZDQBSEMF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methylbutyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbutyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbutyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-dimethylpropyl ethanoate',
    'C<sub>7</sub>H<sub>14</sub>O<sub>2</sub>',
    '1,2-dimethylpropyl acetate',
    '5343-96-4',
    'ZLSXRPTWWRGMTJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,2-dimethylpropyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethylpropyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethylpropyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-ethylpropyl ethanoate',
    'C<sub>7</sub>H<sub>14</sub>O<sub>2</sub>',
    '1-ethylpropyl acetate',
    '620-11-1',
    'PBKYSIMDORTIEU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethylpropyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1-dimethylpropyl ethanoate',
    'C<sub>7</sub>H<sub>14</sub>O<sub>2</sub>',
    '<i>tert</i>-pentyl acetate',
    '625-16-1',
    'JCCIFDCPHCKATH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,1-dimethylpropyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,1-dimethylpropyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dimethylpropyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dimethylpropyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dimethylpropyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dimethylpropyl ethanoate',
    'C<sub>7</sub>H<sub>14</sub>O<sub>2</sub>',
    'neopentyl acetate',
    '926-41-0',
    'QLNYTCSELYEEPV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2-dimethylpropyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethylpropyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-propanediol, diacetate',
    'C<sub>7</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '623-84-7',
    'MLHOXUWWKVQEJB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-propanediol, diacetate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-pentanol, acetate',
    'C<sub>7</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '626-38-0',
    'GQKZRWSUJHVIPE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentanol, acetate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentanol, acetate'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methylbutyl ethanoate',
    'CH<sub>3</sub>COOC<sub>5</sub>H<sub>11</sub>',
    'isoamyl acetate',
    '123-92-2',
    'MLFHJEHSLIIPHL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '6700',
    'L',
    (SELECT id from species WHERE iupac='3-methylbutyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '6500',
    'L',
    (SELECT id from species WHERE iupac='3-methylbutyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3616'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '6600',
    'M',
    (SELECT id from species WHERE iupac='3-methylbutyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3788'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;2</sup>',
    '4300',
    'M',
    (SELECT id from species WHERE iupac='3-methylbutyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3650'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at303K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3-methylbutyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3631'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-methylbutyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-methylbutyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-methylbutyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-methylbutyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methylbutyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '5000',
    'X',
    (SELECT id from species WHERE iupac='3-methylbutyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='3-methylbutyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3650'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3521'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbutyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-methylbutyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-methylbutyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-methylbutyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hexyl ethanoate',
    'CH<sub>3</sub>COOC<sub>6</sub>H<sub>13</sub>',
    'hexyl acetate',
    '142-92-7',
    'AOGQPLXWSUTHQB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '7100',
    'L',
    (SELECT id from species WHERE iupac='hexyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3518-142-92-7-consicheck',
    '3518', 'Values at 298&nbsp;K in Tables&nbsp;C2 and C5 of Brockbank (2013) are inconsistent, with 5&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3518-142-92-7-consicheck'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '7300',
    'L',
    (SELECT id from species WHERE iupac='hexyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3616'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='hexyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3671'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='hexyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='1922'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='hexyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='hexyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='hexyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='hexyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='hexyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-2-pentyl ethanoate',
    'C<sub>8</sub>H<sub>16</sub>O<sub>2</sub>',
    '4-methyl-2-pentyl acetate',
    '108-84-9',
    'CPIVYSAVIPTCCX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-methyl-2-pentyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-pentyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-pentyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-pentyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-pentyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-pentyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-pentyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-pentyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cyclohexyl ethanoate',
    'C<sub>8</sub>H<sub>14</sub>O<sub>2</sub>',
    'cyclohexyl acetate',
    '622-45-7',
    'YYLLIJHXUHJATK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '7000',
    'L',
    (SELECT id from species WHERE iupac='cyclohexyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3518-622-45-7-consicheck',
    '3518', 'Values at 298&nbsp;K in Tables&nbsp;C2 and C5 of Brockbank (2013) are inconsistent, with 6&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3518-622-45-7-consicheck'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethanol, 2-(2-ethoxyethoxy)-, acetate',
    'C<sub>8</sub>H<sub>16</sub>O<sub>4</sub>',
    'diethylene glycol monoethyl ether acetate',
    '112-15-2',
    'FPZWZCWUIYYYBU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethanol, 2-(2-ethoxyethoxy)-, acetate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phenyl ethanoate',
    'C<sub>8</sub>H<sub>8</sub>O<sub>2</sub>',
    'phenyl acetate',
    '122-79-2',
    'IPBVNPXQWQGGJP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '7200',
    'L',
    (SELECT id from species WHERE iupac='phenyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'heptyl ethanoate',
    'C<sub>9</sub>H<sub>18</sub>O<sub>2</sub>',
    'heptyl acetate',
    '112-06-1',
    'ZCZSIDMEHXZRLG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='heptyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='heptyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='heptyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3518-112-06-1',
    '', 'The value listed as A for n-heptyl acetate is probably not A but the Henry''s law volatility constant H<sub>v</sub><sup>px</sup> at 298&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3518-112-06-1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phenylmethyl ethanoate',
    'C<sub>9</sub>H<sub>10</sub>O<sub>2</sub>',
    'benzyl acetate',
    '140-11-4',
    'QUKGYYKBILRGFE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;1</sup>',
    '6800',
    'L',
    (SELECT id from species WHERE iupac='phenylmethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='phenylmethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='phenylmethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenylmethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenylmethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenylmethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenylmethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenylmethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'octyl ethanoate',
    'CH<sub>3</sub>COOC<sub>8</sub>H<sub>17</sub>',
    'octyl acetate',
    '112-14-1',
    'YLYBTZIQSIBWLI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='octyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='octyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='octyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3518-112-14-1',
    '', 'The value listed as A for n-octyl acetate is probably not A but the Henry''s law volatility constant H<sub>v</sub><sup>px</sup> at 298&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3518-112-14-1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-ethylhexyl ethanoate',
    'C<sub>10</sub>H<sub>20</sub>O<sub>2</sub>',
    '2-ethylhexyl acetate',
    '103-09-3',
    'WOYWLLHHWAMFCB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-ethylhexyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-ethylhexyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-ethylhexyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylhexyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylhexyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylhexyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylhexyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-ethylhexyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nonyl ethanoate',
    'C<sub>11</sub>H<sub>22</sub>O<sub>2</sub>',
    'nonyl acetate',
    '143-13-5',
    'GJQIMXVRFNLMTB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='nonyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'decyl ethanoate',
    'C<sub>12</sub>H<sub>24</sub>O<sub>2</sub>',
    'decyl acetate',
    '112-17-4',
    'NUPSHWCALHZGOV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='decyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'undecyl ethanoate',
    'C<sub>13</sub>H<sub>26</sub>O<sub>2</sub>',
    'undecyl acetate',
    '1731-81-3',
    'CKQGCFFDQIFZFA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='undecyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethanol, 2,2''-[1,2-ethanediylbis(oxy)]bis-, diacetate',
    'C<sub>10</sub>H<sub>18</sub>O<sub>6</sub>',
    'triethylene glycol, diacetate',
    '111-21-7',
    'OVOUKWFJRHALDD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanol, 2,2''-[1,2-ethanediylbis(oxy)]bis-, diacetate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methoxy-2-propyl ethanoate',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '1-methoxy-2-propyl acetate',
    '108-65-6',
    'LLHKCFNBLRBOGN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-methoxy-2-propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methoxy-2-propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methoxy-2-propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methoxy-2-propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methoxy-2-propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methoxy-2-propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methoxy-2-propyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-ethoxyethyl ethanoate',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '2-ethoxyethyl acetate',
    '111-15-9',
    'SVONRAPFKPVNKG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '',
    'L',
    (SELECT id from species WHERE iupac='2-ethoxyethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-ethoxyethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3609'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at303K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-ethoxyethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3079'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethoxyethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethoxyethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethoxyethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethoxyethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethoxyethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethoxyethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethoxyethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-ethoxyethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-ethoxyethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-butoxyethyl ethanoate',
    'C<sub>8</sub>H<sub>16</sub>O<sub>3</sub>',
    'butyl cellosolve acetate',
    '112-07-2',
    'NQBXSWAWVZHKBZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'L',
    (SELECT id from species WHERE iupac='2-butoxyethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '25000',
    'M',
    (SELECT id from species WHERE iupac='2-butoxyethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2837'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butoxyethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butoxyethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butoxyethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butoxyethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butoxyethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butoxyethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butoxyethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-butoxyethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-(2-butoxyethoxy)-ethanol, ethanoate',
    'C<sub>10</sub>H<sub>20</sub>O<sub>4</sub>',
    '',
    '124-17-4',
    'VXQBJTKSVGFQOL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-(2-butoxyethoxy)-ethanol, ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-(2-butoxyethoxy)-ethanol, ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(2-butoxyethoxy)-ethanol, ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(2-butoxyethoxy)-ethanol, ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(2-butoxyethoxy)-ethanol, ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(2-butoxyethoxy)-ethanol, ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(2-butoxyethoxy)-ethanol, ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(2-butoxyethoxy)-ethanol, ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-ethanediol, diethanoate',
    'C<sub>6</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '111-55-7',
    'JTXMVXSTHSMVQF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-ethanediol, diethanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-ethanediol, diethanoate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,2-ethanediol, diethanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-ethanediol, diethanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-ethanediol, diethanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-ethanediol, diethanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-ethanediol, diethanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-ethanediol, diethanoate'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-ethanediol, diethanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-ethanediol, diethanoate'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'geranyl acetate',
    'C<sub>12</sub>H<sub>20</sub>O<sub>2</sub>',
    '',
    '105-87-3',
    'HIGQPQRQIQDZMP-DHZHZOJOSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='geranyl acetate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'linalyl acetate',
    'C<sub>12</sub>H<sub>20</sub>O<sub>2</sub>',
    '',
    '115-95-7',
    'UWKAYLJWKGQEPM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='linalyl acetate'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='linalyl acetate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cyclohexanol, 5-methyl-2-(1-methylethyl)-, acetate',
    'C<sub>12</sub>H<sub>22</sub>O<sub>2</sub>',
    'menthyl acetate',
    '16409-45-3',
    'XHXUANMFYXWVNG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexanol, 5-methyl-2-(1-methylethyl)-, acetate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl propanoate',
    'C<sub>2</sub>H<sub>5</sub>COOCH<sub>3</sub>',
    'methyl propionate',
    '554-12-1',
    'RJUFJBKOKNCXHH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '5700',
    'L',
    (SELECT id from species WHERE iupac='methyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '5400',
    'L',
    (SELECT id from species WHERE iupac='methyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='3616'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='3640'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='754'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '3900',
    'V',
    (SELECT id from species WHERE iupac='methyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='3638'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;2</sup>',
    '5400',
    'T',
    (SELECT id from species WHERE iupac='methyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='2016'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2016'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '5000',
    '?',
    (SELECT id from species WHERE iupac='methyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='510'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '510mepr',
    '510,628', 'Betterton (1992) gives Kieckbusch and King (1979b) as the source. However, no data were found in that reference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='510mepr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl 2-hydroxypropanoate',
    'C<sub>4</sub>H<sub>8</sub>O<sub>3</sub>',
    'methyl lactate',
    '547-64-8',
    'LPEKGGXMPWTOCB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1',
    '5000',
    'M',
    (SELECT id from species WHERE iupac='methyl 2-hydroxypropanoate'),
    (SELECT id from literature WHERE bibtexkey='3214'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl 2-hydroxypropanoate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl 2-hydroxypropanoate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl 2-hydroxypropanoate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl 2-hydroxypropanoate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyl propanoate',
    'C<sub>2</sub>H<sub>5</sub>COOC<sub>2</sub>H<sub>5</sub>',
    'ethyl propionate',
    '105-37-3',
    'FKRCODPIKNYEAC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '5900',
    'L',
    (SELECT id from species WHERE iupac='ethyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '6000',
    'L',
    (SELECT id from species WHERE iupac='ethyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='3616'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '5900',
    'M',
    (SELECT id from species WHERE iupac='ethyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='3093'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propyl propanoate',
    'C<sub>2</sub>H<sub>5</sub>COOC<sub>3</sub>H<sub>7</sub>',
    'propyl propionate',
    '106-36-5',
    'MCSINKKTEDDPNK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '6400',
    'L',
    (SELECT id from species WHERE iupac='propyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3518-106-36-5-consicheck',
    '3518', 'Values at 298&nbsp;K in Tables&nbsp;C2 and C5 of Brockbank (2013) are inconsistent, with 6&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3518-106-36-5-consicheck'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '6200',
    'L',
    (SELECT id from species WHERE iupac='propyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='3616'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-Test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'isopropyl propanoate',
    'C<sub>2</sub>H<sub>5</sub>COOC<sub>3</sub>H<sub>7</sub>',
    'isopropyl propionate',
    '637-78-5',
    'IJMWOMHMDSDKGK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='isopropyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='3616'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='isopropyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='isopropyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='isopropyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isopropyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isopropyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isopropyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isopropyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isopropyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isopropyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='isopropyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'butyl propanoate',
    'C<sub>7</sub>H<sub>14</sub>O<sub>2</sub>',
    'butyl propionate',
    '590-01-2',
    'BTMVHUNTONAYDX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '6900',
    'L',
    (SELECT id from species WHERE iupac='butyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '7000',
    'L',
    (SELECT id from species WHERE iupac='butyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='3616'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='butyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='butyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='butyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(2-methylpropyl)-propanoate',
    'C<sub>7</sub>H<sub>14</sub>O<sub>2</sub>',
    'isobutyl propionate',
    '540-42-1',
    'FZXRXKLUIMKDEL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '6600',
    'L',
    (SELECT id from species WHERE iupac='(2-methylpropyl)-propanoate'),
    (SELECT id from literature WHERE bibtexkey='3616'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(2-methylpropyl)-propanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2-methylpropyl)-propanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2-methylpropyl)-propanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5900',
    'Q',
    (SELECT id from species WHERE iupac='(2-methylpropyl)-propanoate'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2-methylpropyl)-propanoate'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2-methylpropyl)-propanoate'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7300',
    '?',
    (SELECT id from species WHERE iupac='(2-methylpropyl)-propanoate'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>tert</i>-butyl propanoate',
    'C<sub>7</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '20487-40-5',
    'JAELLLITIZHOGQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='<i>tert</i>-butyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pentyl propanoate',
    'C<sub>2</sub>H<sub>5</sub>COOC<sub>5</sub>H<sub>11</sub>',
    'amyl propionate',
    '624-54-4',
    'TWSRVQVEYJNFKQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='pentyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='3616'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pentyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pentyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pentyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pentyl propanoate'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propanoic acid, 2-hydroxy-, ethyl ester',
    'C<sub>5</sub>H<sub>10</sub>O<sub>3</sub>',
    'ethyl lactate',
    '97-64-3',
    'LZCLXQDLBQLTDK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propanoic acid, 2-hydroxy-, ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propanoic acid, 2-hydroxy-, ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanoic acid, 2-hydroxy-, ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyl 3-ethoxypropanoate',
    'C<sub>7</sub>H<sub>14</sub>O<sub>3</sub>',
    'ethyl 3-ethoxypropionate',
    '763-69-9',
    'BHXIWUJLHYHGSJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethyl 3-ethoxypropanoate'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propanoic acid, 2-phenylethyl ester',
    'C<sub>11</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '122-70-3',
    'HVGZQCSMLUDISR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanoic acid, 2-phenylethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl butanoate',
    'C<sub>3</sub>H<sub>7</sub>COOCH<sub>3</sub>',
    'methyl butyrate',
    '623-42-7',
    'UUIQMZJEGPQKFD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '5700',
    'L',
    (SELECT id from species WHERE iupac='methyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3518-623-42-7-consicheck',
    '3518', 'Values at 298&nbsp;K in Tables&nbsp;C2 and C5 of Brockbank (2013) are inconsistent, with 5&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3518-623-42-7-consicheck'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '5700',
    'L',
    (SELECT id from species WHERE iupac='methyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='3616'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='2371'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='3640'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='754'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;1</sup>',
    '4400',
    'V',
    (SELECT id from species WHERE iupac='methyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='3638'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='2388'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5800',
    'T',
    (SELECT id from species WHERE iupac='methyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='2220'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='methyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='3644'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyl butanoate',
    'C<sub>3</sub>H<sub>7</sub>COOC<sub>2</sub>H<sub>5</sub>',
    'ethyl butyrate',
    '105-54-4',
    'OBNCKNCVKJNDBV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '6100',
    'L',
    (SELECT id from species WHERE iupac='ethyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '6300',
    'L',
    (SELECT id from species WHERE iupac='ethyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='3616'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '6400',
    'M',
    (SELECT id from species WHERE iupac='ethyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='3093'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='2371'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='3671'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='3643'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='3670'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3670'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='3611'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='3651'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='3647'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='3642'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='ethyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='3644'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='3521'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='3025'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propyl butanoate',
    'C<sub>3</sub>H<sub>7</sub>COOC<sub>3</sub>H<sub>7</sub>',
    'propyl butyrate',
    '105-66-8',
    'HUAZGNHGCJGYNP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '6400',
    'L',
    (SELECT id from species WHERE iupac='propyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '6600',
    'L',
    (SELECT id from species WHERE iupac='propyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='3616'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='propyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at290K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at290K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-propyl butanoate',
    'C<sub>7</sub>H<sub>14</sub>O<sub>2</sub>',
    'isopropyl butyrate',
    '638-11-9',
    'FFOPEPMHKILNIT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2-propyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='3616'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'butyl butanoate',
    'C<sub>8</sub>H<sub>16</sub>O<sub>2</sub>',
    'butyl butyrate',
    '109-21-7',
    'XUPYJHCZDLZNFP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '7600',
    'L',
    (SELECT id from species WHERE iupac='butyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '7600',
    'L',
    (SELECT id from species WHERE iupac='butyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='3616'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='butyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methylpropyl butanoate',
    'C<sub>8</sub>H<sub>16</sub>O<sub>2</sub>',
    '2-methylpropyl butyrate',
    '539-90-2',
    'RGFNRWTWDWVHDD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methylpropyl 2-methylpropanoate',
    'C<sub>8</sub>H<sub>16</sub>O<sub>2</sub>',
    'isobutyl isobutyrate',
    '97-85-8',
    'RXGUIWHIADMCFC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;3</sup>',
    '6900',
    'L',
    (SELECT id from species WHERE iupac='2-methylpropyl 2-methylpropanoate'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3518-97-85-8-consicheck',
    '3518', 'Values at 298&nbsp;K in Tables&nbsp;C2 and C5 of Brockbank (2013) are inconsistent, with 6&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3518-97-85-8-consicheck'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;3</sup>',
    '6700',
    'L',
    (SELECT id from species WHERE iupac='2-methylpropyl 2-methylpropanoate'),
    (SELECT id from literature WHERE bibtexkey='3616'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methylpropyl 2-methylpropanoate'),
    (SELECT id from literature WHERE bibtexkey='2388'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylpropyl 2-methylpropanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylpropyl 2-methylpropanoate'),
    (SELECT id from literature WHERE bibtexkey='2388'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropyl 2-methylpropanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropyl 2-methylpropanoate'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropyl 2-methylpropanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropyl 2-methylpropanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropyl 2-methylpropanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropyl 2-methylpropanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropyl 2-methylpropanoate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropyl 2-methylpropanoate'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropyl 2-methylpropanoate'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropyl 2-methylpropanoate'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methylpropyl 2-methylpropanoate'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methylpropyl 2-methylpropanoate'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pentyl butanoate',
    'C<sub>9</sub>H<sub>18</sub>O<sub>2</sub>',
    'pentyl butyrate',
    '540-18-1',
    'CFNJLPHOBMVMNS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '6400',
    'L',
    (SELECT id from species WHERE iupac='pentyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methylbutyl butanoate',
    'C<sub>9</sub>H<sub>18</sub>O<sub>2</sub>',
    'isopentyl butyrate',
    '106-27-4',
    'PQLMXFQTAMDXIZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '7500',
    'L',
    (SELECT id from species WHERE iupac='3-methylbutyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl 2-methylpropanoate',
    'C<sub>5</sub>H<sub>10</sub>O<sub>2</sub>',
    'methyl isobutyrate',
    '547-63-7',
    'BHIWKHZACMWKOJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '5600',
    'L',
    (SELECT id from species WHERE iupac='methyl 2-methylpropanoate'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '5500',
    'L',
    (SELECT id from species WHERE iupac='methyl 2-methylpropanoate'),
    (SELECT id from literature WHERE bibtexkey='3616'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '5700',
    'T',
    (SELECT id from species WHERE iupac='methyl 2-methylpropanoate'),
    (SELECT id from literature WHERE bibtexkey='2016'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2016'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5700',
    'T',
    (SELECT id from species WHERE iupac='methyl 2-methylpropanoate'),
    (SELECT id from literature WHERE bibtexkey='2220'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyl 2-methylpropanoate',
    'C<sub>6</sub>H<sub>12</sub>O<sub>2</sub>',
    'ethyl isobutyrate',
    '97-62-1',
    'WDAXFOBOLVPGLV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '6000',
    'L',
    (SELECT id from species WHERE iupac='ethyl 2-methylpropanoate'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '6200',
    'L',
    (SELECT id from species WHERE iupac='ethyl 2-methylpropanoate'),
    (SELECT id from literature WHERE bibtexkey='3616'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl 2-methylpropanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl 2-methylpropanoate'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethyl 2-methylpropanoate'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hexyl butanoate',
    'C<sub>10</sub>H<sub>20</sub>O<sub>2</sub>',
    'hexyl butyrate',
    '2639-63-6',
    'XAPCMTMQBXLDBB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cyclohexyl butanoate',
    'C<sub>10</sub>H<sub>18</sub>O<sub>2</sub>',
    'cyclohexyl butyrate',
    '1551-44-6',
    'VZHUBBUZNIULNM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6500',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5600',
    '?',
    (SELECT id from species WHERE iupac='cyclohexyl butanoate'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-oxobutanoic acid, methyl ester',
    'C<sub>5</sub>H<sub>8</sub>O<sub>3</sub>',
    'methylacetoacetate',
    '105-45-3',
    'WRQNANDWMGAFTP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4',
    '',
    'M',
    (SELECT id from species WHERE iupac='3-oxobutanoic acid, methyl ester'),
    (SELECT id from literature WHERE bibtexkey='3609'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at303K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-oxobutanoic acid, methyl ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-oxobutanoic acid, methyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-oxobutanoic acid, methyl ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-oxobutanoic acid, methyl ester'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-oxobutanoic acid, methyl ester'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-oxobutanoic acid, methyl ester'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-oxobutanoic acid, methyl ester'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-oxobutanoic acid, methyl ester'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-oxobutanoic acid, ethyl ester',
    'C<sub>6</sub>H<sub>10</sub>O<sub>3</sub>',
    'ethylacetoacetate',
    '141-97-9',
    'XYIBRDXRRQCHLP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0',
    '7200',
    'L',
    (SELECT id from species WHERE iupac='3-oxobutanoic acid, ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8',
    '',
    'M',
    (SELECT id from species WHERE iupac='3-oxobutanoic acid, ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3609'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at303K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-oxobutanoic acid, ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-oxobutanoic acid, ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-oxobutanoic acid, ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at290K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-oxobutanoic acid, ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-oxobutanoic acid, ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-oxobutanoic acid, ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-oxobutanoic acid, ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-oxobutanoic acid, ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-oxobutanoic acid, ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-oxobutanoic acid, ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-oxobutanoic acid, ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-oxobutanoic acid, ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at290K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl pentanoate',
    'C<sub>4</sub>H<sub>9</sub>COOCH<sub>3</sub>',
    'methyl valerate',
    '624-24-8',
    'HNBDRPTVWVGKBR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '6100',
    'L',
    (SELECT id from species WHERE iupac='methyl pentanoate'),
    (SELECT id from literature WHERE bibtexkey='3616'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methyl pentanoate'),
    (SELECT id from literature WHERE bibtexkey='754'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;1</sup>',
    '5000',
    'V',
    (SELECT id from species WHERE iupac='methyl pentanoate'),
    (SELECT id from literature WHERE bibtexkey='3638'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6200',
    'T',
    (SELECT id from species WHERE iupac='methyl pentanoate'),
    (SELECT id from literature WHERE bibtexkey='2220'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl pentanoate'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl pentanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl pentanoate'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl pentanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl pentanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl pentanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl pentanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl pentanoate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl pentanoate'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl pentanoate'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl pentanoate'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl pentanoate'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methyl pentanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methyl pentanoate'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyl pentanoate',
    'C<sub>4</sub>H<sub>9</sub>COOC<sub>2</sub>H<sub>5</sub>',
    'ethyl valerate',
    '539-82-2',
    'ICMAFTSLXCXHRK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '6800',
    'L',
    (SELECT id from species WHERE iupac='ethyl pentanoate'),
    (SELECT id from literature WHERE bibtexkey='3616'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '4800',
    'M',
    (SELECT id from species WHERE iupac='ethyl pentanoate'),
    (SELECT id from literature WHERE bibtexkey='3650'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at303K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl pentanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl pentanoate'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl pentanoate'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl pentanoate'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='ethyl pentanoate'),
    (SELECT id from literature WHERE bibtexkey='3650'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl pentanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl pentanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl pentanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl pentanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl pentanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl pentanoate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl pentanoate'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl pentanoate'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl pentanoate'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl pentanoate'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethyl pentanoate'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl 2,2-dimethylpropanoate',
    'C<sub>6</sub>H<sub>12</sub>O<sub>2</sub>',
    'methyl pivalate',
    '598-98-1',
    'CNMFHDIDIMZHKY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;3</sup>',
    '5600',
    'L',
    (SELECT id from species WHERE iupac='methyl 2,2-dimethylpropanoate'),
    (SELECT id from literature WHERE bibtexkey='3616'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '6000',
    'T',
    (SELECT id from species WHERE iupac='methyl 2,2-dimethylpropanoate'),
    (SELECT id from literature WHERE bibtexkey='2016'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2016'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6000',
    'T',
    (SELECT id from species WHERE iupac='methyl 2,2-dimethylpropanoate'),
    (SELECT id from literature WHERE bibtexkey='2220'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl 2,2-dimethylpropanoate'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl 2,2-dimethylpropanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl 2,2-dimethylpropanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl 2,2-dimethylpropanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl 2,2-dimethylpropanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl 2,2-dimethylpropanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl 2,2-dimethylpropanoate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl 2,2-dimethylpropanoate'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl 2,2-dimethylpropanoate'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl 2,2-dimethylpropanoate'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methyl 2,2-dimethylpropanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyl 2-methylbutanoate',
    'C<sub>7</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '7452-79-1',
    'HCRBXQFHJMCTLF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '6700',
    'L',
    (SELECT id from species WHERE iupac='ethyl 2-methylbutanoate'),
    (SELECT id from literature WHERE bibtexkey='3616'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethyl 2-methylbutanoate'),
    (SELECT id from literature WHERE bibtexkey='1923'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethyl 2-methylbutanoate'),
    (SELECT id from literature WHERE bibtexkey='2389'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyl 3-methylbutanoate',
    'C<sub>7</sub>H<sub>14</sub>O<sub>2</sub>',
    'ethyl isovalerate',
    '108-64-5',
    'PPXUHEORWJQRHJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '6500',
    'L',
    (SELECT id from species WHERE iupac='ethyl 3-methylbutanoate'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '6700',
    'L',
    (SELECT id from species WHERE iupac='ethyl 3-methylbutanoate'),
    (SELECT id from literature WHERE bibtexkey='3616'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '5900',
    'M',
    (SELECT id from species WHERE iupac='ethyl 3-methylbutanoate'),
    (SELECT id from literature WHERE bibtexkey='3215'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3215-108-64-5-ABC',
    '3215', 'The data from Wieland et&nbsp;al. (2015) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( 34.46832 +3269.29552/T &#8722;8.76905&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3215-108-64-5-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl 3-methylbutanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl 3-methylbutanoate'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl 3-methylbutanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl 3-methylbutanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl 3-methylbutanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl 3-methylbutanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl 3-methylbutanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl 3-methylbutanoate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl 3-methylbutanoate'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethyl 3-methylbutanoate'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyl 2,2-dimethylpropanoate',
    'C<sub>7</sub>H<sub>14</sub>O<sub>2</sub>',
    'ethyl pivalate',
    '3938-95-2',
    'HHEIMYAXCOIQCJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;3</sup>',
    '6700',
    'L',
    (SELECT id from species WHERE iupac='ethyl 2,2-dimethylpropanoate'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;3</sup>',
    '6100',
    'L',
    (SELECT id from species WHERE iupac='ethyl 2,2-dimethylpropanoate'),
    (SELECT id from literature WHERE bibtexkey='3616'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'butyl pentanoate',
    'C<sub>9</sub>H<sub>18</sub>O<sub>2</sub>',
    'butyl valerate',
    '591-68-4',
    'OKJADYKTJJGKDX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='butyl pentanoate'),
    (SELECT id from literature WHERE bibtexkey='3616'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl pentanoate'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl pentanoate'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='butyl pentanoate'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methylbutyl 3-methylbutanoate',
    'C<sub>10</sub>H<sub>20</sub>O<sub>2</sub>',
    'isoamyl isovalerate',
    '659-70-1',
    'XINCECQTMHSORG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-methylbutyl 3-methylbutanoate'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl hexanoate',
    'C<sub>5</sub>H<sub>11</sub>COOCH<sub>3</sub>',
    'methyl caproate',
    '106-70-7',
    'NUKZAGXMHTUAFE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '6600',
    'L',
    (SELECT id from species WHERE iupac='methyl hexanoate'),
    (SELECT id from literature WHERE bibtexkey='3616'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methyl hexanoate'),
    (SELECT id from literature WHERE bibtexkey='2371'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methyl hexanoate'),
    (SELECT id from literature WHERE bibtexkey='754'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6',
    '5600',
    'V',
    (SELECT id from species WHERE iupac='methyl hexanoate'),
    (SELECT id from literature WHERE bibtexkey='3638'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl hexanoate'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl hexanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl hexanoate'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl hexanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl hexanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl hexanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl hexanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl hexanoate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl hexanoate'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl hexanoate'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-Test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl hexanoate'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl hexanoate'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl hexanoate'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methyl hexanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methyl hexanoate'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyl hexanoate',
    'C<sub>5</sub>H<sub>11</sub>COOC<sub>2</sub>H<sub>5</sub>',
    'ethyl caproate',
    '123-66-0',
    'SHZIWNPUGXLXDT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '7200',
    'L',
    (SELECT id from species WHERE iupac='ethyl hexanoate'),
    (SELECT id from literature WHERE bibtexkey='3616'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethyl hexanoate'),
    (SELECT id from literature WHERE bibtexkey='2371'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethyl hexanoate'),
    (SELECT id from literature WHERE bibtexkey='3651'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethyl hexanoate'),
    (SELECT id from literature WHERE bibtexkey='3647'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl hexanoate'),
    (SELECT id from literature WHERE bibtexkey='3642'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl hexanoate'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl hexanoate'),
    (SELECT id from literature WHERE bibtexkey='3521'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl hexanoate'),
    (SELECT id from literature WHERE bibtexkey='3025'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl hexanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl hexanoate'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl hexanoate'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethyl hexanoate'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-ethylbutanoic acid, 1,2-ethanediylbis(oxy-2,1-ethanediyl) ester',
    'C<sub>18</sub>H<sub>34</sub>O<sub>6</sub>',
    '',
    '95-08-9',
    'JEYLQCXBYFQJRO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylbutanoic acid, 1,2-ethanediylbis(oxy-2,1-ethanediyl) ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl heptanoate',
    'C<sub>8</sub>H<sub>16</sub>O<sub>2</sub>',
    '',
    '106-73-0',
    'XNCNNDVCAUWAIT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='methyl heptanoate'),
    (SELECT id from literature WHERE bibtexkey='3616'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyl heptanoate',
    'C<sub>6</sub>H<sub>13</sub>COOC<sub>2</sub>H<sub>5</sub>',
    '',
    '106-30-9',
    'TVQGDYNRXLTQAP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl heptanoate'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl heptanoate'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl heptanoate'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl heptanoate'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl heptanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl heptanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl heptanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl heptanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl heptanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl heptanoate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl heptanoate'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl heptanoate'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl heptanoate'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethyl heptanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethyl heptanoate'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl octanoate',
    'C<sub>6</sub>H<sub>13</sub>COOCH<sub>3</sub>',
    '',
    '111-11-5',
    'JGHZJRVDZXSNKQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='methyl octanoate'),
    (SELECT id from literature WHERE bibtexkey='3616'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methyl octanoate'),
    (SELECT id from literature WHERE bibtexkey='2371'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methyl octanoate'),
    (SELECT id from literature WHERE bibtexkey='754'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl octanoate'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl octanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl octanoate'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl octanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl octanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl octanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl octanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl octanoate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl octanoate'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl octanoate'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl octanoate'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methyl octanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyl octanoate',
    'C<sub>7</sub>H<sub>15</sub>COOC<sub>2</sub>H<sub>5</sub>',
    '',
    '106-32-1',
    'YYZUSRORWSJGET-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='ethyl octanoate'),
    (SELECT id from literature WHERE bibtexkey='3616'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethyl octanoate'),
    (SELECT id from literature WHERE bibtexkey='2371'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl octanoate'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl octanoate'),
    (SELECT id from literature WHERE bibtexkey='3025'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'octadecanoic acid, 2-methylpropyl ester',
    'C<sub>22</sub>H<sub>44</sub>O<sub>2</sub>',
    'isobutyl stearate',
    '646-13-9',
    'ORFWYUFLWUWSFM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octadecanoic acid, 2-methylpropyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'octadecanoic acid, butyl ester',
    'C<sub>22</sub>H<sub>44</sub>O<sub>2</sub>',
    '',
    '123-95-5',
    'ULBTUVJTXULMLP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octadecanoic acid, butyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl nonanoate',
    'C<sub>10</sub>H<sub>20</sub>O<sub>2</sub>',
    '',
    '1731-84-6',
    'IJXHLVMUNBOGRR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='methyl nonanoate'),
    (SELECT id from literature WHERE bibtexkey='3616'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl nonanoate'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyl nonanoate',
    'C<sub>8</sub>H<sub>17</sub>COOC<sub>2</sub>H<sub>5</sub>',
    '',
    '123-29-5',
    'BYEVBITUADOIGY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl nonanoate'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nonanedioic acid, bis(2-ethylhexyl) ester',
    'C<sub>25</sub>H<sub>48</sub>O<sub>4</sub>',
    'di-2-ethylhexyl azelate',
    '103-24-2',
    'ZDWGXBPVPXVXMQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonanedioic acid, bis(2-ethylhexyl) ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl decanoate',
    'C<sub>11</sub>H<sub>22</sub>O<sub>2</sub>',
    'methyl caprate',
    '110-42-9',
    'YRHYCMZPEVDGFQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methyl decanoate'),
    (SELECT id from literature WHERE bibtexkey='2371'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl decanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl decanoate'),
    (SELECT id from literature WHERE bibtexkey='977'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl decanoate'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl decanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl decanoate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl decanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyl decanoate',
    'C<sub>9</sub>H<sub>19</sub>COOC<sub>2</sub>H<sub>5</sub>',
    '',
    '110-38-3',
    'RGXWDWUGBIJHDO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='ethyl decanoate'),
    (SELECT id from literature WHERE bibtexkey='3616'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethyl decanoate'),
    (SELECT id from literature WHERE bibtexkey='2371'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl decanoate'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'decanedioic acid, diethyl ester',
    'C<sub>14</sub>H<sub>26</sub>O<sub>4</sub>',
    'diethyl sebacate',
    '110-40-7',
    'ONKUXPIBXRRIDU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    '?',
    (SELECT id from species WHERE iupac='decanedioic acid, diethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3393'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl dodecanoate',
    'C<sub>13</sub>H<sub>26</sub>O<sub>2</sub>',
    'methyl laurate',
    '111-82-0',
    'UQDUPQYQJKYHQI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl dodecanoate'),
    (SELECT id from literature WHERE bibtexkey='977'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl dodecanoate'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl dodecanoate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl dodecanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyl dodecanoate',
    'C<sub>14</sub>H<sub>28</sub>O<sub>2</sub>',
    'ethyl laurate',
    '106-33-2',
    'MMXKVMNBHPAILY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl dodecanoate'),
    (SELECT id from literature WHERE bibtexkey='977'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl dodecanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propyl dodecanoate',
    'C<sub>15</sub>H<sub>30</sub>O<sub>2</sub>',
    'propyl laurate',
    '3681-78-5',
    'FTBUKOLPOATXGV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propyl dodecanoate'),
    (SELECT id from literature WHERE bibtexkey='977'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl dodecanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-hydroxypropyl dodecanoate',
    'C<sub>15</sub>H<sub>30</sub>O<sub>3</sub>',
    '',
    '142-55-2',
    'BHIZVZJETFVJMJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-hydroxypropyl dodecanoate'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dodecanoic acid, 2-hydroxy-1-methylethyl ester',
    'C<sub>15</sub>H<sub>30</sub>O<sub>3</sub>',
    '',
    '107328-11-0',
    'SVWZGNLBKFWCMV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dodecanoic acid, 2-hydroxy-1-methylethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'butyl dodecanoate',
    'C<sub>16</sub>H<sub>32</sub>O<sub>2</sub>',
    'butyl laurate',
    '106-18-3',
    'NDKYEUQMPZIGFN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butyl dodecanoate'),
    (SELECT id from literature WHERE bibtexkey='977'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl dodecanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-ethylhexyl dodecanoate',
    'C<sub>20</sub>H<sub>40</sub>O<sub>2</sub>',
    '2-ethylhexyl laurate',
    '20292-08-4',
    'LWLRMRFJCCMNML-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-ethylhexyl dodecanoate'),
    (SELECT id from literature WHERE bibtexkey='977'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylhexyl dodecanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl tetradecanoate',
    'C<sub>15</sub>H<sub>30</sub>O<sub>2</sub>',
    'methyl myristate',
    '124-10-7',
    'ZAZKJZBWRNNLDS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl tetradecanoate'),
    (SELECT id from literature WHERE bibtexkey='977'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl tetradecanoate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl tetradecanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl hexadecanoate',
    'C<sub>17</sub>H<sub>34</sub>O<sub>2</sub>',
    'methyl palmitate',
    '112-39-0',
    'FLIACVVOZYBSBS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl hexadecanoate'),
    (SELECT id from literature WHERE bibtexkey='977'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl hexadecanoate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl hexadecanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'isopropyl palmitate',
    'C<sub>19</sub>H<sub>38</sub>O<sub>2</sub>',
    '',
    '142-91-6',
    'XUGNVMKQXJXZCD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isopropyl palmitate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ascorbic palmitate',
    'C<sub>22</sub>H<sub>38</sub>O<sub>7</sub>',
    '',
    '137-66-6',
    'QAQJMLQRFWZOBN-LAUBAEHRSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ascorbic palmitate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl octadecanoate',
    'C<sub>19</sub>H<sub>38</sub>O<sub>2</sub>',
    'methyl stearate',
    '112-61-8',
    'HPEUJPJOZXNMSJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl octadecanoate'),
    (SELECT id from literature WHERE bibtexkey='977'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl octadecanoate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl octadecanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl eicosanoate',
    'C<sub>21</sub>H<sub>42</sub>O<sub>2</sub>',
    'methyl arachidate',
    '1120-28-1',
    'QGBRLVONZXHAKJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl eicosanoate'),
    (SELECT id from literature WHERE bibtexkey='977'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl docosanoate',
    'C<sub>23</sub>H<sub>46</sub>O<sub>2</sub>',
    'methyl behenate',
    '929-77-1',
    'QSQLTHHMFHEFIY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl docosanoate'),
    (SELECT id from literature WHERE bibtexkey='977'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cyclopropanecarboxylic acid, methyl ester',
    'C<sub>5</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '2868-37-3',
    'PKAHQJNJPDVTDP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '6100',
    'T',
    (SELECT id from species WHERE iupac='cyclopropanecarboxylic acid, methyl ester'),
    (SELECT id from literature WHERE bibtexkey='2016'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2016'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopropanecarboxylic acid, methyl ester'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclopropanecarboxylic acid, methyl ester'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cyclohexanecarboxylic acid, methyl ester',
    'C<sub>6</sub>H<sub>11</sub>COOCH<sub>3</sub>',
    '',
    '4630-82-4',
    'ZQWPRMPSCMSAJU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '7200',
    'T',
    (SELECT id from species WHERE iupac='cyclohexanecarboxylic acid, methyl ester'),
    (SELECT id from literature WHERE bibtexkey='2016'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2016'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexanecarboxylic acid, methyl ester'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(Z,Z,Z)-9,12,15-octadecatrienoic acid, methyl ester',
    'C<sub>19</sub>H<sub>32</sub>O<sub>2</sub>',
    'methyl linolenate',
    '301-00-8',
    'DVWSXZIHSUZZKJ-YSTUJMKBSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(Z,Z,Z)-9,12,15-octadecatrienoic acid, methyl ester'),
    (SELECT id from literature WHERE bibtexkey='977'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(Z,Z,Z)-9,12,15-octadecatrienoic acid, methyl ester'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(Z,Z)-9,12-octadecadienoic acid, methyl ester',
    'C<sub>19</sub>H<sub>34</sub>O<sub>2</sub>',
    'methyl linolate',
    '112-63-0',
    'WTTJVINHCBCLGX-NQLNTKRDSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(Z,Z)-9,12-octadecadienoic acid, methyl ester'),
    (SELECT id from literature WHERE bibtexkey='977'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(Z,Z)-9,12-octadecadienoic acid, methyl ester'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(Z)-9-octadecenoic acid, methyl ester',
    'C<sub>19</sub>H<sub>36</sub>O<sub>2</sub>',
    'methyl oleate',
    '112-62-9',
    'QYDYPVFESGNLHU-KHPPLWFESA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(Z)-9-octadecenoic acid, methyl ester'),
    (SELECT id from literature WHERE bibtexkey='977'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(Z)-9-octadecenoic acid, methyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(Z)-9-octadecenoic acid, methyl ester'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(Z)-13-docosenoic acid, methyl ester',
    'C<sub>23</sub>H<sub>44</sub>O<sub>2</sub>',
    'methyl erucate',
    '1120-34-9',
    'ZYNDJIBBPLNPOW-KHPPLWFESA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(Z)-13-docosenoic acid, methyl ester'),
    (SELECT id from literature WHERE bibtexkey='977'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(Z)-13-docosenoic acid, methyl ester'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>trans</i>-quercus lactone',
    'C<sub>9</sub>H<sub>16</sub>O<sub>2</sub>',
    '<i>trans</i>-whisky lactone',
    '105119-22-0',
    'WNVCMFHPRIBNCW-SFYZADRCSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-quercus lactone'),
    (SELECT id from literature WHERE bibtexkey='3521'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '&#947;-decalactone',
    'C<sub>10</sub>H<sub>18</sub>O<sub>2</sub>',
    '',
    '706-14-9',
    'IFYYFLINQYPWGJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#947;-decalactone'),
    (SELECT id from literature WHERE bibtexkey='3521'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '&#947;-dodecalactone',
    'C<sub>12</sub>H<sub>22</sub>O<sub>2</sub>',
    '',
    '2305-05-7',
    'WGPCZPLRVAWXPW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#947;-dodecalactone'),
    (SELECT id from literature WHERE bibtexkey='3521'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'oxacyclohexadecan-2-one',
    'C<sub>15</sub>H<sub>28</sub>O<sub>2</sub>',
    'pentadecalactone',
    '106-02-5',
    'FKUPPRZPSYCDRS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='oxacyclohexadecan-2-one'),
    (SELECT id from literature WHERE bibtexkey='2388'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='oxacyclohexadecan-2-one'),
    (SELECT id from literature WHERE bibtexkey='2388'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-<i>tert</i>-butylcyclohexyl acetate',
    'C<sub>12</sub>H<sub>22</sub>O<sub>2</sub>',
    '',
    '88-41-5',
    'FINOAUDUYKVGDS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-<i>tert</i>-butylcyclohexyl acetate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-<i>tert</i>-butylcyclohexyl acetate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-<i>tert</i>-butylcyclohexyl acetate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-<i>tert</i>-butylcyclohexyl acetate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hedione',
    'C<sub>13</sub>H<sub>22</sub>O<sub>3</sub>',
    '',
    '24851-98-7',
    'KVWWIYGFBYDJQC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hedione'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethylene brassylate',
    'C<sub>15</sub>H<sub>26</sub>O<sub>4</sub>',
    '',
    '105-95-3',
    'XRHCAGNSDHCHFJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethylene brassylate'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propyl 3-oxo-2-pentylcyclopentaneacetate',
    'C<sub>15</sub>H<sub>26</sub>O<sub>3</sub>',
    '',
    '158474-72-7',
    'IPDFPNNPBMREIF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propyl 3-oxo-2-pentylcyclopentaneacetate'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-ethyl-3-oxo-butanoic acid, ethyl ester',
    'C<sub>8</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '607-97-6',
    'OKANYBNORCUPKZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-3-oxo-butanoic acid, ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-hydroxypropanoic acid, butyl ester',
    'C<sub>7</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '138-22-7',
    'MRABAEUHTLLEML-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-hydroxypropanoic acid, butyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxypropanoic acid, butyl ester'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxypropanoic acid, butyl ester'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxypropanoic acid, butyl ester'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxypropanoic acid, butyl ester'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxypropanoic acid, butyl ester'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxypropanoic acid, butyl ester'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxypropanoic acid, butyl ester'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxypropanoic acid, butyl ester'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl propenoate',
    'C<sub>4</sub>H<sub>6</sub>O<sub>2</sub>',
    'methyl acrylate',
    '96-33-3',
    'BAPJBEWLBFYGME-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl propenoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl propenoate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl propenoate'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl propenoate'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methyl propenoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at296K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl propenoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl propenoate'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl propenoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl propenoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl propenoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl propenoate'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl propenoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl propenoate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methyl propenoate'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at296K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyl propenoate',
    'C<sub>5</sub>H<sub>8</sub>O<sub>2</sub>',
    'ethyl acrylate',
    '140-88-5',
    'JIGUQPWFLRLWPJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '4400',
    'L',
    (SELECT id from species WHERE iupac='ethyl propenoate'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl propenoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl propenoate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl propenoate'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl propenoate'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethyl propenoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl propenoate'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl propenoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl propenoate'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl propenoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl propenoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl propenoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl propenoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl propenoate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl propenoate'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethyl propenoate'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-propenoic acid, butyl ester',
    'C<sub>7</sub>H<sub>12</sub>O<sub>2</sub>',
    'butyl acrylate',
    '141-32-2',
    'CQEYYJKEWSMYFG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-propenoic acid, butyl ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-propenoic acid, butyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propenoic acid, butyl ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propenoic acid, butyl ester'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propenoic acid, butyl ester'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propenoic acid, butyl ester'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propenoic acid, butyl ester'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propenoic acid, butyl ester'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propenoic acid, butyl ester'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propenoic acid, butyl ester'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-propenoic acid, butyl ester'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-propenoic acid, 2-methylpropyl ester',
    'C<sub>7</sub>H<sub>12</sub>O<sub>2</sub>',
    'isobutyl acrylate',
    '106-63-8',
    'CFVWNXQPGQOHRJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-propenoic acid, 2-methylpropyl ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-propenoic acid, 2-methylpropyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propenoic acid, 2-methylpropyl ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propenoic acid, 2-methylpropyl ester'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propenoic acid, 2-methylpropyl ester'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propenoic acid, 2-methylpropyl ester'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propenoic acid, 2-methylpropyl ester'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propenoic acid, 2-methylpropyl ester'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propenoic acid, 2-methylpropyl ester'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propenoic acid, 2-methylpropyl ester'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-propenoic acid, 2-methylpropyl ester'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at296K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-propenoic acid, 2-ethylhexyl ester',
    'C<sub>11</sub>H<sub>20</sub>O<sub>2</sub>',
    '2-ethylhexyl acrylate',
    '103-11-7',
    'GOXQRTZXKQZDDN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-propenoic acid, 2-ethylhexyl ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-propenoic acid, 2-ethylhexyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-propenoic acid, 2-ethylhexyl ester'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at296K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propenoic acid, 2-ethylhexyl ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propenoic acid, 2-ethylhexyl ester'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propenoic acid, 2-ethylhexyl ester'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propenoic acid, 2-ethylhexyl ester'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propenoic acid, 2-ethylhexyl ester'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propenoic acid, 2-ethylhexyl ester'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propenoic acid, 2-ethylhexyl ester'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propenoic acid, 2-ethylhexyl ester'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propenoic acid, 2-ethylhexyl ester'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-propenoic acid, 2-ethylhexyl ester'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at296K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-propenoic acid, 2-hydroxyethyl ester',
    'C<sub>5</sub>H<sub>8</sub>O<sub>3</sub>',
    '2-hydroxyethyl acrylate',
    '818-61-1',
    'OMIGHNLMNHATMP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-propenoic acid, 2-hydroxyethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-2-propenoic acid, ethyl ester',
    'C<sub>6</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '97-63-2',
    'SUPCQIBBMFXVTL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-2-propenoic acid, ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-2-propenoic acid, ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='2-methyl-2-propenoic acid, ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propenoic acid, ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propenoic acid, ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propenoic acid, ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propenoic acid, ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propenoic acid, ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propenoic acid, ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-2-propenoic acid, 2-propenyl ester',
    'C<sub>7</sub>H<sub>10</sub>O<sub>2</sub>',
    'allyl methacrylate',
    '96-05-9',
    'FBCQUCJYYPMKRO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propenoic acid, 2-propenyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-2-propenoic acid, oxiranylmethyl ester',
    'C<sub>7</sub>H<sub>10</sub>O<sub>3</sub>',
    'glycidyl methacrylate',
    '106-91-2',
    'VOZRXNHHFUQHIL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propenoic acid, oxiranylmethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'allyl acetoacetate',
    'C<sub>7</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '1118-84-9',
    'AXLMPTNTPOWPLT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='allyl acetoacetate'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-2-propenoic acid, propyl ester',
    'C<sub>7</sub>H<sub>12</sub>O<sub>2</sub>',
    'propyl methacrylate',
    '2210-28-8',
    'NHARPDSAXCBDDR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propenoic acid, propyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-2-propenoic acid, butyl ester',
    'C<sub>8</sub>H<sub>14</sub>O<sub>2</sub>',
    'butyl methacrylate',
    '97-88-1',
    'SOGAXMICEFXMKE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-2-propenoic acid, butyl ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-2-propenoic acid, butyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propenoic acid, butyl ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propenoic acid, butyl ester'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propenoic acid, butyl ester'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propenoic acid, butyl ester'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propenoic acid, butyl ester'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propenoic acid, butyl ester'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-2-propenoic acid, 2-methylpropyl ester',
    'C<sub>8</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '97-86-9',
    'RUMACXVDVNRZJZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-2-propenoic acid, 2-methylpropyl ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-2-propenoic acid, 2-methylpropyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propenoic acid, 2-methylpropyl ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propenoic acid, 2-methylpropyl ester'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propenoic acid, 2-methylpropyl ester'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propenoic acid, 2-methylpropyl ester'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propenoic acid, 2-methylpropyl ester'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propenoic acid, 2-methylpropyl ester'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-2-propenoic acid, 1,2-ethanediylbis(oxy-2,1-ethanediyl) ester',
    'C<sub>14</sub>H<sub>22</sub>O<sub>6</sub>',
    '',
    '109-16-0',
    'HWSSEYVMGDIFMH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propenoic acid, 1,2-ethanediylbis(oxy-2,1-ethanediyl) ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl methacrylate',
    'C<sub>5</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '80-62-6',
    'VVQNEPGJFQJSBK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '5300',
    'L',
    (SELECT id from species WHERE iupac='methyl methacrylate'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '7700',
    'M',
    (SELECT id from species WHERE iupac='methyl methacrylate'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl methacrylate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl methacrylate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '5300',
    'V',
    (SELECT id from species WHERE iupac='methyl methacrylate'),
    (SELECT id from literature WHERE bibtexkey='3523'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl methacrylate'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl methacrylate'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl methacrylate'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl methacrylate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl methacrylate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl methacrylate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl methacrylate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl methacrylate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl methacrylate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='methyl methacrylate'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3500-80-62-6',
    '3500,3523', 'Burkholder et&nbsp;al. (2019) refer to Dohnal et&nbsp;al. (2010) but the quoted value cannot be found there.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3500-80-62-6'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='methyl methacrylate'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3245-80-62-6',
    '3245,3523', 'Burkholder et&nbsp;al. (2015) refer to Dohnal et&nbsp;al. (2010) but the quoted value cannot be found there.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3245-80-62-6'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(E)-3-hexenyl ethanoate',
    'C<sub>8</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '3681-82-1',
    'NPFVOOAXDOBMCE-SNAWJCMRSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='(E)-3-hexenyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='1922'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(Z)-3-hexenyl ethanoate',
    'C<sub>8</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '3681-71-8',
    'NPFVOOAXDOBMCE-PLNGDYQASA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='(Z)-3-hexenyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='1922'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethenyl ethanoate',
    'CH<sub>3</sub>COOCHCH<sub>2</sub>',
    'vinyl acetate',
    '108-05-4',
    'XTXRWKRVRITETP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '4500',
    'L',
    (SELECT id from species WHERE iupac='ethenyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '4500',
    'L',
    (SELECT id from species WHERE iupac='ethenyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '4600',
    'L',
    (SELECT id from species WHERE iupac='ethenyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '4400',
    'M',
    (SELECT id from species WHERE iupac='ethenyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3302'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethenyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '4600',
    'V',
    (SELECT id from species WHERE iupac='ethenyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3523'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethenyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethenyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethenyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethenyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethenyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethenyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '2600',
    'X',
    (SELECT id from species WHERE iupac='ethenyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethenyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethenyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethenyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethenyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethenyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethenyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethenyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethenyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethenyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(7E,9Z)-dodecadienyl acetate',
    'C<sub>14</sub>H<sub>24</sub>O<sub>2</sub>',
    '',
    '54364-62-4',
    'LLRZUAWETKPZJO-SCFJQAPRSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(7E,9Z)-dodecadienyl acetate'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(9Z,12E)-9,12-tetradecadienyl acetate',
    'C<sub>16</sub>H<sub>28</sub>O<sub>2</sub>',
    '',
    '30507-70-1',
    'ZZGJZGSVLNSDPG-FDTUMDBZSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(9Z,12E)-9,12-tetradecadienyl acetate'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'isoambrettolide',
    'C<sub>16</sub>H<sub>28</sub>O<sub>2</sub>',
    '',
    '28645-51-4',
    'QILMAYXCYBTEDM-IWQZZHSRSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isoambrettolide'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'vetyveryl acetate',
    'C<sub>17</sub>H<sub>26</sub>O<sub>2</sub>',
    '',
    '117-98-6',
    'UAVFEMBKDRODDE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='vetyveryl acetate'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hydroprene',
    'C<sub>17</sub>H<sub>30</sub>O<sub>2</sub>',
    '',
    '41096-46-2',
    'FYQGBXGJFWXIPP-UEVLXMDPSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='hydroprene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'empenthrin',
    'C<sub>18</sub>H<sub>26</sub>O<sub>2</sub>',
    '',
    '54406-48-3',
    'YUGWDVYLFSETPE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='empenthrin'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-(4-methoxyphenyl)-2-propenoic acid, 2-ethylhexyl ester',
    'C<sub>18</sub>H<sub>26</sub>O<sub>3</sub>',
    'octinoxate',
    '5466-77-3',
    'YBGZDTIWKVFICR-JLHYYAGUSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-(4-methoxyphenyl)-2-propenoic acid, 2-ethylhexyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'kinoprene',
    'C<sub>18</sub>H<sub>28</sub>O<sub>2</sub>',
    '',
    '42588-37-4',
    'FZRBKIRIBLNOAM-WHVZTFIZSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='kinoprene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'allethrin',
    'C<sub>19</sub>H<sub>26</sub>O<sub>3</sub>',
    '',
    '584-79-2',
    'ZCVAOQKBXKSDMS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='allethrin'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'S-methoprene',
    'C<sub>19</sub>H<sub>34</sub>O<sub>3</sub>',
    '',
    '65733-16-6',
    'NFGXHKASABOEEW-GYMWBFJFSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    '?',
    (SELECT id from species WHERE iupac='S-methoprene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl benzoate',
    'C<sub>6</sub>H<sub>5</sub>COOCH<sub>3</sub>',
    '',
    '93-58-3',
    'QPJVMBTYPHYUOC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '6400',
    'L',
    (SELECT id from species WHERE iupac='methyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='methyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;1</sup>',
    '6300',
    'T',
    (SELECT id from species WHERE iupac='methyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='2016'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2016'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5100',
    'Q',
    (SELECT id from species WHERE iupac='methyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-Test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3500',
    '?',
    (SELECT id from species WHERE iupac='methyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyl benzoate',
    'C<sub>6</sub>H<sub>5</sub>COOC<sub>2</sub>H<sub>5</sub>',
    '',
    '93-89-0',
    'MTZQAGJQAFMTAQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '6300',
    'L',
    (SELECT id from species WHERE iupac='ethyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='ethyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-hydroxybenzoic acid methyl ester',
    'C<sub>8</sub>H<sub>8</sub>O<sub>3</sub>',
    'methyl salicylate',
    '119-36-8',
    'OSWPMRLSEDHDFF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '9500',
    'L',
    (SELECT id from species WHERE iupac='2-hydroxybenzoic acid methyl ester'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-hydroxybenzoic acid methyl ester'),
    (SELECT id from literature WHERE bibtexkey='3555'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-hydroxybenzoic acid methyl ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-hydroxybenzoic acid methyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxybenzoic acid methyl ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxybenzoic acid methyl ester'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxybenzoic acid methyl ester'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-hydroxybenzoic acid methyl ester'),
    (SELECT id from literature WHERE bibtexkey='3393'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-hydroxybenzoic acid methyl ester'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at303K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benzoic acid, 4-methyl-, methyl ester',
    'C<sub>9</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '99-75-2',
    'QSSJZLPUHJDYKF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzoic acid, 4-methyl-, methyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzoic acid, 4-methyl-, methyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzoic acid, 4-methyl-, methyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzoic acid, 4-methyl-, methyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'acetylsalicylic acid',
    'C<sub>9</sub>H<sub>8</sub>O<sub>4</sub>',
    'aspirin',
    '50-78-2',
    'BSYNRYMUTXBXSQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='acetylsalicylic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='acetylsalicylic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='acetylsalicylic acid'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='acetylsalicylic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='acetylsalicylic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='acetylsalicylic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4-benzenedicarboxylic acid, dimethyl ester',
    'C<sub>10</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '120-61-6',
    'WOZVHXUHUFLZGK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-benzenedicarboxylic acid, dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-benzenedicarboxylic acid, dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-benzenedicarboxylic acid, dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-benzenedicarboxylic acid, dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-benzenedicarboxylic acid, dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-benzenedicarboxylic acid, dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-benzenedicarboxylic acid, dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-benzenedicarboxylic acid, dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'butyl benzoate',
    'C<sub>11</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '136-60-7',
    'XSIFPSYPOVKYCO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diphenyl carbonate',
    'C<sub>13</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '102-09-0',
    'ROORDVPLFPIABK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diphenyl carbonate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diphenyl carbonate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diphenyl carbonate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diphenyl carbonate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diphenyl carbonate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benzyl benzoate',
    'C<sub>14</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '120-51-4',
    'SESFRYSPDFLNCH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzyl benzoate'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>trans</i>-ethylcinnamate',
    'C<sub>11</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '103-36-6',
    'KBEBGUQPQBELIU-CMDGGOBGSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'V',
    (SELECT id from species WHERE iupac='<i>trans</i>-ethylcinnamate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-ethylcinnamate'),
    (SELECT id from literature WHERE bibtexkey='3521'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-ethylcinnamate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dipropylene glycol dibenzoate',
    'C<sub>20</sub>H<sub>22</sub>O<sub>5</sub>',
    '',
    '27138-31-4',
    'CGLQOIMEUPORRI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dipropylene glycol dibenzoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dipropylene glycol dibenzoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimethyl phthalate',
    'C<sub>10</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '131-11-3',
    'NIQCNGHVCWTJSM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>1</sup>',
    '8000',
    'L',
    (SELECT id from species WHERE iupac='dimethyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dimethyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dimethyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dimethyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dimethyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dimethyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dimethyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2957'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dimethyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2958'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dimethyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dimethyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dimethyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0',
    '',
    'V',
    (SELECT id from species WHERE iupac='dimethyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2956'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dimethyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dimethyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>1</sup>',
    '5700',
    'X',
    (SELECT id from species WHERE iupac='dimethyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dimethyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='mccarty80'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from2556'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='dimethyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dimethyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4-cyclohexanedicarboxylic acid, dimethyl ester',
    'C<sub>10</sub>H<sub>16</sub>O<sub>4</sub>',
    'dimethyl hexahydroterephthalate',
    '94-60-0',
    'LNGAGQAGYITKCW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-cyclohexanedicarboxylic acid, dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3-benzenedicarboxylic acid, dimethyl ester',
    'C<sub>10</sub>H<sub>10</sub>O<sub>4</sub>',
    'dimethyl isophthalate',
    '1459-93-4',
    'VNGOYPQMJFJDLV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-benzenedicarboxylic acid, dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diethyl phthalate',
    'C<sub>12</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '84-66-2',
    'FLKPEMZONWLCSK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>1</sup>',
    '10000',
    'L',
    (SELECT id from species WHERE iupac='diethyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='diethyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diethyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diethyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diethyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diethyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2957'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diethyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2958'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diethyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diethyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diethyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2956'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='diethyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='diethyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '5600',
    'X',
    (SELECT id from species WHERE iupac='diethyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='diethyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='diethyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2556'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '12000',
    'Q',
    (SELECT id from species WHERE iupac='diethyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='diethyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3393'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '12000',
    '?',
    (SELECT id from species WHERE iupac='diethyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='diethyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dipropyl phthalate',
    'C<sub>14</sub>H<sub>18</sub>O<sub>4</sub>',
    '',
    '131-16-8',
    'MQHNKCZKNAJROC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='dipropyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dipropyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dipropyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2957'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2957',
    '', 'Dipropyl phthalate is listed twice with different values.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2957'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3',
    '',
    'V',
    (SELECT id from species WHERE iupac='dipropyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2957'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2957'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dipropyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2958'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dipropyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dipropyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dipropyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dipropyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dipropyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diallyl phthalate',
    'C<sub>14</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '131-17-9',
    'QUDWYFHPNIMBFC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diallyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diallyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2957'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diallyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2958'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diallyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diallyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bis(2-methoxyethyl) phthalate',
    'C<sub>14</sub>H<sub>18</sub>O<sub>5</sub>',
    '',
    '117-82-8',
    'HSUIVCLOAAJSRE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bis(2-methoxyethyl) phthalate'),
    (SELECT id from literature WHERE bibtexkey='2959'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis(2-methoxyethyl) phthalate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dibutyl phthalate',
    'C<sub>16</sub>H<sub>22</sub>O<sub>4</sub>',
    '',
    '84-74-2',
    'DOIRQSBPFJWKBE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '12000',
    'L',
    (SELECT id from species WHERE iupac='dibutyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3518-84-74-2-consicheck',
    '3518', 'Values at 298&nbsp;K in Tables&nbsp;C2 and C5 of Brockbank (2013) are inconsistent, with 9&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3518-84-74-2-consicheck'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3',
    '',
    'M',
    (SELECT id from species WHERE iupac='dibutyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3014'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5',
    '',
    'M',
    (SELECT id from species WHERE iupac='dibutyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2533'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at296K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dibutyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dibutyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='dibutyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2957'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dibutyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2958'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dibutyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dibutyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dibutyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6',
    '',
    'V',
    (SELECT id from species WHERE iupac='dibutyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2956'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dibutyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dibutyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='mccarty80'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from2556'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='dibutyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibutyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibutyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibutyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '14000',
    'Q',
    (SELECT id from species WHERE iupac='dibutyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibutyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '13000',
    '?',
    (SELECT id from species WHERE iupac='dibutyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dibutyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diisobutyl phthalate',
    'C<sub>16</sub>H<sub>22</sub>O<sub>4</sub>',
    '',
    '84-69-5',
    'MGWAVDBGNNKXQV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='diisobutyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='diisobutyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2957'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diisobutyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2958'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diisobutyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-benzenedicarboxylic acid, butyl cyclohexyl ester',
    'C<sub>18</sub>H<sub>24</sub>O<sub>4</sub>',
    'butyl cyclohexyl phthalate',
    '84-64-0',
    'BHKLONWXRPJNAE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-benzenedicarboxylic acid, butyl cyclohexyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'butyl glycolyl butyl phthalate',
    'C<sub>18</sub>H<sub>24</sub>O<sub>6</sub>',
    '',
    '85-70-1',
    'GOJCZVPJCKEBQV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl glycolyl butyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diamyl phthalate',
    'C<sub>18</sub>H<sub>26</sub>O<sub>4</sub>',
    '',
    '131-18-0',
    'IPKKHRVROFYTEK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diamyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'butyl benzyl phthalate',
    'C<sub>19</sub>H<sub>20</sub>O<sub>4</sub>',
    '',
    '85-68-7',
    'IRIAEXORFWYRCZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='butyl benzyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3014'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8',
    '',
    'V',
    (SELECT id from species WHERE iupac='butyl benzyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6',
    '',
    'V',
    (SELECT id from species WHERE iupac='butyl benzyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='butyl benzyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butyl benzyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    'V',
    (SELECT id from species WHERE iupac='butyl benzyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2957'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butyl benzyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2958'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8',
    '',
    'V',
    (SELECT id from species WHERE iupac='butyl benzyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6',
    '',
    'C',
    (SELECT id from species WHERE iupac='butyl benzyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl benzyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl benzyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 9.9',
    '',
    'E',
    (SELECT id from species WHERE iupac='butyl benzyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2556'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dihexyl phthalate',
    'C<sub>20</sub>H<sub>30</sub>O<sub>4</sub>',
    '',
    '84-75-3',
    'KCXZNSGUUQJJTR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3',
    '',
    'L',
    (SELECT id from species WHERE iupac='dihexyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dihexyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dihexyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'V',
    (SELECT id from species WHERE iupac='dihexyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2957'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dihexyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2958'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dihexyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dihexyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'butyl 2-ethylhexyl phthalate',
    'C<sub>20</sub>H<sub>30</sub>O<sub>4</sub>',
    '',
    '85-69-8',
    'AVOLBYOSCILFLL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='butyl 2-ethylhexyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2957'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butyl 2-ethylhexyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2958'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl 2-ethylhexyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl 2-ethylhexyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diphenyl terephthalate',
    'C<sub>20</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '1539-04-4',
    'HPGJOUYGWKFYQW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diphenyl terephthalate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diphenyl terephthalate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diphenyl terephthalate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diphenyl terephthalate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dicyclohexyl phthalate',
    'C<sub>20</sub>H<sub>26</sub>O<sub>4</sub>',
    '',
    '84-61-7',
    'VOWAEIGWURALJQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dicyclohexyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dicyclohexyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dicyclohexyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bis(2-butoxyethyl) phthalate',
    'C<sub>20</sub>H<sub>30</sub>O<sub>6</sub>',
    '',
    '117-83-9',
    'CMCJNODIWQEOAI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis(2-butoxyethyl) phthalate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diheptyl phthalate',
    'C<sub>22</sub>H<sub>34</sub>O<sub>4</sub>',
    '',
    '3648-21-3',
    'JQCXWCOOWVGKMT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diheptyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2957'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diheptyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diheptyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dioctyl phthalate',
    'C<sub>24</sub>H<sub>38</sub>O<sub>4</sub>',
    '',
    '117-84-0',
    'MQIUGAXCHLFZKX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8',
    '',
    'V',
    (SELECT id from species WHERE iupac='dioctyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8',
    '',
    'V',
    (SELECT id from species WHERE iupac='dioctyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dioctyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dioctyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2957'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dioctyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2958'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'V',
    (SELECT id from species WHERE iupac='dioctyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'V',
    (SELECT id from species WHERE iupac='dioctyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2956'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dioctyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at297K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='dioctyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dioctyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dioctyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dioctyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 9.9',
    '',
    'E',
    (SELECT id from species WHERE iupac='dioctyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2556'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dioctyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at297K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diisooctyl phthalate',
    'C<sub>24</sub>H<sub>38</sub>O<sub>4</sub>',
    '',
    '27554-26-3',
    'IJFPVINAQGWBRJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diisooctyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diisooctyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diisooctyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2957'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diisooctyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diisooctyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'decyl hexyl phthalate',
    'C<sub>24</sub>H<sub>38</sub>O<sub>4</sub>',
    '',
    '25724-58-7',
    'OMQBXAQAHHFSST-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decyl hexyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bis(2-ethylhexyl)-phthalate',
    'C<sub>24</sub>H<sub>38</sub>O<sub>4</sub>',
    'DEHP',
    '117-81-7',
    'BJQHLKABXJIVAM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bis(2-ethylhexyl)-phthalate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bis(2-ethylhexyl)-phthalate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bis(2-ethylhexyl)-phthalate'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bis(2-ethylhexyl)-phthalate'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bis(2-ethylhexyl)-phthalate'),
    (SELECT id from literature WHERE bibtexkey='2957'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bis(2-ethylhexyl)-phthalate'),
    (SELECT id from literature WHERE bibtexkey='2958'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bis(2-ethylhexyl)-phthalate'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bis(2-ethylhexyl)-phthalate'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bis(2-ethylhexyl)-phthalate'),
    (SELECT id from literature WHERE bibtexkey='2966'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bis(2-ethylhexyl)-phthalate'),
    (SELECT id from literature WHERE bibtexkey='2956'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='bis(2-ethylhexyl)-phthalate'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='bis(2-ethylhexyl)-phthalate'),
    (SELECT id from literature WHERE bibtexkey='2556'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis(2-ethylhexyl)-phthalate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis(2-ethylhexyl)-phthalate'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis(2-ethylhexyl)-phthalate'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='bis(2-ethylhexyl)-phthalate'),
    (SELECT id from literature WHERE bibtexkey='3393'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bis(2-ethylhexyl) terephthalate',
    'C<sub>24</sub>H<sub>38</sub>O<sub>4</sub>',
    '',
    '6422-86-2',
    'RWPICVVBGZBXNA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis(2-ethylhexyl) terephthalate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dinonyl phthalate',
    'C<sub>26</sub>H<sub>42</sub>O<sub>4</sub>',
    '',
    '84-76-4',
    'DROMNWUQASBTFM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dinonyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2957'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dinonyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dinonyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diisononyl phthalate',
    'C<sub>26</sub>H<sub>42</sub>O<sub>4</sub>',
    '',
    '28553-12-0',
    'HBGGXOJOCNVPFY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6',
    '',
    'V',
    (SELECT id from species WHERE iupac='diisononyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6',
    '',
    'V',
    (SELECT id from species WHERE iupac='diisononyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diisononyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2957'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diisononyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diisononyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'didecyl phthalate',
    'C<sub>28</sub>H<sub>46</sub>O<sub>4</sub>',
    '',
    '84-77-5',
    'PGIBJVOPLXHHGS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='didecyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2957'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='didecyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diisodecyl phthalate',
    'C<sub>28</sub>H<sub>46</sub>O<sub>4</sub>',
    '',
    '26761-40-0',
    'ZVFDTKUVRCTHQE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9',
    '',
    'V',
    (SELECT id from species WHERE iupac='diisodecyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0',
    '',
    'V',
    (SELECT id from species WHERE iupac='diisodecyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diisodecyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diisodecyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2957'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='diisodecyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at297K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diisodecyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diisodecyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diisodecyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9',
    '',
    '?',
    (SELECT id from species WHERE iupac='diisodecyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at297K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diundecyl phthalate',
    'C<sub>30</sub>H<sub>50</sub>O<sub>4</sub>',
    '',
    '3648-20-2',
    'QQVHEQUEHCEAKS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diundecyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diundecyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2957'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diundecyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diundecyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ditridecyl phthalate',
    'C<sub>34</sub>H<sub>58</sub>O<sub>4</sub>',
    '',
    '119-06-2',
    'YCZJVRCZIPDYHH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ditridecyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2957'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ditridecyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ditridecyl phthalate'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethanedioic acid, dimethyl ester',
    'C<sub>4</sub>H<sub>6</sub>O<sub>4</sub>',
    'dimethyl oxalate',
    '553-90-2',
    'LOMVENUNSWAXEN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethanedioic acid, dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanedioic acid, dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanedioic acid, dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanedioic acid, dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanedioic acid, dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanedioic acid, dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanedioic acid, dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethanedioic acid, diethyl ester',
    'C<sub>6</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '95-92-1',
    'WYACBZDAHNBPPB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethanedioic acid, diethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanedioic acid, diethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propanedioic acid, dimethyl ester',
    'C<sub>5</sub>H<sub>8</sub>O<sub>4</sub>',
    'dimethyl malonate',
    '108-59-8',
    'BEPAFCGSDWSTEL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>1</sup>',
    '11000',
    'M',
    (SELECT id from species WHERE iupac='propanedioic acid, dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='1940'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propanedioic acid, diethyl ester',
    'C<sub>7</sub>H<sub>12</sub>O<sub>4</sub>',
    'diethyl malonate',
    '105-53-3',
    'IYXGSMUGOJNHAZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9',
    '7500',
    'L',
    (SELECT id from species WHERE iupac='propanedioic acid, diethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7',
    '',
    'V',
    (SELECT id from species WHERE iupac='propanedioic acid, diethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanedioic acid, diethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanedioic acid, diethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanedioic acid, diethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanedioic acid, diethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanedioic acid, diethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanedioic acid, diethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5900',
    'Q',
    (SELECT id from species WHERE iupac='propanedioic acid, diethyl ester'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2',
    '',
    '?',
    (SELECT id from species WHERE iupac='propanedioic acid, diethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3393'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6400',
    '?',
    (SELECT id from species WHERE iupac='propanedioic acid, diethyl ester'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1',
    '',
    '?',
    (SELECT id from species WHERE iupac='propanedioic acid, diethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'butanedioic acid, dimethyl ester',
    'C<sub>6</sub>H<sub>10</sub>O<sub>4</sub>',
    'dimethyl succinate',
    '106-65-0',
    'MUXOBHXGJLMRAB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>1</sup>',
    '8500',
    'M',
    (SELECT id from species WHERE iupac='butanedioic acid, dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='1940'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanedioic acid, dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7100',
    'Q',
    (SELECT id from species WHERE iupac='butanedioic acid, dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7000',
    '?',
    (SELECT id from species WHERE iupac='butanedioic acid, dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diethyl succinate',
    'C<sub>8</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '123-25-1',
    'DKMROQRQHGEIOW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diethyl succinate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl succinate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl succinate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl succinate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl succinate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl succinate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl succinate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(Z)-2-butenedioic acid dimethyl ester',
    'C<sub>6</sub>H<sub>8</sub>O<sub>4</sub>',
    'dimethyl maleate',
    '624-48-6',
    'LDCRTTXIJACKKU-ARJAWSKDSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(Z)-2-butenedioic acid dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(Z)-2-butenedioic acid dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(Z)-2-butenedioic acid dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(Z)-2-butenedioic acid dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(Z)-2-butenedioic acid dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(Z)-2-butenedioic acid dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(Z)-2-butenedioic acid dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(E)-2-butenedioic acid dimethyl ester',
    'C<sub>6</sub>H<sub>8</sub>O<sub>4</sub>',
    'dimethyl fumarate',
    '624-49-7',
    'LDCRTTXIJACKKU-ONEGZZNKSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(E)-2-butenedioic acid dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pentanedioic acid, dimethyl ester',
    'C<sub>7</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '1119-40-0',
    'XTDYIOOONNVFMA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pentanedioic acid, dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentanedioic acid, dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diethyl glutarate',
    'C<sub>9</sub>H<sub>16</sub>O<sub>4</sub>',
    '',
    '818-38-2',
    'OUWSNHWQZPEFEX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='diethyl glutarate'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diethyl pimelate',
    'C<sub>11</sub>H<sub>20</sub>O<sub>4</sub>',
    '',
    '2050-20-6',
    'LKKOGZVQGQUVHF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diethyl pimelate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl pimelate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl pimelate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl pimelate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='diethyl pimelate'),
    (SELECT id from literature WHERE bibtexkey='3393'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3-benzenedicarboxylic acid, diethyl ester',
    'C<sub>12</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '636-53-3',
    'JLVWYWVLMFVCDI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-benzenedicarboxylic acid, diethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-benzenedicarboxylic acid, diethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-benzenedicarboxylic acid, diethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-benzenedicarboxylic acid, diethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dibutyl maleate',
    'C<sub>12</sub>H<sub>20</sub>O<sub>4</sub>',
    '',
    '105-76-0',
    'JBSLOWBPDRZSMB-FPLPWBNLSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dibutyl maleate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibutyl maleate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibutyl maleate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibutyl maleate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibutyl maleate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimethyl sebacate',
    'C<sub>12</sub>H<sub>22</sub>O<sub>4</sub>',
    'decanedioic acid, dimethyl ester',
    '106-79-6',
    'ALOUNLDAKADEEB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dimethyl sebacate'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6-naphthalenedicarboxylic acid, dimethyl ester',
    'C<sub>14</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '840-65-3',
    'GYUVMLBYMPKZAZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-naphthalenedicarboxylic acid, dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-naphthalenedicarboxylic acid, dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-naphthalenedicarboxylic acid, dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-naphthalenedicarboxylic acid, dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diisooctyl adipate',
    'C<sub>22</sub>H<sub>42</sub>O<sub>4</sub>',
    '',
    '1330-86-5',
    'CJFLBOQMPJCWLR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diisooctyl adipate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'di-(2-ethylhexyl)-adipate',
    'C<sub>22</sub>H<sub>42</sub>O<sub>4</sub>',
    '',
    '103-23-1',
    'SAOKZLXYCUGLFA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='di-(2-ethylhexyl)-adipate'),
    (SELECT id from literature WHERE bibtexkey='3943'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='di-(2-ethylhexyl)-adipate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='di-(2-ethylhexyl)-adipate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'peroxybenzoic acid, <i>tert</i>-butyl ester',
    'C<sub>11</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '614-45-9',
    'GJBRNHKUVLOCEB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='peroxybenzoic acid, <i>tert</i>-butyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='peroxybenzoic acid, <i>tert</i>-butyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='peroxybenzoic acid, <i>tert</i>-butyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='peroxybenzoic acid, <i>tert</i>-butyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='peroxybenzoic acid, <i>tert</i>-butyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'neodecaneperoxoic acid, 1,1-dimethylethyl ester',
    'C<sub>14</sub>H<sub>28</sub>O<sub>3</sub>',
    '',
    '26748-41-4',
    'NMOALOSNPWTWRH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='neodecaneperoxoic acid, 1,1-dimethylethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='neodecaneperoxoic acid, 1,1-dimethylethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='neodecaneperoxoic acid, 1,1-dimethylethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='neodecaneperoxoic acid, 1,1-dimethylethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'neoheptaneperoxoic acid, 1-methyl-1-phenylethyl ester',
    'C<sub>16</sub>H<sub>24</sub>O<sub>3</sub>',
    '',
    '130097-36-8',
    'WFAUFYAGXAXBEG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='neoheptaneperoxoic acid, 1-methyl-1-phenylethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='neoheptaneperoxoic acid, 1-methyl-1-phenylethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='neoheptaneperoxoic acid, 1-methyl-1-phenylethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='neoheptaneperoxoic acid, 1-methyl-1-phenylethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hydroxypropyl acrylate',
    'C<sub>6</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '25584-83-2',
    'AYEFIAVHMUFQPZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydroxypropyl acrylate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-hydroxyethyl methacrylate',
    'C<sub>6</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '868-77-9',
    'WOBHKFSMXKNTIM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-hydroxyethyl methacrylate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxyethyl methacrylate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxyethyl methacrylate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-hydroxypropyl acrylate',
    'C<sub>6</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '999-61-1',
    'GWZMWHWAWHPNHN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxypropyl acrylate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hexanedioic acid, dimethyl ester',
    'C<sub>8</sub>H<sub>14</sub>O<sub>4</sub>',
    'dimethyl adipate',
    '627-93-0',
    'UDSFAEKRVUSQDD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexanedioic acid, dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanedioic acid, dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanedioic acid, dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0',
    '',
    '?',
    (SELECT id from species WHERE iupac='hexanedioic acid, dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3393'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl 4-hydroxybenzoate',
    'C<sub>8</sub>H<sub>8</sub>O<sub>3</sub>',
    'methylparaben',
    '99-76-3',
    'LXCFILQKKLGQFO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl 4-hydroxybenzoate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diethyl fumarate',
    'C<sub>8</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '623-91-6',
    'IEPRKVQEAMIZSS-AATRIKPKSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl fumarate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diethyl adipate',
    'C<sub>10</sub>H<sub>18</sub>O<sub>4</sub>',
    '',
    '141-28-6',
    'VIZORQUEIQEFRT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    'V',
    (SELECT id from species WHERE iupac='diethyl adipate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    'V',
    (SELECT id from species WHERE iupac='diethyl adipate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl adipate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7',
    '',
    '?',
    (SELECT id from species WHERE iupac='diethyl adipate'),
    (SELECT id from literature WHERE bibtexkey='3393'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propyl 4-hydroxybenzoate',
    'C<sub>10</sub>H<sub>12</sub>O<sub>3</sub>',
    'propylparaben',
    '94-13-3',
    'QELSKZZBTMNZEB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl 4-hydroxybenzoate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diethylene glycol diacrylate',
    'C<sub>10</sub>H<sub>14</sub>O<sub>5</sub>',
    '',
    '4074-88-8',
    'LEJBBGNFPAFPKQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethylene glycol diacrylate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(2,2-dimethyl-3-prop-2-enoyloxypropyl) prop-2-enoate',
    'C<sub>11</sub>H<sub>16</sub>O<sub>4</sub>',
    '2,2-dimethyltrimethylene acrylate',
    '2223-82-7',
    'MXFQRSUWYYSPOC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2,2-dimethyl-3-prop-2-enoyloxypropyl) prop-2-enoate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl jasmonate',
    'C<sub>13</sub>H<sub>20</sub>O<sub>3</sub>',
    '',
    '1211-29-6',
    'GEWDNTWNSAZUDX-NNOMMRTBSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methyl jasmonate'),
    (SELECT id from literature WHERE bibtexkey='3555'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl jasmonate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cinoxate',
    'C<sub>14</sub>H<sub>18</sub>O<sub>4</sub>',
    '',
    '104-28-9',
    'CMDKPGRTAQVGFQ-RMKNXTFCSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cinoxate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'trimethylolpropane triacrylate',
    'C<sub>15</sub>H<sub>20</sub>O<sub>6</sub>',
    '',
    '15625-89-5',
    'DAKWPKUUDNSNPN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trimethylolpropane triacrylate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benzyl cinnamate',
    'C<sub>16</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '103-41-3',
    'NGHOLYJTSCBCGC-VAWYXSNFSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzyl cinnamate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,4-trimethyl-1,3-pentanediol diisobutyrate',
    'C<sub>16</sub>H<sub>30</sub>O<sub>4</sub>',
    '',
    '6846-50-0',
    'OMVSWZDEEGIJJI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethyl-1,3-pentanediol diisobutyrate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nonanedioic acid, dibutyl ester',
    'C<sub>17</sub>H<sub>32</sub>O<sub>4</sub>',
    'dibutyl azelate',
    '2917-73-9',
    'RISLXYINQFKFRL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonanedioic acid, dibutyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'isopropyl myristate',
    'C<sub>17</sub>H<sub>34</sub>O<sub>2</sub>',
    '',
    '110-27-0',
    'AXISYYRBXTVTFY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isopropyl myristate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'decanedioic acid, dibutyl ester',
    'C<sub>18</sub>H<sub>34</sub>O<sub>4</sub>',
    '',
    '109-43-3',
    'PYGXAGIECVVIOZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='decanedioic acid, dibutyl ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='decanedioic acid, dibutyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decanedioic acid, dibutyl ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diethylene glycol dibenzoate',
    'C<sub>18</sub>H<sub>18</sub>O<sub>5</sub>',
    '',
    '120-55-8',
    'NXQMCAOPTPLPRL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethylene glycol dibenzoate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '12-hydroxy-9-octadecenoic acid, methyl ester',
    'C<sub>19</sub>H<sub>36</sub>O<sub>3</sub>',
    'ricinoleic acid, methyl ester',
    '141-24-2',
    'XKGDWZQXVZSXAO-RAXLEYEMSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='12-hydroxy-9-octadecenoic acid, methyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chrysanthemumic acid 2,4-dimethylbenzyl ester',
    'C<sub>19</sub>H<sub>26</sub>O<sub>2</sub>',
    'dimethrin',
    '70-38-2',
    'FHNKBSDJERHDHZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chrysanthemumic acid 2,4-dimethylbenzyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tributyl acetylcitrate',
    'C<sub>20</sub>H<sub>34</sub>O<sub>8</sub>',
    'acetyl tributyl citrate',
    '77-90-7',
    'QZCLKYGREBVARF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tributyl acetylcitrate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hexanedioic acid, bis[2-(2-butoxyethoxy)ethyl] ester',
    'C<sub>22</sub>H<sub>42</sub>O<sub>8</sub>',
    'bis(2-(2-butoxyethoxy)ethyl) adipate',
    '141-17-3',
    'SCABKEBYDRTODC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanedioic acid, bis[2-(2-butoxyethoxy)ethyl] ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-benzenedicarboxylic acid, decyl octyl ester',
    'C<sub>26</sub>H<sub>42</sub>O<sub>4</sub>',
    '',
    '119-07-3',
    'LVAGMBHLXLZJKZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-benzenedicarboxylic acid, decyl octyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phthalic acid, isodecyl octyl ester',
    'C<sub>26</sub>H<sub>42</sub>O<sub>4</sub>',
    '',
    '1330-96-7',
    'UXLBXTIBYMXRNX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phthalic acid, isodecyl octyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diisononyl hexahydrophthalate',
    'C<sub>26</sub>H<sub>48</sub>O<sub>4</sub>',
    '',
    '166412-78-8',
    'HORIEOQXBKUKGQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diisononyl hexahydrophthalate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'decanedioic acid, bis(2-ethylhexyl) ester',
    'C<sub>26</sub>H<sub>50</sub>O<sub>4</sub>',
    'bis(2-ethylhexyl) sebacate',
    '122-62-3',
    'VJHINFRRDQUWOJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decanedioic acid, bis(2-ethylhexyl) ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'glycerol tricaprylate',
    'C<sub>27</sub>H<sub>50</sub>O<sub>6</sub>',
    'tricaprylin',
    '538-23-8',
    'VLPFTAMPNXLGLX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='glycerol tricaprylate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tris(2-ethylhexyl) trimellitate',
    'C<sub>33</sub>H<sub>54</sub>O<sub>6</sub>',
    '',
    '3319-31-1',
    'KRADHMIOFJQKEZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tris(2-ethylhexyl) trimellitate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CHOOCH2OOH',
    'C<sub>2</sub>H<sub>4</sub>O<sub>4</sub>',
    '',
    '',
    'RHCLSHTZJFAXOU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOOCH2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOOCH2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOOCH2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CHOOCHO',
    'C<sub>2</sub>H<sub>2</sub>O<sub>3</sub>',
    '',
    '',
    'VGGRCVDNFAQIKO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOOCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOOCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOOCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CHOOMCO3H',
    'C<sub>3</sub>H<sub>4</sub>O<sub>5</sub>',
    '',
    '',
    'NYMJKVCDMUPZFI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOOMCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOOMCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOOMCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ETHFORMOOH',
    'C<sub>3</sub>H<sub>6</sub>O<sub>4</sub>',
    '',
    '',
    'DJECRZORXDSOEF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETHFORMOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETHFORMOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETHFORMOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MECOFOROOH',
    'C<sub>3</sub>H<sub>4</sub>O<sub>5</sub>',
    '',
    '',
    'TUWVUCWHUYJQAO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MECOFOROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MECOFOROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MECOFOROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:METACETHO',
    'C<sub>3</sub>H<sub>4</sub>O<sub>3</sub>',
    '',
    '',
    'ORWKVZNEPHTCQE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METACETHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METACETHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METACETHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:METACETO2H',
    'C<sub>3</sub>H<sub>6</sub>O<sub>4</sub>',
    '',
    '',
    'AIBRVUZTVKELQP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METACETO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METACETO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METACETO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MMCF',
    'C<sub>3</sub>H<sub>4</sub>O<sub>4</sub>',
    '',
    '',
    'IIHOUWJOSQHHHH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MMCF'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MMCF'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MMCF'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MMCFOOH',
    'C<sub>3</sub>H<sub>4</sub>O<sub>6</sub>',
    '',
    '',
    'LQGPNTLGGGGYKM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MMCFOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MMCFOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MMCFOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MOCOCH2OOH',
    'C<sub>3</sub>H<sub>6</sub>O<sub>4</sub>',
    '',
    '',
    'OQIIXPHPHGKJRP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MOCOCH2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MOCOCH2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MOCOCH2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ACEC2H4OOH',
    'C<sub>4</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'JNHNRXKAKFYQGM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACEC2H4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACEC2H4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACEC2H4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ACETMECO3H',
    'C<sub>4</sub>H<sub>6</sub>O<sub>5</sub>',
    '',
    '',
    'UCKKJLQTXHILBL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACETMECO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACETMECO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACETMECO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:COO2C3CO3H',
    'C<sub>4</sub>H<sub>6</sub>O<sub>5</sub>',
    '',
    '',
    'CKNWOSHDVKEZAO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:COO2C3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:COO2C3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:COO2C3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:COO2C4OOH',
    'C<sub>4</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'KATJWBCCJXQUDM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:COO2C4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:COO2C4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:COO2C4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EOCOCH2OOH',
    'C<sub>4</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'ZDXGLRBKCRTGQP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EOCOCH2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EOCOCH2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EOCOCH2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ETHACETOOH',
    'C<sub>4</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'FITNUWWXWGTMFO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETHACETOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETHACETOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETHACETOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPRFORMOOH',
    'C<sub>4</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'DHNDYBGDIQCRQB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRFORMOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRFORMOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRFORMOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'maleic anhydride',
    'C<sub>4</sub>H<sub>2</sub>O<sub>3</sub>',
    'MCM:MALANHY',
    '108-31-6',
    'FPYJFEHAWHCUMM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='maleic anhydride'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='maleic anhydride'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='maleic anhydride'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MECOACEOOH',
    'C<sub>4</sub>H<sub>6</sub>O<sub>5</sub>',
    '',
    '',
    'ZCPJTWSQAFRVMG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MECOACEOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MECOACEOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MECOACEOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ACCOETOOH',
    'C<sub>5</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'MRPVYADEHOUTJI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACCOETOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACCOETOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACCOETOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ACCOMECO3H',
    'C<sub>5</sub>H<sub>6</sub>O<sub>6</sub>',
    '',
    '',
    'OSZJUWKUAMKWAM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACCOMECO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACCOMECO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACCOMECO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ACETC2CO3H',
    'C<sub>5</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'LEMDJBHCHPODAJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACETC2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACETC2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACETC2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ACETCOC2H5',
    'C<sub>5</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'KLUDQUOLAFVLOL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACETCOC2H5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACETCOC2H5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACETCOC2H5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BUFORMOOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'HTFWPRQCJNWCFL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BUFORMOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BUFORMOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BUFORMOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:COO2C4CO3H',
    'C<sub>5</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'XFYUESMQFXHHIL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:COO2C4CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:COO2C4CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:COO2C4CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPRACBCO3H',
    'C<sub>5</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'IEXBKLGSFAHQBW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRACBCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRACBCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRACBCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPRACBOOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'HJBGHGSQOFAQDB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRACBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRACBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRACBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPRACOOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'UMMAXRSQAGVERV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRACOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRACOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRACOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MMALANHY',
    'C<sub>5</sub>H<sub>4</sub>O<sub>3</sub>',
    '',
    '',
    'AYKYXWQEBUNJCN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MMALANHY'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MMALANHY'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MMALANHY'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MTBEAALOOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'OJPAWJIXAIXDOD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBEAALOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBEAALOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBEAALOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MTBEALCO3H',
    'C<sub>5</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'GVHAIIVWIJOUAR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBEALCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBEALCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBEALCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NPRACAOOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'BAISPQOWBPLMQI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPRACAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPRACAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPRACAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NPRACBOOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'KUTULJFZWKOEBJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPRACBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPRACBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPRACBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NPRACCOOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'GYDFEBDSBUDYEN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPRACCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPRACCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPRACCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PRCOFORM',
    'C<sub>5</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'JKMPLJUAEDQBOK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRCOFORM'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRCOFORM'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRCOFORM'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PRCOFOROOH',
    'C<sub>5</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'VVRRHCGIFBEYON-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRCOFOROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRCOFOROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRCOFOROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PRCOOMOOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'JALZRJAYIBRIKJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRCOOMOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRCOOMOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRCOOMOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TLFUONE',
    'C<sub>5</sub>H<sub>6</sub>O<sub>2</sub>',
    '',
    '',
    'BGLUXFNVVSVEET-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TLFUONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TLFUONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TLFUONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ACCOPROOH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'HNMHVARGKGGINS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACCOPROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACCOPROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACCOPROOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ACETCOC3H7',
    'C<sub>6</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'BVQHHUQLZPXYAQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACETCOC3H7'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACETCOC3H7'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACETCOC3H7'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BOCOCH2OOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'DQCMTBDKSIDVDF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOCOCH2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOCOCH2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOCOCH2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DMMALANHY',
    'C<sub>6</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '',
    'MFGALGYVFGDXIX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMMALANHY'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMMALANHY'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMMALANHY'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EBFUONE',
    'C<sub>6</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '',
    'GOUILHYTHSOMQJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBFUONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBFUONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBFUONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EMALANHY',
    'C<sub>6</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '',
    'AXGOOCLYBPQWNG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EMALANHY'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EMALANHY'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EMALANHY'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MCOOTBOOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'GZZAVFPVGHHZEL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MCOOTBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MCOOTBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MCOOTBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MXYFUONE',
    'C<sub>6</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '',
    'SAXRUMLUKZBSTO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYFUONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYFUONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYFUONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NBUACAOOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'VUJYCIVMLKMZJB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBUACAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBUACAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBUACAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NBUACBOOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'ZDNJENJHBNLWSZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBUACBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBUACBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBUACBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NBUACCOOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'CCXFYGGLIMLVCI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBUACCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBUACCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBUACCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PRCOOMCO3H',
    'C<sub>6</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'NIESGQMUWIIUQP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRCOOMCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRCOOMCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRCOOMCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:SBUACAOOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'XEFYSNUZBIEBQZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:SBUACAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:SBUACAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:SBUACAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:SBUACBOOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'SHPWQWOSZRJPCY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:SBUACBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:SBUACBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:SBUACBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TBUACCO3H',
    'C<sub>6</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'CTLNPRHGCLAPPZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TBUACCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TBUACCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TBUACCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TMB1FUONE',
    'C<sub>6</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '',
    'GLCOTRLUPUIAFI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TMB1FUONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TMB1FUONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TMB1FUONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPBFUONE',
    'C<sub>7</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'LWFKYUIZWLTJCA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBFUONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBFUONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBFUONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPMALANHY',
    'C<sub>7</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'QSWLSAYLEATCSH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPMALANHY'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPMALANHY'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPMALANHY'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MEBFUONE',
    'C<sub>7</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'UVERQUDHQJYTIT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MEBFUONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MEBFUONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MEBFUONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PBFUONE',
    'C<sub>7</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'CLCLZCBNFSGUOD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBFUONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBFUONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBFUONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PMALANHY',
    'C<sub>7</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'LPFJFXRQANKTRA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PMALANHY'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PMALANHY'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PMALANHY'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TMB2FUONE',
    'C<sub>7</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'OSFZDFIHIYXIEL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TMB2FUONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TMB2FUONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TMB2FUONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1013OOH',
    'C<sub>10</sub>H<sub>18</sub>O<sub>4</sub>',
    '',
    '',
    'BQYOGPDLQGPEQM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1013OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1013OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1013OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1013CO3H',
    'C<sub>11</sub>H<sub>18</sub>O<sub>5</sub>',
    '',
    '',
    'ZWRGNVXICSEPNH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1013CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1013CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1013CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PXYFUONE',
    'C<sub>5</sub>H<sub>6</sub>O<sub>2</sub>',
    '',
    '',
    'VGHBEMPMIVEGJP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYFUONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYFUONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYFUONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OXYFUONE',
    'C<sub>6</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '',
    'QHQDWCHELGHSTO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYFUONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYFUONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYFUONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CHOOCH2OH',
    'C<sub>2</sub>H<sub>4</sub>O<sub>3</sub>',
    '',
    '',
    'APUQIHKCZFWODD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOOCH2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOOCH2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOOCH2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ETHFORMOH',
    'C<sub>3</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '',
    'JRUKHAIVAGVYRP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETHFORMOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETHFORMOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETHFORMOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ETOHOCHO',
    'C<sub>3</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '',
    'UKQJDWBNQNAJHB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETOHOCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETOHOCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETOHOCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:METACETOH',
    'C<sub>3</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '',
    'JYVNDCLJHKQUHE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METACETOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METACETOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METACETOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MMCFOH',
    'C<sub>3</sub>H<sub>4</sub>O<sub>5</sub>',
    '',
    '',
    'XDYLYGBFMHJJOW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MMCFOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MMCFOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MMCFOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MOXCOCH2OH',
    'C<sub>3</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '',
    'GSJFXBNYJCXDGI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MOXCOCH2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MOXCOCH2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MOXCOCH2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ACEETOHOOH',
    'C<sub>4</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'QQYYYRFGUJQKRH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACEETOHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACEETOHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACEETOHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BZFUOH',
    'C<sub>4</sub>H<sub>6</sub>O<sub>4</sub>',
    '',
    '',
    'SGMJBNSHAZVGMC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BZFUOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BZFUOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BZFUOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BZFUOOH',
    'C<sub>4</sub>H<sub>6</sub>O<sub>5</sub>',
    '',
    '',
    'LZJWYIKGTDPLAQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BZFUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BZFUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BZFUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EOX2COMEOH',
    'C<sub>4</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'ZANNOFHADGWOLI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EOX2COMEOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EOX2COMEOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EOX2COMEOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ETACETOH',
    'C<sub>4</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'HXDLWJWIAHWIKI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETACETOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETACETOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETACETOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ETHACETOH',
    'C<sub>4</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'MLAFRLBDNVSLPE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETHACETOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETHACETOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETHACETOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HOACETEOOH',
    'C<sub>4</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'QWYGOSGRTMPWCI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOACETEOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOACETEOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOACETEOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPRFORMOH',
    'C<sub>4</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'SVJMGLNDGCVDIT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRFORMOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRFORMOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRFORMOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MALANHY2OH',
    'C<sub>4</sub>H<sub>4</sub>O<sub>5</sub>',
    '',
    '',
    'BOGVTNYNTGOONP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MALANHY2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MALANHY2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MALANHY2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MALANHYOOH',
    'C<sub>4</sub>H<sub>4</sub>O<sub>6</sub>',
    '',
    '',
    'UPSCPEYLZZUIND-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>12</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MALANHYOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MALANHYOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MALANHYOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PROL2FORM',
    'C<sub>4</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'CRMUFGZQBODVGS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PROL2FORM'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PROL2FORM'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PROL2FORM'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BUOHFORM',
    'C<sub>5</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'KIZCCPGSHHAFRX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BUOHFORM'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BUOHFORM'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BUOHFORM'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPRACBOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'YJNKLTDJZSXVHQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRACBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRACBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRACBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPRACOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'MYOAZFOMGTTYOD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRACOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRACOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRACOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MMALNHY2OH',
    'C<sub>5</sub>H<sub>6</sub>O<sub>5</sub>',
    '',
    '',
    'DGWWNMWYNUWPBC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MMALNHY2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MMALNHY2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MMALNHY2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MMALNHYOOH',
    'C<sub>5</sub>H<sub>6</sub>O<sub>6</sub>',
    '',
    '',
    'JNCHKPBVXWMPAJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MMALNHYOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MMALNHYOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MMALNHYOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MTBEACHOHO',
    'C<sub>5</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'GQMJADBSHHFADW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBEACHOHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBEACHOHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBEACHOHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NPRACAOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'PPPFYBPQAPISCT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPRACAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPRACAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPRACAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NPRACBOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'VEGXEWGKYMMJKP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPRACBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPRACBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPRACBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NPRACCOH',
    'C<sub>5</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'DOUBAFNWVFAWEC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPRACCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPRACCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPRACCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PXYFUOH',
    'C<sub>5</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'OHTGZAWPVDWARE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYFUOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYFUOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYFUOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PXYFUOOH',
    'C<sub>5</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'IEFDVDGOIVKGRZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYFUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYFUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYFUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TLFUOH',
    'C<sub>5</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'JYHWQRJRDKSSIF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TLFUOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TLFUOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TLFUOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TLFUOOH',
    'C<sub>5</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'GNXADMJANDYCAE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TLFUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TLFUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TLFUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BOX2COMOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'VFGRALUHHHDIQI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOX2COMOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOX2COMOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOX2COMOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DMMALYOH',
    'C<sub>6</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'KIOPGGAGDHZEGB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMMALYOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMMALYOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMMALYOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DMMALYOOH',
    'C<sub>6</sub>H<sub>8</sub>O<sub>6</sub>',
    '',
    '',
    'VRKLPKITGMCVQP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMMALYOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMMALYOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMMALYOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EBFUOH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'AQSJHOPJZAKOAP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBFUOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBFUOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBFUOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EBFUOOH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'KIZOVCBYCQGADC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBFUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBFUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBFUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EMALNHY2OH',
    'C<sub>6</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'GPJQUVLKFIAXFZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EMALNHY2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EMALNHY2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EMALNHY2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EMALNHYOOH',
    'C<sub>6</sub>H<sub>8</sub>O<sub>6</sub>',
    '',
    '',
    'LSSHMOINJMVLHQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EMALNHYOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EMALNHYOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EMALNHYOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MXYFUOH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'WCMYKJKBZGIGND-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYFUOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYFUOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYFUOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MXYFUOOH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'WCIMCWKIICZLLM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYFUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYFUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYFUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NBUACAOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'KLUHZXMBIDAHSJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBUACAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBUACAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBUACAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NBUACBOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'BZLQSYFOTWOIDC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBUACBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBUACBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBUACBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NBUACCOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'BMNRJWUOBYYCRX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBUACCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBUACCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBUACCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OXYFUOH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'GZKXVWYDQQSODI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYFUOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYFUOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYFUOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OXYFUOOH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'DHHFHIZBMAEZJT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYFUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYFUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYFUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PRCOOETOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'GIOCILWWMFZESP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRCOOETOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRCOOETOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRCOOETOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:SBUACAOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'WAXXMBOGFVJIHX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:SBUACAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:SBUACAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:SBUACAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:SBUACBOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'BCWWODMTUXMSAB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:SBUACBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:SBUACBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:SBUACBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TBOCOCH2OH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'WINGEFIITRDOLJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TBOCOCH2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TBOCOCH2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TBOCOCH2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TBUACOH',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'GWOKHTMCBUZSOP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TBUACOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TBUACOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TBUACOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TMB1FUOH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'AUTABLFJFWRKGZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TMB1FUOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TMB1FUOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TMB1FUOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TMB1FUOOH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'NFODFJMABSYJFC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TMB1FUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TMB1FUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TMB1FUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BOXCOOLOOH',
    'C<sub>7</sub>H<sub>14</sub>O<sub>5</sub>',
    '',
    '',
    'PDOIGHDIMNJPNL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXCOOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXCOOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXCOOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPBFUOH',
    'C<sub>7</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'ZIPHTXAVHSYMQR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBFUOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBFUOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBFUOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPBFUOOH',
    'C<sub>7</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'HVQWCSPFZPPNOE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBFUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBFUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBFUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPMLNHY2OH',
    'C<sub>7</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'RBIJYTIBBLMIRU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPMLNHY2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPMLNHY2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPMLNHY2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPMLNHYOOH',
    'C<sub>7</sub>H<sub>10</sub>O<sub>6</sub>',
    '',
    '',
    'LGGLTRMSNOIPLU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPMLNHYOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPMLNHYOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPMLNHYOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MEBFUOH',
    'C<sub>7</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'SYHJYGJIPQZFIO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MEBFUOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MEBFUOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MEBFUOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MEBFUOOH',
    'C<sub>7</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'VRHMFTJWRSNJLN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MEBFUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MEBFUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MEBFUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PBFUOH',
    'C<sub>7</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'DMMDFVMQHRHVSU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBFUOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBFUOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBFUOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PBFUOOH',
    'C<sub>7</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'KAMUACRVJWJEFX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBFUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBFUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBFUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PMALNHY2OH',
    'C<sub>7</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'PVDNZCIFUUKKBS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PMALNHY2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PMALNHY2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PMALNHY2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PMALNHYOOH',
    'C<sub>7</sub>H<sub>10</sub>O<sub>6</sub>',
    '',
    '',
    'VKSMRBCXNQEUFP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PMALNHYOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PMALNHYOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PMALNHYOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PRCOOPROL',
    'C<sub>7</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'QXXGFEMAULVMST-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRCOOPROL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRCOOPROL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRCOOPROL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TMB2FUOH',
    'C<sub>7</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'YEQCQVSGZKCWAA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TMB2FUOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TMB2FUOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TMB2FUOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TMB2FUOOH',
    'C<sub>7</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'MINPHQZFUPUEBD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TMB2FUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TMB2FUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TMB2FUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1013OH',
    'C<sub>10</sub>H<sub>18</sub>O<sub>3</sub>',
    '',
    '',
    'OYGVMQZTRRRABW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1013OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1013OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1013OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ALCOMOXOOH',
    'C<sub>3</sub>H<sub>4</sub>O<sub>5</sub>',
    '',
    '',
    'DRQRCDXSDDWNEU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ALCOMOXOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ALCOMOXOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ALCOMOXOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DFC',
    'C<sub>3</sub>H<sub>2</sub>O<sub>5</sub>',
    '',
    '',
    'DOMHJQJKOPZSOM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DFC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DFC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DFC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MOXY2CHO',
    'C<sub>3</sub>H<sub>4</sub>O<sub>3</sub>',
    '',
    '',
    'MFRMAQFRVTUENW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MOXY2CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MOXY2CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MOXY2CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MOXYCOCHO',
    'C<sub>3</sub>H<sub>4</sub>O<sub>3</sub>',
    '',
    '',
    'KFKXSMSQHIOMSO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MOXYCOCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MOXYCOCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MOXYCOCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ACETETCHO',
    'C<sub>4</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '',
    'GUPGZURVZDIQPM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACETETCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACETETCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACETETCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO14O3CHO',
    'C<sub>4</sub>H<sub>4</sub>O<sub>4</sub>',
    '',
    '',
    'ZFWWLKBCHQUFEJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO14O3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO14O3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO14O3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:COO2C3CHO',
    'C<sub>4</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '',
    'AGADEVQOWQDDFX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:COO2C3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:COO2C3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:COO2C3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EOCOCHO',
    'C<sub>4</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '',
    'DBPFRRFGLYGEJI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EOCOCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EOCOCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EOCOCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ACCOMECHO',
    'C<sub>5</sub>H<sub>6</sub>O<sub>4</sub>',
    '',
    '',
    'GRUDDVNYUQQBCU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACCOMECHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACCOMECHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACCOMECHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ACEC2CHO',
    'C<sub>5</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'PRSPLAWXBFRHKV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACEC2CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACEC2CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACEC2CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:COO2C4CHO',
    'C<sub>5</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'DLZVZNAPRCRXEG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:COO2C4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:COO2C4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:COO2C4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPRACBCHO',
    'C<sub>5</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'FXPPNKAYSGWCQG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRACBCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRACBCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRACBCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MTBEACHO13',
    'C<sub>5</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'MDWWHOIDIKOPHH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBEACHO13'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBEACHO13'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBEACHO13'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BOXCOALOOH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'MZUJTBRWESAMQA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXCOALOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXCOALOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXCOALOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BOXCOCHO',
    'C<sub>6</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'NRYDRJHYTRBBEA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXCOCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXCOCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXCOCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C14O3ECHO',
    'C<sub>6</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'FVLOJCOPOCRBFF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C14O3ECHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C14O3ECHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C14O3ECHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PRCOOMCHO',
    'C<sub>6</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'YEBNSRBQIIWQQC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRCOOMCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRCOOMCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRCOOMCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TBOCOCHO',
    'C<sub>6</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'WDPZTIFGRQKSEN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TBOCOCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TBOCOCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TBOCOCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TBUACCO',
    'C<sub>6</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'BYYPPVMBDPUHHR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TBUACCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TBUACCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TBUACCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C14O3IPCHO',
    'C<sub>7</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'NPPWDFRKAMDHMM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C14O3IPCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C14O3IPCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C14O3IPCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C14O3PCHO',
    'C<sub>7</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'GNODSIBUYMXKGR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C14O3PCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C14O3PCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C14O3PCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1014OOH',
    'C<sub>10</sub>H<sub>18</sub>O<sub>5</sub>',
    '',
    '',
    'REYZAYCUYYNPLJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1014OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1014OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1014OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BCALBOC',
    'C<sub>15</sub>H<sub>24</sub>O<sub>3</sub>',
    '',
    '',
    'FEPYZLRQFOQWRK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCALBOC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCALBOC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCALBOC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CHOOMCO2H',
    'C<sub>3</sub>H<sub>6</sub>O<sub>4</sub>',
    '',
    '',
    'CBNAABWGSNQFTA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOOMCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOOMCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOOMCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1014OH',
    'C<sub>10</sub>H<sub>18</sub>O<sub>4</sub>',
    '',
    '',
    'IJPJFXOOJHUBTK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1014OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1014OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1014OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C152OH',
    'C<sub>15</sub>H<sub>26</sub>O<sub>5</sub>',
    '',
    '',
    'XZXFZFZFZSKVDT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C152OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C152OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C152OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C152OOH',
    'C<sub>15</sub>H<sub>26</sub>O<sub>6</sub>',
    '',
    '',
    'PKQOWOPWICZSPN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C152OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C152OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C152OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C23O3CHO',
    'C<sub>4</sub>H<sub>4</sub>O<sub>4</sub>',
    '',
    '',
    'RULCSXTUAHNYHJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23O3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23O3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23O3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MCOCOMOOOH',
    'C<sub>4</sub>H<sub>6</sub>O<sub>5</sub>',
    '',
    '',
    'BJTKGFWDIAZUGI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MCOCOMOOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MCOCOMOOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MCOCOMOOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MCOCOMOX',
    'C<sub>4</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '',
    'CWKLZLBVOJRSOM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MCOCOMOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MCOCOMOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MCOCOMOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PRNFORMOOH',
    'C<sub>4</sub>H<sub>6</sub>O<sub>5</sub>',
    '',
    '',
    'LIFMXPSJWIBAGH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRNFORMOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRNFORMOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRNFORMOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PRONFORM',
    'C<sub>4</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '',
    'WNVAJGCMEDTLIE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRONFORM'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRONFORM'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRONFORM'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ACCOCOMOOH',
    'C<sub>5</sub>H<sub>6</sub>O<sub>6</sub>',
    '',
    '',
    'WKJHUBLAYZIBAJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACCOCOMOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACCOCOMOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACCOCOMOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ACECOCOCH3',
    'C<sub>5</sub>H<sub>6</sub>O<sub>4</sub>',
    '',
    '',
    'OBTVATRSWTWNGS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACECOCOCH3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACECOCOCH3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACECOCOCH3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ACEPROPONE',
    'C<sub>5</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'DBERHVIZRVGDFO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACEPROPONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACEPROPONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACEPROPONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ACPRONEOOH',
    'C<sub>5</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'FOWIMBLOPIOWII-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACPRONEOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACPRONEOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACPRONEOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C23O3CCO3H',
    'C<sub>5</sub>H<sub>6</sub>O<sub>6</sub>',
    '',
    '',
    'SPYAIQASSDQEIX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23O3CCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23O3CCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23O3CCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C23O3MCOOH',
    'C<sub>5</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'RVGUYYZMHBERKG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23O3MCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23O3MCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23O3MCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PRNOCOMOOH',
    'C<sub>5</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'GJTAOZDAMDVHTP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRNOCOMOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRNOCOMOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRNOCOMOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ACBUOAOOH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'BDHJVYCZNHBETI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACBUOAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACBUOAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACBUOAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ACBUONBOOH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'RISONYRIGLPILV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACBUONBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACBUONBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACBUONBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ACCOCOC2H5',
    'C<sub>6</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'WZGYRWNUCYXCFD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACCOCOC2H5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACCOCOC2H5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACCOCOC2H5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ACCOCOEOOH',
    'C<sub>6</sub>H<sub>8</sub>O<sub>6</sub>',
    '',
    '',
    'RKPSGJVLERUIIG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACCOCOEOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACCOCOEOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACCOCOEOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ACCOPRONE',
    'C<sub>6</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'RYLHMXPGTMYTTF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACCOPRONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACCOPRONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACCOPRONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ACEBUTBONE',
    'C<sub>6</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'LHGWJCBYBIICPP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACEBUTBONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACEBUTBONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACEBUTBONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ACEBUTONE',
    'C<sub>6</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'NWCYECXHIYEBJE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACEBUTONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACEBUTONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACEBUTONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ACOMCOMOOH',
    'C<sub>6</sub>H<sub>8</sub>O<sub>6</sub>',
    '',
    '',
    'NKXSSYAJYGYQPN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACOMCOMOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACOMCOMOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACOMCOMOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C23O3ECOOH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'NLYPTRYHUBHKKI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23O3ECOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23O3ECOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23O3ECOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C23O3EHO',
    'C<sub>6</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'AIDIMUPPUNPUTI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23O3EHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23O3EHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23O3EHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C23O3MCO3H',
    'C<sub>6</sub>H<sub>8</sub>O<sub>6</sub>',
    '',
    '',
    'FIPISRZHVPVVNA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23O3MCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23O3MCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23O3MCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6O4KETOOH',
    'C<sub>6</sub>H<sub>6</sub>O<sub>7</sub>',
    '',
    '',
    'LLKUMVBDCSCXDR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6O4KETOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6O4KETOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6O4KETOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6OTKETCO',
    'C<sub>6</sub>H<sub>6</sub>O<sub>5</sub>',
    '',
    '',
    'GAPVBMQBWAUBHC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6OTKETCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6OTKETCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6OTKETCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6OTKETOOH',
    'C<sub>6</sub>H<sub>8</sub>O<sub>6</sub>',
    '',
    '',
    'USMDUVUWRKQXQG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6OTKETOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6OTKETOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6OTKETOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6OTRIKET',
    'C<sub>6</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'XAHWCAXZWOTSBC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6OTRIKET'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6OTRIKET'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6OTRIKET'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO356OCOOH',
    'C<sub>6</sub>H<sub>8</sub>O<sub>6</sub>',
    '',
    '',
    'MVKXXKVCXUKLOS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO356OCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO356OCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO356OCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:SBUACCOOH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'DTGNYNGASXJUMP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:SBUACCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:SBUACCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:SBUACCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:SBUACEONE',
    'C<sub>6</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'ZKPTYCJWRHHBOW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:SBUACEONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:SBUACEONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:SBUACEONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BOX2COMOOH',
    'C<sub>7</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'YCDXONIQHOVSSF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOX2COMOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOX2COMOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOX2COMOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BOXCOCOME',
    'C<sub>7</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'ZAZUOXBHFXAWMD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXCOCOME'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXCOCOME'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXCOCOME'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C23O3ECO3H',
    'C<sub>7</sub>H<sub>10</sub>O<sub>6</sub>',
    '',
    '',
    'FWVKIPPVGIEQRB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23O3ECO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23O3ECO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23O3ECO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MC6OTKTOOH',
    'C<sub>7</sub>H<sub>10</sub>O<sub>6</sub>',
    '',
    '',
    'DJTBKMNUYULRIV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MC6OTKTOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MC6OTKTOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MC6OTKTOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MC6OTRIKET',
    'C<sub>7</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'FJYCWZCSXDGURV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MC6OTRIKET'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MC6OTRIKET'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MC6OTRIKET'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PRCOOPRONE',
    'C<sub>7</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'AIJLJYUDTAJRDN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRCOOPRONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRCOOPRONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRCOOPRONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PRNOCOPOOH',
    'C<sub>7</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'RGEURRORAZXRIV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRNOCOPOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRNOCOPOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRNOCOPOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1013CO',
    'C<sub>10</sub>H<sub>16</sub>O<sub>3</sub>',
    '',
    '',
    'DPRGOCIPALHGLN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1013CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1013CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1013CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BZFUCO',
    'C<sub>4</sub>H<sub>4</sub>O<sub>4</sub>',
    '',
    '',
    'MFFNSLKCUZEAFI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BZFUCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BZFUCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BZFUCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MALNHYOHCO',
    'C<sub>4</sub>H<sub>2</sub>O<sub>5</sub>',
    '',
    '',
    'DBWAPECJPVXLJZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MALNHYOHCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MALNHYOHCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MALNHYOHCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ACPRONEOH',
    'C<sub>5</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'LBOLMEABDOYQGX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACPRONEOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACPRONEOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACPRONEOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C23O3MOH',
    'C<sub>5</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'WHFDSTOTVFOUIH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23O3MOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23O3MOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23O3MOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ACBUONAOH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'UGJVDYQVVBKWGL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACBUONAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACBUONAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACBUONAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ACBUONBOH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'GYQPXJWBTJDNGC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACBUONBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACBUONBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACBUONBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C23O3EOH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'BVDDSYZMRAYYIJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23O3EOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23O3EOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23O3EOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6OTKETOH',
    'C<sub>6</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'NOUUUBJIFPBZMZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>4</sup>',
    '16000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6OTKETOH'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6OTKETOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6OTKETOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6OTKETOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EBFUCO',
    'C<sub>6</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'QFGGPABGKQEYQI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBFUCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBFUCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBFUCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:SBUACCOH',
    'C<sub>6</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'SUDJMSTXSVVFNQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:SBUACCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:SBUACCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:SBUACCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPBFUCO',
    'C<sub>7</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'NHSFIZKDULUUEP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBFUCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBFUCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBFUCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MC6OTKETOH',
    'C<sub>7</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'GQVIXHCRVNFYGI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MC6OTKETOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MC6OTKETOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MC6OTKETOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PBFUCO',
    'C<sub>7</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'PKKIVTPUHZVJRM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBFUCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBFUCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBFUCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C23O3CCHO',
    'C<sub>5</sub>H<sub>6</sub>O<sub>4</sub>',
    '',
    '',
    'JQZIMULKJBYVEJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23O3CCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23O3CCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23O3CCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C23O3MCHO',
    'C<sub>6</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'KNKMVXKCHLTCEX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23O3MCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23O3MCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23O3MCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5OCO3M',
    'C<sub>6</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'MFFVRQLCBYBQSQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5OCO3M'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5OCO3M'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5OCO3M'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C23O3ECHO',
    'C<sub>7</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'RCPFVGJRKWBYKE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23O3ECHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23O3ECHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23O3ECHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1014CO',
    'C<sub>10</sub>H<sub>16</sub>O<sub>4</sub>',
    '',
    '',
    'MPJVRMHYAPYGFM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1014CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1014CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1014CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BCLKBOC',
    'C<sub>14</sub>H<sub>22</sub>O<sub>4</sub>',
    '',
    '',
    'YETGIZICMMLUOK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCLKBOC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCLKBOC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCLKBOC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C148CO',
    'C<sub>14</sub>H<sub>20</sub>O<sub>5</sub>',
    '',
    '',
    'WKRISEJACIFSSJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C148CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C148CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C148CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C148OOH',
    'C<sub>14</sub>H<sub>22</sub>O<sub>6</sub>',
    '',
    '',
    'QNGFZXSUHFZFIE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C148OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C148OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C148OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C148OH',
    'C<sub>14</sub>H<sub>22</sub>O<sub>5</sub>',
    '',
    '',
    'LXDPLKVHKWYPKP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C148OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C148OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C148OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ACETC2CO2H',
    'C<sub>5</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'RFEXARYJXBYPLD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACETC2CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACETC2CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACETC2CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C24O3CCO2H',
    'C<sub>5</sub>H<sub>6</sub>O<sub>5</sub>',
    '',
    '',
    'HSSKPURIBYAXCO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C24O3CCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C24O3CCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C24O3CCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPRACBCO2H',
    'C<sub>5</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'WTLNOANVTIKPEE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRACBCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRACBCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRACBCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MTBEALCO2H',
    'C<sub>5</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'BXXOFUQIACXFIW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBEALCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBEALCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBEALCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1013CO2H',
    'C<sub>11</sub>H<sub>18</sub>O<sub>4</sub>',
    '',
    '',
    'QWGCLZMSSSTRLX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1013CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1013CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1013CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO14O3CO2H',
    'C<sub>4</sub>H<sub>4</sub>O<sub>5</sub>',
    '',
    '',
    'OPFWUCMVKDVVTF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO14O3CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO14O3CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO14O3CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C23O3CCO2H',
    'C<sub>5</sub>H<sub>6</sub>O<sub>5</sub>',
    '',
    '',
    'WRKCXTWVOWDGBE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23O3CCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23O3CCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23O3CCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C23O3MCO2H',
    'C<sub>6</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'OGSBZWITKXVLIV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23O3MCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23O3MCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23O3MCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C23O3ECO2H',
    'C<sub>7</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'OEONINCNUUTEPU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Esters (RCOOR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23O3ECO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23O3ECO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23O3ECO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Ethers (ROR)',
    (SELECT id from categories WHERE catname='Organic species with oxygen (O)'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimethyl ether',
    'CH<sub>3</sub>OCH<sub>3</sub>',
    '',
    '115-10-6',
    'LCGLNKUTAGEVQW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dimethyl ether'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dimethyl ether'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dimethyl ether'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dimethyl ether'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dimethyl ether'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;3</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='dimethyl ether'),
    (SELECT id from literature WHERE bibtexkey='714'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '4900',
    'T',
    (SELECT id from species WHERE iupac='dimethyl ether'),
    (SELECT id from literature WHERE bibtexkey='2016'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2016'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dimethyl ether'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at291K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl ether'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl ether'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl ether'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl ether'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl ether'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl ether'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl ether'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl ether'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl ether'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl ether'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl ether'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl ether'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl ether'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-P'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl ether'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dimethyl ether'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at291K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dimethyl ether'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dimethyl ether'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyl methyl ether',
    'C<sub>2</sub>H<sub>5</sub>OCH<sub>3</sub>',
    '',
    '540-67-0',
    'XOBKSJJDNFUZPF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl methyl ether'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='ethyl methyl ether'),
    (SELECT id from literature WHERE bibtexkey='2016'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2016'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl methyl ether'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl methyl ether'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl methyl ether'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl methyl ether'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl methyl ether'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl methyl ether'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;3</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='ethyl methyl ether'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethyl methyl ether'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diethyl ether',
    'C<sub>2</sub>H<sub>5</sub>OC<sub>2</sub>H<sub>5</sub>',
    '',
    '60-29-7',
    'RTZKZFJDLAIYFH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;3</sup>',
    '5800',
    'L',
    (SELECT id from species WHERE iupac='diethyl ether'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '5800',
    'L',
    (SELECT id from species WHERE iupac='diethyl ether'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;3</sup>',
    '5800',
    'L',
    (SELECT id from species WHERE iupac='diethyl ether'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='diethyl ether'),
    (SELECT id from literature WHERE bibtexkey='2441'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;3</sup>',
    '5000',
    'L',
    (SELECT id from species WHERE iupac='diethyl ether'),
    (SELECT id from literature WHERE bibtexkey='3696'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '6600',
    'M',
    (SELECT id from species WHERE iupac='diethyl ether'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='diethyl ether'),
    (SELECT id from literature WHERE bibtexkey='2955'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '5700',
    'M',
    (SELECT id from species WHERE iupac='diethyl ether'),
    (SELECT id from literature WHERE bibtexkey='3305'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='diethyl ether'),
    (SELECT id from literature WHERE bibtexkey='622'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='diethyl ether'),
    (SELECT id from literature WHERE bibtexkey='3675'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;3</sup>',
    '3900',
    'M',
    (SELECT id from species WHERE iupac='diethyl ether'),
    (SELECT id from literature WHERE bibtexkey='2901'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2901'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='diethyl ether'),
    (SELECT id from literature WHERE bibtexkey='2924'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '7400',
    'M',
    (SELECT id from species WHERE iupac='diethyl ether'),
    (SELECT id from literature WHERE bibtexkey='3697'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='diethyl ether'),
    (SELECT id from literature WHERE bibtexkey='3698'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='diethyl ether'),
    (SELECT id from literature WHERE bibtexkey='795'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='diethyl ether'),
    (SELECT id from literature WHERE bibtexkey='3699'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diethyl ether'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '5800',
    'V',
    (SELECT id from species WHERE iupac='diethyl ether'),
    (SELECT id from literature WHERE bibtexkey='3693'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diethyl ether'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diethyl ether'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diethyl ether'),
    (SELECT id from literature WHERE bibtexkey='714'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diethyl ether'),
    (SELECT id from literature WHERE bibtexkey='713'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;3</sup>',
    '5700',
    'T',
    (SELECT id from species WHERE iupac='diethyl ether'),
    (SELECT id from literature WHERE bibtexkey='2016'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2016'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='diethyl ether'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl ether'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl ether'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl ether'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl ether'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl ether'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl ether'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl ether'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl ether'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl ether'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl ether'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl ether'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl ether'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl ether'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5300',
    'Q',
    (SELECT id from species WHERE iupac='diethyl ether'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl ether'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl ether'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl ether'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl ether'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl ether'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl ether'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='diethyl ether'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5700',
    '?',
    (SELECT id from species WHERE iupac='diethyl ether'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='diethyl ether'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='diethyl ether'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='diethyl ether'),
    (SELECT id from literature WHERE bibtexkey='637'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='diethyl ether'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diethyl ether-d10',
    'C<sub>2</sub>D<sub>5</sub>OC<sub>2</sub>D<sub>5</sub>',
    '',
    '2679-89-2',
    'RTZKZFJDLAIYFH-MWUKXHIBSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '6500',
    'M',
    (SELECT id from species WHERE iupac='diethyl ether-d10'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl propyl ether',
    'CH<sub>3</sub>OC<sub>3</sub>H<sub>7</sub>',
    '',
    '557-17-5',
    'VNKYTQGIUYNRMY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl propyl ether'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl propyl ether'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl propyl ether'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methyl propyl ether'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl propyl ether'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl propyl ether'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl propyl ether'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl propyl ether'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl propyl ether'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl propyl ether'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl propyl ether'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl propyl ether'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl propyl ether'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl propyl ether'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl propyl ether'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl propyl ether'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methyl propyl ether'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl 2-propyl ether',
    'CH<sub>3</sub>OC<sub>3</sub>H<sub>7</sub>',
    'methyl isopropyl ether',
    '598-53-8',
    'RMGHERXMTMUMMV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl 2-propyl ether'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl 2-propyl ether'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methyl 2-propyl ether'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methyl 2-propyl ether'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl 2-propyl ether'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl 2-propyl ether'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl 2-propyl ether'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl 2-propyl ether'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl 2-propyl ether'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl 2-propyl ether'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl 2-propyl ether'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl 2-propyl ether'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl 2-propyl ether'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl 2-propyl ether'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl 2-propyl ether'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methyl 2-propyl ether'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'divinyl ether',
    'C<sub>4</sub>H<sub>6</sub>O',
    '',
    '109-93-3',
    'QYKIQEUNHZKYBP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='divinyl ether'),
    (SELECT id from literature WHERE bibtexkey='2441'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='divinyl ether'),
    (SELECT id from literature WHERE bibtexkey='3696'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='divinyl ether'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='divinyl ether'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='divinyl ether'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='divinyl ether'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='divinyl ether'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='divinyl ether'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='divinyl ether'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='divinyl ether'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='divinyl ether'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='divinyl ether'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl butyl ether',
    'C<sub>5</sub>H<sub>12</sub>O',
    '',
    '628-28-4',
    'CXBDYQVECUFKRK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;3</sup>',
    '6100',
    'L',
    (SELECT id from species WHERE iupac='methyl butyl ether'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3518-628-28-4-consicheck',
    '3518', 'Values at 298&nbsp;K in Tables&nbsp;C2 and C5 of Brockbank (2013) are inconsistent, with 17&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3518-628-28-4-consicheck'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl butyl ether'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl butyl ether'),
    (SELECT id from literature WHERE bibtexkey='2388'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methyl butyl ether'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl butyl ether'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl butyl ether'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl butyl ether'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl butyl ether'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl butyl ether'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl butyl ether'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl butyl ether'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl butyl ether'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl butyl ether'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methoxybutane',
    'C<sub>5</sub>H<sub>12</sub>O',
    'methyl <i>sec</i>-butyl ether',
    '6795-87-5',
    'FVNIMHIOIXPIQT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methoxybutane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methoxybutane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methoxybutane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methoxybutane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methoxybutane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methoxybutane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methoxybutane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methoxybutane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methoxybutane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methoxybutane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methoxybutane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl isobutyl ether',
    'C<sub>5</sub>H<sub>12</sub>O',
    '',
    '625-44-5',
    'ZYVYEJXMYBUCMN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;3</sup>',
    '6700',
    'L',
    (SELECT id from species WHERE iupac='methyl isobutyl ether'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl isobutyl ether'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methyl isobutyl ether'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl isobutyl ether'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl isobutyl ether'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl isobutyl ether'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl isobutyl ether'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl isobutyl ether'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl isobutyl ether'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methyl isobutyl ether'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl <i>tert</i>-butyl ether',
    'CH<sub>3</sub>OC(CH<sub>3</sub>)<sub>3</sub>',
    'MTBE',
    '1634-04-4',
    'BZLVMXJERCGZMT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '5100',
    'L',
    (SELECT id from species WHERE iupac='methyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='3681'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '5900',
    'L',
    (SELECT id from species WHERE iupac='methyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '9100',
    'M',
    (SELECT id from species WHERE iupac='methyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '18000',
    'M',
    (SELECT id from species WHERE iupac='methyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='2921'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2921H0'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='2921'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2921H1'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '5300',
    'M',
    (SELECT id from species WHERE iupac='methyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='3691'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HTdep_r2_lessthan_0.9'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3691',
    '3691', 'Hwang et&nbsp;al. (2010) present regression parameters in their Table&nbsp;6 and values extrapolated to 298.15&nbsp;K in their Table&nbsp;5. However, I was not able to reproduce their calculation. The data shown here are from my own regression of the measured data between 318.15&nbsp;K and 333.15&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3691'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '4800',
    'M',
    (SELECT id from species WHERE iupac='methyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='2645'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2645'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '4400',
    'M',
    (SELECT id from species WHERE iupac='methyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='3116'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='alsosalt'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '5900',
    'M',
    (SELECT id from species WHERE iupac='methyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='3302'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '5100',
    'M',
    (SELECT id from species WHERE iupac='methyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='3304'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3304-1634-04-4-ABC',
    '3304', 'The data from Haimi et&nbsp;al. (2006) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( 752.39274 &#8722;29351.83448/T &#8722;115.55407&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3304-1634-04-4-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '5000',
    'M',
    (SELECT id from species WHERE iupac='methyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='2646'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2646-1634-04-4-consicheck',
    '2646', 'Different types of Henry''s law constants of Arp and Schmidt (2004) are inconsistent, with 5&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2646-1634-04-4-consicheck'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '4500',
    'M',
    (SELECT id from species WHERE iupac='methyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='2647'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;3</sup>',
    '3200',
    'M',
    (SELECT id from species WHERE iupac='methyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='2522'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='1928'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at296K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='2905'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '15000',
    'M',
    (SELECT id from species WHERE iupac='methyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='599'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0599-1634-04-4-ABC',
    '599', 'The data from Robbins et&nbsp;al. (1993) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;4264.16032 +202439.46180/T +628.54371&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0599-1634-04-4-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '3700',
    'V',
    (SELECT id from species WHERE iupac='methyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='3693'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='2905'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='794'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='methyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='2016'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2016'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6300',
    'Q',
    (SELECT id from species WHERE iupac='methyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6000',
    '?',
    (SELECT id from species WHERE iupac='methyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyl propyl ether',
    'C<sub>2</sub>H<sub>5</sub>OC<sub>3</sub>H<sub>7</sub>',
    '',
    '628-32-0',
    'NVJUHMXYKCUMQA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl propyl ether'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl propyl ether'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl propyl ether'),
    (SELECT id from literature WHERE bibtexkey='713'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethyl propyl ether'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethyl propyl ether'),
    (SELECT id from literature WHERE bibtexkey='howard97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl propyl ether'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl propyl ether'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl propyl ether'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl propyl ether'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl propyl ether'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl propyl ether'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl propyl ether'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl propyl ether'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl propyl ether'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl propyl ether'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl propyl ether'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethyl propyl ether'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyl isopropyl ether',
    'C<sub>5</sub>H<sub>12</sub>O',
    '',
    '625-54-7',
    'XSJVWZAETSBXKU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethyl isopropyl ether'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl isopropyl ether'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl isopropyl ether'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dimethoxypropane',
    'C<sub>5</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '77-76-9',
    'HEWZVZIVELJPQZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2-dimethoxypropane'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl 1,2-dimethylpropyl ether',
    'C<sub>6</sub>H<sub>14</sub>O',
    '',
    '62016-49-3',
    'JPUDLQKLSRSRGN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methyl 1,2-dimethylpropyl ether'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl 1,2-dimethylpropyl ether'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl 1,2-dimethylpropyl ether'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl 1-ethylpropyl ether',
    'C<sub>6</sub>H<sub>14</sub>O',
    '',
    '36839-67-5',
    'CQRFEDVNTJTKFU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methyl 1-ethylpropyl ether'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl 1-ethylpropyl ether'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl 1-ethylpropyl ether'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl 1-methylbutyl ether',
    'C<sub>6</sub>H<sub>14</sub>O',
    '',
    '6795-88-6',
    'XSAJCGUYMQTAHL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methyl 1-methylbutyl ether'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl 1-methylbutyl ether'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl 1-methylbutyl ether'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl 2,2-dimethylpropyl ether',
    'C<sub>6</sub>H<sub>14</sub>O',
    '',
    '1118-00-9',
    'JILHZKWLEAKYRC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methyl 2,2-dimethylpropyl ether'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl 2,2-dimethylpropyl ether'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl 2,2-dimethylpropyl ether'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl 2-methylbutyl ether',
    'C<sub>6</sub>H<sub>14</sub>O',
    '',
    '62016-48-2',
    'XGLHRCWEOMNVKS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methyl 2-methylbutyl ether'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl 2-methylbutyl ether'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl 2-methylbutyl ether'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl 3-methylbutyl ether',
    'C<sub>6</sub>H<sub>14</sub>O',
    '',
    '626-91-5',
    'ZQAYBCWERYRAMF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methyl 3-methylbutyl ether'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl 3-methylbutyl ether'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl 3-methylbutyl ether'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl pentyl ether',
    'C<sub>6</sub>H<sub>14</sub>O',
    '',
    '628-80-8',
    'DBUJFULDVAZULB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methyl pentyl ether'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl pentyl ether'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl pentyl ether'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methoxy-2-methylbutane',
    'C<sub>6</sub>H<sub>14</sub>O',
    '<i>tert</i>-amyl methyl ether',
    '994-05-8',
    'HVZJRWJGKQPSFL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;3</sup>',
    '6600',
    'L',
    (SELECT id from species WHERE iupac='2-methoxy-2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;2</sup>',
    '9400',
    'M',
    (SELECT id from species WHERE iupac='2-methoxy-2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='3691'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3691'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '7000',
    'M',
    (SELECT id from species WHERE iupac='2-methoxy-2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='3304'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3304-994-05-8-ABC',
    '3304', 'The data from Haimi et&nbsp;al. (2006) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( 224.10069 &#8722;4205.03828/T &#8722;37.65761&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3304-994-05-8-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;3</sup>',
    '6500',
    'M',
    (SELECT id from species WHERE iupac='2-methoxy-2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='2646'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methoxy-2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='1928'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at296K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methoxy-2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='2938'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methoxy-2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='2905'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methoxy-2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='2905'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methoxy-2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methoxy-2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methoxy-2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methoxy-2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methoxy-2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methoxy-2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methoxy-2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6600',
    'Q',
    (SELECT id from species WHERE iupac='2-methoxy-2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methoxy-2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6900',
    '?',
    (SELECT id from species WHERE iupac='2-methoxy-2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methoxy-2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;3</sup>',
    '7600',
    '?',
    (SELECT id from species WHERE iupac='2-methoxy-2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='2431'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-ethoxy-butane',
    'C<sub>6</sub>H<sub>14</sub>O',
    'ethyl butyl ether',
    '628-81-9',
    'PZHIWRCQKBBTOW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;3</sup>',
    '5700',
    'L',
    (SELECT id from species WHERE iupac='1-ethoxy-butane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-ethoxy-butane'),
    (SELECT id from literature WHERE bibtexkey='1928'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at296K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-ethoxy-butane'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-ethoxy-butane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-ethoxy-butane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethoxy-butane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethoxy-butane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5900',
    'Q',
    (SELECT id from species WHERE iupac='1-ethoxy-butane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5000',
    '?',
    (SELECT id from species WHERE iupac='1-ethoxy-butane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyl isobutyl ether',
    'C<sub>6</sub>H<sub>14</sub>O',
    '',
    '627-02-1',
    'RQUBQBFVDOLUKC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethyl isobutyl ether'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl isobutyl ether'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl isobutyl ether'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyl <i>sec</i>-butyl ether',
    'C<sub>6</sub>H<sub>14</sub>O',
    '',
    '2679-87-0',
    'VSCUCHUDCLERMY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethyl <i>sec</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl <i>sec</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl <i>sec</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyl <i>tert</i>-butyl ether',
    'C<sub>2</sub>H<sub>5</sub>OC(CH<sub>3</sub>)<sub>3</sub>',
    'ETBE',
    '637-92-3',
    'NUMQCACRALPSHD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;3</sup>',
    '6900',
    'L',
    (SELECT id from species WHERE iupac='ethyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '13000',
    'M',
    (SELECT id from species WHERE iupac='ethyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='3691'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3691'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;3</sup>',
    '6600',
    'M',
    (SELECT id from species WHERE iupac='ethyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='2645'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2645'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;3</sup>',
    '4300',
    'M',
    (SELECT id from species WHERE iupac='ethyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='3116'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='alsosalt'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;3</sup>',
    '7300',
    'M',
    (SELECT id from species WHERE iupac='ethyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='3304'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3304-637-92-3-ABC',
    '3304', 'The data from Haimi et&nbsp;al. (2006) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;780.30940 +40758.59752/T +112.07468&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3304-637-92-3-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;3</sup>',
    '6500',
    'M',
    (SELECT id from species WHERE iupac='ethyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='2646'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='1928'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at296K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;3</sup>',
    '7600',
    '?',
    (SELECT id from species WHERE iupac='ethyl <i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='2431'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dipropyl ether',
    'C<sub>3</sub>H<sub>7</sub>OC<sub>3</sub>H<sub>7</sub>',
    '',
    '111-43-3',
    'POLCUAVZOMRGSN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '6400',
    'L',
    (SELECT id from species WHERE iupac='dipropyl ether'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dipropyl ether'),
    (SELECT id from literature WHERE bibtexkey='2457'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dipropyl ether'),
    (SELECT id from literature WHERE bibtexkey='2493'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '9100',
    'M',
    (SELECT id from species WHERE iupac='dipropyl ether'),
    (SELECT id from literature WHERE bibtexkey='640'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dipropyl ether'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dipropyl ether'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dipropyl ether'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dipropyl ether'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dipropyl ether'),
    (SELECT id from literature WHERE bibtexkey='713'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dipropyl ether'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dipropyl ether'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dipropyl ether'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dipropyl ether'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dipropyl ether'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dipropyl ether'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dipropyl ether'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dipropyl ether'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dipropyl ether'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dipropyl ether'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dipropyl ether'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dipropyl ether'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5900',
    'Q',
    (SELECT id from species WHERE iupac='dipropyl ether'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dipropyl ether'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dipropyl ether'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dipropyl ether'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dipropyl ether'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dipropyl ether'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7300',
    '?',
    (SELECT id from species WHERE iupac='dipropyl ether'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dipropyl ether'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dipropyl ether'),
    (SELECT id from literature WHERE bibtexkey='637'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dipropyl ether'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dipropyl ether'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diisopropyl ether',
    'C<sub>3</sub>H<sub>7</sub>OC<sub>3</sub>H<sub>7</sub>',
    '',
    '108-20-3',
    'ZAFNJMIOTHYJRJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;3</sup>',
    '6600',
    'L',
    (SELECT id from species WHERE iupac='diisopropyl ether'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '8400',
    'M',
    (SELECT id from species WHERE iupac='diisopropyl ether'),
    (SELECT id from literature WHERE bibtexkey='3691'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3691'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '6400',
    'M',
    (SELECT id from species WHERE iupac='diisopropyl ether'),
    (SELECT id from literature WHERE bibtexkey='2646'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='diisopropyl ether'),
    (SELECT id from literature WHERE bibtexkey='1928'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at296K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='diisopropyl ether'),
    (SELECT id from literature WHERE bibtexkey='2938'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='diisopropyl ether'),
    (SELECT id from literature WHERE bibtexkey='622'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='diisopropyl ether'),
    (SELECT id from literature WHERE bibtexkey='2457'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='diisopropyl ether'),
    (SELECT id from literature WHERE bibtexkey='2493'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='diisopropyl ether'),
    (SELECT id from literature WHERE bibtexkey='2924'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diisopropyl ether'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diisopropyl ether'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;3</sup>',
    '6200',
    'V',
    (SELECT id from species WHERE iupac='diisopropyl ether'),
    (SELECT id from literature WHERE bibtexkey='3693'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '6400',
    'V',
    (SELECT id from species WHERE iupac='diisopropyl ether'),
    (SELECT id from literature WHERE bibtexkey='2431'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diisopropyl ether'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diisopropyl ether'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diisopropyl ether'),
    (SELECT id from literature WHERE bibtexkey='714'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='diisopropyl ether'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='diisopropyl ether'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diisopropyl ether'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diisopropyl ether'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diisopropyl ether'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diisopropyl ether'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diisopropyl ether'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diisopropyl ether'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diisopropyl ether'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diisopropyl ether'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diisopropyl ether'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diisopropyl ether'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diisopropyl ether'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diisopropyl ether'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diisopropyl ether'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6600',
    'Q',
    (SELECT id from species WHERE iupac='diisopropyl ether'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diisopropyl ether'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diisopropyl ether'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diisopropyl ether'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diisopropyl ether'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='diisopropyl ether'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7200',
    '?',
    (SELECT id from species WHERE iupac='diisopropyl ether'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='diisopropyl ether'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='diisopropyl ether'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='diisopropyl ether'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propyl isopropyl ether',
    'C<sub>6</sub>H<sub>14</sub>O',
    '',
    '627-08-7',
    'JIEJJGMNDWIGBJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='propyl isopropyl ether'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl isopropyl ether'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl isopropyl ether'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl isopropyl ether'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl isopropyl ether'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl isopropyl ether'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl isopropyl ether'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl isopropyl ether'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-ethoxy-2-methylbutane',
    'C<sub>7</sub>H<sub>16</sub>O',
    '<i>tert</i>-amyl ethyl ether',
    '919-94-8',
    'KFRVYYGHSPLXSZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;3</sup>',
    '7400',
    'L',
    (SELECT id from species WHERE iupac='2-ethoxy-2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;3</sup>',
    '7600',
    'M',
    (SELECT id from species WHERE iupac='2-ethoxy-2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='3304'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3304-919-94-8-ABC',
    '3304', 'The data from Haimi et&nbsp;al. (2006) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;565.00561 +31411.46240/T +79.73748&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3304-919-94-8-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-ethoxy-2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethoxy-2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethoxy-2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethoxy-2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethoxy-2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethoxy-2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethoxy-2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>tert</i>-butyl isopropyl ether',
    'C<sub>7</sub>H<sub>16</sub>O',
    '',
    '17348-59-3',
    'HNFSPSWQNZVCTB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='<i>tert</i>-butyl isopropyl ether'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dipropylene glycol monomethyl ether',
    'C<sub>7</sub>H<sub>16</sub>O<sub>3</sub>',
    '',
    '34590-94-8',
    'WGYZMNBUZFHYRX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dipropylene glycol monomethyl ether'),
    (SELECT id from literature WHERE bibtexkey='3393'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dibutyl ether',
    'C<sub>4</sub>H<sub>9</sub>OC<sub>4</sub>H<sub>9</sub>',
    '',
    '142-96-1',
    'DURPTKYDGMDSBL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '6700',
    'L',
    (SELECT id from species WHERE iupac='dibutyl ether'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;3</sup>',
    '10000',
    'M',
    (SELECT id from species WHERE iupac='dibutyl ether'),
    (SELECT id from literature WHERE bibtexkey='3691'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3691'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dibutyl ether'),
    (SELECT id from literature WHERE bibtexkey='2457'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dibutyl ether'),
    (SELECT id from literature WHERE bibtexkey='2493'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dibutyl ether'),
    (SELECT id from literature WHERE bibtexkey='3640'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dibutyl ether'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dibutyl ether'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dibutyl ether'),
    (SELECT id from literature WHERE bibtexkey='2223'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibutyl ether'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibutyl ether'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibutyl ether'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibutyl ether'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibutyl ether'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibutyl ether'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibutyl ether'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibutyl ether'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibutyl ether'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6600',
    'Q',
    (SELECT id from species WHERE iupac='dibutyl ether'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibutyl ether'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibutyl ether'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibutyl ether'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibutyl ether'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibutyl ether'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dibutyl ether'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7000',
    '?',
    (SELECT id from species WHERE iupac='dibutyl ether'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dibutyl ether'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dibutyl ether'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diisobutyl ether',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '628-55-7',
    'SZNYYWIUQFZLLT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diisobutyl ether'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'di-<i>sec</i>-butyl ether',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '6863-58-7',
    'HHBZZTKMMLDNDN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='di-<i>sec</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='di-<i>sec</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='di-<i>sec</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='di-<i>sec</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='di-<i>sec</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='di-<i>sec</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'di-<i>tert</i>-butyl ether',
    'C<sub>8</sub>H<sub>18</sub>O',
    '',
    '6163-66-2',
    'AQEFLFZSWDEAIP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='di-<i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='di-<i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='di-<i>tert</i>-butyl ether'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methoxy-2,4,4-trimethylpentane',
    'C<sub>9</sub>H<sub>20</sub>O',
    'methyl <i>tert</i>-octyl ether',
    '62108-41-2',
    'IKZVAPMTXDXWMX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methoxy-2,4,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3766_O3',
    '3766', 'Ebert et&nbsp;al. (2023) present "curated experimental" Henry''s law constants from the literature but do not provide any references. It is only mentioned that the value is from a single original paper and obtained from experimental vapor pressure and the infinite-dilution activity coefficient.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_O3'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methoxy-2-methylheptane',
    'C<sub>9</sub>H<sub>20</sub>O',
    '',
    '76589-16-7',
    'KJRACWZCOVHBQU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '8100',
    'M',
    (SELECT id from species WHERE iupac='2-methoxy-2-methylheptane'),
    (SELECT id from literature WHERE bibtexkey='3304'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3304-76589-16-7-ABC',
    '3304', 'The data from Haimi et&nbsp;al. (2006) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;1125.52184 +56732.54277/T +163.04749&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3304-76589-16-7-ABC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-ethoxy-2,4,4-trimethylpentane',
    'C<sub>10</sub>H<sub>22</sub>O',
    'ethyl tert-octyl ether',
    '187103-12-4',
    'JGPJRBWLBUGAQN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;4</sup>',
    '6900',
    'M',
    (SELECT id from species WHERE iupac='2-ethoxy-2,4,4-trimethylpentane'),
    (SELECT id from literature WHERE bibtexkey='3304'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3304-187103-12-4-ABC',
    '3304', 'The data from Haimi et&nbsp;al. (2006) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;1315.53726 +64110.36765/T +191.89554&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3304-187103-12-4-ABC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1''-oxybispentane',
    'C<sub>10</sub>H<sub>22</sub>O',
    'dipentyl ether',
    '693-65-2',
    'AOPDRZXCEAKHHW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,1''-oxybispentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,1''-oxybispentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1''-oxybispentane'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1''-oxybispentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1''-oxybispentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1''-oxybispentane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1''-oxybispentane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='1,1''-oxybispentane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3518-693-65-2',
    '', 'The value listed as A for di-n-pentyl ether is probably not A but the Henry''s law volatility constant H<sub>v</sub><sup>px</sup> at 298&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3518-693-65-2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1''-oxybis(3-methylbutane)',
    'C<sub>10</sub>H<sub>22</sub>O',
    'diisopentyl ether',
    '544-01-4',
    'AQZGPSLYZOOYQP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1''-oxybis(3-methylbutane)'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1''-oxybis(3-methylbutane)'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1''-oxybis(3-methylbutane)'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1''-oxybis(3-methylbutane)'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1''-oxybis(3-methylbutane)'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1''-oxybis(3-methylbutane)'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1''-oxybis(3-methylbutane)'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1''-oxybis(3-methylbutane)'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1''-oxybishexane',
    'C<sub>12</sub>H<sub>26</sub>O',
    'dihexyl ether',
    '112-58-3',
    'BPIUIOXAFBGMNB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,1''-oxybishexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1''-oxybishexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1''-oxybishexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1''-oxybishexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1''-oxybishexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='1,1''-oxybishexane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3518-112-58-3',
    '', 'The value listed as A for di-n-hexyl ether is probably not A but the Henry''s law volatility constant H<sub>v</sub><sup>px</sup> at 298&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3518-112-58-3'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-ethoxy-3,7-dimethyloctane',
    'C<sub>12</sub>H<sub>26</sub>O',
    '',
    '22810-10-2',
    'HCHHIPCZJSRFRT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethoxy-3,7-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethoxy-3,7-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethoxy-3,7-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethoxy-3,7-dimethyloctane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diheptyl ether',
    'C<sub>14</sub>H<sub>30</sub>O',
    '',
    '629-64-1',
    'UJEGHEMJVNQWOJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='diheptyl ether'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diheptyl ether'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dioctyl ether',
    'C<sub>16</sub>H<sub>34</sub>O',
    '',
    '629-82-3',
    'NKJOXAZJBOMXID-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dioctyl ether'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dioctyl ether'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dioctyl ether'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methoxycyclohexane',
    'C<sub>7</sub>H<sub>14</sub>O',
    '',
    '931-56-6',
    'GHDIHPNJQVDFBL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methoxycyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl cedryl ether',
    'C<sub>16</sub>H<sub>28</sub>O',
    '',
    '19870-74-7',
    'HRGPYCVTDOECMG-WALBABNVSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl cedryl ether'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl cedryl ether'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl cedryl ether'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl cedryl ether'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimethoxymethane',
    'CH<sub>3</sub>OCH<sub>2</sub>OCH<sub>3</sub>',
    'methylal',
    '109-87-5',
    'NKDDWNXOKDWJAK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;2</sup>',
    '4700',
    'L',
    (SELECT id from species WHERE iupac='dimethoxymethane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;2</sup>',
    '4800',
    'M',
    (SELECT id from species WHERE iupac='dimethoxymethane'),
    (SELECT id from literature WHERE bibtexkey='3305'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dimethoxymethane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dimethoxymethane'),
    (SELECT id from literature WHERE bibtexkey='2223'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethoxymethane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethoxymethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethoxymethane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethoxymethane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethoxymethane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethoxymethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethoxymethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethoxymethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethoxymethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethoxymethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dimethoxymethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dimethoxymethane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'trimethoxymethane',
    'HC(OCH<sub>3</sub>)<sub>3</sub>',
    '',
    '149-73-5',
    'PYOKUURKVVELLB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='trimethoxymethane'),
    (SELECT id from literature WHERE bibtexkey='794'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diethoxymethane',
    'C<sub>5</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '462-95-3',
    'KLKFAASOGCDTDT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diethoxymethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethoxymethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethoxymethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethoxymethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethoxymethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethoxymethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1-diethoxyethane',
    '(C<sub>2</sub>H<sub>5</sub>O)<sub>2</sub>CHCH<sub>3</sub>',
    'acetal',
    '105-57-7',
    'DHKHKXVYLBGOIT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1-diethoxyethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1-diethoxyethane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1-diethoxyethane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-diethoxyethane'),
    (SELECT id from literature WHERE bibtexkey='3521'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-diethoxyethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-diethoxyethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-diethoxyethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1-diethoxyethane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-diethoxyethane',
    'C<sub>2</sub>H<sub>5</sub>OC<sub>2</sub>H<sub>4</sub>OC<sub>2</sub>H<sub>5</sub>',
    '',
    '629-14-1',
    'LZDKZFUFMNSQCJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-diethoxyethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-diethoxyethane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-diethoxyethane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,2-diethoxyethane'),
    (SELECT id from literature WHERE bibtexkey='howard97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-diethoxyethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-diethoxyethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-diethoxyethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,1-trimethoxyethane',
    'CH<sub>3</sub>C(OCH<sub>3</sub>)<sub>3</sub>',
    '',
    '1445-45-0',
    'HDPNBNXLBDFELL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1,1-trimethoxyethane'),
    (SELECT id from literature WHERE bibtexkey='794'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-dimethoxyethane',
    'C<sub>4</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '110-71-4',
    'XTHFKEDIFFGKHM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '7300',
    'L',
    (SELECT id from species WHERE iupac='1,2-dimethoxyethane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3518-110-71-4-consicheck',
    '3518', 'Values at 298&nbsp;K in Tables&nbsp;C2 and C5 of Brockbank (2013) are inconsistent, with 5&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3518-110-71-4-consicheck'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-dimethoxyethane'),
    (SELECT id from literature WHERE bibtexkey='3526'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '7200',
    'M',
    (SELECT id from species WHERE iupac='1,2-dimethoxyethane'),
    (SELECT id from literature WHERE bibtexkey='3305'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '7100',
    'T',
    (SELECT id from species WHERE iupac='1,2-dimethoxyethane'),
    (SELECT id from literature WHERE bibtexkey='2381'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethoxyethane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethoxyethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-oxa-1-hexanol',
    'C<sub>5</sub>H<sub>12</sub>O<sub>2</sub>',
    '2-propoxyethanol',
    '2807-30-9',
    'YEYKMVJDLWJFOA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '8400',
    'T',
    (SELECT id from species WHERE iupac='3-oxa-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='2381'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-oxa-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-oxa-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-oxa-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-oxa-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-oxa-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-oxa-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-oxa-1-heptanol',
    'C<sub>6</sub>H<sub>14</sub>O<sub>2</sub>',
    '2-butoxyethanol; butyl cellosolve',
    '111-76-2',
    'POAOYUHQDCAZBD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '8300',
    'L',
    (SELECT id from species WHERE iupac='3-oxa-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5',
    '7700',
    'M',
    (SELECT id from species WHERE iupac='3-oxa-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '8300',
    'M',
    (SELECT id from species WHERE iupac='3-oxa-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='2837'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HTdep_r2_lessthan_0.9'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    'M',
    (SELECT id from species WHERE iupac='3-oxa-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3079'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '8900',
    'T',
    (SELECT id from species WHERE iupac='3-oxa-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='2381'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-oxa-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-oxa-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-oxa-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-oxa-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-oxa-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-oxa-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-oxa-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-oxa-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-oxa-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-oxa-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-oxa-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-oxa-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-oxa-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methoxy-2-propanol',
    'C<sub>4</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '107-98-2',
    'ARXJGSRGQADJSQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-methoxy-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3079'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1-methoxy-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methoxy-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methoxy-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methoxy-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methoxy-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methoxy-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methoxy-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methoxy-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methoxy-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methoxy-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methoxy-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methoxy-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methoxy-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-methoxy-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-3-oxa-1-pentanol',
    'C<sub>5</sub>H<sub>12</sub>O<sub>2</sub>',
    '2-isopropoxyethanol',
    '109-59-1',
    'HCGFUIQPSOCUHI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8',
    '',
    'M',
    (SELECT id from species WHERE iupac='4-methyl-3-oxa-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3079'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-3-oxa-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-3-oxa-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-3-oxa-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-3-oxa-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-3-oxa-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-3-oxa-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-3-oxa-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-methyl-3-oxa-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-dibutoxyethane',
    'C<sub>10</sub>H<sub>22</sub>O<sub>2</sub>',
    '',
    '112-48-1',
    'GDXHBFHOEYVPED-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dibutoxyethane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dibutoxyethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dibutoxyethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,6-dioxa-1-decanol',
    'C<sub>8</sub>H<sub>18</sub>O<sub>3</sub>',
    'butyl carbitol',
    '112-34-5',
    'OAYXUHPQHDHDDZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3,6-dioxa-1-decanol'),
    (SELECT id from literature WHERE bibtexkey='2837'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diethylene glycol dibutyl ether',
    'C<sub>12</sub>H<sub>26</sub>O<sub>3</sub>',
    '',
    '112-73-2',
    'KZVBBTZJMSWGTK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '13000',
    'L',
    (SELECT id from species WHERE iupac='diethylene glycol dibutyl ether'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9',
    '',
    'V',
    (SELECT id from species WHERE iupac='diethylene glycol dibutyl ether'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1',
    '',
    'X',
    (SELECT id from species WHERE iupac='diethylene glycol dibutyl ether'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethylene glycol dibutyl ether'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethylene glycol dibutyl ether'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethylene glycol dibutyl ether'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethylene glycol dibutyl ether'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0',
    '',
    '?',
    (SELECT id from species WHERE iupac='diethylene glycol dibutyl ether'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl vinyl ether',
    'C<sub>3</sub>H<sub>6</sub>O',
    '',
    '107-25-5',
    'XJRBAMWJDBPFIM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl vinyl ether'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl vinyl ether'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl vinyl ether'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl vinyl ether'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyl vinyl ether',
    'C<sub>4</sub>H<sub>8</sub>O',
    '',
    '109-92-2',
    'FJKIXWOMBXYWOQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl vinyl ether'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl vinyl ether'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl vinyl ether'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl vinyl ether'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl vinyl ether'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propyl vinyl ether',
    'C<sub>5</sub>H<sub>10</sub>O',
    '',
    '764-47-6',
    'OVGRCEFMXPHEBL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '4800',
    'M',
    (SELECT id from species WHERE iupac='propyl vinyl ether'),
    (SELECT id from literature WHERE bibtexkey='3691'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3691'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'allyl glycidyl ether',
    'C<sub>6</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '106-92-3',
    'LSWYGACWGAICNM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    '?',
    (SELECT id from species WHERE iupac='allyl glycidyl ether'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'butyl vinyl ether',
    'C<sub>6</sub>H<sub>12</sub>O',
    '',
    '111-34-2',
    'UZKWTJUDCOPSNM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butyl vinyl ether'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butyl vinyl ether'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl vinyl ether'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl vinyl ether'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl vinyl ether'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl vinyl ether'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl vinyl ether'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl vinyl ether'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'isobutyl vinyl ether',
    'C<sub>6</sub>H<sub>12</sub>O',
    '',
    '109-53-5',
    'OZCMOJQQLBXBKI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isobutyl vinyl ether'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isobutyl vinyl ether'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isobutyl vinyl ether'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isobutyl vinyl ether'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isobutyl vinyl ether'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benzyl methyl ether',
    'C<sub>8</sub>H<sub>10</sub>O',
    '',
    '538-86-3',
    'GQKZBCPTCWJTAS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzyl methyl ether'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzyl methyl ether'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benzyl ethyl ether',
    'C<sub>9</sub>H<sub>12</sub>O',
    '',
    '539-30-0',
    'AXPZDYVDTMMLNB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzyl ethyl ether'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methoxybenzene',
    'C<sub>6</sub>H<sub>5</sub>OCH<sub>3</sub>',
    'anisole',
    '100-66-3',
    'RDOXTESZEPMUJZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '4200',
    'L',
    (SELECT id from species WHERE iupac='methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '4200',
    'M',
    (SELECT id from species WHERE iupac='methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2926'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '4800',
    'M',
    (SELECT id from species WHERE iupac='methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1107'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2457'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='714'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2165'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4500',
    'Q',
    (SELECT id from species WHERE iupac='methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4300',
    '?',
    (SELECT id from species WHERE iupac='methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethoxybenzene',
    'C<sub>8</sub>H<sub>10</sub>O',
    'phenetole',
    '103-73-1',
    'DLRJIFUOBPOJNS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2457'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-dimethoxybenzene',
    'C<sub>8</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '91-16-7',
    'ABDKAPXRBAPSQN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5100',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2400',
    '?',
    (SELECT id from species WHERE iupac='1,2-dimethoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-phenoxyethanol',
    'C<sub>8</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '122-99-6',
    'QCDWFXQBSFUVSP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-phenoxyethanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-phenoxyethanol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-phenoxyethanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-phenoxyethanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-phenoxyethanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-(phenylmethoxy)-ethanol',
    'C<sub>9</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '622-08-2',
    'CUZKCNWZBXLAJX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-(phenylmethoxy)-ethanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(phenylmethoxy)-ethanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(phenylmethoxy)-ethanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(phenylmethoxy)-ethanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(phenylmethoxy)-ethanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(phenylmethoxy)-ethanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(phenylmethoxy)-ethanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3-trimethoxybenzene',
    'C<sub>9</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '634-36-6',
    'CRUILBNAQILVHZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3-trimethoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2165'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methoxy-4-(1-propenyl)-benzene',
    'C<sub>10</sub>H<sub>12</sub>O',
    'anethole',
    '104-46-1',
    'RUVINXPYWBROJD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '6200',
    'V',
    (SELECT id from species WHERE iupac='1-methoxy-4-(1-propenyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2125'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-methoxy-4-(1-propenyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methoxy-4-(1-propenyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methoxy-4-(1-propenyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methoxy-4-(1-propenyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-methoxy-4-(1-propenyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methoxy-4-(2-propenyl)-phenol',
    'C<sub>10</sub>H<sub>12</sub>O<sub>2</sub>',
    'eugenol',
    '97-53-0',
    'RRAFCDWBNXTKKO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methoxy-4-(2-propenyl)-phenol'),
    (SELECT id from literature WHERE bibtexkey='3723'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methoxy-4-(2-propenyl)-phenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methoxy-4-(2-propenyl)-phenol'),
    (SELECT id from literature WHERE bibtexkey='3678'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3678'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methoxy-4-(2-propenyl)-phenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2',
    '9700',
    'V',
    (SELECT id from species WHERE iupac='2-methoxy-4-(2-propenyl)-phenol'),
    (SELECT id from literature WHERE bibtexkey='2125'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methoxy-4-(2-propenyl)-phenol'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methoxy-4-(2-propenyl)-phenol'),
    (SELECT id from literature WHERE bibtexkey='3521'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methoxy-4-(2-propenyl)-phenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methoxy-4-(2-propenyl)-phenol'),
    (SELECT id from literature WHERE bibtexkey='3723'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3723'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-dimethoxy-4-(2-propenyl)-benzene',
    'C<sub>11</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '93-15-2',
    'ZYEMGPIYFIJGTP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dimethoxy-4-(2-propenyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dimethoxy-4-(2-propenyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethoxy-4-(2-propenyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethoxy-4-(2-propenyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethoxy-4-(2-propenyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diphenyl ether',
    'C<sub>12</sub>H<sub>10</sub>O',
    '',
    '101-84-8',
    'USIUVYZYUHIAEV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='diphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='diphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='diphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(phenoxymethyl)-oxirane',
    'C<sub>9</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '122-60-1',
    'FQYUMYWMJTYZTK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(phenoxymethyl)-oxirane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(phenoxymethyl)-oxirane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(phenoxymethyl)-oxirane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(phenoxymethyl)-oxirane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(phenoxymethyl)-oxirane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-dodecyl-4-phenoxybenzene',
    'C<sub>24</sub>H<sub>34</sub>O',
    '',
    '119345-02-7',
    'XSAHYEQPUFJGKW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-dodecyl-4-phenoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-dodecyl-4-phenoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-dodecyl-4-phenoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-dodecyl-4-phenoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,4-trimethyl-4-(4-(4-(2,4,4-trimethylpentan-2-yl)phenoxy)phenyl)pentane',
    'C<sub>28</sub>H<sub>42</sub>O',
    '',
    '61702-88-3',
    'AJDONJVWDSZZQF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethyl-4-(4-(4-(2,4,4-trimethylpentan-2-yl)phenoxy)phenyl)pentane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethyl-4-(4-(4-(2,4,4-trimethylpentan-2-yl)phenoxy)phenyl)pentane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethyl-4-(4-(4-(2,4,4-trimethylpentan-2-yl)phenoxy)phenyl)pentane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,4-trimethyl-4-(4-(4-(2,4,4-trimethylpentan-2-yl)phenoxy)phenyl)pentane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'etofenprox',
    'C<sub>25</sub>H<sub>28</sub>O<sub>3</sub>',
    '',
    '80844-07-1',
    'YREQHYQNNWYQCJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='etofenprox'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'di-<i>tert</i>-butyl <i>sec</i>-butylidene diperoxide',
    'C<sub>12</sub>H<sub>26</sub>O<sub>4</sub>',
    '',
    '2167-23-9',
    'HQOVXPHOJANJBR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='di-<i>tert</i>-butyl <i>sec</i>-butylidene diperoxide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='di-<i>tert</i>-butyl <i>sec</i>-butylidene diperoxide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='di-<i>tert</i>-butyl <i>sec</i>-butylidene diperoxide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='di-<i>tert</i>-butyl <i>sec</i>-butylidene diperoxide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'peroxide, 1,1-dimethylethyl 1-methyl-1-phenylethyl',
    'C<sub>13</sub>H<sub>20</sub>O<sub>2</sub>',
    '',
    '3457-61-2',
    'BIISIZOQPWZPPS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='peroxide, 1,1-dimethylethyl 1-methyl-1-phenylethyl'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='peroxide, 1,1-dimethylethyl 1-methyl-1-phenylethyl'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='peroxide, 1,1-dimethylethyl 1-methyl-1-phenylethyl'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='peroxide, 1,1-dimethylethyl 1-methyl-1-phenylethyl'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'di-<i>tert</i>-butyl 1,1,4,4-tetramethyltetramethylene diperoxide',
    'C<sub>16</sub>H<sub>34</sub>O<sub>4</sub>',
    '',
    '78-63-7',
    'DMWVYCCGCQPJEA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='di-<i>tert</i>-butyl 1,1,4,4-tetramethyltetramethylene diperoxide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='di-<i>tert</i>-butyl 1,1,4,4-tetramethyltetramethylene diperoxide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='di-<i>tert</i>-butyl 1,1,4,4-tetramethyltetramethylene diperoxide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='di-<i>tert</i>-butyl 1,1,4,4-tetramethyltetramethylene diperoxide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4-bis(1-<i>tert</i>-butylperoxy-1-methyl-ethyl)benzene',
    'C<sub>20</sub>H<sub>34</sub>O<sub>4</sub>',
    '',
    '2781-00-2',
    'GWQOYRSARAWVTC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-bis(1-<i>tert</i>-butylperoxy-1-methyl-ethyl)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-bis(1-<i>tert</i>-butylperoxy-1-methyl-ethyl)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-bis(1-<i>tert</i>-butylperoxy-1-methyl-ethyl)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-bis(1-<i>tert</i>-butylperoxy-1-methyl-ethyl)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CH3OCH2OOH',
    'C<sub>2</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '',
    'CDXAGPPPWKCPRI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3OCH2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3OCH2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3OCH2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ETHOXOOH',
    'C<sub>2</sub>H<sub>4</sub>O<sub>3</sub>',
    '',
    '',
    'NOEKFNMWGHEGBN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETHOXOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETHOXOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETHOXOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DMMAOOH',
    'C<sub>3</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'SHLFZQKLTPTTSZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMMAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMMAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMMAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DMMBOOH',
    'C<sub>3</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'HODDSHZVZWXLHR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMMBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMMBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMMBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ETOMEOOH',
    'C<sub>3</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'NZBMKAZNWPZJND-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETOMEOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETOMEOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETOMEOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MEMOXYCO3H',
    'C<sub>3</sub>H<sub>6</sub>O<sub>4</sub>',
    '',
    '',
    'PWWCDEMRYRBWOJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MEMOXYCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MEMOXYCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MEMOXYCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DIETETOOH',
    'C<sub>4</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'CXWWPQGYBJCHJL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DIETETOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DIETETOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DIETETOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ETOC2OOH',
    'C<sub>4</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'NYVGIYPKZJSYSP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETOC2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETOC2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETOC2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ETOMECO3H',
    'C<sub>4</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'ULYBJOMJQUHMOL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETOMECO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETOMECO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETOMECO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPRMETOOH',
    'C<sub>4</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'PSBSELFEZHDPTA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRMETOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRMETOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRMETOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BOXMOOH',
    'C<sub>5</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'DCHWALHTYQHXTG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXMOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXMOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXMOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EIPEOOH',
    'C<sub>5</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'ZZXLAMSYBUVKJS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EIPEOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EIPEOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EIPEOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPROC21OOH',
    'C<sub>5</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'VGMUBGNCFVOQDX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPROC21OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPROC21OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPROC21OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MTBEAOOH',
    'C<sub>5</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'BGZKVDIFKPQYHL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBEAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBEAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBEAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MTBEBCO3H',
    'C<sub>5</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'NGYXBYFCPPVOQA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBEBCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBEBCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBEBCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MTBEBOOH',
    'C<sub>5</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'FPTBRWWJTBOWHN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBEBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBEBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBEBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BOXMCO3H',
    'C<sub>6</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'BMXLBBYCODRNIJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXMCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXMCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXMCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DIIPRETOOH',
    'C<sub>6</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'PFVPTWUDXVSVAC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DIIPRETOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DIIPRETOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DIIPRETOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ETBEACO3H',
    'C<sub>6</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'UAVAAIVEDVDYSQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETBEACO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETBEACO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETBEACO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ETBEAOOH',
    'C<sub>6</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'ITRUGVUCIYLYDK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETBEAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETBEAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETBEAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ETBEBOOH',
    'C<sub>6</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'VOZHKKMLSSYDIG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETBEBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETBEBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETBEBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ETBECCO3H',
    'C<sub>6</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'AELSWALKLVZVPO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETBECCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETBECCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETBECCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ETBECOOH',
    'C<sub>6</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'WJMPPRSRRBMJID-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETBECOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETBECOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETBECOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPROMC2OOH',
    'C<sub>6</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'JCIUPJDJCBRYHD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPROMC2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPROMC2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPROMC2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPROMCCO3H',
    'C<sub>6</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'SFJQIQZNOBLTBZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPROMCCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPROMCCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPROMCCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BCSOZ',
    'C<sub>15</sub>H<sub>24</sub>O<sub>3</sub>',
    '',
    '',
    'DXZCAIRIBLPJLG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCSOZ'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCSOZ'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCSOZ'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CH3OCH2OH',
    'C<sub>2</sub>H<sub>6</sub>O<sub>2</sub>',
    '',
    '',
    'VHWYCFISAQVCCP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3OCH2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3OCH2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3OCH2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DMMAOH',
    'C<sub>3</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'YANOHILBFNXRFM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMMAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMMAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMMAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DMMBOH',
    'C<sub>3</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'IIGJYLXJNYBXEO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMMBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMMBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMMBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ETOMEOH',
    'C<sub>3</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '',
    'RRLWYLINGKISHN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETOMEOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETOMEOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETOMEOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MO2EOLA2OH',
    'C<sub>3</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'CSCSROFYRUZJJH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MO2EOLA2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MO2EOLA2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MO2EOLA2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MO2EOLAOOH',
    'C<sub>3</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'PFSIOEPXGRVTPO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MO2EOLAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MO2EOLAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MO2EOLAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MO2EOLB2OH',
    'C<sub>3</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'ONSWVOSXVUHESJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MO2EOLB2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MO2EOLB2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MO2EOLB2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MO2EOLBOOH',
    'C<sub>3</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'VULCDXDIAONDTM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MO2EOLBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MO2EOLBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MO2EOLBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DIETETOH',
    'C<sub>4</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'CAFAOQIVXSSFSY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DIETETOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DIETETOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DIETETOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EOX2ETA2OH',
    'C<sub>4</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'WWVBRUMYFUDEJQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EOX2ETA2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EOX2ETA2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EOX2ETA2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EOX2ETB2OH',
    'C<sub>4</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'RZYMXMZJVMXDRP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EOX2ETB2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EOX2ETB2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EOX2ETB2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EOX2OLAOOH',
    'C<sub>4</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'OSAXOMWTXDBXFG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EOX2OLAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EOX2OLAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EOX2OLAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EOX2OLBOOH',
    'C<sub>4</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'IWDPPKCJRWMAAT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EOX2OLBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EOX2OLBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EOX2OLBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H2C3OCOH',
    'C<sub>4</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'OAPWFUZUONIVKV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2C3OCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2C3OCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2C3OCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H2C3OCOOH',
    'C<sub>4</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'ZZOFHQOVQLUGOX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2C3OCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2C3OCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2C3OCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPRMEETOH',
    'C<sub>4</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'BFSUQRCCKXZXEX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRMEETOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRMEETOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRMEETOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PR2OHMOOOH',
    'C<sub>4</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'BIISZUJLPYTCKS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PR2OHMOOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PR2OHMOOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PR2OHMOOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PROH2MOX',
    'C<sub>4</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'OEYNWAWWSZUGDU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PROH2MOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PROH2MOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PROH2MOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BOXMOH',
    'C<sub>5</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'CRHLZRRTZDFDAJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXMOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXMOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXMOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EIPEOH',
    'C<sub>5</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'MGMXTRZFWPWZFH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EIPEOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EIPEOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EIPEOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HIEPOXB',
    'C<sub>5</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'YTIKZIBPNMOYQX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HIEPOXB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HIEPOXB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HIEPOXB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IEACO3H',
    'C<sub>5</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'WBOLSVSGSKMCPN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IEACO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IEACO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IEACO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IECCO3H',
    'C<sub>5</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'CEWHGLGNUIHIJU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IECCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IECCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IECCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IEPOXA',
    'C<sub>5</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'CIDUHKBATDRWPE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IEPOXA'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IEPOXA'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IEPOXA'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IEPOXC',
    'C<sub>5</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'REKLCZSNEUFIBP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IEPOXC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IEPOXC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IEPOXC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPROC21OH',
    'C<sub>5</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'PWLPTLCMMFJZIU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPROC21OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPROC21OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPROC21OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MTBEAOH',
    'C<sub>5</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'NHNNIMVRQJIZFW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBEAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBEAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBEAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MTBEBOH',
    'C<sub>5</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'VMPUAIZSESMILD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBEBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBEBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBEBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BOX2E2OH',
    'C<sub>6</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'WQHNZXURJISVCT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOX2E2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOX2E2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOX2E2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BOX2OHAOOH',
    'C<sub>6</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'XRZMTAXNHOGTME-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOX2OHAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOX2OHAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOX2OHAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BOX2OHBOOH',
    'C<sub>6</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'LCMMTUJPIXBSDS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOX2OHBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOX2OHBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOX2OHBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BOXOHETOH',
    'C<sub>6</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'QLKNFVRAYYHHDF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXOHETOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXOHETOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXOHETOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DIIPRETOH',
    'C<sub>6</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '',
    'FRKCZFUUIQCQPC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DIIPRETOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DIIPRETOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DIIPRETOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ETBEAOH',
    'C<sub>6</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '',
    'WOSZILCYMCIWFB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETBEAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETBEAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETBEAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ETBEBOH',
    'C<sub>6</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '',
    'DUNYNUFVLYAWTI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETBEBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETBEBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETBEBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ETBECOH',
    'C<sub>6</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '',
    'BDLXTDLGTWNUFM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETBECOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETBECOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETBECOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPROMC2OH',
    'C<sub>6</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '',
    'ZFEKANLLFQEKED-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPROMC2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPROMC2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPROMC2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-butoxy-2-propanol',
    'C<sub>7</sub>H<sub>16</sub>O<sub>2</sub>',
    'MCM:BOX2PROL',
    '5131-66-8',
    'RWNUSVWFHDHRCJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butoxy-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butoxy-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butoxy-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BOXOHPROL',
    'C<sub>7</sub>H<sub>16</sub>O<sub>3</sub>',
    '',
    '',
    'ITIQJVOJGXCBQB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXOHPROL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXOHPROL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXOHPROL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BOXPOLAOOH',
    'C<sub>7</sub>H<sub>16</sub>O<sub>4</sub>',
    '',
    '',
    'JGCUFCZSCOGTSN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXPOLAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXPOLAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXPOLAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BOXPOLBOOH',
    'C<sub>7</sub>H<sub>16</sub>O<sub>4</sub>',
    '',
    '',
    'AJCGQJRNRRPZGZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXPOLBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXPOLBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXPOLBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BOXPR2OH',
    'C<sub>7</sub>H<sub>16</sub>O<sub>3</sub>',
    '',
    '',
    'XKPKIGSYCLTAJO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXPR2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXPR2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXPR2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BCSOZOH',
    'C<sub>15</sub>H<sub>26</sub>O<sub>5</sub>',
    '',
    '',
    'JQRHKAPCWHNLMS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCSOZOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCSOZOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCSOZOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BCSOZOOH',
    'C<sub>15</sub>H<sub>26</sub>O<sub>6</sub>',
    '',
    '',
    'VCKYKGHDZKOMMJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCSOZOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCSOZOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCSOZOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MEMOXYCHO',
    'C<sub>3</sub>H<sub>6</sub>O<sub>2</sub>',
    '',
    '',
    'YSEFYOVWKJXNCH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MEMOXYCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MEMOXYCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MEMOXYCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EOX2ETCHO',
    'C<sub>4</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '',
    'IAHZBRPNDIVNNR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EOX2ETCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EOX2ETCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EOX2ETCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EPXC4DIAL',
    'C<sub>4</sub>H<sub>4</sub>O<sub>3</sub>',
    '',
    '',
    'IRJHVNZVWOCVLV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXC4DIAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXC4DIAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXC4DIAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EPXDLCO3H',
    'C<sub>4</sub>H<sub>4</sub>O<sub>5</sub>',
    '',
    '',
    'OKYIQGCZHSMTGV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXDLCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXDLCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXDLCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EPXMC4DIAL',
    'C<sub>5</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '',
    'SYCYSIWUSJFZTN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXMC4DIAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXMC4DIAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXMC4DIAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EPXMDLCO3H',
    'C<sub>5</sub>H<sub>6</sub>O<sub>5</sub>',
    '',
    '',
    'LLYFBEXLHOFXFI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXMDLCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXMDLCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXMDLCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MTBEBCHO',
    'C<sub>5</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '',
    'HSCUZOQCNBPBST-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBEBCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBEBCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBEBCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BOX2ECHO',
    'C<sub>6</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'RPLPGIHCAYAYKX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOX2ECHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOX2ECHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOX2ECHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BZEMUCCO3H',
    'C<sub>6</sub>H<sub>6</sub>O<sub>5</sub>',
    '',
    '',
    'LTCNUSVDDXPSIF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BZEMUCCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BZEMUCCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BZEMUCCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BZEPOXMUC',
    'C<sub>6</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '',
    'NQHJMOLWTXQPLS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BZEPOXMUC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BZEPOXMUC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BZEPOXMUC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EPXM2C4DAL',
    'C<sub>6</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'QTKFOEFUZGORGI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXM2C4DAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXM2C4DAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXM2C4DAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EPXM2DCO3H',
    'C<sub>6</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'CFBRPHMFNHCZFV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXM2DCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXM2DCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXM2DCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ETBEACHO',
    'C<sub>6</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'HHIYJPQUMUPZIZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETBEACHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETBEACHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETBEACHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ETBECCHO',
    'C<sub>6</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'SMUYZOMGNHBYHU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETBECCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETBECCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETBECCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPROMCCHO',
    'C<sub>6</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '',
    'AAPDVSFWBQNMLJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPROMCCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPROMCCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPROMCCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EPXMEC4DAL',
    'C<sub>7</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'MOJUYSNCEBTQMW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXMEC4DAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXMEC4DAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXMEC4DAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EPXMEDCO3H',
    'C<sub>7</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'IBELTJZUJIPVRI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXMEDCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXMEDCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXMEDCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OXYEPOXMUC',
    'C<sub>8</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'QLTFECLMPRWGQQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYEPOXMUC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYEPOXMUC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYEPOXMUC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OXYMUCCO3H',
    'C<sub>8</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'PBSKNYKKTPMDFL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYMUCCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYMUCCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYMUCCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OETLMUCO3H',
    'C<sub>9</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'UVJSWMTUJCHEOZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OETLMUCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OETLMUCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OETLMUCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OETLPOXMUC',
    'C<sub>9</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'NORSPZZKBNMHEY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OETLPOXMUC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OETLPOXMUC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OETLPOXMUC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IEACHO',
    'C<sub>5</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'SXTKPSXTIDLSQV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IEACHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IEACHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IEACHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IECCHO',
    'C<sub>5</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'FUNIHXJAXNKVQS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IECCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IECCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IECCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BZEMUCOH',
    'C<sub>6</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'HYRDKGAOZPVDDL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BZEMUCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BZEMUCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BZEMUCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BZEMUCOOH',
    'C<sub>6</sub>H<sub>8</sub>O<sub>6</sub>',
    '',
    '',
    'YPGXWAYLBNMEJL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BZEMUCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BZEMUCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BZEMUCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OXYMUCOH',
    'C<sub>8</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'SKTLSFGOHJFJLD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYMUCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYMUCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYMUCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OXYMUCOOH',
    'C<sub>8</sub>H<sub>12</sub>O<sub>6</sub>',
    '',
    '',
    'ZBCSCRLAPOVYAB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYMUCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYMUCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYMUCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OETLMUCOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>5</sub>',
    '',
    '',
    'BKCWOZADWPGCRT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OETLMUCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OETLMUCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OETLMUCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OETLMUCOOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>6</sub>',
    '',
    '',
    'OMPONQJDZISYFQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OETLMUCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OETLMUCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OETLMUCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PRONEMOOOH',
    'C<sub>4</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'WKDIYCKWLNCFHJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRONEMOOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRONEMOOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRONEMOOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PRONEMOX',
    'C<sub>4</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '',
    'CUZLJOLBIRPEFB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRONEMOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRONEMOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRONEMOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EPXKTMCO3H',
    'C<sub>6</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'ABDSVLWFPNKKBV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXKTMCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXKTMCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXKTMCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EPXMKTCO3H',
    'C<sub>6</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'CAGQARJHZCESJI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXMKTCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXMKTCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXMKTCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BOXPROBOOH',
    'C<sub>7</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'YHFJWWLEGMYFFZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXPROBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXPROBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXPROBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BOXPRONE',
    'C<sub>7</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '',
    'UYNCDYOFUJEUQN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXPRONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXPRONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXPRONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BOXPROOOH',
    'C<sub>7</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'YUTHBWBUPOPMPG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXPROOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXPROOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXPROOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EPXEKTCO3H',
    'C<sub>7</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'PGCJNBUAAIEYIA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXEKTCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXEKTCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXEKTCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TLEMUCCO3H',
    'C<sub>7</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'RISGILSSNRWCFR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TLEMUCCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TLEMUCCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TLEMUCCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EBZMUCCO3H',
    'C<sub>8</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'GTEVSPXWKYUSQE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBZMUCCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBZMUCCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBZMUCCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MXYMUCCO3H',
    'C<sub>8</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'ROKAXOITEMHIEK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYMUCCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYMUCCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYMUCCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PXYMUCCO3H',
    'C<sub>8</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'AYUPQGRQZSTAMO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYMUCCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYMUCCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYMUCCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPBZMUCO3H',
    'C<sub>9</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'SKJBPGYNTSYQCQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBZMUCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBZMUCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBZMUCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:METLMUCO3H',
    'C<sub>9</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'CXRRYJPLLOUVIM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METLMUCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METLMUCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METLMUCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PBZMUCCO3H',
    'C<sub>9</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'ZGGPGQBINYKWGU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBZMUCCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBZMUCCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBZMUCCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PETLMUCO3H',
    'C<sub>9</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'KWWJCAVGGMMMRV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PETLMUCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PETLMUCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PETLMUCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TM123OXMUC',
    'C<sub>9</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'XYHNNFZVTWOCNN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM123OXMUC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM123OXMUC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM123OXMUC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TM124MUO3H',
    'C<sub>9</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'FTWAFKXUKWKGAJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124MUO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124MUO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124MUO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TM135MUO3H',
    'C<sub>9</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'JNFPQQOSCDIIIK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM135MUO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM135MUO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM135MUO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DMEBMUO3H',
    'C<sub>10</sub>H<sub>14</sub>O<sub>5</sub>',
    '',
    '',
    'JWBQDZWURHDWCA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMEBMUO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMEBMUO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMEBMUO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DETLMUO3H',
    'C<sub>11</sub>H<sub>16</sub>O<sub>5</sub>',
    '',
    '',
    'QEEAHFHJZRPBGG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DETLMUO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DETLMUO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DETLMUO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BCKSOZ',
    'C<sub>14</sub>H<sub>22</sub>O<sub>4</sub>',
    '',
    '',
    'JTZKRSQXPBULRM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCKSOZ'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCKSOZ'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCKSOZ'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PRONEMOXOH',
    'C<sub>4</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'RETWRLMOZHRKHX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRONEMOXOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRONEMOXOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRONEMOXOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BOXPRONBOH',
    'C<sub>7</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'ANPLAICHKIQBPV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXPRONBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXPRONBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXPRONBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BOXPRONOH',
    'C<sub>7</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'NQJNHGUTJISDHM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXPRONOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXPRONOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXPRONOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TM123MUCCO',
    'C<sub>9</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'ZVWGUKJQFRZUIG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM123MUCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM123MUCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM123MUCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TM123MUCOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>5</sub>',
    '',
    '',
    'JUUFKUYJQYFRGA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM123MUCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM123MUCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM123MUCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TM123MUOOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>6</sub>',
    '',
    '',
    'LLVDHGQYZCXGKH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM123MUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM123MUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM123MUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EPXALMKT',
    'C<sub>6</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'QIJMAVIYYVSLPO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXALMKT'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXALMKT'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXALMKT'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EPXMALKT',
    'C<sub>6</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'MWBGBWUOLRJCDU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXMALKT'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXMALKT'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXMALKT'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EPXEALKT',
    'C<sub>7</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'HQSBJPSKMKUTIT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXEALKT'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXEALKT'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXEALKT'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EBZPOXMUC',
    'C<sub>8</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'UTCVUMOGNJSPDS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBZPOXMUC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBZPOXMUC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBZPOXMUC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MXYEPOXMUC',
    'C<sub>8</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'VLMKIGFKBHEGBU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYEPOXMUC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYEPOXMUC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYEPOXMUC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PXYEPOXMUC',
    'C<sub>8</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'LGKLIBFTBUCZPW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYEPOXMUC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYEPOXMUC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYEPOXMUC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPBZPOXMUC',
    'C<sub>9</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'NUCYHGVQTCVYLO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBZPOXMUC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBZPOXMUC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBZPOXMUC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:METLPOXMUC',
    'C<sub>9</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'SWHMTTAIKVELRE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METLPOXMUC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METLPOXMUC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METLPOXMUC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PBZPOXMUC',
    'C<sub>9</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'AHKQGNMGHQLOPP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBZPOXMUC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBZPOXMUC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBZPOXMUC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PETLPOXMUC',
    'C<sub>9</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'UTBNMXYREJYVNQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PETLPOXMUC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PETLPOXMUC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PETLPOXMUC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TM124OXMUC',
    'C<sub>9</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'HFTMUUPKJAPOHL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124OXMUC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124OXMUC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124OXMUC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TM135OXMUC',
    'C<sub>9</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'JFCWARPMSNNZLY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM135OXMUC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM135OXMUC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM135OXMUC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DMEBPOXMUC',
    'C<sub>10</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '',
    'VGOICOHBXPGRQT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMEBPOXMUC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMEBPOXMUC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMEBPOXMUC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DETLPOXMUC',
    'C<sub>11</sub>H<sub>16</sub>O<sub>3</sub>',
    '',
    '',
    'VPGNNECRJBEQEI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DETLPOXMUC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DETLPOXMUC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DETLPOXMUC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BZEMUCCO',
    'C<sub>6</sub>H<sub>6</sub>O<sub>5</sub>',
    '',
    '',
    'KQXCODNTIAPVKL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BZEMUCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BZEMUCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BZEMUCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TLEMUCCO',
    'C<sub>7</sub>H<sub>8</sub>O<sub>5</sub>',
    '',
    '',
    'AJWOUZMMNQLKHW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TLEMUCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TLEMUCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TLEMUCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TLEMUCOH',
    'C<sub>7</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'WPTVRQIFDQMAMS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TLEMUCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TLEMUCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TLEMUCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TLEMUCOOH',
    'C<sub>7</sub>H<sub>10</sub>O<sub>6</sub>',
    '',
    '',
    'DVPKQTIPCHKXBD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>12</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TLEMUCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TLEMUCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TLEMUCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EBZMUCCO',
    'C<sub>8</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'MYHWFJZUBUHIGJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBZMUCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBZMUCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBZMUCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EBZMUCOH',
    'C<sub>8</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'VKTUBYIQTACODT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBZMUCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBZMUCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBZMUCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EBZMUCOOH',
    'C<sub>8</sub>H<sub>12</sub>O<sub>6</sub>',
    '',
    '',
    'KWCWGZCSJYJCAS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBZMUCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBZMUCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBZMUCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MXYMUCCO',
    'C<sub>8</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'KJOIECUJZBFUMR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYMUCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYMUCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYMUCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MXYMUCOH',
    'C<sub>8</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'UZLLCOIUEBQPHF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYMUCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYMUCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYMUCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MXYMUCOOH',
    'C<sub>8</sub>H<sub>12</sub>O<sub>6</sub>',
    '',
    '',
    'ZYWDOJNDZBPDDO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYMUCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYMUCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYMUCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OXYMUCCO',
    'C<sub>8</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'RJHLIQPRSGXWHC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYMUCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYMUCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYMUCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PXYMUCCO',
    'C<sub>8</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'UICQALDYFNTPHO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYMUCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYMUCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYMUCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PXYMUCOH',
    'C<sub>8</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'MIBKDAKBVPRIGB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYMUCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYMUCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYMUCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PXYMUCOOH',
    'C<sub>8</sub>H<sub>12</sub>O<sub>6</sub>',
    '',
    '',
    'GSJPWDRXFYTPMH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYMUCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYMUCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYMUCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPBZMUCCO',
    'C<sub>9</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'XOMPDNKHXMMXOK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBZMUCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBZMUCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBZMUCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPBZMUCOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>5</sub>',
    '',
    '',
    'AKVRVUIGBHJRNQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBZMUCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBZMUCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBZMUCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPBZMUCOOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>6</sub>',
    '',
    '',
    'LSOCHQKLDSXALN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBZMUCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBZMUCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBZMUCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:METLMUCCO',
    'C<sub>9</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'ZRMCSOCJQIXUEX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METLMUCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METLMUCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METLMUCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:METLMUCOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>5</sub>',
    '',
    '',
    'ARJLZFCPXRPKBS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METLMUCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METLMUCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METLMUCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:METLMUCOOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>6</sub>',
    '',
    '',
    'UXABECSPQFCGIJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METLMUCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METLMUCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METLMUCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OETLMUCCO',
    'C<sub>9</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'JSKKVRLLVVSVCZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OETLMUCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OETLMUCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OETLMUCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PBZMUCCO',
    'C<sub>9</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'FCRYPGHUONBQCX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBZMUCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBZMUCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBZMUCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PBZMUCOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>5</sub>',
    '',
    '',
    'VYXNVIKZUYYSSA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBZMUCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBZMUCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBZMUCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PBZMUCOOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>6</sub>',
    '',
    '',
    'FCKGMMNUJIAHAV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBZMUCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBZMUCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBZMUCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PETLMUCCO',
    'C<sub>9</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'RORTYMWKJCCJQU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PETLMUCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PETLMUCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PETLMUCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PETLMUCOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>5</sub>',
    '',
    '',
    'ZLOWXLKYIJYQIH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PETLMUCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PETLMUCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PETLMUCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PETLMUCOOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>6</sub>',
    '',
    '',
    'RSNULGXAYPPPGL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PETLMUCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PETLMUCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PETLMUCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TM124MUCCO',
    'C<sub>9</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '',
    'DQECTOJLTKBSTJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124MUCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124MUCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124MUCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TM124MUCOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>5</sub>',
    '',
    '',
    'KPYCPCVRGFCQPX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124MUCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124MUCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124MUCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TM124MUOOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>6</sub>',
    '',
    '',
    'DQFPDDPNMNSRMG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124MUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124MUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124MUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TM135MUOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>5</sub>',
    '',
    '',
    'CZQCDAJVGDGQTR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM135MUOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM135MUOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM135MUOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TM135MUOOH',
    'C<sub>9</sub>H<sub>14</sub>O<sub>6</sub>',
    '',
    '',
    'FIFCCDBMOKNVLN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM135MUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM135MUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM135MUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DMEBMUOH',
    'C<sub>10</sub>H<sub>16</sub>O<sub>5</sub>',
    '',
    '',
    'MURMIEBRJYKLPQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMEBMUOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMEBMUOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMEBMUOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DMEBMUOOH',
    'C<sub>10</sub>H<sub>16</sub>O<sub>6</sub>',
    '',
    '',
    'QHUZCFCKANZAOE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMEBMUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMEBMUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMEBMUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DETLMUOH',
    'C<sub>11</sub>H<sub>18</sub>O<sub>5</sub>',
    '',
    '',
    'BLCXZNPOSIAMRZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DETLMUOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DETLMUOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DETLMUOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DETLMUOOH',
    'C<sub>11</sub>H<sub>18</sub>O<sub>6</sub>',
    '',
    '',
    'ZGRWZBBDFVAIEE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DETLMUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DETLMUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DETLMUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ETOMECO2H',
    'C<sub>4</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'YZGQDNOIGFBYKF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETOMECO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETOMECO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETOMECO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MTBEBCO2H',
    'C<sub>5</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'BKBZFJRHYSCZQA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBEBCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBEBCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBEBCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BOXMCO2H',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '',
    'AJQOASGWDCBKCJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXMCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXMCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXMCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EPXDLCO2H',
    'C<sub>4</sub>H<sub>4</sub>O<sub>4</sub>',
    '',
    '',
    'BIFCJMYQXQSHFE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXDLCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXDLCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXDLCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EPXMDLCO2H',
    'C<sub>5</sub>H<sub>6</sub>O<sub>4</sub>',
    '',
    '',
    'HNJRQDPCPFMZIJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXMDLCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXMDLCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXMDLCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BZEMUCCO2H',
    'C<sub>6</sub>H<sub>6</sub>O<sub>4</sub>',
    '',
    '',
    'YYDFWEKDUXDLMC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BZEMUCCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BZEMUCCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BZEMUCCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EPXM2DCO2H',
    'C<sub>6</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'TVFMSHFDVSCCSQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXM2DCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXM2DCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXM2DCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EPXMEDCO2H',
    'C<sub>7</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'CTYOPZSWGBYACX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXMEDCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXMEDCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXMEDCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OXYMUCCO2H',
    'C<sub>8</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'CDVXJWVOWNWWPU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYMUCCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYMUCCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYMUCCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OETLMUCO2H',
    'C<sub>9</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'UVQOKFRFLASUOJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OETLMUCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OETLMUCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OETLMUCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EPXKTMCO2H',
    'C<sub>6</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'BXVGKWFSHJVVPB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXKTMCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXKTMCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXKTMCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EPXMKTCO2H',
    'C<sub>6</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'FTLSPZDBESPPRR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXMKTCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXMKTCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXMKTCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EPXEKTCO2H',
    'C<sub>7</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'XBMXXNQRKRSRRJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXEKTCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXEKTCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXEKTCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TLEMUCCO2H',
    'C<sub>7</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'YZQFSRDEODCLRC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TLEMUCCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TLEMUCCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TLEMUCCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EBZMUCCO2H',
    'C<sub>8</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'BSMJHSATRRVHTI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBZMUCCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBZMUCCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBZMUCCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MXYMUCCO2H',
    'C<sub>8</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'BMJHPUYAWBLOER-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYMUCCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYMUCCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYMUCCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PXYMUCCO2H',
    'C<sub>8</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'FMBYVAMRNZYNGO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYMUCCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYMUCCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYMUCCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPBZMUCO2H',
    'C<sub>9</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'LXYULRJMRUJREP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBZMUCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBZMUCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBZMUCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:METLMUCO2H',
    'C<sub>9</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'TZAADSLPRMCSBM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METLMUCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METLMUCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METLMUCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PBZMUCCO2H',
    'C<sub>9</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'MSVJIRWCUUEXSY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBZMUCCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBZMUCCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBZMUCCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PETLMUCO2H',
    'C<sub>9</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'YZGPSCFZKHZHEQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PETLMUCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PETLMUCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PETLMUCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TM124MUO2H',
    'C<sub>9</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'VDBMALGYQLXWML-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124MUO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124MUO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124MUO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TM135MUO2H',
    'C<sub>9</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '',
    'RLMHTEATULORAU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM135MUO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM135MUO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM135MUO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DMEBMUO2H',
    'C<sub>10</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'GTDCDBIZJZUTJP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMEBMUO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMEBMUO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMEBMUO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DETLMUO2H',
    'C<sub>11</sub>H<sub>16</sub>O<sub>4</sub>',
    '',
    '',
    'FTAMRHAZJZCWNK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DETLMUO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DETLMUO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DETLMUO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DMCOOH',
    'C<sub>3</sub>H<sub>6</sub>O<sub>5</sub>',
    '',
    '',
    'ISFGCMQHKVEPTP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MMF',
    'C<sub>3</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '',
    'VKWJMTLAAJULGF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MMF'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MMF'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MMF'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MMFOOH',
    'C<sub>3</sub>H<sub>6</sub>O<sub>5</sub>',
    '',
    '',
    'AAAZTRZXKHTMLL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MMFOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MMFOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MMFOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DMCOH',
    'C<sub>3</sub>H<sub>6</sub>O<sub>4</sub>',
    '',
    '',
    'YGODNDLTUXBUQH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MMFOH',
    'C<sub>3</sub>H<sub>6</sub>O<sub>4</sub>',
    '',
    '',
    'GDDJZBRTXIGGHV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MMFOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MMFOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MMFOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'GOLIG1',
    'C<sub>4</sub>H<sub>6</sub>O<sub>5</sub>',
    '',
    '',
    'LEKXYOUPWKVTGM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>12</sup>',
    '19000',
    'Q',
    (SELECT id from species WHERE iupac='GOLIG1'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'GOLIG2',
    'C<sub>4</sub>H<sub>8</sub>O<sub>6</sub>',
    '',
    '',
    'GWSRJJGBNXJVPO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>15</sup>',
    '24000',
    'Q',
    (SELECT id from species WHERE iupac='GOLIG2'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'GOLIG3',
    'C<sub>4</sub>H<sub>10</sub>O<sub>7</sub>',
    '',
    '',
    'ADECTKUVLJSMDK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>18</sup>',
    '29000',
    'Q',
    (SELECT id from species WHERE iupac='GOLIG3'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MGLYFB',
    'C<sub>6</sub>H<sub>10</sub>O<sub>6</sub>',
    '',
    '',
    'UCPBJDKPOQEXSQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>8</sup>',
    '23000',
    'Q',
    (SELECT id from species WHERE iupac='MGLYFB'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MGLYOXDA',
    'C<sub>6</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '',
    'QMSLRDMQAWWKIZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>8</sup>',
    '16000',
    'Q',
    (SELECT id from species WHERE iupac='MGLYOXDA'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MGLYOXDB',
    'C<sub>6</sub>H<sub>12</sub>O<sub>6</sub>',
    '',
    '',
    'IUHMFBWAUOLAFM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Ethers (ROR)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>13</sup>',
    '22000',
    'Q',
    (SELECT id from species WHERE iupac='MGLYOXDB'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Heterocycles with oxygen',
    (SELECT id from categories WHERE catname='Organic species with oxygen (O)'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '&#946;-propiolactone',
    'C<sub>3</sub>H<sub>4</sub>O<sub>2</sub>',
    '',
    '57-57-8',
    'VEZXCJBBBCKRPI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='&#946;-propiolactone'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-1,3-dioxolane',
    'C<sub>4</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '497-26-7',
    'HTWIZMNMTWYQRN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methyl-1,3-dioxolane'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'DIEPOXO3',
    'C<sub>5</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'QGQUFAZKBSHWQB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '14000',
    'Q',
    (SELECT id from species WHERE iupac='DIEPOXO3'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'IEPOXO4',
    'C<sub>5</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '',
    'DNQIATHBSKHPLN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>4</sup>',
    '14000',
    'Q',
    (SELECT id from species WHERE iupac='IEPOXO4'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dimethyl-1,3-dioxolane',
    'C<sub>5</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '2916-31-6',
    'SIJBDWPVNAYVGY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2-dimethyl-1,3-dioxolane'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'METHFDIOL',
    'C<sub>5</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '',
    'UNAIOYXCADSMDR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>5</sup>',
    '11000',
    'Q',
    (SELECT id from species WHERE iupac='METHFDIOL'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4-dihydro-2-methoxy-2H-pyran',
    'C<sub>6</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '4454-05-1',
    'XCYWUZHUTJDTGS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,4-dihydro-2-methoxy-2H-pyran'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'maltol',
    'C<sub>6</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '118-71-8',
    'XPCTZQVDEJYUGT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='maltol'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methylfuran',
    'C<sub>5</sub>H<sub>6</sub>O',
    '',
    '534-22-5',
    'VQKFNUFAXTZWDK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '4100',
    'M',
    (SELECT id from species WHERE iupac='2-methylfuran'),
    (SELECT id from literature WHERE bibtexkey='3215'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3215-534-22-5-ABC',
    '3215', 'The data from Wieland et&nbsp;al. (2015) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;157.10556 +10203.60762/T +20.42555&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3215-534-22-5-ABC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methylfuran',
    'C<sub>5</sub>H<sub>6</sub>O',
    '',
    '930-27-8',
    'KJRRQXYWFQKJIP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylfuran'),
    (SELECT id from literature WHERE bibtexkey='3719'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3719-SPARC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-furanmethanol',
    'C<sub>5</sub>H<sub>6</sub>O<sub>2</sub>',
    'furfuryl alcohol',
    '98-00-0',
    'XPFVYQJUAUNWIW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-furanmethanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-furanmethanol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-furanmethanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-furanmethanol'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-furanmethanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-furanmethanol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-furanmethanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-furanmethanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-furanmethanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-furanmethanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-furanmethanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-furanmethanol'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-furanmethanol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tetrahydropyran-2-methanol',
    'C<sub>6</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '100-72-1',
    'ROTONRWJLXYJBD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tetrahydropyran-2-methanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrahydropyran-2-methanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrahydropyran-2-methanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrahydropyran-2-methanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrahydropyran-2-methanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrahydropyran-2-methanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrahydropyran-2-methanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'oxirane',
    'C<sub>2</sub>H<sub>4</sub>O',
    'ethylene oxide',
    '75-21-8',
    'IAYPIBMASNFSPL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '3200',
    'M',
    (SELECT id from species WHERE iupac='oxirane'),
    (SELECT id from literature WHERE bibtexkey='2534'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='oxirane'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='oxirane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='oxirane'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='oxirane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='oxirane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='oxirane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='oxirane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='oxirane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='oxirane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='oxirane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='oxirane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='oxirane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='oxirane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='oxirane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-epoxypropane',
    'C<sub>3</sub>H<sub>6</sub>O',
    '1,2-propylene oxide',
    '75-56-9',
    'GOOHAUXETOMSMM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-epoxypropane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-epoxypropane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-epoxypropane'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-epoxypropane'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-epoxypropane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,2-epoxypropane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,2-epoxypropane'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;2</sup>',
    '3500',
    'X',
    (SELECT id from species WHERE iupac='1,2-epoxypropane'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-epoxypropane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-epoxypropane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-epoxypropane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-epoxypropane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-epoxypropane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-epoxypropane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phenyloxirane',
    'C<sub>8</sub>H<sub>8</sub>O',
    'styrene oxide',
    '96-09-3',
    'AWMVMTVKBNGEAK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='phenyloxirane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='phenyloxirane'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='phenyloxirane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='phenyloxirane'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenyloxirane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenyloxirane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenyloxirane'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'oxacyclopentadiene',
    'C<sub>4</sub>H<sub>4</sub>O',
    'furan; furfuran',
    '110-00-9',
    'YLQBMQCUIZJEEH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='oxacyclopentadiene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='oxacyclopentadiene'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='oxacyclopentadiene'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='oxacyclopentadiene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='oxacyclopentadiene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='oxacyclopentadiene'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='oxacyclopentadiene'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='oxacyclopentadiene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='oxacyclopentadiene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='oxacyclopentadiene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='oxacyclopentadiene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='oxacyclopentadiene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='oxacyclopentadiene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='oxacyclopentadiene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='oxacyclopentadiene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='oxacyclopentadiene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='oxacyclopentadiene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dibenzofuran',
    'C<sub>12</sub>H<sub>8</sub>O',
    '2,2''-biphenylene oxide',
    '132-64-9',
    'TXCDCPKCNAJMEE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;2</sup>',
    '5800',
    'L',
    (SELECT id from species WHERE iupac='dibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='634'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3034'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-furancarboxaldehyde',
    'C<sub>5</sub>H<sub>4</sub>O<sub>2</sub>',
    'furfural; 2-furanaldehyde',
    '98-01-1',
    'HYBBIBNJHNGZAN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-furancarboxaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-furancarboxaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-furancarboxaldehyde'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-furancarboxaldehyde'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-furancarboxaldehyde'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-furancarboxaldehyde'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-furancarboxaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-furancarboxaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-furancarboxaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-furancarboxaldehyde'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-furancarboxaldehyde'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-furancarboxaldehyde'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-furancarboxaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-furancarboxaldehyde'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-furancarboxaldehyde'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-furancarboxaldehyde'),
    (SELECT id from literature WHERE bibtexkey='2597'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at373K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-furancarboxaldehyde'),
    (SELECT id from literature WHERE bibtexkey='2599'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at373K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6100',
    'Q',
    (SELECT id from species WHERE iupac='2-furancarboxaldehyde'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5900',
    '?',
    (SELECT id from species WHERE iupac='2-furancarboxaldehyde'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-furancarboxaldehyde'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-methylfurfural',
    'C<sub>6</sub>H<sub>6</sub>O<sub>2</sub>',
    '',
    '620-02-0',
    'OUDFNZMQXZILJD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7',
    '',
    '?',
    (SELECT id from species WHERE iupac='5-methylfurfural'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dimethyloxirane',
    'C<sub>4</sub>H<sub>8</sub>O',
    'isobutylene oxide',
    '558-30-5',
    'GELKGHVAFRCJNA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2-dimethyloxirane'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tetrahydrofuran',
    'C<sub>4</sub>H<sub>8</sub>O',
    'THF',
    '109-99-9',
    'WYURNTSHIVDZCO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '5700',
    'L',
    (SELECT id from species WHERE iupac='tetrahydrofuran'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '5700',
    'M',
    (SELECT id from species WHERE iupac='tetrahydrofuran'),
    (SELECT id from literature WHERE bibtexkey='3305'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='tetrahydrofuran'),
    (SELECT id from literature WHERE bibtexkey='3646'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;1</sup>',
    '4200',
    'M',
    (SELECT id from species WHERE iupac='tetrahydrofuran'),
    (SELECT id from literature WHERE bibtexkey='3648'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='tetrahydrofuran'),
    (SELECT id from literature WHERE bibtexkey='795'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '5700',
    'T',
    (SELECT id from species WHERE iupac='tetrahydrofuran'),
    (SELECT id from literature WHERE bibtexkey='723'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='tetrahydrofuran'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrahydrofuran'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrahydrofuran'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrahydrofuran'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrahydrofuran'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrahydrofuran'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrahydrofuran'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrahydrofuran'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrahydrofuran'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrahydrofuran'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4000',
    'Q',
    (SELECT id from species WHERE iupac='tetrahydrofuran'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrahydrofuran'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrahydrofuran'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrahydrofuran'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrahydrofuran'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tetrahydrofuran'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3200',
    '?',
    (SELECT id from species WHERE iupac='tetrahydrofuran'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tetrahydrofuran'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tetrahydrofuran'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tetrahydrofuran-d8',
    'C<sub>4</sub>D<sub>8</sub>O',
    'THF-d8',
    '1693-74-9',
    'WYURNTSHIVDZCO-SVYQBANQSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '8000',
    'M',
    (SELECT id from species WHERE iupac='tetrahydrofuran-d8'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyltetrahydrofuran',
    'CH<sub>3</sub>C<sub>4</sub>H<sub>7</sub>O',
    '',
    '96-47-9',
    'JWUJQDFVADABEY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyltetrahydrofuran'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '6200',
    'T',
    (SELECT id from species WHERE iupac='2-methyltetrahydrofuran'),
    (SELECT id from literature WHERE bibtexkey='723'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyltetrahydrofuran'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyltetrahydrofuran'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyltetrahydrofuran'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyltetrahydrofuran'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyltetrahydrofuran'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyltetrahydrofuran'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyltetrahydrofuran'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4400',
    'Q',
    (SELECT id from species WHERE iupac='2-methyltetrahydrofuran'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyltetrahydrofuran'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyltetrahydrofuran'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyltetrahydrofuran'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methyltetrahydrofuran'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5400',
    '?',
    (SELECT id from species WHERE iupac='2-methyltetrahydrofuran'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5-dimethyltetrahydrofuran',
    '(CH<sub>3</sub>)<sub>2</sub>C<sub>4</sub>H<sub>6</sub>O',
    '',
    '1003-38-9',
    'OXMIDRBAFOEOQT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '6800',
    'T',
    (SELECT id from species WHERE iupac='2,5-dimethyltetrahydrofuran'),
    (SELECT id from literature WHERE bibtexkey='723'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyltetrahydrofuran'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyltetrahydrofuran'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyltetrahydrofuran'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyltetrahydrofuran'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyltetrahydrofuran'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethyltetrahydrofuran'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tetrahydropyran',
    'C<sub>5</sub>H<sub>10</sub>O',
    'THP',
    '142-68-7',
    'DHXVGJBLRPWPCS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;2</sup>',
    '5800',
    'L',
    (SELECT id from species WHERE iupac='tetrahydropyran'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;2</sup>',
    '5900',
    'M',
    (SELECT id from species WHERE iupac='tetrahydropyran'),
    (SELECT id from literature WHERE bibtexkey='3305'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tetrahydropyran'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tetrahydropyran'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;2</sup>',
    '5900',
    'T',
    (SELECT id from species WHERE iupac='tetrahydropyran'),
    (SELECT id from literature WHERE bibtexkey='723'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrahydropyran'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrahydropyran'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrahydropyran'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrahydropyran'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrahydropyran'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrahydropyran'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrahydropyran'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrahydropyran'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrahydropyran'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-Test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrahydropyran'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrahydropyran'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tetrahydropyran'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tetrahydropyran'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyltetrahydropyran',
    'C<sub>6</sub>H<sub>12</sub>O',
    '',
    '26093-63-0',
    'UJQZTMFRMLEYQN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4700',
    'Q',
    (SELECT id from species WHERE iupac='3-methyltetrahydropyran'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5300',
    '?',
    (SELECT id from species WHERE iupac='3-methyltetrahydropyran'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4-dihydro-2H-pyran',
    'C<sub>5</sub>H<sub>8</sub>O',
    '',
    '110-87-2',
    'BUDQDWGNQVEFAC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3500',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dihydro-2H-pyran'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3600',
    '?',
    (SELECT id from species WHERE iupac='3,4-dihydro-2H-pyran'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3-dioxolane',
    'C<sub>3</sub>H<sub>6</sub>O<sub>2</sub>',
    '',
    '646-06-0',
    'WNXJIVFYUVYPPR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;1</sup>',
    '4800',
    'M',
    (SELECT id from species WHERE iupac='1,3-dioxolane'),
    (SELECT id from literature WHERE bibtexkey='3305'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '4800',
    'T',
    (SELECT id from species WHERE iupac='1,3-dioxolane'),
    (SELECT id from literature WHERE bibtexkey='723'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dioxolane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dioxolane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dioxolane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dioxolane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,3-dioxolane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3-dioxane',
    'C<sub>4</sub>H<sub>8</sub>O<sub>2</sub>',
    '',
    '505-22-6',
    'VDFVNEFVBPFDSB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,3-dioxane'),
    (SELECT id from literature WHERE bibtexkey='3526'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dioxane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4-dioxane',
    'C<sub>4</sub>H<sub>8</sub>O<sub>2</sub>',
    'dioxane',
    '123-91-1',
    'RYHBNJHYFVUHQT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '5800',
    'L',
    (SELECT id from species WHERE iupac='1,4-dioxane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '6600',
    'M',
    (SELECT id from species WHERE iupac='1,4-dioxane'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '5800',
    'M',
    (SELECT id from species WHERE iupac='1,4-dioxane'),
    (SELECT id from literature WHERE bibtexkey='3305'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,4-dioxane'),
    (SELECT id from literature WHERE bibtexkey='3646'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '5100',
    'M',
    (SELECT id from species WHERE iupac='1,4-dioxane'),
    (SELECT id from literature WHERE bibtexkey='857'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='857'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,4-dioxane'),
    (SELECT id from literature WHERE bibtexkey='2449'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,4-dioxane'),
    (SELECT id from literature WHERE bibtexkey='3640'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,4-dioxane'),
    (SELECT id from literature WHERE bibtexkey='729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at303K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,4-dioxane'),
    (SELECT id from literature WHERE bibtexkey='792'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-dioxane'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-dioxane'),
    (SELECT id from literature WHERE bibtexkey='2388'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '5800',
    'T',
    (SELECT id from species WHERE iupac='1,4-dioxane'),
    (SELECT id from literature WHERE bibtexkey='723'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dioxane'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dioxane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dioxane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dioxane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dioxane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dioxane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dioxane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dioxane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5200',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dioxane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dioxane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dioxane'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,4-dioxane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6100',
    '?',
    (SELECT id from species WHERE iupac='1,4-dioxane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,4-dioxane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,4-dioxane'),
    (SELECT id from literature WHERE bibtexkey='510'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '510diox714',
    '510,714', 'Betterton (1992) gives Hine and Weimar (1965) as the source. However, no data were found in that reference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='510diox714'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,4-dioxane'),
    (SELECT id from literature WHERE bibtexkey='510'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '510diox728',
    '510,728', 'Betterton (1992) gives Vitenberg et&nbsp;al. (1975) as the source. However, no data were found in that reference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='510diox728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,4-dioxane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4-dioxane-d8',
    'C<sub>4</sub>D<sub>8</sub>O<sub>2</sub>',
    'dioxane-d8',
    '17647-74-4',
    'RYHBNJHYFVUHQT-SVYQBANQSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '6800',
    'M',
    (SELECT id from species WHERE iupac='1,4-dioxane-d8'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'trioxane',
    'C<sub>3</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '110-88-3',
    'BGJSXRVXTHVRSN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='trioxane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trioxane'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-1,3-dioxolan-2-one',
    'C<sub>4</sub>H<sub>6</sub>O<sub>3</sub>',
    'propylene carbonate',
    '108-32-7',
    'RUOJZAUFBMNUDX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-methyl-1,3-dioxolan-2-one'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-methyl-1,3-dioxolan-2-one'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1,3-dioxolan-2-one'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-methyl-1,3-dioxolan-2-one'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3,3-trimethyl-2-oxabicyclo[2.2.2]octane',
    'C<sub>10</sub>H<sub>18</sub>O',
    'eucalyptol; 1,8-cineole',
    '470-82-6',
    'WEEGYLXZBRQIMU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,3,3-trimethyl-2-oxabicyclo[2.2.2]octane'),
    (SELECT id from literature WHERE bibtexkey='3007'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,3,3-trimethyl-2-oxabicyclo[2.2.2]octane'),
    (SELECT id from literature WHERE bibtexkey='2388'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3,3-trimethyl-2-oxabicyclo[2.2.2]octane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3,3-trimethyl-2-oxabicyclo[2.2.2]octane'),
    (SELECT id from literature WHERE bibtexkey='2124'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3,3-trimethyl-2-oxabicyclo[2.2.2]octane'),
    (SELECT id from literature WHERE bibtexkey='2487'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3,3-trimethyl-2-oxabicyclo[2.2.2]octane'),
    (SELECT id from literature WHERE bibtexkey='2388'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,3-trimethyl-2-oxabicyclo[2.2.2]octane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,3-trimethyl-2-oxabicyclo[2.2.2]octane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,3-trimethyl-2-oxabicyclo[2.2.2]octane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'limonene oxide',
    'C<sub>10</sub>H<sub>16</sub>O',
    '',
    '1195-92-2',
    'CCEFMUBVSUDRLG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='limonene oxide'),
    (SELECT id from literature WHERE bibtexkey='2462'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='limonene oxide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '4600',
    'V',
    (SELECT id from species WHERE iupac='limonene oxide'),
    (SELECT id from literature WHERE bibtexkey='2125'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='limonene oxide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dibenzo[b,e][1,4]dioxin',
    'C<sub>12</sub>H<sub>8</sub>O<sub>2</sub>',
    'dibenzo-p-dioxin',
    '262-12-4',
    'NFBOHOGPQUYFRF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dibenzo[b,e][1,4]dioxin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dibenzo[b,e][1,4]dioxin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dibenzo[b,e][1,4]dioxin'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dibenzo[b,e][1,4]dioxin'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dibenzo[b,e][1,4]dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dibenzo[b,e][1,4]dioxin'),
    (SELECT id from literature WHERE bibtexkey='854'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibenzo[b,e][1,4]dioxin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibenzo[b,e][1,4]dioxin'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibenzo[b,e][1,4]dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2949GCRI',
    '', 'Based on gas chromatograph retention indices (GC-RIs).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibenzo[b,e][1,4]dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'piperonal',
    'C<sub>8</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '120-57-0',
    'SATCULPHIDQDRE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='piperonal'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='piperonal'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='piperonal'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='piperonal'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='piperonal'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'paraldehyde',
    'C<sub>6</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '123-63-7',
    'SQYNKIJPMDEDEG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='paraldehyde'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='paraldehyde'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='paraldehyde'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='paraldehyde'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='paraldehyde'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='paraldehyde'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at303K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benzofuran',
    'C<sub>8</sub>H<sub>6</sub>O',
    '',
    '271-89-6',
    'IANQTJSKSUMEQM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzofuran'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzofuran'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '&#947;-nonalactone',
    'C<sub>9</sub>H<sub>16</sub>O<sub>2</sub>',
    '',
    '104-61-0',
    'OALYTRUKMRCXNH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#947;-nonalactone'),
    (SELECT id from literature WHERE bibtexkey='2599'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at373K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'xanthene',
    'C<sub>13</sub>H<sub>10</sub>O',
    '',
    '92-83-1',
    'GJCOSYZMQJWQCA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='xanthene'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,5,5,9-tetramethyl-13-oxatricyclo(8.3.0.0(4,9))tridecane',
    'C<sub>16</sub>H<sub>28</sub>O',
    'ambroxan',
    '3738-00-9',
    'YPZUZOLGGMJZJO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,5,5,9-tetramethyl-13-oxatricyclo(8.3.0.0(4,9))tridecane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,5,5,9-tetramethyl-13-oxatricyclo(8.3.0.0(4,9))tridecane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,5,5,9-tetramethyl-13-oxatricyclo(8.3.0.0(4,9))tridecane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,5,5,9-tetramethyl-13-oxatricyclo(8.3.0.0(4,9))tridecane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3,4,6,7,8-hexahydro-4,6,6,7,8,8-hexamethylcyclopenta[g]-2-benzopyran',
    'C<sub>18</sub>H<sub>26</sub>O',
    '',
    '1222-05-5',
    'ONKNPOPIGWHAQC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3,4,6,7,8-hexahydro-4,6,6,7,8,8-hexamethylcyclopenta[g]-2-benzopyran'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,4,6,7,8-hexahydro-4,6,6,7,8,8-hexamethylcyclopenta[g]-2-benzopyran'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,4,6,7,8-hexahydro-4,6,6,7,8,8-hexamethylcyclopenta[g]-2-benzopyran'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,4,6,7,8-hexahydro-4,6,6,7,8,8-hexamethylcyclopenta[g]-2-benzopyran'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,4,6,7,8-hexahydro-4,6,6,7,8,8-hexamethylcyclopenta[g]-2-benzopyran'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cinmethylin',
    'C<sub>18</sub>H<sub>26</sub>O<sub>2</sub>',
    '',
    '87818-31-3',
    'QMTNOLKHSWIQBE-FGTMMUONSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cinmethylin'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'milbemycin A4',
    'C<sub>32</sub>H<sub>46</sub>O<sub>7</sub>',
    'milbemectin A4',
    '51596-11-3',
    'VOZIAWLUULBIPN-LRBNAKOISA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='milbemycin A4'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Oxidized terpenoids',
    (SELECT id from categories WHERE catname='Organic species with oxygen (O)'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(1S-endo)-1,7,7-trimethyl-bicyclo[2.2.1]heptan-2-ol',
    'C<sub>10</sub>H<sub>18</sub>O',
    '1S-endo-(-)-borneol',
    '464-45-9',
    'DTGKSKDOIYIVQL-QXFUBDJGSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxidized terpenoids'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='(1S-endo)-1,7,7-trimethyl-bicyclo[2.2.1]heptan-2-ol'),
    (SELECT id from literature WHERE bibtexkey='2462'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(1S-endo)-1,7,7-trimethyl-bicyclo[2.2.1]heptan-2-ol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(1S-endo)-1,7,7-trimethyl-bicyclo[2.2.1]heptan-2-ol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(1R)-1,3,3-trimethylbicyclo[2.2.1]heptan-2-ol',
    'C<sub>10</sub>H<sub>18</sub>O',
    'endo-(+)-fenchyl alcohol',
    '2217-02-9',
    'IAIHUHQCLTYTSF-OYNCUSHFSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxidized terpenoids'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='(1R)-1,3,3-trimethylbicyclo[2.2.1]heptan-2-ol'),
    (SELECT id from literature WHERE bibtexkey='2462'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(1R)-1,3,3-trimethylbicyclo[2.2.1]heptan-2-ol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(1R)-1,3,3-trimethylbicyclo[2.2.1]heptan-2-ol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-(4-methyl-3-cyclohexen-1-yl)-2-propanol',
    'C<sub>10</sub>H<sub>18</sub>O',
    '&#945;-terpineol',
    '98-55-5',
    'WUOACPNHFRMFPN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxidized terpenoids'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4',
    '2200',
    'M',
    (SELECT id from species WHERE iupac='2-(4-methyl-3-cyclohexen-1-yl)-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2124'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-(4-methyl-3-cyclohexen-1-yl)-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2124'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;1</sup>',
    '4800',
    'V',
    (SELECT id from species WHERE iupac='2-(4-methyl-3-cyclohexen-1-yl)-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2125'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-(4-methyl-3-cyclohexen-1-yl)-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2487'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;1</sup>',
    '5400',
    'V',
    (SELECT id from species WHERE iupac='2-(4-methyl-3-cyclohexen-1-yl)-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2464'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(4-methyl-3-cyclohexen-1-yl)-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(4-methyl-3-cyclohexen-1-yl)-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(4-methyl-3-cyclohexen-1-yl)-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-dimethyl-3-(1-methylethenyl)-cyclopentanol',
    'C<sub>10</sub>H<sub>18</sub>O',
    'plinol',
    '72402-00-7',
    'ZRVPDCMGGOSDKG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxidized terpenoids'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dimethyl-3-(1-methylethenyl)-cyclopentanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '17000',
    'V',
    (SELECT id from species WHERE iupac='1,2-dimethyl-3-(1-methylethenyl)-cyclopentanol'),
    (SELECT id from literature WHERE bibtexkey='2464'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethyl-3-(1-methylethenyl)-cyclopentanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethyl-3-(1-methylethenyl)-cyclopentanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethyl-3-(1-methylethenyl)-cyclopentanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-4-(1-methylethyl)-7-oxabicyclo[2.2.1]heptane',
    'C<sub>10</sub>H<sub>18</sub>O',
    '1,4-cineole',
    '470-67-7',
    'RFFOTVCVTJUTAD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxidized terpenoids'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-7-oxabicyclo[2.2.1]heptane'),
    (SELECT id from literature WHERE bibtexkey='2955'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-7-oxabicyclo[2.2.1]heptane'),
    (SELECT id from literature WHERE bibtexkey='2124'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '4000',
    'V',
    (SELECT id from species WHERE iupac='1-methyl-4-(1-methylethyl)-7-oxabicyclo[2.2.1]heptane'),
    (SELECT id from literature WHERE bibtexkey='2125'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,7,7-trimethyl-bicyclo[2.2.1]heptan-2-one',
    'C<sub>10</sub>H<sub>16</sub>O',
    'camphor',
    '76-22-2',
    'DSSYKIVIOFKYAU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxidized terpenoids'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,7,7-trimethyl-bicyclo[2.2.1]heptan-2-one'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,7,7-trimethyl-bicyclo[2.2.1]heptan-2-one'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,7,7-trimethyl-bicyclo[2.2.1]heptan-2-one'),
    (SELECT id from literature WHERE bibtexkey='2124'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;1</sup>',
    '4800',
    'V',
    (SELECT id from species WHERE iupac='1,7,7-trimethyl-bicyclo[2.2.1]heptan-2-one'),
    (SELECT id from literature WHERE bibtexkey='2125'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,7,7-trimethyl-bicyclo[2.2.1]heptan-2-one'),
    (SELECT id from literature WHERE bibtexkey='2487'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,7,7-trimethyl-bicyclo[2.2.1]heptan-2-one'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,7,7-trimethyl-bicyclo[2.2.1]heptan-2-one'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,7,7-trimethyl-3-oxatricyclo[4.1.1.0(2,4)]octane',
    'C<sub>10</sub>H<sub>16</sub>O',
    '(-)-&#945;-pinene oxide',
    '1686-14-2',
    'NQFUSWIGRKFAHK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxidized terpenoids'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,7,7-trimethyl-3-oxatricyclo[4.1.1.0(2,4)]octane'),
    (SELECT id from literature WHERE bibtexkey='2462'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,7,7-trimethyl-3-oxatricyclo[4.1.1.0(2,4)]octane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,7,7-trimethyl-3-oxatricyclo[4.1.1.0(2,4)]octane'),
    (SELECT id from literature WHERE bibtexkey='2124'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;2</sup>',
    '4400',
    'V',
    (SELECT id from species WHERE iupac='2,7,7-trimethyl-3-oxatricyclo[4.1.1.0(2,4)]octane'),
    (SELECT id from literature WHERE bibtexkey='2125'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,7,7-trimethyl-3-oxatricyclo[4.1.1.0(2,4)]octane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-methyl-2-(1-methylethylidene)-cyclohexanone',
    'C<sub>10</sub>H<sub>16</sub>O',
    'pulegone',
    '89-82-7',
    'NZGWDASTMWDZIW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxidized terpenoids'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '5300',
    'V',
    (SELECT id from species WHERE iupac='5-methyl-2-(1-methylethylidene)-cyclohexanone'),
    (SELECT id from literature WHERE bibtexkey='2125'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-2-(1-methylethylidene)-cyclohexanone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'exo-2-[(1,7,7-trimethylbicyclo[2.2.1]hept-2-yl)-oxy]ethanol',
    'C<sub>12</sub>H<sub>22</sub>O<sub>2</sub>',
    'arbanol',
    '7070-15-7',
    'IWWCSDGEIDYEJV-JBLDHEPKSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxidized terpenoids'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '4100',
    'V',
    (SELECT id from species WHERE iupac='exo-2-[(1,7,7-trimethylbicyclo[2.2.1]hept-2-yl)-oxy]ethanol'),
    (SELECT id from literature WHERE bibtexkey='2464'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bornyl acetate',
    'C<sub>12</sub>H<sub>20</sub>O<sub>2</sub>',
    '',
    '5655-61-8',
    'KGEKLUUHTZCSIP-SCVCMEIPSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxidized terpenoids'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;4</sup>',
    '1700',
    'M',
    (SELECT id from species WHERE iupac='bornyl acetate'),
    (SELECT id from literature WHERE bibtexkey='3216'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '&#946;-ionone',
    'C<sub>13</sub>H<sub>20</sub>O',
    '',
    '79-77-6',
    'PSQYTAPXSHCGMF-BQYQJAHWSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxidized terpenoids'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'M',
    (SELECT id from species WHERE iupac='&#946;-ionone'),
    (SELECT id from literature WHERE bibtexkey='2462'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='&#946;-ionone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#946;-ionone'),
    (SELECT id from literature WHERE bibtexkey='3521'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#946;-ionone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nerolidol',
    'C<sub>15</sub>H<sub>26</sub>O',
    '',
    '7212-44-4',
    'FQTLCLSUCSAZDY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxidized terpenoids'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;4</sup>',
    '4300',
    'M',
    (SELECT id from species WHERE iupac='nerolidol'),
    (SELECT id from literature WHERE bibtexkey='3216'));
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Miscellaneous',
    (SELECT id from categories WHERE catname='Organic species with oxygen (O)'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'oxoethanoic acid',
    'OHCCOOH',
    'glyoxylic acid',
    '298-12-4',
    'HHLFWLYXYJOTON-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '4800',
    'L',
    (SELECT id from species WHERE iupac='oxoethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='RCHOdiol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '4800',
    'L',
    (SELECT id from species WHERE iupac='oxoethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='RCHOdiol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '4800',
    'L',
    (SELECT id from species WHERE iupac='oxoethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '4800',
    'M',
    (SELECT id from species WHERE iupac='oxoethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2401'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='oxoethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='oxoethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='oxoethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='oxoethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='oxoethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='oxoethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='oxoethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>1</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='oxoethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    '?',
    (SELECT id from species WHERE iupac='oxoethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2212'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2212wrongref',
    '2212,588', 'Warneck (2005) refers to Saxena and Hildemann (1996) as the source, but the quoted value cannot be found there.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2212wrongref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hydroxyethanoic acid',
    'HOCH<sub>2</sub>COOH',
    'glycolic acid',
    '79-14-1',
    'AEMRFAOFKBGASW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>2</sup>',
    '4000',
    'L',
    (SELECT id from species WHERE iupac='hydroxyethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='RCHOdiol'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3500-79-14-1',
    '3500', 'The formula of hydroxyethanoic acid is incorrectly given as "HC(OH)C(O)OH" by Burkholder et&nbsp;al. (2019).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3500-79-14-1'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>2</sup>',
    '4000',
    'L',
    (SELECT id from species WHERE iupac='hydroxyethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='RCHOdiol'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3245-79-14-1',
    '3245', 'The formula of hydroxyethanoic acid is incorrectly given as "HC(OH)C(O)OH" by Burkholder et&nbsp;al. (2015).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3245-79-14-1'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>2</sup>',
    '4000',
    'L',
    (SELECT id from species WHERE iupac='hydroxyethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>2</sup>',
    '4000',
    'M',
    (SELECT id from species WHERE iupac='hydroxyethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2401'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydroxyethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydroxyethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydroxyethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydroxyethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydroxyethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydroxyethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-hydroxyethanal',
    'HOCH<sub>2</sub>CHO',
    'hydroxyacetaldehyde; glycolaldehyde',
    '141-46-8',
    'WGCNASOHLSPBMP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>2</sup>',
    '4600',
    'L',
    (SELECT id from species WHERE iupac='2-hydroxyethanal'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='RCHOdiol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>2</sup>',
    '4600',
    'L',
    (SELECT id from species WHERE iupac='2-hydroxyethanal'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='RCHOdiol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>2</sup>',
    '4600',
    'M',
    (SELECT id from species WHERE iupac='2-hydroxyethanal'),
    (SELECT id from literature WHERE bibtexkey='484'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='RCHOdiol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='2-hydroxyethanal'),
    (SELECT id from literature WHERE bibtexkey='2527'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxyethanal'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxyethanal'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxyethanal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxyethanal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxyethanal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxyethanal'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxyethanal'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxyethanal'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxyethanal'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxyethanal'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7600',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxyethanal'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-hydroxyethanal'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4600',
    '?',
    (SELECT id from species WHERE iupac='2-hydroxyethanal'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propanonal',
    'CH<sub>3</sub>COCHO',
    'methylglyoxal; pyruvaldehyde',
    '78-98-8',
    'AIJULSRZWUXGPQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>1</sup>',
    '7500',
    'L',
    (SELECT id from species WHERE iupac='propanonal'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='RCHOdiol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>1</sup>',
    '7500',
    'L',
    (SELECT id from species WHERE iupac='propanonal'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='RCHOdiol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='propanonal'),
    (SELECT id from literature WHERE bibtexkey='630'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>1</sup>',
    '7500',
    'M',
    (SELECT id from species WHERE iupac='propanonal'),
    (SELECT id from literature WHERE bibtexkey='484'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='RCHOdiol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='propanonal'),
    (SELECT id from literature WHERE bibtexkey='2527'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanonal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanonal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanonal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanonal'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanonal'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanonal'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanonal'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6200',
    'Q',
    (SELECT id from species WHERE iupac='propanonal'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanonal'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7600',
    '?',
    (SELECT id from species WHERE iupac='propanonal'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-oxopropanoic acid',
    'CH<sub>3</sub>COCOOH',
    'pyruvic acid',
    '127-17-3',
    'LCTONWCANYUPML-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>3</sup>',
    '5100',
    'L',
    (SELECT id from species WHERE iupac='2-oxopropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>3</sup>',
    '5100',
    'L',
    (SELECT id from species WHERE iupac='2-oxopropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>3</sup>',
    '5100',
    'L',
    (SELECT id from species WHERE iupac='2-oxopropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>3</sup>',
    '5100',
    'L',
    (SELECT id from species WHERE iupac='2-oxopropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>3</sup>',
    '5300',
    'L',
    (SELECT id from species WHERE iupac='2-oxopropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>3</sup>',
    '5100',
    'M',
    (SELECT id from species WHERE iupac='2-oxopropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='493'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-oxopropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1063'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>3</sup>',
    '5200',
    'M',
    (SELECT id from species WHERE iupac='2-oxopropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2230'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-oxopropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-oxopropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-oxopropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-oxopropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-oxopropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-oxopropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-oxopropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-oxopropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-oxopropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-oxopropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5600',
    'Q',
    (SELECT id from species WHERE iupac='2-oxopropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-oxopropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5300',
    '?',
    (SELECT id from species WHERE iupac='2-oxopropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-oxopropanoic acid',
    'OHCCH<sub>2</sub>COOH',
    '',
    '926-61-4',
    'OAKURXIZZOAYBC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-oxopropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-oxopropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-oxopropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>1</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='3-oxopropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-hydroxypropanoic acid',
    'CH<sub>3</sub>CHOHCOOH',
    'lactic acid',
    '50-21-5',
    'JVTAAEKCZFNVCJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-hydroxypropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-hydroxypropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxypropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxypropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxypropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxypropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>5</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='2-hydroxypropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'glycidaldehyde',
    'C<sub>3</sub>H<sub>4</sub>O<sub>2</sub>',
    '',
    '765-34-4',
    'IWYRWIUNAVNFPE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='glycidaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'trimethylene oxide',
    'C<sub>3</sub>H<sub>6</sub>O',
    '1,3-epoxypropane; 1,3-propylene oxide; oxetane',
    '503-30-0',
    'AHHWIHXENZJRFG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='trimethylene oxide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='trimethylene oxide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trimethylene oxide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dihydroxypropanal',
    'C<sub>3</sub>H<sub>6</sub>O<sub>3</sub>',
    'glyceraldehyde',
    '367-47-5',
    'MNQZXJOMYWMBOU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dihydroxypropanal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dihydroxypropanal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dihydroxypropanal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>8</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='2,3-dihydroxypropanal'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dihydroxyacetone',
    'C<sub>3</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '96-26-4',
    'RXKJFZQQPQGTFL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dihydroxyacetone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dihydroxyacetone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dihydroxyacetone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dihydroxyacetone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methoxyethanol',
    'C<sub>3</sub>H<sub>8</sub>O<sub>2</sub>',
    'methyl cellosolve',
    '109-86-4',
    'XNWFRZJHXBZDAG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4',
    '7500',
    'M',
    (SELECT id from species WHERE iupac='2-methoxyethanol'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;4</sup>',
    '-730',
    'M',
    (SELECT id from species WHERE iupac='2-methoxyethanol'),
    (SELECT id from literature WHERE bibtexkey='1156'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '1156-108-10-1-consicheck',
    '1156', 'Temperature dependencies in Tables&nbsp;1 and 2 of Ashworth et&nbsp;al. (1988) are inconsistent, with 31&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1156-108-10-1-consicheck'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HTdep_r2_lessthan_0.5'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1156'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methoxyethanol'),
    (SELECT id from literature WHERE bibtexkey='3079'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>1</sup>',
    '7300',
    'T',
    (SELECT id from species WHERE iupac='2-methoxyethanol'),
    (SELECT id from literature WHERE bibtexkey='2381'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methoxyethanol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methoxyethanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methoxyethanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methoxyethanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methoxyethanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methoxyethanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methoxyethanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methoxyethanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methoxyethanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methoxyethanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methoxyethanol'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methoxyethanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-oxobutanoic acid',
    'OHC(CH<sub>2</sub>)<sub>2</sub>COOH',
    '',
    '692-29-5',
    'UIUJIQZEACWQSV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-oxobutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-oxobutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-oxobutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>1</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='4-oxobutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dihydroxybutanedioic acid',
    'HOOCCHOHCHOHCOOH',
    'tartaric acid',
    '87-69-4',
    'FEWJPZIEWOKRBE-JCYAYHJZSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>15</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2,3-dihydroxybutanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>15</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2,3-dihydroxybutanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3-dihydroxybutanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3022'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3022-87-69-4-range',
    '3022', 'Compernolle and Müller (2014a) recommend H<sub>s</sub><sup>cp</sup> for tartaric acid in the range of 6.9&times;10<sup>14</sup>&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>  &lt;  H<sub>s</sub><sup>cp</sup> &lt;  9.2&times;10<sup>15</sup>&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3022-87-69-4-range'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>13</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3-dihydroxybutanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dihydroxybutanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>13</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dihydroxybutanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>15</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='2,3-dihydroxybutanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-oxapentane-1,5-diol',
    'HO(CH<sub>2</sub>)<sub>2</sub>O(CH<sub>2</sub>)<sub>2</sub>OH',
    'diethylene glycol',
    '111-46-6',
    'MTHSVFCYNBDYFN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-oxapentane-1,5-diol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-oxapentane-1,5-diol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-oxapentane-1,5-diol'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-oxapentane-1,5-diol'),
    (SELECT id from literature WHERE bibtexkey='3246'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3246-FEP'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-oxapentane-1,5-diol'),
    (SELECT id from literature WHERE bibtexkey='3246'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3246-TI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-oxapentane-1,5-diol'),
    (SELECT id from literature WHERE bibtexkey='3246'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3246-BAR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-oxapentane-1,5-diol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-oxapentane-1,5-diol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-oxapentane-1,5-diol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-oxapentane-1,5-diol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-oxapentane-1,5-diol'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>7</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='3-oxapentane-1,5-diol'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-oxapentane-1,5-diol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hydroxybutanedioic acid',
    'HOOCCH<sub>2</sub>CHOHCOOH',
    'malic acid',
    '6915-15-7',
    'BJEPYKJPYRNKOW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>8</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hydroxybutanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3022'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>9</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='hydroxybutanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at299K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydroxybutanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydroxybutanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydroxybutanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>11</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='hydroxybutanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-ethoxyethanol',
    'C<sub>4</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '110-80-5',
    'ZNQVEEAIQZEUHB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-ethoxyethanol'),
    (SELECT id from literature WHERE bibtexkey='3079'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>1</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='2-ethoxyethanol'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>1</sup>',
    '8000',
    'T',
    (SELECT id from species WHERE iupac='2-ethoxyethanol'),
    (SELECT id from literature WHERE bibtexkey='2381'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethoxyethanol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethoxyethanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethoxyethanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethoxyethanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethoxyethanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethoxyethanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethoxyethanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethoxyethanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethoxyethanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethoxyethanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethoxyethanol'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-ethoxyethanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-ethoxyethanol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methoxy-1-propanol',
    'C<sub>4</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '1589-47-5',
    'YTTFFPATQICAQN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methoxy-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1-dimethoxyethane',
    'C<sub>4</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '534-15-6',
    'SPEUIVXLLWOEMJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dimethoxyethane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methylene-2-oxetanone',
    'C<sub>4</sub>H<sub>4</sub>O<sub>2</sub>',
    'acetyl ketene',
    '674-82-8',
    'WASQWSOJHCZDFK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylene-2-oxetanone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2(5H)-furanone',
    'C<sub>4</sub>H<sub>4</sub>O<sub>2</sub>',
    '',
    '497-23-4',
    'VIHAEDVKXSOUAT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2(5H)-furanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2(5H)-furanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2(5H)-furanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2(5H)-furanone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2''-bioxirane',
    'C<sub>4</sub>H<sub>6</sub>O<sub>2</sub>',
    '',
    '1464-53-5',
    'ZFIVKAOQEXOYFY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2''-bioxirane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '&#947;-butyrolactone',
    'C<sub>4</sub>H<sub>6</sub>O<sub>2</sub>',
    '',
    '96-48-0',
    'YEJRWHAVMIAJKC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='&#947;-butyrolactone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='&#947;-butyrolactone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#947;-butyrolactone'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#947;-butyrolactone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyloxirane',
    'C<sub>4</sub>H<sub>8</sub>O',
    '1,2-epoxybutane',
    '106-88-7',
    'RBACIKXCRWGCBB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyloxirane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyloxirane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyloxirane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-epoxy-2-methyl-1,4-butanediol',
    'C<sub>5</sub>H<sub>10</sub>O<sub>3</sub>',
    'IEPOX',
    '',
    'FLVAIUDBQNOKHB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-epoxy-2-methyl-1,4-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-epoxy-2-methyl-1,4-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-epoxy-2-methyl-1,4-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-epoxy-2-methyl-1,4-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3583'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3583'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-epoxy-2-methyl-1,4-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3097'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3097-FLVAIUDBQNOKHB-UHFFFAOYSA-N-range',
    '3097', 'Chan et&nbsp;al. (2010) give a range of 1.9&times;10<sup>5</sup>&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>  &lt;  H<sub>s</sub><sup>cp</sup> &lt;  9.5&times;10<sup>6</sup>&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3097-FLVAIUDBQNOKHB-UHFFFAOYSA-N-range'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-epoxy-2-methyl-1,4-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3580'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3580',
    '', 'Calculated using the HENRYWIN program and calibration to 1,3-propanediol.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3580'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>5</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='2,3-epoxy-2-methyl-1,4-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3582'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3582',
    '', 'The value was chosen for a model study because it gave the best agreement with measurements.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3582'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3-epoxy-2-methyl-1,4-butanediol'),
    (SELECT id from literature WHERE bibtexkey='3581'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3581'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MEDICO1CO',
    'C<sub>5</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'RRXXDUUNVWXRFN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>7</sup>',
    '12000',
    'Q',
    (SELECT id from species WHERE iupac='MEDICO1CO'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MEDICO4CO',
    'C<sub>5</sub>H<sub>8</sub>O<sub>4</sub>',
    '',
    '',
    'GXKSWJOBVXKANI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>6</sup>',
    '12000',
    'Q',
    (SELECT id from species WHERE iupac='MEDICO4CO'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'METRICO',
    'C<sub>5</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '',
    'LCGBCDAYKOJPSO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>6</sup>',
    '12000',
    'Q',
    (SELECT id from species WHERE iupac='METRICO'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-epoxy-6-oxo-heptenal',
    'C<sub>7</sub>H<sub>8</sub>O<sub>3</sub>',
    'MCM:TLEPOXMUC',
    '',
    'YHZQHUOBDYTWMQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-epoxy-6-oxo-heptenal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-epoxy-6-oxo-heptenal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-epoxy-6-oxo-heptenal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-epoxy-6-oxo-heptenal'),
    (SELECT id from literature WHERE bibtexkey='3098'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-hydroxy-2-butanone',
    'C<sub>4</sub>H<sub>8</sub>O<sub>2</sub>',
    'acetoin',
    '513-86-0',
    'ROWKJAVDOGWPAT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '',
    'M',
    (SELECT id from species WHERE iupac='3-hydroxy-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='3776'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3776_acetoin',
    '', 'Center of the range (2.3... 4.0)&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3776_acetoin'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3-hydroxy-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='1937'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hydroxy-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hydroxy-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hydroxy-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hydroxy-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-(vinyloxy)ethanol',
    'C<sub>4</sub>H<sub>8</sub>O<sub>2</sub>',
    'ethylene glycol monovinyl ether',
    '764-48-7',
    'VUIWJRYTWUGOOF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(vinyloxy)ethanol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyloxetane',
    'C<sub>4</sub>H<sub>8</sub>O',
    '',
    '2167-39-7',
    'FZIIBDOXPQOKBP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyloxetane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-oxopentanoic acid',
    'OHC(CH<sub>2</sub>)<sub>3</sub>COOH',
    '',
    '5746-02-1',
    'VBKPPDYGFUZOAJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='5-oxopentanoic acid'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-oxopentanedioic acid',
    'HOOC(CH<sub>2</sub>)<sub>2</sub>COCOOH',
    '&#945;-keto glutaric acid',
    '328-50-7',
    'KPGXRSRHYNQIFN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>6</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='2-oxopentanedioic acid'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tetrahydro-2-furanmethanol',
    'C<sub>5</sub>H<sub>10</sub>O<sub>2</sub>',
    'tetrahydrofurfuryl alcohol',
    '97-99-4',
    'BSYVTEYKTMYBMK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='tetrahydro-2-furanmethanol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrahydro-2-furanmethanol'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrahydro-2-furanmethanol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'xylose',
    'C<sub>5</sub>H<sub>10</sub>O<sub>5</sub>',
    '',
    '58-86-6',
    'PYMYPHUHKUWMLA-VPENINKCSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='xylose'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-(2-methoxyethoxy)ethanol',
    'C<sub>5</sub>H<sub>12</sub>O<sub>3</sub>',
    'diethylene glycol monomethyl ether',
    '111-77-3',
    'SBASXUCJHJRPEV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(2-methoxyethoxy)ethanol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,6-dioxaoctane-1,8-diol',
    'HO(CH<sub>2</sub>CH<sub>2</sub>O)<sub>3</sub>H',
    'triethylene glycol',
    '112-27-6',
    'ZIBGPFATKBEMQZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,6-dioxaoctane-1,8-diol'),
    (SELECT id from literature WHERE bibtexkey='3246'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3246-FEP'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,6-dioxaoctane-1,8-diol'),
    (SELECT id from literature WHERE bibtexkey='3246'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3246-TI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,6-dioxaoctane-1,8-diol'),
    (SELECT id from literature WHERE bibtexkey='3246'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3246-BAR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,6-dioxaoctane-1,8-diol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>9</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='3,6-dioxaoctane-1,8-diol'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-oxepanone',
    'C<sub>6</sub>H<sub>10</sub>O<sub>2</sub>',
    'caprolactone',
    '502-44-3',
    'PAPBSGBWRJIAAV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-oxepanone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'glycidyl ether',
    'C<sub>6</sub>H<sub>10</sub>O<sub>3</sub>',
    'diglycidyl ether',
    '2238-07-5',
    'GYZLOYUZLJXAJU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='glycidyl ether'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-hydroxy-4-methyl-2-pentanone',
    'C<sub>6</sub>H<sub>12</sub>O<sub>2</sub>',
    'diacetone alcohol',
    '123-42-2',
    'SWXVUIWOUIDPGS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-hydroxy-4-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-hydroxy-4-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-hydroxy-4-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-hydroxy-4-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-hydroxy-4-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-hydroxy-4-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-hydroxy-4-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-hydroxy-4-methyl-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3088-642',
    '642', 'Calculated based on the method by Hine and Mookerjee (1975).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-642'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-propoxy-2-propanol',
    'C<sub>6</sub>H<sub>14</sub>O<sub>2</sub>',
    '',
    '1569-01-3',
    'FENFUOGYJVOCRY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-propoxy-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-642'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-(2-ethoxyethoxy)ethanol',
    'C<sub>6</sub>H<sub>14</sub>O<sub>3</sub>',
    'diethylene glycol monoethyl ether',
    '111-90-0',
    'XXJWXESWEXIICW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-(2-ethoxyethoxy)ethanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-(2-ethoxyethoxy)ethanol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(2-ethoxyethoxy)ethanol'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(2-ethoxyethoxy)ethanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5,8-trioxanonane',
    'C<sub>6</sub>H<sub>14</sub>O<sub>3</sub>',
    'diglyme',
    '111-96-6',
    'SBZXBUIDTXKZTM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,5,8-trioxanonane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,5,8-trioxanonane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5,8-trioxanonane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'oxydipropanol',
    'C<sub>6</sub>H<sub>14</sub>O<sub>3</sub>',
    'dipropylene glycol',
    '25265-71-8',
    'SZXQTJUDPRGNJN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='oxydipropanol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'p-benzoquinone',
    'C<sub>6</sub>H<sub>4</sub>O<sub>2</sub>',
    '1,4-benzoquinone',
    '106-51-4',
    'AZQWKYJCGOJGHM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='p-benzoquinone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='p-benzoquinone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='p-benzoquinone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='p-benzoquinone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='p-benzoquinone'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='p-benzoquinone'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-hydroxymethylfurfural',
    'C<sub>6</sub>H<sub>6</sub>O<sub>3</sub>',
    '5-hydroxymethyl-2-furfuraldehyde',
    '67-47-0',
    'NOEGNKMFWQHSLB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-hydroxymethylfurfural'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-hydroxy-2-(hydroxymethyl)-4H-pyran-4-one',
    'C<sub>6</sub>H<sub>6</sub>O<sub>4</sub>',
    'kojic acid',
    '501-30-4',
    'BEJNERDRQOWKJM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-hydroxy-2-(hydroxymethyl)-4H-pyran-4-one'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-hydroxy-1,2,3-propanetricarboxylic acid',
    'C<sub>6</sub>H<sub>8</sub>O<sub>7</sub>',
    'citric acid',
    '77-92-9',
    'KRKNYBCHXYNGOX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>15</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2-hydroxy-1,2,3-propanetricarboxylic acid'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>15</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2-hydroxy-1,2,3-propanetricarboxylic acid'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-hydroxy-1,2,3-propanetricarboxylic acid'),
    (SELECT id from literature WHERE bibtexkey='3022'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3022-77-92-9-range',
    '3022', 'Compernolle and Müller (2014a) recommend H<sub>s</sub><sup>cp</sup> for citric acid in the range of 2.0&times;10<sup>14</sup>&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>  &lt;  H<sub>s</sub><sup>cp</sup> &lt;  5.9&times;10<sup>15</sup>&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3022-77-92-9-range'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>12</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-hydroxy-1,2,3-propanetricarboxylic acid'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxy-1,2,3-propanetricarboxylic acid'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>12</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxy-1,2,3-propanetricarboxylic acid'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>16</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='2-hydroxy-1,2,3-propanetricarboxylic acid'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(butoxymethyl)oxirane',
    'C<sub>7</sub>H<sub>14</sub>O<sub>2</sub>',
    'n-butyl glycidyl ether',
    '2426-08-6',
    'YSUQLAYJZDEMOT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(butoxymethyl)oxirane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(butoxymethyl)oxirane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(butoxymethyl)oxirane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-(1,1-dimethylethoxy)-2-propanol',
    'C<sub>7</sub>H<sub>16</sub>O<sub>2</sub>',
    'propylene glycol mono-t-butyl ether',
    '57018-52-7',
    'GQCZPFJGIXHZMB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-(1,1-dimethylethoxy)-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-[2-(2-methoxyethoxy)ethoxy]ethanol',
    'C<sub>7</sub>H<sub>16</sub>O<sub>4</sub>',
    'triethylene glycol monomethyl ether',
    '112-35-6',
    'JLGLQAWTXXGVEM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-[2-(2-methoxyethoxy)ethoxy]ethanol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-p-benzoquinone',
    'C<sub>7</sub>H<sub>6</sub>O<sub>2</sub>',
    '',
    '553-97-9',
    'VTWDKFNVVLAELH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-p-benzoquinone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-p-benzoquinone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-p-benzoquinone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-p-benzoquinone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'patulin',
    'C<sub>7</sub>H<sub>6</sub>O<sub>4</sub>',
    '',
    '149-29-1',
    'ZRWPUFFVAOMMNM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='patulin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-hydroxy-3-methoxybenzene',
    'C<sub>7</sub>H<sub>8</sub>O<sub>2</sub>',
    '3-methoxyphenol',
    '150-19-6',
    'ASHGTJPOSUFTGB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='1-hydroxy-3-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-3-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-3-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-3-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-3-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-3-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-3-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-3-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-3-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-hydroxy-3-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'mequinol',
    'C<sub>7</sub>H<sub>8</sub>O<sub>2</sub>',
    '4-methoxyphenol',
    '150-76-5',
    'NWVVVBRKAWDGAB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='mequinol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='mequinol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='mequinol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    '?',
    (SELECT id from species WHERE iupac='mequinol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-hydroxy-2-methoxybenzene',
    'C<sub>7</sub>H<sub>8</sub>O<sub>2</sub>',
    'guaiacol; 2-methoxyphenol',
    '90-05-1',
    'LHGVFZTZFXWLCP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3723'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0',
    '7900',
    'M',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3215'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3215-90-05-1-ABC',
    '3215', 'The data from Wieland et&nbsp;al. (2015) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;96.39127 +11107.87195/T +10.76466&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3215-90-05-1-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1142'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1',
    '7600',
    'M',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1142'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1142'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1068'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at281K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0',
    '',
    'R',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3521'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3723'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3723'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6700',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-Test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7800',
    '?',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-hydroxy-2-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4-dimethoxybenzene',
    'C<sub>8</sub>H<sub>10</sub>O<sub>2</sub>',
    'hydroquinone dimethyl ether',
    '150-78-7',
    'OHBQPCCCRFSCAX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dimethoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-2-methoxyphenol',
    'C<sub>8</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '93-51-6',
    'PETRWTHZSKVLRE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7',
    '',
    'M',
    (SELECT id from species WHERE iupac='4-methyl-2-methoxyphenol'),
    (SELECT id from literature WHERE bibtexkey='1142'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1',
    '7400',
    'M',
    (SELECT id from species WHERE iupac='4-methyl-2-methoxyphenol'),
    (SELECT id from literature WHERE bibtexkey='1142'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-methyl-2-methoxyphenol'),
    (SELECT id from literature WHERE bibtexkey='1142'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-methoxyphenol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-methoxyphenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-methoxyphenol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-methoxyphenol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-methoxyphenol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-methoxyphenol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-methoxyphenol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7100',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-methoxyphenol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-methoxyphenol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-methoxyphenol'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-methyl-2-methoxyphenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7900',
    '?',
    (SELECT id from species WHERE iupac='4-methyl-2-methoxyphenol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tyrosol',
    'C<sub>8</sub>H<sub>10</sub>O<sub>2</sub>',
    '4-hydroxybenzeneethanol',
    '501-94-0',
    'YCCILVSKPBXVIP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tyrosol'),
    (SELECT id from literature WHERE bibtexkey='3723'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3723'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3-dimethoxy-2-hydroxybenzene',
    'C<sub>8</sub>H<sub>10</sub>O<sub>3</sub>',
    '2,6-dimethoxyphenol',
    '91-10-1',
    'KLIDCXVFHGNTTM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,3-dimethoxy-2-hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1142'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>1</sup>',
    '6700',
    'M',
    (SELECT id from species WHERE iupac='1,3-dimethoxy-2-hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1142'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3-dimethoxy-2-hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1142'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dimethoxy-2-hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dimethoxy-2-hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dimethoxy-2-hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dimethoxy-2-hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dimethoxy-2-hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dimethoxy-2-hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dimethoxy-2-hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7300',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dimethoxy-2-hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,3-dimethoxy-2-hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7600',
    '?',
    (SELECT id from species WHERE iupac='1,3-dimethoxy-2-hydroxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hexahydro-1,3-isobenzofurandione',
    'C<sub>8</sub>H<sub>10</sub>O<sub>3</sub>',
    'hexahydrophthalic anhydride',
    '85-42-7',
    'MUTGBJKUEZFXGO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexahydro-1,3-isobenzofurandione'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'vanillyl alcohol',
    'C<sub>8</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '498-00-0',
    'ZENOXNGFMSCLLL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='vanillyl alcohol'),
    (SELECT id from literature WHERE bibtexkey='3723'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='vanillyl alcohol'),
    (SELECT id from literature WHERE bibtexkey='3723'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3723'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methoxy-4-methylbenzene',
    'C<sub>8</sub>H<sub>10</sub>O',
    '',
    '104-93-8',
    'CHLICZRVGGXEOD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methoxy-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimethoxane',
    'C<sub>8</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '828-00-2',
    'PHMNXPYGVPEQSJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethoxane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'RO5R5',
    'C<sub>8</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '',
    'MESHXYGXEHAFFE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>5</sup>',
    '17000',
    'Q',
    (SELECT id from species WHERE iupac='RO5R5'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-hydroxy-2-octanone',
    'C<sub>8</sub>H<sub>16</sub>O<sub>2</sub>',
    'C82CO5OH',
    '',
    'KZPPEBIAPHLFQD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '11000',
    'Q',
    (SELECT id from species WHERE iupac='5-hydroxy-2-octanone'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'metaldehyde',
    'C<sub>8</sub>H<sub>16</sub>O<sub>4</sub>',
    '',
    '108-62-3',
    'GKKDCARASOJPNG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='metaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='metaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diethyl carbitol',
    'C<sub>8</sub>H<sub>18</sub>O<sub>3</sub>',
    'diethylene glycol diethyl ether',
    '112-36-7',
    'RRQYJINTUHWNHW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diethyl carbitol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diethyl carbitol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl carbitol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-[2-(2-ethoxyethoxy)ethoxy]ethanol',
    'C<sub>8</sub>H<sub>18</sub>O<sub>4</sub>',
    'triethylene glycol monoethyl ether',
    '112-50-5',
    'WFSMVVDJSNMRAR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-[2-(2-ethoxyethoxy)ethoxy]ethanol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tetraethylene glycol',
    'C<sub>8</sub>H<sub>18</sub>O<sub>5</sub>',
    '',
    '112-60-7',
    'UWHCKJMYHZGTIT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>13</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetraethylene glycol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'vanillin',
    'C<sub>8</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '121-33-5',
    'MWOOGOJBHIARFG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '6800',
    'L',
    (SELECT id from species WHERE iupac='vanillin'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='vanillin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='vanillin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='vanillin'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='vanillin'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='vanillin'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='vanillin'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='vanillin'),
    (SELECT id from literature WHERE bibtexkey='3521'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='vanillin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='vanillin'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='vanillin'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='vanillin'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='vanillin'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='vanillin'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethylparaben',
    'C<sub>9</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '120-47-8',
    'NUVBSKCKDOMJSU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethylparaben'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyl vanillin',
    'C<sub>9</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '121-32-4',
    'CBOQJANXLMLOSS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl vanillin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-phenoxypropan-2-ol',
    'C<sub>9</sub>H<sub>12</sub>O<sub>2</sub>',
    'propylene glycol phenyl ether',
    '770-35-4',
    'IBLKWZIFZMJLFL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-phenoxypropan-2-ol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'triacetin',
    'C<sub>9</sub>H<sub>14</sub>O<sub>6</sub>',
    '',
    '102-76-1',
    'URAYPUMNDPQOKB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='triacetin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='triacetin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triacetin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triacetin'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triacetin'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triacetin'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tripropylene glycol',
    'C<sub>9</sub>H<sub>20</sub>O<sub>4</sub>',
    '',
    '24800-44-0',
    'LCZVSXRMYJUNFX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tripropylene glycol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'coumarin',
    'C<sub>9</sub>H<sub>6</sub>O<sub>2</sub>',
    '',
    '91-64-5',
    'ZYGHJZDHTFUPRJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='coumarin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='coumarin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='coumarin'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='coumarin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-ethylguaiacol',
    'C<sub>9</sub>H<sub>12</sub>O<sub>2</sub>',
    '4-ethyl-2-methoxyphenol',
    '2785-89-9',
    'CHWNEIVBYREQRF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethylguaiacol'),
    (SELECT id from literature WHERE bibtexkey='3723'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3723'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methylsyringol',
    'C<sub>9</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '6638-05-7',
    'ZFBNNSOJNZBLLS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylsyringol'),
    (SELECT id from literature WHERE bibtexkey='3723'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3723'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'acetovanillone',
    'C<sub>9</sub>H<sub>10</sub>O<sub>3</sub>',
    'apocynin',
    '498-02-2',
    'DFYRUELUNQRZTB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='acetovanillone'),
    (SELECT id from literature WHERE bibtexkey='3723'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3723'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'syringaldehyde',
    'C<sub>9</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '134-96-3',
    'KCDXJAYRVLXPFO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='syringaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3723'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3723'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-(1-propenyl)-1,3-benzodioxole',
    'C<sub>10</sub>H<sub>10</sub>O<sub>2</sub>',
    'isosafrole',
    '120-58-1',
    'VHVOLFRBFDOUSH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-(1-propenyl)-1,3-benzodioxole'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'safrole',
    'C<sub>10</sub>H<sub>10</sub>O<sub>2</sub>',
    '',
    '94-59-7',
    'ZMQAAUBTXCXRIC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='safrole'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-propyl-1,3-benzodioxole',
    'C<sub>10</sub>H<sub>12</sub>O<sub>2</sub>',
    'dihydrosafrole',
    '94-58-6',
    'MYEIDJPOUKASEC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-propyl-1,3-benzodioxole'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methoxy-4-(1-propenyl)phenol',
    'C<sub>10</sub>H<sub>12</sub>O<sub>2</sub>',
    'isoeugenol',
    '97-54-1',
    'BJIOGJUNALELMI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methoxy-4-(1-propenyl)phenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methoxy-4-(1-propenyl)phenol'),
    (SELECT id from literature WHERE bibtexkey='3723'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3723'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'p-cresyl glycidyl ether',
    'C<sub>10</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '26447-14-3',
    'CUFXMPWHOWYNSO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='p-cresyl glycidyl ether'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-(4-hydroxyphenyl)-2-butanone',
    'C<sub>10</sub>H<sub>12</sub>O<sub>2</sub>',
    'raspberry ketone',
    '5471-51-2',
    'NJGBTKGETPDVIK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-(4-hydroxyphenyl)-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'guaifenesin',
    'C<sub>10</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '93-14-1',
    'HSRJKNPTNIJEKV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='guaifenesin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'RO5R4O2H',
    'C<sub>10</sub>H<sub>18</sub>O<sub>7</sub>',
    '',
    '',
    'YORZXZYHORHTRW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>10</sup>',
    '24000',
    'Q',
    (SELECT id from species WHERE iupac='RO5R4O2H'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'levomenthol',
    'C<sub>10</sub>H<sub>20</sub>O',
    'L-menthol',
    '2216-51-5',
    'NOOLISFMXDJSKH-AEJSXWLSSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='levomenthol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diethylene glycol hexyl ether',
    'C<sub>10</sub>H<sub>22</sub>O<sub>3</sub>',
    '',
    '112-59-4',
    'GZMAAYIALGURDQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diethylene glycol hexyl ether'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diethylene glycol hexyl ether'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethylene glycol hexyl ether'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-[2-(2-butoxyethoxy)ethoxy]ethanol',
    'C<sub>10</sub>H<sub>22</sub>O<sub>4</sub>',
    'triethylene glycol monobutyl ether',
    '143-22-6',
    'COBPKKZHLDDMTB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-[2-(2-butoxyethoxy)ethoxy]ethanol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-propylguaiacol',
    'C<sub>10</sub>H<sub>14</sub>O<sub>2</sub>',
    '2-methoxy-4-propylphenol',
    '2785-87-7',
    'PXIKRTCSSLJURC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3',
    '',
    'M',
    (SELECT id from species WHERE iupac='4-propylguaiacol'),
    (SELECT id from literature WHERE bibtexkey='3723'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-propylguaiacol'),
    (SELECT id from literature WHERE bibtexkey='3723'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3723'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'vanillyl ethyl ether',
    'C<sub>10</sub>H<sub>14</sub>O<sub>3</sub>',
    '4-(ethoxymethyl)-2-methoxyphenol',
    '13184-86-6',
    'KOCVACNWDMSLBM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='vanillyl ethyl ether'),
    (SELECT id from literature WHERE bibtexkey='3723'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='vanillyl ethyl ether'),
    (SELECT id from literature WHERE bibtexkey='3723'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3723'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-ethylsyringol',
    'C<sub>10</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '14059-92-8',
    'PJWDIHUFLXQRFF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethylsyringol'),
    (SELECT id from literature WHERE bibtexkey='3723'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3723'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'guaiacylacetone',
    'C<sub>10</sub>H<sub>12</sub>O<sub>3</sub>',
    '1-(4-hydroxy-3-methoxyphenyl)-2-propanone',
    '2503-46-0',
    'LFVCJQWZGDLHSD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='guaiacylacetone'),
    (SELECT id from literature WHERE bibtexkey='3723'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='guaiacylacetone'),
    (SELECT id from literature WHERE bibtexkey='3723'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3723'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'acetosyringone',
    'C<sub>10</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '2478-38-8',
    'OJOBTAOGJIWAGB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='acetosyringone'),
    (SELECT id from literature WHERE bibtexkey='3723'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3723'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'coniferylaldehyde',
    'C<sub>10</sub>H<sub>10</sub>O<sub>3</sub>',
    '',
    '458-36-6',
    'UCZOBXQKIUMJDZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='coniferylaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3723'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3723'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methoxy-6-(2-propenyl)-1,3-benzodioxole',
    'C<sub>11</sub>H<sub>12</sub>O<sub>3</sub>',
    'myristicin',
    '607-91-0',
    'BNWJOHGLIBDBOB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methoxy-6-(2-propenyl)-1,3-benzodioxole'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'butylparaben',
    'C<sub>11</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '94-26-8',
    'QFOHBWFCKVYLES-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butylparaben'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-<i>tert</i>-butyl-4-methoxyphenol',
    'C<sub>11</sub>H<sub>16</sub>O<sub>2</sub>',
    'butylated hydroxyanisole',
    '25013-16-5',
    'MRBKEAMVRSLQPH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-<i>tert</i>-butyl-4-methoxyphenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-hydroxy-2-naphthalenecarboxylic acid',
    'C<sub>11</sub>H<sub>8</sub>O<sub>3</sub>',
    '',
    '92-70-6',
    'ALKYHXVLJMQRLQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hydroxy-2-naphthalenecarboxylic acid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hydroxy-2-naphthalenecarboxylic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hydroxy-2-naphthalenecarboxylic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hydroxy-2-naphthalenecarboxylic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hydroxy-2-naphthalenecarboxylic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-propylsyringol',
    'C<sub>11</sub>H<sub>16</sub>O<sub>3</sub>',
    '',
    '6766-82-1',
    'YHEWWEXPVKCVFY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-propylsyringol'),
    (SELECT id from literature WHERE bibtexkey='3723'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3723'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'zingerone',
    'C<sub>11</sub>H<sub>14</sub>O<sub>3</sub>',
    'vanillylacetone',
    '122-48-5',
    'OJYLAHXKWMRDGS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='zingerone'),
    (SELECT id from literature WHERE bibtexkey='3723'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='zingerone'),
    (SELECT id from literature WHERE bibtexkey='3723'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3723'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'allylsyringol',
    'C<sub>11</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '5438-54-0',
    'IYIVYBWBUQPWAU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='allylsyringol'),
    (SELECT id from literature WHERE bibtexkey='3723'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3723'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-propenylsyringol',
    'C<sub>11</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '6635-22-9',
    'YFHOHYAUMDHSBX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-propenylsyringol'),
    (SELECT id from literature WHERE bibtexkey='3723'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3723'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propionylsyringol',
    'C<sub>11</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '5650-43-1',
    'CXCPJZXJNRBTGF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propionylsyringol'),
    (SELECT id from literature WHERE bibtexkey='3723'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3723'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'sinapylaldehyde',
    'C<sub>11</sub>H<sub>12</sub>O<sub>4</sub>',
    '',
    '4206-58-0',
    'CDICDSOGTRCHMG-ONEGZZNKSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='sinapylaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3723'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3723'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'arbutin',
    'C<sub>12</sub>H<sub>16</sub>O<sub>7</sub>',
    '',
    '497-76-7',
    'BJRNKVDFDLYUGJ-RMPHRYRLSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>13</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='arbutin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'butopyronoxyl',
    'C<sub>12</sub>H<sub>18</sub>O<sub>4</sub>',
    'indalone',
    '532-34-3',
    'OKIJSNGRQAOIGZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butopyronoxyl'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diethylene glycol bis(methacrylate)',
    'C<sub>12</sub>H<sub>18</sub>O<sub>5</sub>',
    '',
    '2358-84-1',
    'XFCMNSHQOZQILR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethylene glycol bis(methacrylate)'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dikegulac',
    'C<sub>12</sub>H<sub>18</sub>O<sub>7</sub>',
    '',
    '18467-77-1',
    'FWCBATIDXGJRMF-FLNNQWSLSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dikegulac'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propofol',
    'C<sub>12</sub>H<sub>18</sub>O',
    '',
    '2078-54-8',
    'OLBCVFGFOZPWHH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propofol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'lactitol',
    'C<sub>12</sub>H<sub>24</sub>O<sub>11</sub>',
    '',
    '585-86-4',
    'VQHSOMBJVWLPSR-JVCRWLNRSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>16</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='lactitol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'maltitol',
    'C<sub>12</sub>H<sub>24</sub>O<sub>11</sub>',
    '',
    '585-88-6',
    'VQHSOMBJVWLPSR-WUJBLJFYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>15</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='maltitol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'naphthalic anhydride',
    'C<sub>12</sub>H<sub>6</sub>O<sub>3</sub>',
    '',
    '81-84-5',
    'GRSMWKLPSNHDHA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='naphthalic anhydride'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methoxsalen',
    'C<sub>12</sub>H<sub>8</sub>O<sub>4</sub>',
    '8-methoxypsoralen',
    '298-81-7',
    'QXKHYNVANLEOEG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methoxsalen'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'syringylacetone',
    'C<sub>12</sub>H<sub>16</sub>O<sub>4</sub>',
    '',
    '112468-41-4',
    'NULBEPOZYDYWOV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>6</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='syringylacetone'),
    (SELECT id from literature WHERE bibtexkey='3723'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='syringylacetone'),
    (SELECT id from literature WHERE bibtexkey='3723'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3723'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'butyrylsyringol',
    'C<sub>12</sub>H<sub>16</sub>O<sub>4</sub>',
    '',
    '69271-91-6',
    'QFHXMVPZYYMTCS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyrylsyringol'),
    (SELECT id from literature WHERE bibtexkey='3723'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3723'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bisphenol F',
    'C<sub>13</sub>H<sub>12</sub>O<sub>2</sub>',
    '',
    '620-92-8',
    'PXKLMJQFEQBVLD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bisphenol F'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ibuprofen',
    'C<sub>13</sub>H<sub>18</sub>O<sub>2</sub>',
    '',
    '15687-27-1',
    'HEFNNWSXXWATRW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ibuprofen'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ibuprofen'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'trinexapac-ethyl',
    'C<sub>13</sub>H<sub>16</sub>O<sub>5</sub>',
    '',
    '95266-40-3',
    'RVKCCVTVZORVGD-QXMHVHEDSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='trinexapac-ethyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trinexapac-ethyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='trinexapac-ethyl'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benzoyl peroxide',
    'C<sub>14</sub>H<sub>10</sub>O<sub>4</sub>',
    '',
    '94-36-0',
    'OMPJBNCRMGITSC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzoyl peroxide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzoyl peroxide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzoyl peroxide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzoyl peroxide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzoyl peroxide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'oxybenzone',
    'C<sub>14</sub>H<sub>12</sub>O<sub>3</sub>',
    '2-hydroxy-4-methoxybenzophenone',
    '131-57-7',
    'DXGLGDHPHMLXJC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='oxybenzone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'resveratrol',
    'C<sub>14</sub>H<sub>12</sub>O<sub>3</sub>',
    '',
    '501-36-0',
    'LUKBXSAWLPMMSZ-OWOJBTEDSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='resveratrol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pindone',
    'C<sub>14</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '83-26-1',
    'RZKYEQDPDZUERB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pindone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1''-[oxybis(methylene)]bisbenzene',
    'C<sub>14</sub>H<sub>14</sub>O',
    'dibenzyl ether',
    '103-50-4',
    'MHDVGSVTJDSBDK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1''-[oxybis(methylene)]bisbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1''-[oxybis(methylene)]bisbenzene'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1''-[oxybis(methylene)]bisbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1''-[oxybis(methylene)]bisbenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1''-[oxybis(methylene)]bisbenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'butanoic acid, 3,3-bis((1,1-dimethylethyl)dioxy)-, ethyl ester',
    'C<sub>14</sub>H<sub>28</sub>O<sub>6</sub>',
    '',
    '55794-20-2',
    'HARQWLDROVMFJE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanoic acid, 3,3-bis((1,1-dimethylethyl)dioxy)-, ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanoic acid, 3,3-bis((1,1-dimethylethyl)dioxy)-, ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanoic acid, 3,3-bis((1,1-dimethylethyl)dioxy)-, ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanoic acid, 3,3-bis((1,1-dimethylethyl)dioxy)-, ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-hydroxy-9,10-anthracenedione',
    'C<sub>14</sub>H<sub>8</sub>O<sub>3</sub>',
    '1-hydroxyanthraquinone',
    '129-43-1',
    'BTLXPCBPYBNQNR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-9,10-anthracenedione'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-9,10-anthracenedione'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-9,10-anthracenedione'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'danthron',
    'C<sub>14</sub>H<sub>8</sub>O<sub>4</sub>',
    '1,8-dihydroxyanthraquinone',
    '117-10-2',
    'QBPFLULOKWLNNW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='danthron'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bisphenol A',
    'C<sub>15</sub>H<sub>16</sub>O<sub>2</sub>',
    '',
    '80-05-7',
    'IISBACLAFKSPIT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bisphenol A'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'atractylenolide III',
    'C<sub>15</sub>H<sub>20</sub>O<sub>3</sub>',
    '',
    '73030-71-4',
    'FBMORZZOJSDNRQ-GLQYFDAESA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='atractylenolide III'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'deoxynivalenol',
    'C<sub>15</sub>H<sub>20</sub>O<sub>6</sub>',
    '',
    '51481-10-8',
    'LINOMUASTDIRTM-WHNKEALZSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='deoxynivalenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nivalenol',
    'C<sub>15</sub>H<sub>20</sub>O<sub>7</sub>',
    '',
    '23282-20-4',
    'UKOTXHQERFPCBU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nivalenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tributyrin',
    'C<sub>15</sub>H<sub>26</sub>O<sub>6</sub>',
    '',
    '60-01-5',
    'UYXTWWCETRIEDR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tributyrin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diosmetin',
    'C<sub>16</sub>H<sub>12</sub>O<sub>6</sub>',
    '',
    '520-34-3',
    'MBNGWHIJMBWFHU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>12</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diosmetin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'shikonin',
    'C<sub>16</sub>H<sub>16</sub>O<sub>5</sub>',
    '',
    '517-89-5',
    'NEZONWMXZKDMKF-SNVBAGLBSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='shikonin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-bis(4-hydroxyphenyl)butane',
    'C<sub>16</sub>H<sub>18</sub>O<sub>2</sub>',
    'bisphenol B',
    '77-40-7',
    'HTVITOHKHWFJKO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-bis(4-hydroxyphenyl)butane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyl 3,3-bis(<i>tert</i>-amylperoxy)butyrate',
    'C<sub>16</sub>H<sub>32</sub>O<sub>6</sub>',
    '',
    '67567-23-1',
    'NICWAKGKDIAMOD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl 3,3-bis(<i>tert</i>-amylperoxy)butyrate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl 3,3-bis(<i>tert</i>-amylperoxy)butyrate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl 3,3-bis(<i>tert</i>-amylperoxy)butyrate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl 3,3-bis(<i>tert</i>-amylperoxy)butyrate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'aflatoxin B1',
    'C<sub>17</sub>H<sub>12</sub>O<sub>6</sub>',
    '',
    '1162-65-8',
    'OQIQSTLJSLGHID-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='aflatoxin B1'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'aflatoxin G1',
    'C<sub>17</sub>H<sub>12</sub>O<sub>7</sub>',
    '',
    '1165-39-5',
    'XWIYFDMXXLINPU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='aflatoxin G1'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'aflatoxin B2',
    'C<sub>17</sub>H<sub>14</sub>O<sub>6</sub>',
    '',
    '7220-81-7',
    'WWSYXEZEXMQWHT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='aflatoxin B2'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'aflatoxin G2',
    'C<sub>17</sub>H<sub>14</sub>O<sub>7</sub>',
    '',
    '7241-98-7',
    'WPCVRWVBBXIRMA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='aflatoxin G2'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bisphenol C',
    'C<sub>17</sub>H<sub>20</sub>O<sub>2</sub>',
    '',
    '79-97-0',
    'YMTYZTXUZLQUSF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bisphenol C'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'PR-toxin',
    'C<sub>17</sub>H<sub>20</sub>O<sub>6</sub>',
    '',
    '56299-00-4',
    'GSPFUBNBRPVALJ-VIEAGMIOSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='PR-toxin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fusarenon X',
    'C<sub>17</sub>H<sub>22</sub>O<sub>8</sub>',
    '',
    '23255-69-8',
    'XGCUCFKWVIWWNW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fusarenon X'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dihydrotanshinone I',
    'C<sub>18</sub>H<sub>14</sub>O<sub>3</sub>',
    '',
    '87205-99-0',
    'HARGZZNYNSYSGJ-JTQLQIEISA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dihydrotanshinone I'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diethylstilbestrol',
    'C<sub>18</sub>H<sub>20</sub>O<sub>2</sub>',
    '',
    '56-53-1',
    'RGLYKWWBQGJZGM-ISLYRVAYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethylstilbestrol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'laminarin',
    'C<sub>18</sub>H<sub>32</sub>O<sub>16</sub>',
    '',
    '9008-22-4',
    'DBTMGCOVALSLOR-AWHOAIGYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 2.9&times;10<sup>6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='laminarin'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at296K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'estrone',
    'C<sub>18</sub>H<sub>22</sub>O<sub>2</sub>',
    '',
    '53-16-7',
    'DNXHEGUUPJUMQT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='estrone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'estradiol',
    'C<sub>18</sub>H<sub>24</sub>O<sub>2</sub>',
    '',
    '50-28-2',
    'VOXZDWNPVJITMN-AWDGRILASA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='estradiol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'estriol',
    'C<sub>18</sub>H<sub>24</sub>O<sub>3</sub>',
    '',
    '50-27-1',
    'PROQIPRRNZUXQM-PVGHXWSTSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='estriol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nandrolone',
    'C<sub>18</sub>H<sub>26</sub>O<sub>2</sub>',
    '',
    '434-22-0',
    'NPAGDVCDWIYMMC-SVXFNXITSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nandrolone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diofenolan',
    'C<sub>18</sub>H<sub>20</sub>O<sub>4</sub>',
    '',
    '63837-33-2',
    'ZDOOQPFIGYHZFV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diofenolan'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diofenolan'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='diofenolan'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dicumarol',
    'C<sub>19</sub>H<sub>12</sub>O<sub>6</sub>',
    '',
    '66-76-2',
    'DOBMPNYZJYQDGZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dicumarol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'coumatetralyl',
    'C<sub>19</sub>H<sub>16</sub>O<sub>3</sub>',
    '',
    '5836-29-3',
    'ULSLJYXHZDTLQK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>8</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='coumatetralyl'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'warfarin',
    'C<sub>19</sub>H<sub>16</sub>O<sub>4</sub>',
    '',
    '81-81-2',
    'PJVWKTKQMONHTI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='warfarin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='warfarin'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tanshinone II',
    'C<sub>19</sub>H<sub>18</sub>O<sub>3</sub>',
    '',
    '568-72-9',
    'HYXITZLLTYIPOF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tanshinone II'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'gibberellic acid',
    'C<sub>19</sub>H<sub>22</sub>O<sub>6</sub>',
    '',
    '77-06-5',
    'IXORZMNAPKEEDV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='gibberellic acid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='gibberellic acid'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'prallethrin',
    'C<sub>19</sub>H<sub>24</sub>O<sub>3</sub>',
    '',
    '23031-36-9',
    'SMKRKQBMYOFFMU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2',
    '',
    'V',
    (SELECT id from species WHERE iupac='prallethrin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'testolactone',
    'C<sub>19</sub>H<sub>24</sub>O<sub>3</sub>',
    '',
    '968-93-4',
    'BPEWUONYVDABNZ-LHXSAFEUSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='testolactone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'androstenedione',
    'C<sub>19</sub>H<sub>26</sub>O<sub>2</sub>',
    '',
    '63-05-8',
    'AEMFNILZOJDQLW-JRCHKSGSSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='androstenedione'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diacetoxyscirpenol',
    'C<sub>19</sub>H<sub>26</sub>O<sub>7</sub>',
    '',
    '2270-40-8',
    'AUGQEEXBDZWUJY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diacetoxyscirpenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'testosterone',
    'C<sub>19</sub>H<sub>28</sub>O<sub>2</sub>',
    '',
    '58-22-0',
    'MUMGGOZAMZWBJJ-JZJKZLICSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='testosterone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5&#945;-androst-16-en-4-one',
    'C<sub>19</sub>H<sub>28</sub>O',
    'androstenone',
    '18339-16-7',
    'HFVMLYAGWXSTQI-QYXZOKGRSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='5&#945;-androst-16-en-4-one'),
    (SELECT id from literature WHERE bibtexkey='2388'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'oxandrolone',
    'C<sub>19</sub>H<sub>30</sub>O<sub>3</sub>',
    '',
    '53-39-4',
    'QSLJIVKCVHQPLV-WPMSWULFSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='oxandrolone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'piperonyl butoxide',
    'C<sub>19</sub>H<sub>30</sub>O<sub>5</sub>',
    '',
    '51-03-6',
    'FIPWRIJSWJWJAI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='piperonyl butoxide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methoprene',
    'C<sub>19</sub>H<sub>34</sub>O<sub>3</sub>',
    '',
    '40596-69-8',
    'NFGXHKASABOEEW-LDRANXPESA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'V',
    (SELECT id from species WHERE iupac='methoprene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fluorescein',
    'C<sub>20</sub>H<sub>12</sub>O<sub>5</sub>',
    '',
    '2321-07-5',
    'GNBHRKFJIUUOQI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fluorescein'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phenolphthalein',
    'C<sub>20</sub>H<sub>14</sub>O<sub>4</sub>',
    '',
    '77-09-8',
    'KJFMBFZCATUALV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenolphthalein'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'avobenzone',
    'C<sub>20</sub>H<sub>22</sub>O<sub>3</sub>',
    '',
    '70356-09-1',
    'XNEFYCZVKIDDMS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='avobenzone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethinyl estradiol',
    'C<sub>20</sub>H<sub>24</sub>O<sub>2</sub>',
    '',
    '57-63-6',
    'BFPYWIDHMRZLRN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethinyl estradiol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'norethynodrel',
    'C<sub>20</sub>H<sub>26</sub>O<sub>2</sub>',
    '',
    '68-23-5',
    'ICTXHFFSOAJUMG-CEVCPLMDSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='norethynodrel'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'norethindrone',
    'C<sub>20</sub>H<sub>26</sub>O',
    '',
    '68-22-4',
    'VIKNJXKGJWUCNN-BROHZWGRSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='norethindrone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methandrostenolone',
    'C<sub>20</sub>H<sub>28</sub>O<sub>2</sub>',
    '',
    '72-63-9',
    'XWALNWXLMVGSFR-NSDIEPNESA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methandrostenolone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cinerin I',
    'C<sub>20</sub>H<sub>28</sub>O<sub>3</sub>',
    '',
    '25402-06-6',
    'FMTFEIJHMMQUJI-FPLPWBNLSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cinerin I'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '17-methyltestosterone',
    'C<sub>20</sub>H<sub>30</sub>O<sub>2</sub>',
    '',
    '58-18-4',
    'GCKMFJBGXUYNAG-NSDIEPNESA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='17-methyltestosterone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'drostanolone',
    'C<sub>20</sub>H<sub>32</sub>O<sub>2</sub>',
    'dromostanolone',
    '58-19-5',
    'IKXILDNPCZPPRV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='drostanolone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'curcumin',
    'C<sub>21</sub>H<sub>20</sub>O<sub>6</sub>',
    '',
    '458-37-7',
    'VFLDPWHFBUODDF-FCXRPNKRSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>16</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='curcumin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bisphenol A diglycidyl ether',
    'C<sub>21</sub>H<sub>24</sub>O<sub>4</sub>',
    '',
    '1675-54-3',
    'LCFVJGUPQDGYKZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bisphenol A diglycidyl ether'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'mestranol',
    'C<sub>21</sub>H<sub>26</sub>O<sub>2</sub>',
    '',
    '72-33-3',
    'IMSSROKUHAOUJS-ALAWOQLPSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='mestranol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'prednisone',
    'C<sub>21</sub>H<sub>26</sub>O<sub>5</sub>',
    '',
    '53-03-2',
    'XOFYZVNMUHMLCC-NUBBXXJJSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='prednisone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'norgestrel',
    'C<sub>21</sub>H<sub>28</sub>O<sub>2</sub>',
    '',
    '6533-00-2',
    'WWYNJERNGUHSAO-ZUHHCLADSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='norgestrel'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'levonorgestrel',
    'C<sub>21</sub>H<sub>28</sub>O<sub>2</sub>',
    '',
    '797-63-7',
    'WWYNJERNGUHSAO-XUDSTZEESA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='levonorgestrel'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pyrethrin I',
    'C<sub>21</sub>H<sub>28</sub>O<sub>3</sub>',
    '',
    '121-21-1',
    'ROVGZAWFACYCSP-CMDGGOBGSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pyrethrin I'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pyrethrin I'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pyrethrin I'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cinerin II',
    'C<sub>21</sub>H<sub>28</sub>O<sub>5</sub>',
    '',
    '121-20-0',
    'SHCRDCOTRILILT-WOBDGSLYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cinerin II'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'prednisolone',
    'C<sub>21</sub>H<sub>28</sub>O<sub>5</sub>',
    '',
    '50-24-8',
    'OIGNJSKKLXVSLS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='prednisolone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dronabinol',
    'C<sub>21</sub>H<sub>30</sub>O<sub>2</sub>',
    'delta 9-tetrahydrocannabinol',
    '1972-08-3',
    'CYQFCXCEBYINGO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dronabinol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'progesterone',
    'C<sub>21</sub>H<sub>30</sub>O<sub>2</sub>',
    '',
    '57-83-0',
    'RJKFOVLPORLFTN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='progesterone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hydrocortisone',
    'C<sub>21</sub>H<sub>30</sub>O<sub>5</sub>',
    '',
    '50-23-7',
    'JYGXADMDTFJGBT-NDNUHCHRSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydrocortisone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'calusterone',
    'C<sub>21</sub>H<sub>32</sub>O<sub>2</sub>',
    '',
    '17021-26-0',
    'IVFYLRMMHVYGJH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='calusterone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'oxymetholone',
    'C<sub>21</sub>H<sub>32</sub>O<sub>3</sub>',
    '',
    '434-07-1',
    'ICMWWNHDUZJFDW-RCXBLOTCSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='oxymetholone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'resmethrin',
    'C<sub>22</sub>H<sub>26</sub>O<sub>3</sub>',
    '',
    '10453-86-8',
    'VEMKTZHHVJILDY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='resmethrin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='resmethrin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='resmethrin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pyrethrin II',
    'C<sub>22</sub>H<sub>28</sub>O<sub>5</sub>',
    '',
    '121-29-9',
    'VJFUPGQZSXIULQ-VKTMSVCMSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pyrethrin II'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pyrethrin II'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pyrethrin II'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methylprednisolone',
    'C<sub>22</sub>H<sub>30</sub>O<sub>5</sub>',
    '',
    '83-43-2',
    'VHRSUDSXCMQTMA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylprednisolone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'medroxyprogesterone',
    'C<sub>22</sub>H<sub>32</sub>O<sub>3</sub>',
    '',
    '520-85-4',
    'FRQMUZJSZHZSGN-HBNHAYAOSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='medroxyprogesterone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimethirimol',
    'C<sub>23</sub>H<sub>24</sub>O<sub>5</sub>',
    '',
    '5221-53-4',
    'VNKCZJKGJAEOCW-WXUKJITCSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 2.3&times;10<sup>10</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dimethirimol'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'rotenone',
    'C<sub>23</sub>H<sub>22</sub>O<sub>6</sub>',
    '',
    '83-79-4',
    'JUVIOZPCNVVQFO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='rotenone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phenothrin',
    'C<sub>23</sub>H<sub>26</sub>O<sub>3</sub>',
    '',
    '26002-80-2',
    'SBNFWQZLDJGRLK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'X',
    (SELECT id from species WHERE iupac='phenothrin'),
    (SELECT id from literature WHERE bibtexkey='macbean2012'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'spiromesifen',
    'C<sub>23</sub>H<sub>30</sub>O<sub>4</sub>',
    '',
    '283594-90-1',
    'GOLXNESZZPUPJE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='spiromesifen'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'digoxigenin',
    'C<sub>23</sub>H<sub>34</sub>O<sub>5</sub>',
    '',
    '1672-46-4',
    'SHIBSTMRCDJXLN-KCZCNTNESA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='digoxigenin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'annatto',
    'C<sub>24</sub>H<sub>28</sub>O<sub>4</sub>',
    '',
    '1393-63-1',
    'ZVKOASAVGLETCT-LRRSNBNMSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='annatto'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'acequinocyl',
    'C<sub>24</sub>H<sub>32</sub>O<sub>4</sub>',
    '',
    '57960-19-7',
    'QDRXWCAVUNHOGA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='acequinocyl'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='acequinocyl'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'T-2 mycotoxin',
    'C<sub>24</sub>H<sub>34</sub>O<sub>9</sub>',
    '',
    '21259-20-1',
    'SSHHYBPAMCLKRH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>12</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='T-2 mycotoxin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'milk thistle extract',
    'C<sub>25</sub>H<sub>22</sub>O<sub>10</sub>',
    '',
    '84604-20-6',
    'SEBFKMXJBCUCAI-VGHNRKBZSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>17</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='milk thistle extract'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'simvastatin',
    'C<sub>25</sub>H<sub>38</sub>O<sub>5</sub>',
    '',
    '79902-63-9',
    'RYMZZMVNJRMUDD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='simvastatin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'calcitriol',
    'C<sub>27</sub>H<sub>44</sub>O<sub>3</sub>',
    '1,25-dihydroxycholecalciferol',
    '32222-06-3',
    'GMRQFYUYWCNGIN-NKMMMXOESA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='calcitriol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'paricalcitol',
    'C<sub>27</sub>H<sub>44</sub>O<sub>3</sub>',
    '',
    '131918-61-1',
    'BPKAHTKRCLCHEA-UBFJEZKGSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='paricalcitol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cholecalciferol',
    'C<sub>27</sub>H<sub>44</sub>O',
    '',
    '67-97-0',
    'QYSXJUFSXHHAJI-SMGPGMQOSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cholecalciferol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cholesterol',
    'C<sub>27</sub>H<sub>46</sub>O',
    '',
    '57-88-5',
    'HVYWMOMLDIMFJA-VUDDDUNTSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cholesterol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ergosterol',
    'C<sub>28</sub>H<sub>44</sub>O',
    '',
    '57-87-4',
    'DNVPQKQSNYMLRS-CVGROQQCSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ergosterol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dihydrotachysterol',
    'C<sub>28</sub>H<sub>46</sub>O',
    '',
    '67-96-9',
    'DTSXXSAWQHPLEF-GFVAUXBKSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dihydrotachysterol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'etoposide',
    'C<sub>29</sub>H<sub>32</sub>O<sub>13</sub>',
    '',
    '33419-42-0',
    'VJJPUSNTGOMMGY-KWGSHVRASA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>24</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='etoposide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'stigmasterol',
    'C<sub>29</sub>H<sub>48</sub>O',
    '',
    '83-48-7',
    'HCXVJBMSMIARIN-BASBAMEESA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='stigmasterol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pseudohypericin',
    'C<sub>30</sub>H<sub>16</sub>O<sub>9</sub>',
    '',
    '55954-61-5',
    'YXBUQQDFTYOHQI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>23</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pseudohypericin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'gossypol',
    'C<sub>30</sub>H<sub>30</sub>O<sub>8</sub>',
    '',
    '303-45-7',
    'QBKSWRVVCFFDOT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>22</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='gossypol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'maslinic acid',
    'C<sub>30</sub>H<sub>48</sub>O<sub>4</sub>',
    '',
    '4373-41-5',
    'MDZKJHQSJHYOHJ-LLICELPBSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='maslinic acid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'milbemectin',
    'C<sub>31</sub>H<sub>44</sub>O<sub>7</sub>',
    '',
    '51596-10-2',
    'ZLBGSRMUSVULIE-GSMJGMFJSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='milbemectin'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='milbemectin'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'difenacoum',
    'C<sub>31</sub>H<sub>24</sub>O<sub>3</sub>',
    '',
    '56073-07-5',
    'FVQITOLOYMWVFU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='difenacoum'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nonoxynol 9',
    'C<sub>33</sub>H<sub>60</sub>O<sub>10</sub>',
    '',
    '26571-11-9',
    'FBWNMEQMRUMQSO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>16</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonoxynol 9'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'azadirachtin',
    'C<sub>35</sub>H<sub>44</sub>O<sub>16</sub>',
    '',
    '11141-17-6',
    'FTNJWQUOZFUQQJ-GWTPYEAISA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>19</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='azadirachtin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'monensin',
    'C<sub>36</sub>H<sub>62</sub>O<sub>11</sub>',
    '',
    '17090-79-8',
    'GAOZTHIDHYLHMS-LXKLZWMJSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>18</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='monensin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'gossyplure',
    'C<sub>36</sub>H<sub>64</sub>O<sub>4</sub>',
    '',
    '50933-33-0',
    'BXJHOKLLMOYSRQ-QOXWLJPHSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='gossyplure'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'capsanthin',
    'C<sub>40</sub>H<sub>56</sub>O<sub>3</sub>',
    '',
    '465-42-9',
    'VYIRVAXUEZSDNC-RDJLEWNRSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='capsanthin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'heptamaloxyloglucan',
    'C<sub>40</sub>H<sub>70</sub>O<sub>33</sub>',
    '',
    '870721-81-6',
    'RAUODYOTTYNEJP-RQESCVSBSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>13</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='heptamaloxyloglucan'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'digitoxin',
    'C<sub>41</sub>H<sub>64</sub>O<sub>13</sub>',
    '',
    '71-63-6',
    'WDJUZGPOPHTGOT-UCKSZOHFSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>19</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='digitoxin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'digoxin',
    'C<sub>41</sub>H<sub>64</sub>O<sub>14</sub>',
    '',
    '20830-75-5',
    'LTMHDMANZUZIPE-PUGKRICDSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>21</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='digoxin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pyrethrum',
    'C<sub>43</sub>H<sub>56</sub>O<sub>8</sub>',
    '',
    '8003-34-7',
    'VXSIXFKKSNGRRO-YWUDCVDHSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pyrethrum'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pyrethrum'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pyrethrum'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'punicalagin',
    'C<sub>48</sub>H<sub>28</sub>O<sub>30</sub>',
    '',
    '65995-63-3',
    'SKNLUADAGHCXKF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='punicalagin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'abamectin',
    'C<sub>48</sub>H<sub>72</sub>O<sub>14</sub>',
    '',
    '71751-41-2',
    'RRZXIRBKKLTSOM-IGNCFFBFSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='abamectin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 3.7&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='abamectin'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'notoginsenoside R1',
    'C<sub>48</sub>H<sub>84</sub>O<sub>18</sub>',
    '',
    '80418-24-2',
    'ZBXDHDDTAIOMHK-UWGJVBKGSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>25</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='notoginsenoside R1'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'triolein',
    'C<sub>57</sub>H<sub>104</sub>O<sub>6</sub>',
    '',
    '122-32-7',
    'PHYFQTYBJUILEZ-IUPFWZBJSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triolein'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tristearin',
    'C<sub>57</sub>H<sub>110</sub>O<sub>6</sub>',
    '',
    '555-43-1',
    'DCXXMTOCNZCJGO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Miscellaneous'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tristearin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO categories (catname) VALUES (
    'Organic species with nitrogen (N)');
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Amines (C, H, N)',
    (SELECT id from categories WHERE catname='Organic species with nitrogen (N)'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cyanamide',
    'CH<sub>2</sub>N<sub>2</sub>',
    '',
    '420-04-2',
    'XZMCDFZZKTWFGF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cyanamide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methylhydrazine',
    'CH<sub>6</sub>N<sub>2</sub>',
    '',
    '60-34-4',
    'HDZGCSFEDULWCS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3',
    '',
    'V',
    (SELECT id from species WHERE iupac='methylhydrazine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methanamine',
    'CH<sub>3</sub>NH<sub>2</sub>',
    'methylamine',
    '74-89-5',
    'BAVYZALUXZFZLV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='methanamine'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='methanamine'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '2600',
    'L',
    (SELECT id from species WHERE iupac='methanamine'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methanamine'),
    (SELECT id from literature WHERE bibtexkey='721'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'X',
    (SELECT id from species WHERE iupac='methanamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanamine'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanamine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5000',
    'Q',
    (SELECT id from species WHERE iupac='methanamine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanamine'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanamine'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanamine'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanamine'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methanamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methanamine'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3200',
    '?',
    (SELECT id from species WHERE iupac='methanamine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methanamine'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5400',
    '?',
    (SELECT id from species WHERE iupac='methanamine'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    '?',
    (SELECT id from species WHERE iupac='methanamine'),
    (SELECT id from literature WHERE bibtexkey='641'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='641amine'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethanamine',
    'C<sub>2</sub>H<sub>5</sub>NH<sub>2</sub>',
    'ethylamine',
    '75-04-7',
    'QUSNBJAOOMFDIB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='ethanamine'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='ethanamine'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='ethanamine'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '3600',
    'L',
    (SELECT id from species WHERE iupac='ethanamine'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethanamine'),
    (SELECT id from literature WHERE bibtexkey='721'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethanamine'),
    (SELECT id from literature WHERE bibtexkey='713'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethanamine'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanamine'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanamine'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanamine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanamine'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanamine'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanamine'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanamine'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanamine'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanamine'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethanamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethanamine'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethanamine'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethanamine'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6500',
    '?',
    (SELECT id from species WHERE iupac='ethanamine'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1H-1,2,4-triazole',
    'C<sub>2</sub>H<sub>3</sub>N<sub>3</sub>',
    '',
    '288-88-0',
    'NSPMIYGKQJPBQR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1H-1,2,4-triazole'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dicyandiamide',
    'C<sub>2</sub>H<sub>4</sub>N<sub>4</sub>',
    'cyanoguanidine',
    '461-58-5',
    'QGBSISYHAICWAH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dicyandiamide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethylenimine',
    'C<sub>2</sub>H<sub>5</sub>N',
    '',
    '151-56-4',
    'NOWKCMXCCJGMRR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethylenimine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethylenimine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethylenimine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-dimethylhydrazine',
    'C<sub>2</sub>H<sub>8</sub>N<sub>2</sub>',
    '',
    '540-73-8',
    'DIIIISSCIXVANO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dimethylhydrazine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1-dimethylhydrazine',
    'C<sub>2</sub>H<sub>8</sub>N<sub>2</sub>',
    '',
    '57-14-7',
    'RHUYHJGZWVXEHW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1-dimethylhydrazine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-propanamine',
    'C<sub>3</sub>H<sub>7</sub>NH<sub>2</sub>',
    'propylamine',
    '107-10-8',
    'WGYKZJWCGVVSQN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-propanamine'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-propanamine'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-propanamine'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '6400',
    'M',
    (SELECT id from species WHERE iupac='1-propanamine'),
    (SELECT id from literature WHERE bibtexkey='3685'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-propanamine'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-propanamine'),
    (SELECT id from literature WHERE bibtexkey='721'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-propanamine'),
    (SELECT id from literature WHERE bibtexkey='713'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;1</sup>',
    '6700',
    'T',
    (SELECT id from species WHERE iupac='1-propanamine'),
    (SELECT id from literature WHERE bibtexkey='3674'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-propanamine'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-propanamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-propanamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-propanamine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-propanamine'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-propanamine'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-propanamine'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-propanamine'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-propanamine'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-propanamine'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-propanamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-propanamine'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-propanamine'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-propanamine'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6700',
    '?',
    (SELECT id from species WHERE iupac='1-propanamine'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-propanamine',
    'C<sub>3</sub>H<sub>9</sub>N',
    'isopropylamine',
    '75-31-0',
    'JJWLVOIRVHMVIS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-propanamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='2-propanamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propanamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propanamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propanamine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propanamine'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propanamine'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propanamine'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-propanamine'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propanedinitrile',
    'C<sub>3</sub>H<sub>2</sub>N<sub>2</sub>',
    'malononitrile',
    '109-77-3',
    'CUONGYYJJVDODC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propanedinitrile'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanedinitrile'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanedinitrile'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanedinitrile'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propanedinitrile'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methylaziridine',
    'C<sub>3</sub>H<sub>7</sub>N',
    '',
    '75-55-8',
    'OZDGMOYKSFPLSE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylaziridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylaziridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylaziridine'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylaziridine'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-diaminopropane',
    'C<sub>3</sub>H<sub>10</sub>N<sub>2</sub>',
    '',
    '78-90-0',
    'AOHJOMMDDJHIJH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '7400',
    'M',
    (SELECT id from species WHERE iupac='1,2-diaminopropane'),
    (SELECT id from literature WHERE bibtexkey='3584'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-butanamine',
    'C<sub>4</sub>H<sub>9</sub>NH<sub>2</sub>',
    'butylamine',
    '109-73-9',
    'HQABUPZFAYXKJW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-butanamine'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-butanamine'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-butanamine'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-butanamine'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-butanamine'),
    (SELECT id from literature WHERE bibtexkey='2218'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-butanamine'),
    (SELECT id from literature WHERE bibtexkey='721'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-butanamine'),
    (SELECT id from literature WHERE bibtexkey='713'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-butanamine'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-butanamine'),
    (SELECT id from literature WHERE bibtexkey='2388'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-butanamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-butanamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butanamine'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butanamine'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butanamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butanamine'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butanamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butanamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butanamine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butanamine'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butanamine'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butanamine'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butanamine'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butanamine'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butanamine'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butanamine'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-butanamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-butanamine'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-butanamine'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-butanamine'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7100',
    '?',
    (SELECT id from species WHERE iupac='1-butanamine'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-butanamine',
    'C<sub>4</sub>H<sub>11</sub>N',
    '<i>sec</i>-butylamine',
    '13952-84-6',
    'BHRZNVHARXXAHW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '7700',
    'M',
    (SELECT id from species WHERE iupac='2-butanamine'),
    (SELECT id from literature WHERE bibtexkey='3007'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3007',
    '3007', 'In their Fig.&nbsp;5b, Kish et&nbsp;al. (2013) apply an unspecified factor to the Henry''s law constant, and it is not clear if the temperature dependence shown there is correct (Yong Liu, personal communication, 2014).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3007'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-butanamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='2-butanamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butanamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butanamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butanamine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butanamine'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-1-propanamine',
    'C<sub>4</sub>H<sub>11</sub>N',
    'isobutylamine',
    '78-81-9',
    'KDSNLYIMUZNERS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-1-propanamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='2-methyl-1-propanamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-propanamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-propanamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-propanamine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-propanamine'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-propanamine'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-propanamine'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methyl-1-propanamine'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-2-propanamine',
    'C<sub>4</sub>H<sub>11</sub>N',
    '<i>tert</i>-butylamine',
    '75-64-9',
    'YBRBMKDOPFTVDT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-2-propanamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='2-methyl-2-propanamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propanamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propanamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propanamine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propanamine'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propanamine'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimethylethylamine',
    'C<sub>4</sub>H<sub>11</sub>N',
    '',
    '598-56-1',
    'DAZXVJBJRMWXJP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dimethylethylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylethylamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylethylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-propylguanidine',
    'C<sub>4</sub>H<sub>11</sub>N<sub>3</sub>',
    '',
    '462-25-9',
    'BWMDMTSNSXYYSP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-propylguanidine'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-diethylhydrazine',
    'C<sub>4</sub>H<sub>12</sub>N<sub>2</sub>',
    '',
    '1615-80-1',
    'YCBOYOYVDOUXLH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-diethylhydrazine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-(2-aminoethyl)-1,2-ethanediamine',
    'C<sub>4</sub>H<sub>13</sub>N<sub>3</sub>',
    'diethylenetriamine',
    '111-40-0',
    'RPNUMPOLZDHAAY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-(2-aminoethyl)-1,2-ethanediamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'butanedinitrile',
    'C<sub>4</sub>H<sub>4</sub>N<sub>2</sub>',
    '',
    '110-61-2',
    'IAHFWCOBPZCAEA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>2</sup>',
    '7000',
    'L',
    (SELECT id from species WHERE iupac='butanedinitrile'),
    (SELECT id from literature WHERE bibtexkey='3621'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butanedinitrile'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butanedinitrile'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='butanedinitrile'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanedinitrile'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanedinitrile'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-1H-imidazole',
    'C<sub>4</sub>H<sub>6</sub>N<sub>2</sub>',
    '',
    '693-98-1',
    'LXBGSDVWAMZHDD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methyl-1H-imidazole'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at313K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1H-imidazole'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3426',
    '3584', 'Calculated using the method from Nguyen (2013).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3426'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1H-imidazole'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1H-imidazole'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-1H-imidazole',
    'C<sub>4</sub>H<sub>6</sub>N<sub>2</sub>',
    '',
    '822-36-6',
    'XLSZMDLNRCVEIJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1H-imidazole'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-methyl-1,3-propanediamine',
    'C<sub>4</sub>H<sub>12</sub>N<sub>2</sub>',
    '3-(methylamino)propylamine',
    '6291-84-5',
    'QHJABUZHRJTCAR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '7600',
    'M',
    (SELECT id from species WHERE iupac='N-methyl-1,3-propanediamine'),
    (SELECT id from literature WHERE bibtexkey='3584'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '8800',
    'M',
    (SELECT id from species WHERE iupac='N-methyl-1,3-propanediamine'),
    (SELECT id from literature WHERE bibtexkey='3654'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3654',
    '3654', 'Calculated from the slope of y<sub>1</sub>P vs x<sub>1</sub>, using the tabulated VLE data from Kim et&nbsp;al. (2008) between 40&nbsp;<sup>&#176;</sup>C and 100&nbsp;<sup>&#176;</sup>C. Only dilute solutions with x<sub>1</sub> &#8804; 0.1 were considered.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3654'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-pentanamine',
    'C<sub>5</sub>H<sub>11</sub>NH<sub>2</sub>',
    '1-pentylamine',
    '110-58-7',
    'DPBLXKKOBLCELK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-pentanamine'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-pentanamine'),
    (SELECT id from literature WHERE bibtexkey='2218'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-pentanamine'),
    (SELECT id from literature WHERE bibtexkey='2388'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-pentanamine'),
    (SELECT id from literature WHERE bibtexkey='721'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentanamine'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentanamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentanamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentanamine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentanamine'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentanamine'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentanamine'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentanamine'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentanamine'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-P'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentanamine'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-pentanamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-pentanamine'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7500',
    '?',
    (SELECT id from species WHERE iupac='1-pentanamine'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-1-butanamine',
    'C<sub>5</sub>H<sub>13</sub>N',
    '',
    '107-85-7',
    'BMFVGAAISNGQNM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-1-butanamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-butanamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-butanamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-dimethylpropylamine',
    'C<sub>5</sub>H<sub>13</sub>N',
    '',
    '598-74-3',
    'JOZZAIIGWFLONA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,2-dimethylpropylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethylpropylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimethylpropylamine',
    'C<sub>5</sub>H<sub>13</sub>N',
    '',
    '926-63-6',
    'ZUHZZVMEUAUWHY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dimethylpropylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylpropylamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylpropylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimethylisopropylamine',
    'C<sub>5</sub>H<sub>13</sub>N',
    '',
    '996-35-0',
    'VMOWKUTXPNPTEN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dimethylisopropylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylisopropylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethylpropylamine',
    'C<sub>5</sub>H<sub>13</sub>N',
    '',
    '20193-20-8',
    'XCVNDBIXFPGMIW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethylpropylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethylpropylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethylisopropylamine',
    'C<sub>5</sub>H<sub>13</sub>N',
    '',
    '19961-27-4',
    'RIVIDPPYRINTTH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethylisopropylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethylisopropylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyldiethylamine',
    'C<sub>5</sub>H<sub>13</sub>N',
    '',
    '616-39-7',
    'GNVRJGIVDSQCOP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methyldiethylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyldiethylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methylpiperazine',
    'C<sub>5</sub>H<sub>12</sub>N<sub>2</sub>',
    '',
    '109-07-9',
    'JOMNTHCQHJPVAZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>3</sup>',
    '9200',
    'M',
    (SELECT id from species WHERE iupac='2-methylpiperazine'),
    (SELECT id from literature WHERE bibtexkey='3584'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-hexanamine',
    'C<sub>6</sub>H<sub>13</sub>NH<sub>2</sub>',
    'hexylamine',
    '111-26-2',
    'BMVXCPBXGZKUPN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-hexanamine'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-hexanamine'),
    (SELECT id from literature WHERE bibtexkey='2218'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-hexanamine'),
    (SELECT id from literature WHERE bibtexkey='721'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-hexanamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexanamine'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexanamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexanamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexanamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexanamine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexanamine'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexanamine'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexanamine'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-Test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexanamine'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexanamine'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexanamine'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexanamine'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-hexanamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-hexanamine'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-hexanamine'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7900',
    '?',
    (SELECT id from species WHERE iupac='1-hexanamine'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-hexanamine',
    'C<sub>6</sub>H<sub>15</sub>N',
    '',
    '5329-79-3',
    'WGBBUURBHXLGFM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-hexanamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hexanamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-hexanamine',
    'C<sub>6</sub>H<sub>15</sub>N',
    '',
    '16751-58-9',
    'HQLZFBUAULNEGP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-hexanamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hexanamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-amino-2-methylpentane',
    'C<sub>6</sub>H<sub>15</sub>N',
    '',
    '13364-16-4',
    'WNDXRJBYZOSNQO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-amino-2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-amino-2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-amino-3-methylpentane',
    'C<sub>6</sub>H<sub>15</sub>N',
    '',
    '42245-37-4',
    'JLAUIBFZZUVOBB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-amino-3-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-amino-3-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-amino-4-methylpentane',
    'C<sub>6</sub>H<sub>15</sub>N',
    '',
    '5344-20-7',
    'QVIAMKXOQGCYCV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-amino-4-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-amino-4-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-amino-3-methylpentane',
    'C<sub>6</sub>H<sub>15</sub>N',
    '',
    '35399-81-6',
    'ZFAGOADKDXXTSV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-amino-3-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-amino-3-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-amino-4-methylpentane',
    'C<sub>6</sub>H<sub>15</sub>N',
    '',
    '108-09-8',
    'UNBMPKNTYKDYCG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-amino-4-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-amino-4-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-amino-4-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-amino-4-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-amino-4-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-amino-2-methylpentane',
    'C<sub>6</sub>H<sub>15</sub>N',
    '',
    '54287-41-1',
    'JYNQKCFJPQEXSL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-amino-2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-amino-2-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-amino-2-ethylbutane',
    'C<sub>6</sub>H<sub>15</sub>N',
    '',
    '617-79-8',
    'MGWAGIQQTULHGU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-amino-2-ethylbutane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-amino-2-ethylbutane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-amino-2,2-dimethylbutane',
    'C<sub>6</sub>H<sub>15</sub>N',
    '',
    '41781-17-3',
    'PZVPOYBHOPRJNP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-amino-2,2-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-amino-2,2-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-amino-2,3-dimethylbutane',
    'C<sub>6</sub>H<sub>15</sub>N',
    '',
    '66553-05-7',
    'GBMSZXWHMSSBGP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-amino-2,3-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-amino-2,3-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-amino-3,3-dimethylbutane',
    'C<sub>6</sub>H<sub>15</sub>N',
    '',
    '15673-00-4',
    'GPWHFPWZAPOYNO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-amino-3,3-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-amino-3,3-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-amino-3,3-dimethylbutane',
    'C<sub>6</sub>H<sub>15</sub>N',
    '',
    '3850-30-4',
    'DXSUORGKJZADET-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-amino-3,3-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-amino-3,3-dimethylbutane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimethylbutylamine',
    'C<sub>6</sub>H<sub>15</sub>N',
    '',
    '927-62-8',
    'DJEQZVQFEPKLOY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dimethylbutylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylbutylamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylbutylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimethyl-<i>sec</i>-butylamine',
    'C<sub>6</sub>H<sub>15</sub>N',
    '',
    '921-04-0',
    'USSPHSVODLAWSA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dimethyl-<i>sec</i>-butylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl-<i>sec</i>-butylamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl-<i>sec</i>-butylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimethyl-<i>tert</i>-butylamine',
    'C<sub>6</sub>H<sub>15</sub>N',
    '',
    '918-02-5',
    'OXQMIXBVXHWDPX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dimethyl-<i>tert</i>-butylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl-<i>tert</i>-butylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethylbutylamine',
    'C<sub>6</sub>H<sub>15</sub>N',
    '',
    '13360-63-9',
    'QHCCDDQKNUYGNC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethylbutylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethylbutylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethylisobutylamine',
    'C<sub>6</sub>H<sub>15</sub>N',
    '',
    '13205-60-2',
    'FNLUJDLKYOWMMF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethylisobutylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethylisobutylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyl-<i>sec</i>-butylamine',
    'C<sub>6</sub>H<sub>15</sub>N',
    '',
    '21035-44-9',
    'KFYKZKISJBGVMR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethyl-<i>sec</i>-butylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl-<i>sec</i>-butylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl-1,1-dimethylpropylamine',
    'C<sub>6</sub>H<sub>15</sub>N',
    '',
    '2978-64-5',
    'BUJFTKPQXSIZFX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methyl-1,1-dimethylpropylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl-1,1-dimethylpropylamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl-1,1-dimethylpropylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl-1,2-dimethylpropylamine',
    'C<sub>6</sub>H<sub>15</sub>N',
    '',
    '34317-39-0',
    'LJLWVVCWBURGCC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methyl-1,2-dimethylpropylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl-1,2-dimethylpropylamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl-1,2-dimethylpropylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl-2,2-dimethylpropylamine',
    'C<sub>6</sub>H<sub>15</sub>N',
    '',
    '26153-91-3',
    'UQGXHNDRCRTZAC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methyl-2,2-dimethylpropylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl-2,2-dimethylpropylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl-1-methylbutylamine',
    'C<sub>6</sub>H<sub>15</sub>N',
    '',
    '51932-19-5',
    'IPBXLJFBVNLKFE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methyl-1-methylbutylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl-1-methylbutylamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl-1-methylbutylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methylethylpropylamine',
    'C<sub>6</sub>H<sub>15</sub>N',
    '',
    '4458-32-6',
    'SMBYUOXUISCLCF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methylethylpropylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylethylpropylamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylethylpropylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methylethylisopropylamine',
    'C<sub>6</sub>H<sub>15</sub>N',
    '',
    '39198-07-7',
    'UTLDDSNRFHWERZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methylethylisopropylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylethylisopropylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methylpentylamine',
    'C<sub>6</sub>H<sub>15</sub>N',
    '',
    '25419-06-1',
    'UOIWOHLIGKIYFE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methylpentylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylpentylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propylisopropylamine',
    'C<sub>6</sub>H<sub>15</sub>N',
    '',
    '21968-17-2',
    'VLSTXUUYLIALPB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='propylisopropylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propylisopropylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,6-hexanediamine',
    'C<sub>6</sub>H<sub>16</sub>N<sub>2</sub>',
    'hexamethylenediamine',
    '124-09-4',
    'NAQMVNRVTILPCV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '5000',
    'M',
    (SELECT id from species WHERE iupac='1,6-hexanediamine'),
    (SELECT id from literature WHERE bibtexkey='3584'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,6-hexanediamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N,N''-methanetetraylbis-2-propanamine',
    'C<sub>7</sub>H<sub>14</sub>N<sub>2</sub>',
    '1,3-diisopropylcarbodiimide',
    '693-13-0',
    'BDNKZNFMNDZQMI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N''-methanetetraylbis-2-propanamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-2-hexanamine',
    'C<sub>7</sub>H<sub>17</sub>N',
    '',
    '105-41-9',
    'YAHRDLICUYEDAU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-hexanamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-heptanamine',
    'C<sub>7</sub>H<sub>17</sub>N',
    '1-heptylamine',
    '111-68-2',
    'WJYIASZWHGOTOU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-heptanamine'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-heptanamine'),
    (SELECT id from literature WHERE bibtexkey='2218'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-heptanamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-heptanamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-heptanamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-heptanamine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-heptanamine'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-heptanamine'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-heptanamine'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-heptanamine'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diethylisopropylamine',
    'C<sub>7</sub>H<sub>17</sub>N',
    '',
    '6006-15-1',
    'ULWOJODHECIZAU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='diethylisopropylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethylisopropylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diethylpropylamine',
    'C<sub>7</sub>H<sub>17</sub>N',
    '',
    '4458-31-5',
    'PQZTVWVYCLIIJY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='diethylpropylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethylpropylamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethylpropylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimethyl-1,1-dimethylpropylamine',
    'C<sub>7</sub>H<sub>17</sub>N',
    '',
    '57757-60-5',
    'CUHMMDPUXJFCNB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dimethyl-1,1-dimethylpropylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl-1,1-dimethylpropylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimethyl-1,2-dimethylpropylamine',
    'C<sub>7</sub>H<sub>17</sub>N',
    '',
    '66225-38-5',
    'FWBCYOHCOBOARU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dimethyl-1,2-dimethylpropylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl-1,2-dimethylpropylamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl-1,2-dimethylpropylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimethyl-2,2-dimethylpropylamine',
    'C<sub>7</sub>H<sub>17</sub>N',
    '',
    '10076-31-0',
    'FUIRUFXAVIHAQB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dimethyl-2,2-dimethylpropylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl-2,2-dimethylpropylamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl-2,2-dimethylpropylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimethyl-2-methylbutylamine',
    'C<sub>7</sub>H<sub>17</sub>N',
    '',
    '66225-39-6',
    'BHMZPPHMQJHCHQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dimethyl-2-methylbutylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl-2-methylbutylamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl-2-methylbutylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimethyl-3-methylbutylamine',
    'C<sub>7</sub>H<sub>17</sub>N',
    '',
    '2315-43-7',
    'KOOQJINBDNZUTB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dimethyl-3-methylbutylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl-3-methylbutylamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl-3-methylbutylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimethylpentylamine',
    'C<sub>7</sub>H<sub>17</sub>N',
    '',
    '26153-88-8',
    'IDFANOPDMXWIOP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dimethylpentylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylpentylamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylpentylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimethyl-2-pentylamine',
    'C<sub>7</sub>H<sub>17</sub>N',
    '',
    '57303-85-2',
    'LSTZYJQJHGEVKH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dimethyl-2-pentylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl-2-pentylamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl-2-pentylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimethyl-3-pentylamine',
    'C<sub>7</sub>H<sub>17</sub>N',
    '',
    '18636-94-7',
    'SUEKSPIQGIMSQM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dimethyl-3-pentylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl-3-pentylamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl-3-pentylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethylpentylamine',
    'C<sub>7</sub>H<sub>17</sub>N',
    '',
    '17839-26-8',
    'ICVFPLUSMYSIFO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethylpentylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethylpentylamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethylpentylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyldiisopropylamine',
    'C<sub>7</sub>H<sub>17</sub>N',
    '',
    '10342-97-9',
    'ISRXMEYARGEVIU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methyldiisopropylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyldiisopropylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyldipropylamine',
    'C<sub>7</sub>H<sub>17</sub>N',
    '',
    '3405-42-3',
    'UVBMZKBIZUWTLV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methyldipropylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyldipropylamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyldipropylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methylethylbutylamine',
    'C<sub>7</sub>H<sub>17</sub>N',
    '',
    '66225-40-9',
    'WOLFCKKMHUVEPN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methylethylbutylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylethylbutylamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylethylbutylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methylethylisobutylamine',
    'C<sub>7</sub>H<sub>17</sub>N',
    '',
    '60247-14-5',
    'QQWXQKMVASVXCI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methylethylisobutylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylethylisobutylamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylethylisobutylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methylethyl-<i>sec</i>-butylamine',
    'C<sub>7</sub>H<sub>17</sub>N',
    '',
    '66225-41-0',
    'HAFZSBASGRZPLA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methylethyl-<i>sec</i>-butylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylethyl-<i>sec</i>-butylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methylethyl-<i>tert</i>-butylamine',
    'C<sub>7</sub>H<sub>17</sub>N',
    '',
    '52841-28-8',
    'BWWLCYLGZIWOHK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methylethyl-<i>tert</i>-butylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylethyl-<i>tert</i>-butylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methylhexylamine',
    'C<sub>7</sub>H<sub>17</sub>N',
    '',
    '35161-70-7',
    'XJINZNWPEQMMBV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methylhexylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylhexylamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylhexylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methylpropylisopropylamine',
    'C<sub>7</sub>H<sub>17</sub>N',
    '',
    '66225-42-1',
    'OYQDUCLFZSKBCZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methylpropylisopropylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylpropylisopropylamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylpropylisopropylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-octanamine',
    'C<sub>8</sub>H19N',
    'octylamine',
    '111-86-4',
    'IOQPZZOEVPZRBK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-octanamine'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-octanamine'),
    (SELECT id from literature WHERE bibtexkey='2218'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-octanamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octanamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octanamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octanamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='1-octanamine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octanamine'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octanamine'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octanamine'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6600',
    '?',
    (SELECT id from species WHERE iupac='1-octanamine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-octanamine'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-octanamine'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-ethyl-1-hexanamine',
    'C<sub>8</sub>H<sub>19</sub>N',
    '2-ethylhexylamine',
    '104-75-6',
    'LTHNHFOGQMKPOV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-ethyl-1-hexanamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-1-hexanamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-1-hexanamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-1-hexanamine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-1-hexanamine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7400',
    '?',
    (SELECT id from species WHERE iupac='2-ethyl-1-hexanamine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diethylbutylamine',
    'C<sub>8</sub>H<sub>19</sub>N',
    '',
    '4444-68-2',
    'ORSUTASIQKBEFU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='diethylbutylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethylbutylamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethylbutylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimethylhexylamine',
    'C<sub>8</sub>H<sub>19</sub>N',
    '',
    '4385-04-0',
    'QMHNQZGXPNCMCO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dimethylhexylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylhexylamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylhexylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethylhexylamine',
    'C<sub>8</sub>H<sub>19</sub>N',
    '',
    '20352-67-4',
    'WSTNFGAKGUERTC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethylhexylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethylhexylamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethylhexylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methylheptylamine',
    'C<sub>8</sub>H<sub>19</sub>N',
    '',
    '36343-05-2',
    'LTGYRKOQQQWWAF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methylheptylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylheptylamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylheptylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2''-azobis-(2-methylpropanenitrile)',
    'C<sub>8</sub>H<sub>12</sub>N<sub>4</sub>',
    '',
    '78-67-1',
    'OZAIFHULBGXAKX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2''-azobis-(2-methylpropanenitrile)'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2''-azobis-(2-methylpropanenitrile)'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diethylpentylamine',
    'C<sub>9</sub>H<sub>21</sub>N',
    '',
    '2162-91-6',
    'YZULHOOBWDXEOT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='diethylpentylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethylpentylamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethylpentylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimethylheptylamine',
    'C<sub>9</sub>H<sub>21</sub>N',
    '',
    '5277-11-2',
    'LSICDRUYCNGRIF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dimethylheptylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylheptylamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylheptylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethylheptylamine',
    'C<sub>9</sub>H<sub>21</sub>N',
    '',
    '66793-76-8',
    'IUZZLNVABCISOI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethylheptylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethylheptylamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethylheptylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyloctylamine',
    'C<sub>9</sub>H<sub>21</sub>N',
    '',
    '2439-54-5',
    'SEGJNMCIMOLEDM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methyloctylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyloctylamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyloctylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nonylamine',
    'C<sub>9</sub>H<sub>21</sub>N',
    '',
    '112-20-9',
    'FJDUDHYHRVPMJZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='nonylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diethylhexylamine',
    'C<sub>10</sub>H<sub>23</sub>N',
    '',
    '44979-90-0',
    'XHDKYWMKOLURNK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='diethylhexylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethylhexylamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethylhexylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimethyloctylamine',
    'C<sub>10</sub>H<sub>23</sub>N',
    '',
    '7378-99-6',
    'UQKAOOAFEFCDGT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dimethyloctylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyloctylamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyloctylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dipentylamine',
    'C<sub>10</sub>H<sub>23</sub>N',
    '',
    '2050-92-2',
    'JACMPVXHEARCBO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dipentylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dipentylamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dipentylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyloctylamine',
    'C<sub>10</sub>H<sub>23</sub>N',
    '',
    '4088-36-2',
    'SDQCOADWEMMSGK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethyloctylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyloctylamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyloctylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methylnonylamine',
    'C<sub>10</sub>H<sub>23</sub>N',
    '',
    '39093-27-1',
    'OZIXTIPURXIEMB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methylnonylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylnonylamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylnonylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diethylheptylamine',
    'C<sub>11</sub>H<sub>25</sub>N',
    '',
    '26981-81-7',
    'YUCNJMBRLIZNMO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='diethylheptylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethylheptylamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethylheptylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimethylnonylamine',
    'C<sub>11</sub>H<sub>25</sub>N',
    '',
    '17373-27-2',
    'AMAADDMFZSZCNT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dimethylnonylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylnonylamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylnonylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diethyloctylamine',
    'C<sub>12</sub>H<sub>27</sub>N',
    '',
    '4088-37-3',
    'BVUGARXRRGZONH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='diethyloctylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyloctylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dihexylamine',
    'C<sub>12</sub>H<sub>27</sub>N',
    '',
    '143-16-8',
    'PXSXRABJBXYMFT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dihexylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dihexylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimethyldecylamine',
    'C<sub>12</sub>H<sub>27</sub>N',
    '',
    '1120-24-7',
    'YWWNNLPSZSEZNZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dimethyldecylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyldecylamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyldecylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methylundecylamine',
    'C<sub>12</sub>H<sub>27</sub>N',
    '',
    '66553-53-5',
    'JCJFBKCQLFMABE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methylundecylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylundecylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diethylnonylamine',
    'C<sub>13</sub>H<sub>29</sub>N',
    '',
    '45124-35-4',
    'IBTOMDSHMLGUHA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='diethylnonylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethylnonylamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethylnonylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimethylundecylamine',
    'C<sub>13</sub>H<sub>29</sub>N',
    '',
    '17373-28-3',
    'MMWFTWUMBYZIRZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dimethylundecylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylundecylamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylundecylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethylundecylamine',
    'C<sub>13</sub>H<sub>29</sub>N',
    '',
    '59570-04-6',
    'LKVBHKWFYHKTSM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethylundecylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethylundecylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyldodecylamine',
    'C<sub>13</sub>H<sub>29</sub>N',
    '',
    '7311-30-0',
    'OMEMQVZNTDHENJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methyldodecylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyldodecylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diethyldecylamine',
    'C<sub>14</sub>H<sub>31</sub>N',
    '',
    '6308-94-7',
    'UFFQZCPLBHYOFV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='diethyldecylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyldecylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diheptylamine',
    'C<sub>14</sub>H<sub>31</sub>N',
    '',
    '2470-68-0',
    'NJWMENBYMFZACG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='diheptylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diheptylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyldodecylamine',
    'C<sub>14</sub>H<sub>31</sub>N',
    '',
    '35902-57-9',
    'LWIPGCTWFZCIKX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethyldodecylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyldodecylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyltridecylamine',
    'C<sub>14</sub>H<sub>31</sub>N',
    '',
    '45165-81-9',
    'XMRPIOZXPHTSCE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methyltridecylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyltridecylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tripentylamine',
    'C<sub>15</sub>H<sub>33</sub>N',
    '',
    '621-77-2',
    'OOHAUGDGCWURIT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='tripentylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tripentylamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tripentylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-tridecanamine',
    'C<sub>13</sub>H<sub>29</sub>N',
    '',
    '2869-34-3',
    'ABVVEAHYODGCLZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-tridecanamine'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimethylamine',
    '(CH<sub>3</sub>)<sub>2</sub>NH',
    '',
    '124-40-3',
    'ROSDSFDQCJNGOL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='dimethylamine'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='dimethylamine'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='dimethylamine'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '4000',
    'L',
    (SELECT id from species WHERE iupac='dimethylamine'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dimethylamine'),
    (SELECT id from literature WHERE bibtexkey='721'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;1</sup>',
    '6400',
    'T',
    (SELECT id from species WHERE iupac='dimethylamine'),
    (SELECT id from literature WHERE bibtexkey='2016'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2016'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylamine'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylamine'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylamine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylamine'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylamine'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylamine'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylamine'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylamine'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162inconsistent'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dimethylamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dimethylamine'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dimethylamine'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diethylamine',
    '(C<sub>2</sub>H<sub>5</sub>)<sub>2</sub>NH',
    '',
    '109-89-7',
    'HPNMFZURTQLUMO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='diethylamine'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='diethylamine'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='diethylamine'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='diethylamine'),
    (SELECT id from literature WHERE bibtexkey='721'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '7700',
    'T',
    (SELECT id from species WHERE iupac='diethylamine'),
    (SELECT id from literature WHERE bibtexkey='2016'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2016'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='diethylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '10000',
    'X',
    (SELECT id from species WHERE iupac='diethylamine'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethylamine'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethylamine'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethylamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethylamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethylamine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethylamine'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethylamine'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethylamine'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethylamine'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethylamine'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-P'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethylamine'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='diethylamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='diethylamine'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='diethylamine'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='diethylamine'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='diethylamine'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dipropylamine',
    '(C<sub>3</sub>H<sub>7</sub>)<sub>2</sub>NH',
    '',
    '142-84-7',
    'WEHWNAOGRSTTBQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='dipropylamine'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='dipropylamine'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='dipropylamine'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '8900',
    'M',
    (SELECT id from species WHERE iupac='dipropylamine'),
    (SELECT id from literature WHERE bibtexkey='3685'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dipropylamine'),
    (SELECT id from literature WHERE bibtexkey='721'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dipropylamine'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dipropylamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dipropylamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dipropylamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dipropylamine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6900',
    'Q',
    (SELECT id from species WHERE iupac='dipropylamine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dipropylamine'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dipropylamine'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dipropylamine'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dipropylamine'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dipropylamine'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dipropylamine'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dipropylamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '8100',
    '?',
    (SELECT id from species WHERE iupac='dipropylamine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dipropylamine'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'at309K',
    '', 'Value at T = 309&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at309K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dipropylamine'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='dipropylamine'),
    (SELECT id from literature WHERE bibtexkey='510'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '510-142-84-7',
    '721,510', 'The data from Christie and Crisp (1967) for dipropylamine are incorrectly cited by Betterton (1992).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='510-142-84-7'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-methylpropanamine',
    'C<sub>4</sub>H<sub>11</sub>N',
    '',
    '627-35-0',
    'GVWISOJSERXQBM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-methylpropanamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-methyl-2-propanamine',
    'C<sub>4</sub>H<sub>11</sub>N',
    '',
    '4747-21-1',
    'XHFGWHUWQXTGAT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-methyl-2-propanamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-methyl-2-propanamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-(1-methylethyl)-2-propanamine',
    'C<sub>6</sub>H<sub>15</sub>N',
    'diisopropylamine',
    '108-18-9',
    'UAOMVDZJSHZZME-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='N-(1-methylethyl)-2-propanamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='N-(1-methylethyl)-2-propanamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-(1-methylethyl)-2-propanamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-(1-methylethyl)-2-propanamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-(1-methylethyl)-2-propanamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-(1-methylethyl)-2-propanamine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6900',
    'Q',
    (SELECT id from species WHERE iupac='N-(1-methylethyl)-2-propanamine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-(1-methylethyl)-2-propanamine'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-(1-methylethyl)-2-propanamine'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-Test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-(1-methylethyl)-2-propanamine'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-(1-methylethyl)-2-propanamine'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '8600',
    '?',
    (SELECT id from species WHERE iupac='N-(1-methylethyl)-2-propanamine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='N-(1-methylethyl)-2-propanamine'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N,N-dipropyl-1-propanamine',
    'C<sub>9</sub>H<sub>21</sub>N',
    'tripropylamine',
    '102-69-2',
    'YFTHZRPMJXBUME-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='N,N-dipropyl-1-propanamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='N,N-dipropyl-1-propanamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='N,N-dipropyl-1-propanamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='N,N-dipropyl-1-propanamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N-dipropyl-1-propanamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N-dipropyl-1-propanamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N-dipropyl-1-propanamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N-dipropyl-1-propanamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N-dipropyl-1-propanamine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N-dipropyl-1-propanamine'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N-dipropyl-1-propanamine'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N-dipropyl-1-propanamine'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='N,N-dipropyl-1-propanamine'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-methyl-1-butanamine',
    'C<sub>5</sub>H<sub>13</sub>N',
    'N-methylbutylamine',
    '110-68-9',
    'QCOGKXLOEWLIDC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='N-methyl-1-butanamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-methyl-1-butanamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-methyl-1-butanamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-methyl-1-butanamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6600',
    'Q',
    (SELECT id from species WHERE iupac='N-methyl-1-butanamine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5000',
    '?',
    (SELECT id from species WHERE iupac='N-methyl-1-butanamine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dibutylamine',
    '(C<sub>4</sub>H<sub>9</sub>)<sub>2</sub>NH',
    '',
    '111-92-2',
    'JQVDAXLFBXTEQA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='dibutylamine'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'M',
    (SELECT id from species WHERE iupac='dibutylamine'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dibutylamine'),
    (SELECT id from literature WHERE bibtexkey='721'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dibutylamine'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dibutylamine'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dibutylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibutylamine'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibutylamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibutylamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibutylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibutylamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibutylamine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7600',
    'Q',
    (SELECT id from species WHERE iupac='dibutylamine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibutylamine'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibutylamine'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibutylamine'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibutylamine'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibutylamine'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibutylamine'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dibutylamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7400',
    '?',
    (SELECT id from species WHERE iupac='dibutylamine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dibutylamine'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dibutylamine'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diisobutylamine',
    'C<sub>8</sub>H<sub>19</sub>N',
    '',
    '110-96-3',
    'NJBCRXCAPCODGX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diisobutylamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='diisobutylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diisobutylamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diisobutylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diisobutylamine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7600',
    'Q',
    (SELECT id from species WHERE iupac='diisobutylamine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diisobutylamine'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diisobutylamine'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7300',
    '?',
    (SELECT id from species WHERE iupac='diisobutylamine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bis-(1-methylpropyl)-amine',
    'C<sub>8</sub>H<sub>19</sub>N',
    'di-<i>sec</i>-butylamine',
    '626-23-3',
    'OBYVIBDTOCAXSN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7600',
    'Q',
    (SELECT id from species WHERE iupac='bis-(1-methylpropyl)-amine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7000',
    '?',
    (SELECT id from species WHERE iupac='bis-(1-methylpropyl)-amine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tetraethylenepentamine',
    'C<sub>8</sub>H<sub>23</sub>N<sub>5</sub>',
    '',
    '112-57-2',
    'FAGUFWYHJQFNRV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>14</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetraethylenepentamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N,N-di-2-propenyl-2-propen-1-amine',
    'C<sub>9</sub>H<sub>15</sub>N',
    'triallylamine',
    '102-70-5',
    'VPYJNCGUESNPMV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '7500',
    'L',
    (SELECT id from species WHERE iupac='N,N-di-2-propenyl-2-propen-1-amine'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='N,N-di-2-propenyl-2-propen-1-amine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='N,N-di-2-propenyl-2-propen-1-amine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N-di-2-propenyl-2-propen-1-amine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'trimethylamine',
    '(CH<sub>3</sub>)<sub>3</sub>N',
    '',
    '75-50-3',
    'GETQZCLCWQTVFV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='trimethylamine'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='trimethylamine'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;2</sup>',
    '6300',
    'M',
    (SELECT id from species WHERE iupac='trimethylamine'),
    (SELECT id from literature WHERE bibtexkey='3685'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;1</sup>',
    '4200',
    'M',
    (SELECT id from species WHERE iupac='trimethylamine'),
    (SELECT id from literature WHERE bibtexkey='3668'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3668'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trimethylamine'),
    (SELECT id from literature WHERE bibtexkey='2388'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trimethylamine'),
    (SELECT id from literature WHERE bibtexkey='721'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='trimethylamine'),
    (SELECT id from literature WHERE bibtexkey='2388'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trimethylamine'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trimethylamine'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trimethylamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trimethylamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trimethylamine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trimethylamine'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trimethylamine'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trimethylamine'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trimethylamine'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trimethylamine'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trimethylamine'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='trimethylamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='trimethylamine'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='trimethylamine'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'triethylamine',
    '(C<sub>2</sub>H<sub>5</sub>)<sub>3</sub>N',
    '',
    '121-44-8',
    'ZMANZCXQSJIPKH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='triethylamine'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='triethylamine'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='triethylamine'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '8300',
    'M',
    (SELECT id from species WHERE iupac='triethylamine'),
    (SELECT id from literature WHERE bibtexkey='3686'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='triethylamine'),
    (SELECT id from literature WHERE bibtexkey='721'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='triethylamine'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='triethylamine'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='triethylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='triethylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triethylamine'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triethylamine'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triethylamine'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triethylamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triethylamine'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triethylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triethylamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triethylamine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6700',
    'Q',
    (SELECT id from species WHERE iupac='triethylamine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triethylamine'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triethylamine'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triethylamine'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triethylamine'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triethylamine'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triethylamine'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triethylamine'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='triethylamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '9000',
    '?',
    (SELECT id from species WHERE iupac='triethylamine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='triethylamine'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='triethylamine'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tributylamine',
    'C<sub>12</sub>H<sub>27</sub>N',
    '',
    '102-82-9',
    'IMFACGCPASFAPR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '8700',
    'L',
    (SELECT id from species WHERE iupac='tributylamine'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='tributylamine'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tributylamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tributylamine'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tributylamine'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='tributylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tributylamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tributylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '8700',
    'Q',
    (SELECT id from species WHERE iupac='tributylamine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7500',
    '?',
    (SELECT id from species WHERE iupac='tributylamine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tributylamine'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N,N-dimethyl-1-dodecanamine',
    'C<sub>14</sub>H<sub>31</sub>N',
    '',
    '112-18-5',
    'YWFWDNVOPHGWMX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 4.0',
    '',
    'M',
    (SELECT id from species WHERE iupac='N,N-dimethyl-1-dodecanamine'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='N,N-dimethyl-1-dodecanamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N-dimethyl-1-dodecanamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N-dimethyl-1-dodecanamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N-dimethyl-1-dodecanamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethylenediamine',
    'H<sub>2</sub>NCH<sub>2</sub>CH<sub>2</sub>NH<sub>2</sub>',
    '',
    '107-15-3',
    'PIICEJLVQHRZGT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>3</sup>',
    '6700',
    'M',
    (SELECT id from species WHERE iupac='ethylenediamine'),
    (SELECT id from literature WHERE bibtexkey='3584'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethylenediamine'),
    (SELECT id from literature WHERE bibtexkey='776'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '9200',
    'T',
    (SELECT id from species WHERE iupac='ethylenediamine'),
    (SELECT id from literature WHERE bibtexkey='2381'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethylenediamine'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethylenediamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethylenediamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethylenediamine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethylenediamine'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethylenediamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethylenediamine'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-propen-1-amine',
    'C<sub>3</sub>H<sub>7</sub>N',
    'allylamine',
    '107-11-9',
    'VVJKKWFAADXIJK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '5400',
    'M',
    (SELECT id from species WHERE iupac='2-propen-1-amine'),
    (SELECT id from literature WHERE bibtexkey='3685'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-propen-1-amine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-propen-1-amine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='2-propen-1-amine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propen-1-amine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propen-1-amine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propen-1-amine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'di-2-propenylamine',
    'C<sub>6</sub>H<sub>11</sub>N',
    'diallylamine',
    '124-02-7',
    'DYUWTXWIYMHBQS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='di-2-propenylamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='di-2-propenylamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='di-2-propenylamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7200',
    'Q',
    (SELECT id from species WHERE iupac='di-2-propenylamine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '8000',
    '?',
    (SELECT id from species WHERE iupac='di-2-propenylamine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hexamethyleneimine',
    '(CH<sub>2</sub>)<sub>6</sub>NH',
    '',
    '111-49-9',
    'ZSIQJIWKELUFRJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '8200',
    'T',
    (SELECT id from species WHERE iupac='hexamethyleneimine'),
    (SELECT id from literature WHERE bibtexkey='722'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexamethyleneimine'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexamethyleneimine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexamethyleneimine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexamethyleneimine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexamethyleneimine'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexamethyleneimine'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    '?',
    (SELECT id from species WHERE iupac='hexamethyleneimine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cyclohexanamine',
    'C<sub>6</sub>H<sub>13</sub>N',
    'cyclohexylamine',
    '108-91-8',
    'PAFZNILMFXTMIY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '7500',
    'L',
    (SELECT id from species WHERE iupac='cyclohexanamine'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '',
    'M',
    (SELECT id from species WHERE iupac='cyclohexanamine'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '7800',
    'V',
    (SELECT id from species WHERE iupac='cyclohexanamine'),
    (SELECT id from literature WHERE bibtexkey='2123'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cyclohexanamine'),
    (SELECT id from literature WHERE bibtexkey='2388'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexanamine'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexanamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexanamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexanamine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexanamine'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexanamine'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '',
    '?',
    (SELECT id from species WHERE iupac='cyclohexanamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cyclohexanamine'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methylcyclohexylamine',
    'C<sub>7</sub>H<sub>15</sub>N',
    '',
    '6850-35-7',
    'JYDYHSHPBDZRPU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylcyclohexylamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-ethylcyclohexanamine',
    'C<sub>8</sub>H<sub>17</sub>N',
    'N-ethylcyclohexylamine',
    '5459-93-8',
    'AGVKXDPPPSLISR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7200',
    'Q',
    (SELECT id from species WHERE iupac='N-ethylcyclohexanamine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6500',
    '?',
    (SELECT id from species WHERE iupac='N-ethylcyclohexanamine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N,N-dimethylcyclohexylamine',
    'C<sub>8</sub>H<sub>17</sub>N',
    '',
    '98-94-2',
    'SVYKKECYCPFKGB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='N,N-dimethylcyclohexylamine'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N-dimethylcyclohexylamine'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N-dimethylcyclohexylamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N-dimethylcyclohexylamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N-dimethylcyclohexylamine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7000',
    'Q',
    (SELECT id from species WHERE iupac='N,N-dimethylcyclohexylamine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='N,N-dimethylcyclohexylamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '8500',
    '?',
    (SELECT id from species WHERE iupac='N,N-dimethylcyclohexylamine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hexamethylenetetramine',
    'C<sub>6</sub>H<sub>12</sub>N<sub>4</sub>',
    '',
    '100-97-0',
    'VKYKSIONXSXAKP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexamethylenetetramine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexamethylenetetramine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexamethylenetetramine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexamethylenetetramine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexamethylenetetramine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexamethylenetetramine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexamethylenetetramine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-decanamine',
    'C<sub>10</sub>H<sub>23</sub>N',
    '',
    '2016-57-1',
    'MHZGKXUYDGKKIU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-decanamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-decanamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2001'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-decanamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-cyclohexylcyclohexanamine',
    'C<sub>12</sub>H<sub>23</sub>N',
    'dicyclohexylamine',
    '101-83-7',
    'XBPCUCUWBYBCDP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-cyclohexylcyclohexanamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-dodecanamine',
    'C<sub>12</sub>H<sub>27</sub>N',
    '',
    '124-22-1',
    'JRBPAEWTRLWTQC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-dodecanamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-octadecanamine',
    'C<sub>18</sub>H<sub>39</sub>N',
    '',
    '124-30-1',
    'REYJJPSVUYRZGE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octadecanamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N,N-dioctyl-1-octanamine',
    'C<sub>24</sub>H<sub>51</sub>N',
    'tri-N-octylamine',
    '1116-76-3',
    'XTAZYLNFDRKIHJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N-dioctyl-1-octanamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'aminobenzene',
    'C<sub>6</sub>H<sub>7</sub>N',
    'aniline',
    '62-53-3',
    'PAYRUJLWNCNPSJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '6800',
    'L',
    (SELECT id from species WHERE iupac='aminobenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4',
    '',
    'M',
    (SELECT id from species WHERE iupac='aminobenzene'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2',
    '',
    'M',
    (SELECT id from species WHERE iupac='aminobenzene'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'M',
    (SELECT id from species WHERE iupac='aminobenzene'),
    (SELECT id from literature WHERE bibtexkey='1484'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at283K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0',
    '',
    'M',
    (SELECT id from species WHERE iupac='aminobenzene'),
    (SELECT id from literature WHERE bibtexkey='2525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'M',
    (SELECT id from species WHERE iupac='aminobenzene'),
    (SELECT id from literature WHERE bibtexkey='2944'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'at323K',
    '', 'Value at T = 323&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at323K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4',
    '',
    'V',
    (SELECT id from species WHERE iupac='aminobenzene'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6',
    '6500',
    'V',
    (SELECT id from species WHERE iupac='aminobenzene'),
    (SELECT id from literature WHERE bibtexkey='2123'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0',
    '',
    'V',
    (SELECT id from species WHERE iupac='aminobenzene'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0',
    '',
    'V',
    (SELECT id from species WHERE iupac='aminobenzene'),
    (SELECT id from literature WHERE bibtexkey='2165'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='aminobenzene'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0',
    '',
    'V',
    (SELECT id from species WHERE iupac='aminobenzene'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='aminobenzene'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4',
    '',
    'V',
    (SELECT id from species WHERE iupac='aminobenzene'),
    (SELECT id from literature WHERE bibtexkey='2971'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8',
    '',
    'X',
    (SELECT id from species WHERE iupac='aminobenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='aminobenzene'),
    (SELECT id from literature WHERE bibtexkey='howard89'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3034'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7',
    '',
    'X',
    (SELECT id from species WHERE iupac='aminobenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='aminobenzene'),
    (SELECT id from literature WHERE bibtexkey='howard89'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='aminobenzene'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='aminobenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='aminobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='aminobenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='aminobenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='aminobenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='aminobenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6200',
    'Q',
    (SELECT id from species WHERE iupac='aminobenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='aminobenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='aminobenzene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='aminobenzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    '?',
    (SELECT id from species WHERE iupac='aminobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='aminobenzene'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7100',
    '?',
    (SELECT id from species WHERE iupac='aminobenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8',
    '',
    '?',
    (SELECT id from species WHERE iupac='aminobenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3',
    '',
    '?',
    (SELECT id from species WHERE iupac='aminobenzene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benzylamine',
    'C<sub>7</sub>H<sub>9</sub>N',
    '',
    '100-46-9',
    'WGQKYBSKWIADBV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzylamine'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='benzylamine'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methylbenzenamine',
    'C<sub>7</sub>H<sub>9</sub>N',
    '2-methylaniline; o-toluidine',
    '95-53-4',
    'RNVCVTLRINQCPJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8',
    '7100',
    'L',
    (SELECT id from species WHERE iupac='2-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2165'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2971'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6',
    '',
    'R',
    (SELECT id from species WHERE iupac='2-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methylbenzenamine',
    'C<sub>7</sub>H<sub>9</sub>N',
    '3-methylaniline; m-toluidine',
    '108-44-1',
    'JJYPMNFTHPTTDI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6',
    '7200',
    'L',
    (SELECT id from species WHERE iupac='3-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2',
    '',
    'M',
    (SELECT id from species WHERE iupac='3-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9',
    '',
    'M',
    (SELECT id from species WHERE iupac='3-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methylbenzenamine',
    'C<sub>7</sub>H<sub>9</sub>N',
    '4-methylaniline; p-toluidine',
    '106-49-0',
    'RZXMPPFPUUCRFN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9',
    '4400',
    'L',
    (SELECT id from species WHERE iupac='4-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4',
    '',
    'M',
    (SELECT id from species WHERE iupac='4-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='4-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4',
    '',
    'M',
    (SELECT id from species WHERE iupac='4-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2971'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0',
    '',
    'R',
    (SELECT id from species WHERE iupac='4-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-ethylaniline',
    'C<sub>8</sub>H<sub>11</sub>N',
    'o-ethylaniline',
    '578-54-1',
    'MLPVBIWIRCKMJV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6',
    '7300',
    'L',
    (SELECT id from species WHERE iupac='2-ethylaniline'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3518-578-54-1-consicheck',
    '3518', 'Values at 298&nbsp;K in Tables&nbsp;C2 and C5 of Brockbank (2013) are inconsistent, with 6&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3518-578-54-1-consicheck'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylaniline'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7200',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylaniline'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7500',
    '?',
    (SELECT id from species WHERE iupac='2-ethylaniline'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-ethylaniline',
    'C<sub>8</sub>H<sub>11</sub>N',
    'p-ethylaniline',
    '589-16-2',
    'HRXZRAXKKNUKRF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-ethylaniline'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-ethylaniline'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6900',
    'Q',
    (SELECT id from species WHERE iupac='4-ethylaniline'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '8100',
    '?',
    (SELECT id from species WHERE iupac='4-ethylaniline'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dimethylbenzenamine',
    'C<sub>8</sub>H<sub>11</sub>N',
    '2,4-dimethylaniline; 2,4-xylidine',
    '95-68-1',
    'CZZZABOKJQXEBO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '7700',
    'L',
    (SELECT id from species WHERE iupac='2,4-dimethylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4-dimethylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4-dimethylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2165'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4-dimethylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7200',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7400',
    '?',
    (SELECT id from species WHERE iupac='2,4-dimethylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4-dimethylbenzenamine',
    'C<sub>8</sub>H<sub>11</sub>N',
    '3,4-dimethylaniline; 3,4-xylidine',
    '95-64-7',
    'DOLQYFPDPKPQSS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3',
    '',
    'M',
    (SELECT id from species WHERE iupac='3,4-dimethylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,4-dimethylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5-dimethylbenzenamine',
    'C<sub>8</sub>H<sub>11</sub>N',
    '2,5-dimethylaniline; 2,5-xylidine',
    '95-78-3',
    'VOWZNBNDMFLQGM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,5-dimethylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7200',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7700',
    '?',
    (SELECT id from species WHERE iupac='2,5-dimethylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6-dimethylbenzenamine',
    'C<sub>8</sub>H<sub>11</sub>N',
    '2,6-dimethylaniline; 2,6-xylidine',
    '87-62-7',
    'UFFBMTHBGFGIHF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,6-dimethylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,6-dimethylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,6-dimethylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,6-dimethylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    'R',
    (SELECT id from species WHERE iupac='2,6-dimethylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7500',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7600',
    '?',
    (SELECT id from species WHERE iupac='2,6-dimethylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,5-trimethylbenzenamine',
    'C<sub>9</sub>H<sub>13</sub>N',
    '2,4,5-trimethylaniline',
    '137-17-7',
    'BMIPMKQAAJKBKP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,4,5-trimethylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5-trimethylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5-trimethylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5-trimethylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5-trimethylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,4,5-trimethylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-(1-methylethyl)-benzenamine',
    'C<sub>9</sub>H<sub>13</sub>N',
    '2-isopropylaniline',
    '643-28-7',
    'YKOLZVXSPGIIBJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7500',
    'Q',
    (SELECT id from species WHERE iupac='2-(1-methylethyl)-benzenamine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6400',
    '?',
    (SELECT id from species WHERE iupac='2-(1-methylethyl)-benzenamine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6-diethylbenzenamine',
    'C<sub>10</sub>H<sub>15</sub>N',
    '2,6-diethylaniline',
    '579-66-8',
    'FOYHNROGBXVLLX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,6-diethylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,6-diethylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-diethylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-diethylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-diethylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-diethylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-diethylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,6-diethylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at300K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-benzenediamine',
    'C<sub>6</sub>H<sub>8</sub>N<sub>2</sub>',
    'o-phenylenediamine',
    '95-54-5',
    'GEYOCULIXLDCMW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-benzenediamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-benzenediamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-benzenediamine'),
    (SELECT id from literature WHERE bibtexkey='2165'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,2-benzenediamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'at308K',
    '', 'Value at T = 308&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at308K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-benzenediamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-benzenediamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-benzenediamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-benzenediamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3-benzenediamine',
    'C<sub>6</sub>H<sub>8</sub>N<sub>2</sub>',
    'm-phenylenediamine',
    '108-45-2',
    'WZCQRUWWHSTZEM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3-benzenediamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3-benzenediamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3-benzenediamine'),
    (SELECT id from literature WHERE bibtexkey='2165'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,3-benzenediamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-benzenediamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-benzenediamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-benzenediamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-benzenediamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-benzenediamine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4-benzenediamine',
    'C<sub>6</sub>H<sub>8</sub>N<sub>2</sub>',
    'p-phenylenediamine',
    '106-50-3',
    'CBCKQZAAMUWICA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,4-benzenediamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at297K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-benzenediamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-benzenediamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-benzenediamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-1,3-benzenediamine',
    'C<sub>7</sub>H<sub>10</sub>N<sub>2</sub>',
    '',
    '823-40-5',
    'RLYCRLGLCUXUPO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1,3-benzenediamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-1,4-benzenediamine',
    'C<sub>7</sub>H<sub>10</sub>N<sub>2</sub>',
    '',
    '95-70-5',
    'OBCSAIDCZQSFQH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1,4-benzenediamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-1,2-benzenediamine',
    'C<sub>7</sub>H<sub>10</sub>N<sub>2</sub>',
    '2,3-diaminotoluene',
    '2687-25-4',
    'AXNUJYHFQHQZBE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1,2-benzenediamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-1,3-benzenediamine',
    'C<sub>7</sub>H<sub>10</sub>N<sub>2</sub>',
    'toluene-2,4-diamine',
    '95-80-7',
    'VOZKAJLKRJDJLL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1,3-benzenediamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,5-diaminotoluene',
    'C<sub>7</sub>H<sub>10</sub>N<sub>2</sub>',
    '',
    '108-71-4',
    'LVNDUJYMLJDECN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-diaminotoluene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-642'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phenylhydrazine',
    'C<sub>6</sub>H<sub>8</sub>N<sub>2</sub>',
    '',
    '100-63-0',
    'HKOOXMFOFWEVGF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='phenylhydrazine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='phenylhydrazine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenylhydrazine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenylhydrazine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenylhydrazine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(methylamino)-benzene',
    'C<sub>7</sub>H<sub>9</sub>N',
    'N-methylaniline',
    '100-61-8',
    'AFBPFSWMIHJQDM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(methylamino)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(methylamino)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2165'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'R',
    (SELECT id from species WHERE iupac='(methylamino)-benzene'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(methylamino)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(methylamino)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(methylamino)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(methylamino)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(methylamino)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(methylamino)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(methylamino)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(methylamino)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(methylamino)-benzene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    '?',
    (SELECT id from species WHERE iupac='(methylamino)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(methylamino)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(ethylamino)-benzene',
    'C<sub>8</sub>H<sub>11</sub>N',
    'N-ethylaniline',
    '103-69-5',
    'OJGMBLNIHDZDGS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;1</sup>',
    '7900',
    'L',
    (SELECT id from species WHERE iupac='(ethylamino)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3518-103-69-5-consicheck',
    '3518', 'Values at 298&nbsp;K in Tables&nbsp;C2 and C5 of Brockbank (2013) are inconsistent, with 5&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3518-103-69-5-consicheck'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'M',
    (SELECT id from species WHERE iupac='(ethylamino)-benzene'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(ethylamino)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(ethylamino)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(ethylamino)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(ethylamino)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(ethylamino)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7100',
    'Q',
    (SELECT id from species WHERE iupac='(ethylamino)-benzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(ethylamino)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(ethylamino)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    '?',
    (SELECT id from species WHERE iupac='(ethylamino)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7600',
    '?',
    (SELECT id from species WHERE iupac='(ethylamino)-benzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(dimethylamino)-benzene',
    'C<sub>8</sub>H<sub>11</sub>N',
    'N,N-dimethylaniline',
    '121-69-7',
    'JLTDJTHDQAWBAV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(dimethylamino)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(dimethylamino)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(dimethylamino)-benzene'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(dimethylamino)-benzene'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(dimethylamino)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2971'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(dimethylamino)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(dimethylamino)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6900',
    'Q',
    (SELECT id from species WHERE iupac='(dimethylamino)-benzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(dimethylamino)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(dimethylamino)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(dimethylamino)-benzene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(dimethylamino)-benzene'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6300',
    '?',
    (SELECT id from species WHERE iupac='(dimethylamino)-benzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(dimethylamino)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(dimethylamino)-benzene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benzeneethanamine',
    'C<sub>8</sub>H<sub>11</sub>N',
    '2-phenylethylamine',
    '64-04-0',
    'BHHGXPLMPWCGHP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzeneethanamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethylbenzenamine',
    'C<sub>8</sub>H<sub>11</sub>N',
    '2,3-xylidine',
    '87-59-2',
    'VVAKEQGKZNKUSU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,5-dimethylbenzenamine',
    'C<sub>8</sub>H<sub>11</sub>N',
    '',
    '108-69-0',
    'MKARNSWMMBGSHX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimethylaniline',
    'C<sub>8</sub>H<sub>11</sub>N',
    'xylidine',
    '1300-73-8',
    'CDULGHZNHURECF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylaniline'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phenelzine',
    'C<sub>8</sub>H<sub>12</sub>N<sub>2</sub>',
    '',
    '51-71-8',
    'RMUCZJUITONUFY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenelzine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N,N-dimethyl-1,4-benzenediamine',
    'C<sub>8</sub>H<sub>12</sub>N<sub>2</sub>',
    '',
    '99-98-9',
    'BZORFPDSXLZWJF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N-dimethyl-1,4-benzenediamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,6-trimethylbenzenamine',
    'C<sub>9</sub>H<sub>13</sub>N',
    '2,4,6-trimethylaniline',
    '88-05-1',
    'KWVPRPSXBZNOHS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trimethylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-ethyl-3-methylbenzenamine',
    'C<sub>9</sub>H<sub>13</sub>N',
    '',
    '102-27-2',
    'GUYMMHOQXYZMJQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-ethyl-3-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-(1-methylethyl)benzenamine',
    'C<sub>9</sub>H<sub>13</sub>N',
    '',
    '768-52-5',
    'FRCFWPVMFJMNDP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-(1-methylethyl)benzenamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-ethyl-6-methylbenzenamine',
    'C<sub>9</sub>H<sub>13</sub>N',
    '',
    '24549-06-2',
    'JJVKJJNCIILLRP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-6-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-6-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-6-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-6-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N,N-dimethylbenzylamine',
    'C<sub>9</sub>H<sub>13</sub>N',
    '',
    '103-83-3',
    'XXBDWLFCJWSEKW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7700',
    'Q',
    (SELECT id from species WHERE iupac='N,N-dimethylbenzylamine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7700',
    '?',
    (SELECT id from species WHERE iupac='N,N-dimethylbenzylamine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N,N,4-trimethylbenzenamine',
    'C<sub>9</sub>H<sub>13</sub>N',
    '',
    '99-97-8',
    'GYVGXEWAOAAJEU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='N,N,4-trimethylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N,4-trimethylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N,4-trimethylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N,4-trimethylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N,N''-di-<i>tert</i>-butylethylenediamine',
    'C<sub>10</sub>H<sub>24</sub>N<sub>2</sub>',
    '',
    '4062-60-6',
    'KGHYGBGIWLNFAV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N''-di-<i>tert</i>-butylethylenediamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N''-di-<i>tert</i>-butylethylenediamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N''-di-<i>tert</i>-butylethylenediamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N''-di-<i>tert</i>-butylethylenediamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(diethylamino)-benzene',
    'C<sub>10</sub>H<sub>15</sub>N',
    'N,N-diethylaniline',
    '91-66-7',
    'GGSUCNLOZRCGPQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;2</sup>',
    '6700',
    'L',
    (SELECT id from species WHERE iupac='(diethylamino)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(diethylamino)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(diethylamino)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(diethylamino)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(diethylamino)-benzene'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(diethylamino)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(diethylamino)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(diethylamino)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7600',
    'Q',
    (SELECT id from species WHERE iupac='(diethylamino)-benzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(diethylamino)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5800',
    '?',
    (SELECT id from species WHERE iupac='(diethylamino)-benzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2',
    '',
    '?',
    (SELECT id from species WHERE iupac='(diethylamino)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'at285K',
    '', 'Value at T = 285&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at285K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-naphthylamine',
    'C<sub>10</sub>H<sub>9</sub>N',
    '',
    '134-32-7',
    'RUFPHBVGCFYCNW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-naphthylamine'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-naphthylamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>1</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='1-naphthylamine'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-naphthylamine'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-naphthylamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-naphthylamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-naphthylamine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-naphthylamine'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-naphthylamine'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-naphthylamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-naphthylamine',
    'C<sub>10</sub>H<sub>9</sub>N',
    '',
    '91-59-8',
    'JBIJLHTVPXGSAM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='2-naphthylamine'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-naphthylamine'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-naphthylamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-naphthylamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-naphthylamine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-naphthylamine'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-Test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-naphthylamine'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-naphthylamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-naphthylamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-3072'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,5-naphthalenediamine',
    'C<sub>10</sub>H<sub>10</sub>N<sub>2</sub>',
    '',
    '2243-62-1',
    'KQSABULTKYLFEV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,5-naphthalenediamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phentermine',
    'C<sub>10</sub>H<sub>15</sub>N',
    '',
    '122-09-8',
    'DHHVAGZRUROJKS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phentermine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N,N-diethyl-1,4-benzenediamine',
    'C<sub>10</sub>H<sub>16</sub>N<sub>2</sub>',
    '',
    '93-05-0',
    'QNGVNLMMEQUVQK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N-diethyl-1,4-benzenediamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,5-diethyltoluene-2,6-diamine',
    'C<sub>11</sub>H<sub>18</sub>N<sub>2</sub>',
    '',
    '2095-01-4',
    'RQEOBXYYEPMCPJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-diethyltoluene-2,6-diamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-diethyltoluene-2,6-diamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-diethyltoluene-2,6-diamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-diethyltoluene-2,6-diamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-diethyl-6-methylbenzene-1,3-diamine',
    'C<sub>11</sub>H<sub>18</sub>N<sub>2</sub>',
    '',
    '2095-02-5',
    'PISLZQACAJMAIO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-diethyl-6-methylbenzene-1,3-diamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-diethyl-6-methylbenzene-1,3-diamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-diethyl-6-methylbenzene-1,3-diamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-diethyl-6-methylbenzene-1,3-diamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diphenylamine',
    'C<sub>12</sub>H<sub>11</sub>N',
    '',
    '122-39-4',
    'DMBHHRLKUKUOEG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7',
    '',
    'V',
    (SELECT id from species WHERE iupac='diphenylamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7',
    '',
    'V',
    (SELECT id from species WHERE iupac='diphenylamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diphenylamine'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diphenylamine'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='diphenylamine'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'X',
    (SELECT id from species WHERE iupac='diphenylamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5',
    '',
    'X',
    (SELECT id from species WHERE iupac='diphenylamine'),
    (SELECT id from literature WHERE bibtexkey='howard91'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diphenylamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diphenylamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diphenylamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diphenylamine'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benzidine',
    'C<sub>12</sub>H<sub>12</sub>N<sub>2</sub>',
    '',
    '92-87-5',
    'HFACYLZERDEVSX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzidine'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzidine'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzidine'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='benzidine'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzidine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1-diphenylhydrazine',
    'C<sub>12</sub>H<sub>12</sub>N<sub>2</sub>',
    '',
    '530-50-7',
    'YHYKLKNNBYLTQY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-diphenylhydrazine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-diphenylhydrazine',
    'C<sub>12</sub>H<sub>12</sub>N<sub>2</sub>',
    'N,N''-bianiline',
    '122-66-7',
    'YBQZXXMEJHZYMB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-diphenylhydrazine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-diphenylhydrazine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-diphenylhydrazine'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2614_pc_problem',
    '2614', 'Mackay et&nbsp;al. (2006d) list a vapor pressure p, a solubility c, and a Henry''s law constant calculated as p/c. However, the data are internally inconsistent and deviate by more than 10&nbsp;%.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2614_pc_problem'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-diphenylhydrazine'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-diphenylhydrazine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-(phenylazo)-benzenamine',
    'C<sub>12</sub>H<sub>11</sub>N<sub>3</sub>',
    '4-aminoazobenzene',
    '60-09-3',
    'QPQKUYVSJWQSDY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-(phenylazo)-benzenamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-(phenylazo)-benzenamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-(phenylazo)-benzenamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-(phenylazo)-benzenamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-(phenylazo)-benzenamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-(phenylazo)-benzenamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'azobenzene',
    'C<sub>12</sub>H<sub>10</sub>N<sub>2</sub>',
    '',
    '103-33-3',
    'DMLAVOWQYNRWNQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='azobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='azobenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='azobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-aminobiphenyl',
    'C<sub>12</sub>H<sub>11</sub>N',
    '',
    '90-41-5',
    'TWBPWBPGNQWFSJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-aminobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-aminobiphenyl',
    'C<sub>12</sub>H<sub>11</sub>N',
    '',
    '92-67-1',
    'DMVOXQPQNTYEKQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-aminobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-phenyl-1,4-benzenediamine',
    'C<sub>12</sub>H<sub>12</sub>N<sub>2</sub>',
    'p-aminodiphenylamine',
    '101-54-2',
    'ATGUVEKSASEFFO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='N-phenyl-1,4-benzenediamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-phenyl-1,4-benzenediamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-phenyl-1,4-benzenediamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-phenyl-1,4-benzenediamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-fluorenamine',
    'C<sub>13</sub>H<sub>11</sub>N',
    '',
    '153-78-6',
    'CFRFHWQYWJMEJN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-fluorenamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-642'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,4''-methylenebisbenzenamine',
    'C<sub>13</sub>H<sub>14</sub>N<sub>2</sub>',
    '',
    '101-77-9',
    'YBRVSVVVWCFQMG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4,4''-methylenebisbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-anthracenamine',
    'C<sub>14</sub>H<sub>11</sub>N',
    '',
    '613-13-8',
    'YCSBALJAGZKWFF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-anthracenamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-642'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3''-dimethylbenzidine',
    'C<sub>14</sub>H<sub>16</sub>N<sub>2</sub>',
    '',
    '119-93-7',
    'NUIURNJTPRWVAP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3''-dimethylbenzidine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N,N-dimethyl-4-(phenylazo)-benzenamine',
    'C<sub>14</sub>H<sub>15</sub>N<sub>3</sub>',
    '',
    '60-11-7',
    'JCYPECIVGRXBMO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='N,N-dimethyl-4-(phenylazo)-benzenamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N-dimethyl-4-(phenylazo)-benzenamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N-dimethyl-4-(phenylazo)-benzenamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N-dimethyl-4-(phenylazo)-benzenamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N-dimethyl-4-(phenylazo)-benzenamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'o-aminoazotoluene',
    'C<sub>14</sub>H<sub>15</sub>N<sub>3</sub>',
    '',
    '97-56-3',
    'PFRYFZZSECNQOL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='o-aminoazotoluene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='o-aminoazotoluene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-ethyl-N-phenylbenzenemethanamine',
    'C<sub>15</sub>H<sub>17</sub>N',
    '',
    '92-59-1',
    'HSZCJVZRHXPCIA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-ethyl-N-phenylbenzenemethanamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-ethyl-N-phenylbenzenemethanamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-ethyl-N-phenylbenzenemethanamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-ethyl-N-phenylbenzenemethanamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-(1-methylethyl)-N''-phenyl-1,4-benzenediamine',
    'C<sub>15</sub>H<sub>18</sub>N<sub>2</sub>',
    '4-(iso-propylamino)diphenylamine',
    '101-72-4',
    'OUBMGJOQLXMSNT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-(1-methylethyl)-N''-phenyl-1,4-benzenediamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,4''-methylene-bis-(N-methylaniline)',
    'C<sub>15</sub>H<sub>18</sub>N<sub>2</sub>',
    '',
    '1807-55-2',
    'ZMVMYBGDGJLCHV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4''-methylene-bis-(N-methylaniline)'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'C.I. Food Yellow 10',
    'C<sub>16</sub>H<sub>13</sub>N<sub>3</sub>',
    '',
    '85-84-7',
    'KLCDQSGLLRINHY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='C.I. Food Yellow 10'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3'',5,5''-tetramethylbenzidine',
    'C<sub>16</sub>H<sub>20</sub>N<sub>2</sub>',
    '',
    '54827-17-7',
    'UAIUNKRWKOVEES-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',5,5''-tetramethylbenzidine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-phenyl-1-naphthalenamine',
    'C<sub>16</sub>H<sub>13</sub>N',
    '',
    '90-30-2',
    'XQVWYOYUZDUNRW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='N-phenyl-1-naphthalenamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-phenyl-1-naphthalenamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-phenyl-1-naphthalenamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-phenyl-1-naphthalenamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-phenyl-1-naphthalenamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'yellow OB',
    'C<sub>17</sub>H<sub>15</sub>N<sub>3</sub>',
    '',
    '131-79-3',
    'BWLVSYUUKOQICP-FMQUCBEESA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='yellow OB'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'auramine',
    'C<sub>17</sub>H<sub>21</sub>N<sub>3</sub>',
    '',
    '492-80-8',
    'JPIYZTWMUGTEHX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='auramine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benzphetamine',
    'C<sub>17</sub>H<sub>21</sub>N',
    '',
    '156-08-1',
    'YXKTVDFXDRQTKV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzphetamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,4''-methylenebis(N,N-dimethylbenzenamine)',
    'C<sub>17</sub>H<sub>22</sub>N<sub>2</sub>',
    'bis(p-dimethylamino)phenylmethane',
    '101-61-1',
    'JNRLEMMIVRBKJE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4''-methylenebis(N,N-dimethylbenzenamine)'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phencyclidine',
    'C<sub>17</sub>H<sub>25</sub>N',
    '',
    '77-10-1',
    'JTJMJGYZQZDUJJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phencyclidine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N,N''-diphenyl-1,4-benzenediamine',
    'C<sub>18</sub>H<sub>16</sub>N<sub>2</sub>',
    '',
    '74-31-7',
    'UTGQNNCQYDRXCH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N''-diphenyl-1,4-benzenediamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-(1,3-dimethylbutyl)-N''-phenyl-1,4-phenylenediamine',
    'C<sub>18</sub>H<sub>24</sub>N<sub>2</sub>',
    '',
    '793-24-8',
    'ZZMVLMVFYMGSMY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-(1,3-dimethylbutyl)-N''-phenyl-1,4-phenylenediamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-(1,3-dimethylbutyl)-N''-phenyl-1,4-phenylenediamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-(1,3-dimethylbutyl)-N''-phenyl-1,4-phenylenediamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-(1,3-dimethylbutyl)-N''-phenyl-1,4-phenylenediamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'amitraz',
    'C<sub>19</sub>H<sub>23</sub>N<sub>3</sub>',
    '',
    '33089-61-1',
    'QXAITBQSYVNQDR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'X',
    (SELECT id from species WHERE iupac='amitraz'),
    (SELECT id from literature WHERE bibtexkey='macbean2012'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='amitraz'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='amitraz'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='amitraz'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    '?',
    (SELECT id from species WHERE iupac='amitraz'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N,N''-bis(1-ethyl-3-methylpentyl)-1,4-benzenediamine',
    'C<sub>22</sub>H<sub>40</sub>N<sub>2</sub>',
    '',
    '139-60-6',
    'JUHXTONDLXIGGK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N''-bis(1-ethyl-3-methylpentyl)-1,4-benzenediamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N''-bis(1-ethyl-3-methylpentyl)-1,4-benzenediamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N''-bis(1-ethyl-3-methylpentyl)-1,4-benzenediamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N''-bis(1-ethyl-3-methylpentyl)-1,4-benzenediamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'p,p''-benzylidenebis(N,N-dimethylaniline)',
    'C<sub>23</sub>H<sub>26</sub>N<sub>2</sub>',
    'leucomalachite green',
    '129-73-7',
    'WZKXBGJNNCGHIC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='p,p''-benzylidenebis(N,N-dimethylaniline)'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-phenyl-N-(2,4,4-trimethyl-2-pentanyl)-1-naphthalenamine',
    'C<sub>24</sub>H<sub>29</sub>N',
    '',
    '51772-35-1',
    'SNWVRVDHQRBBFG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-phenyl-N-(2,4,4-trimethyl-2-pentanyl)-1-naphthalenamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-phenyl-N-(2,4,4-trimethyl-2-pentanyl)-1-naphthalenamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-phenyl-N-(2,4,4-trimethyl-2-pentanyl)-1-naphthalenamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-phenyl-N-(2,4,4-trimethyl-2-pentanyl)-1-naphthalenamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tris(2-ethylhexyl)amine',
    'C<sub>24</sub>H<sub>51</sub>N',
    '',
    '1860-26-0',
    'BZUDVELGTZDOIG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tris(2-ethylhexyl)amine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tris(2-ethylhexyl)amine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tris(2-ethylhexyl)amine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tris(2-ethylhexyl)amine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,4'',4"-methylidyne-tris(N,N-dimethylbenzenamine)',
    'C<sub>25</sub>H<sub>31</sub>N<sub>3</sub>',
    'Leucocrystal violet',
    '603-48-5',
    'OAZWDJGLIYNYMU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4'',4"-methylidyne-tris(N,N-dimethylbenzenamine)'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4'',4"-methylidyne-tris(N,N-dimethylbenzenamine)'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4'',4"-methylidyne-tris(N,N-dimethylbenzenamine)'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4'',4"-methylidyne-tris(N,N-dimethylbenzenamine)'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-phenylbenzenamide',
    'C<sub>30</sub>H<sub>47</sub>N',
    '',
    '68608-79-7',
    'FSPSHPMYFQHGQD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-phenylbenzenamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-phenylbenzenamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-phenylbenzenamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-phenylbenzenamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,4'',4"-methanetriyltris(N,N-diethylaniline)',
    'C<sub>31</sub>H<sub>43</sub>N<sub>3</sub>',
    '',
    '68814-02-8',
    'HOGMPEULJBVHLZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4'',4"-methanetriyltris(N,N-diethylaniline)'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4'',4"-methanetriyltris(N,N-diethylaniline)'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4'',4"-methanetriyltris(N,N-diethylaniline)'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4'',4"-methanetriyltris(N,N-diethylaniline)'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Heterocycles with nitrogen (C, H, N)',
    (SELECT id from categories WHERE catname='Organic species with nitrogen (N)'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'amitrole',
    'C<sub>2</sub>H<sub>4</sub>N<sub>4</sub>',
    '',
    '61-82-5',
    'KLSJWNVTNUYHDU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>7</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='amitrole'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>7</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='amitrole'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>9</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='amitrole'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='amitrole'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'azetidine',
    'C<sub>3</sub>H<sub>7</sub>N',
    '',
    '503-29-7',
    'HONIICLYMWZJFZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8',
    '',
    '?',
    (SELECT id from species WHERE iupac='azetidine'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'imidazole',
    'C<sub>3</sub>H<sub>4</sub>N<sub>2</sub>',
    '',
    '288-32-4',
    'RAXXELZNTBOGNW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='imidazole'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at313K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='imidazole'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3426'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='imidazole'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3,5-triazine-2,4,6-triamine',
    'C<sub>3</sub>H<sub>6</sub>N<sub>6</sub>',
    '',
    '108-78-1',
    'JDSHMPZPIAZGSV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>8</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3,5-triazine-2,4,6-triamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-triazine-2,4,6-triamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-triazine-2,4,6-triamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-triazine-2,4,6-triamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-triazine-2,4,6-triamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pyrrolidine',
    'C<sub>4</sub>H<sub>8</sub>NH',
    '',
    '123-75-1',
    'RWRDLPDLKQPQOW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2',
    '',
    'V',
    (SELECT id from species WHERE iupac='pyrrolidine'),
    (SELECT id from literature WHERE bibtexkey='2388'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2',
    '7600',
    'T',
    (SELECT id from species WHERE iupac='pyrrolidine'),
    (SELECT id from literature WHERE bibtexkey='722'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pyrrolidine'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pyrrolidine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pyrrolidine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pyrrolidine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pyrrolidine'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pyrrolidine'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pyrrolidine'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1',
    '',
    '?',
    (SELECT id from species WHERE iupac='pyrrolidine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-pyrroline',
    'C<sub>4</sub>H<sub>7</sub>N',
    '',
    '5724-81-2',
    'ZVJHJDDKYZXRJI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-pyrroline'),
    (SELECT id from literature WHERE bibtexkey='2388'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-pyrroline',
    'C<sub>4</sub>H<sub>7</sub>N',
    '',
    '109-96-6',
    'JVQIKJMSUIMUDI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-pyrroline'),
    (SELECT id from literature WHERE bibtexkey='2388'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4-diazacyclohexane',
    'C<sub>4</sub>H<sub>10</sub>N<sub>2</sub>',
    'piperazine',
    '110-85-0',
    'GLUUGHFHXGJENI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>3</sup>',
    '7400',
    'M',
    (SELECT id from species WHERE iupac='1,4-diazacyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3584'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '11000',
    'T',
    (SELECT id from species WHERE iupac='1,4-diazacyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2376'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pyrrole',
    'C<sub>4</sub>H<sub>5</sub>N',
    '1H-pyrrole',
    '109-97-7',
    'KAESVJOAVNADME-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='pyrrole'),
    (SELECT id from literature WHERE bibtexkey='2232'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pyrrole'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pyrrole'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pyrrole'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pyrrole'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pyrrole'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pyrrole'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pyrrole'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pyrrole'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pyrrole'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-1H-imidazole',
    'C<sub>4</sub>H<sub>6</sub>N<sub>2</sub>',
    '',
    '616-47-7',
    'MCTWTZJPVLRJOU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-methyl-1H-imidazole'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at313K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-1H-imidazole'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3426'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-1H-imidazole'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-1H-imidazole'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3-diazine',
    'C<sub>4</sub>H<sub>4</sub>N<sub>2</sub>',
    '',
    '289-95-2',
    'CZPWVGJYEJSRLH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-diazine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-methylpyrrolidine',
    'C<sub>4</sub>H<sub>8</sub>NCH<sub>3</sub>',
    '',
    '120-94-5',
    'AVFZOVWCLRSYKC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '7600',
    'T',
    (SELECT id from species WHERE iupac='N-methylpyrrolidine'),
    (SELECT id from literature WHERE bibtexkey='722'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-methylpyrrolidine'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-methylpyrrolidine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-methylpyrrolidine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-methylpyrrolidine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-methylpyrrolidine'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='N-methylpyrrolidine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'piperidine',
    'C<sub>5</sub>H<sub>10</sub>NH',
    '',
    '110-89-4',
    'NQRYJNQNLNOLGT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '7900',
    'M',
    (SELECT id from species WHERE iupac='piperidine'),
    (SELECT id from literature WHERE bibtexkey='2826'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'V',
    (SELECT id from species WHERE iupac='piperidine'),
    (SELECT id from literature WHERE bibtexkey='2388'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '7900',
    'T',
    (SELECT id from species WHERE iupac='piperidine'),
    (SELECT id from literature WHERE bibtexkey='722'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='piperidine'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='piperidine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='piperidine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='piperidine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='piperidine'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='piperidine'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='piperidine'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    '?',
    (SELECT id from species WHERE iupac='piperidine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-ethylimidazole',
    'C<sub>5</sub>H<sub>8</sub>N<sub>2</sub>',
    '',
    '1072-62-4',
    'PQAMFDRRWURCFQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-ethylimidazole'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at313K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylimidazole'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3426'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylimidazole'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-dimethylimidazole',
    'C<sub>5</sub>H<sub>8</sub>N<sub>2</sub>',
    '',
    '1739-84-0',
    'GIWQSPITLQVMSG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-dimethylimidazole'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at313K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethylimidazole'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3426'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethylimidazole'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-methylpiperazine',
    'C<sub>5</sub>H<sub>12</sub>N<sub>2</sub>',
    '1-methylpiperazine',
    '109-01-3',
    'PVOAHINGSUIXLS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>3</sup>',
    '9900',
    'M',
    (SELECT id from species WHERE iupac='N-methylpiperazine'),
    (SELECT id from literature WHERE bibtexkey='3584'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '11000',
    'T',
    (SELECT id from species WHERE iupac='N-methylpiperazine'),
    (SELECT id from literature WHERE bibtexkey='2376'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-1H-pyrrole',
    'C<sub>5</sub>H<sub>7</sub>N',
    '',
    '96-54-8',
    'OXHNLMTVIGZXSG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-1H-pyrrole'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pyridine',
    'C<sub>5</sub>H<sub>5</sub>N',
    '',
    '110-86-1',
    'JUJWROOIHBZHMG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;1</sup>',
    '4700',
    'L',
    (SELECT id from species WHERE iupac='pyridine'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '6000',
    'M',
    (SELECT id from species WHERE iupac='pyridine'),
    (SELECT id from literature WHERE bibtexkey='2826'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;2</sup>',
    '-2300',
    'M',
    (SELECT id from species WHERE iupac='pyridine'),
    (SELECT id from literature WHERE bibtexkey='1107'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='pyridine'),
    (SELECT id from literature WHERE bibtexkey='3646'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='pyridine'),
    (SELECT id from literature WHERE bibtexkey='1073'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='pyridine'),
    (SELECT id from literature WHERE bibtexkey='2232'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'M',
    (SELECT id from species WHERE iupac='pyridine'),
    (SELECT id from literature WHERE bibtexkey='2378'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2378like0917',
    '2378,719,2386', 'Calculated using &#8710;G<sub>s</sub><sup>g&#8594; H<sub>2</sub>O</sup> and &#8710;H<sub>s</sub><sup>g&#8594; H<sub>2</sub>O</sup> from Table&nbsp;IV of Arnett and Chawla (1979). Since some of the values in this table are taken directly from Andon et&nbsp;al. (1954), it is assumed that the thermodynamic properties are defined in the same way. Since &#8710;H<sub>s</sub><sup>g&#8594; H<sub>2</sub>O</sup> is defined relative to pyridine, a value of &#8722;11.93&nbsp;kcal&nbsp;mol<sup>&#8722;1</sup> from Arnett et&nbsp;al. (1977) was added.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2378like0917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='pyridine'),
    (SELECT id from literature WHERE bibtexkey='2388'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '5900',
    'M',
    (SELECT id from species WHERE iupac='pyridine'),
    (SELECT id from literature WHERE bibtexkey='719'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='719'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pyridine'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pyridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pyridine'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pyridine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pyridine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6000',
    'Q',
    (SELECT id from species WHERE iupac='pyridine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pyridine'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pyridine'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pyridine'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pyridine'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pyridine'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pyridine'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pyridine'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pyridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    '?',
    (SELECT id from species WHERE iupac='pyridine'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5400',
    '?',
    (SELECT id from species WHERE iupac='pyridine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    '?',
    (SELECT id from species WHERE iupac='pyridine'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pyridine'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    '?',
    (SELECT id from species WHERE iupac='pyridine'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='pyridine'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '1525ref719',
    '719,1525', 'Due to an apparently incorrect definition of the Henry''s law constant by Andon et&nbsp;al. (1954), Staudinger and Roberts (2001) quote incorrect values from that paper.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1525ref719'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pyridine-d5',
    'C<sub>5</sub>D<sub>5</sub>N',
    '',
    '7291-22-7',
    'JUJWROOIHBZHMG-RALIUCGRSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2',
    '10000',
    'M',
    (SELECT id from species WHERE iupac='pyridine-d5'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-aminopyridine',
    'C<sub>5</sub>H<sub>6</sub>N<sub>2</sub>',
    '',
    '504-24-5',
    'NUKYPUAOHBNCPY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-aminopyridine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-aminopyridine',
    'C<sub>5</sub>H<sub>6</sub>N<sub>2</sub>',
    '',
    '504-29-0',
    'ICSNLGPSRYBMBD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-aminopyridine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methylpyrazine',
    'C<sub>4</sub>N<sub>2</sub>H<sub>3</sub>CH<sub>3</sub>',
    '',
    '109-08-0',
    'CAWHJQAVHZEVTJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methylpyrazine'),
    (SELECT id from literature WHERE bibtexkey='755'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpyrazine'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpyrazine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpyrazine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpyrazine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpyrazine'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpyrazine'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpyrazine'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methylpyrazine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'adenine',
    'C<sub>5</sub>H<sub>5</sub>N<sub>5</sub>',
    '',
    '73-24-5',
    'GFFGJBXGBJISGV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>9</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='adenine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='adenine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '9-methyladenine',
    'C<sub>6</sub>H<sub>7</sub>N<sub>5</sub>',
    '',
    '700-00-5',
    'WRXCXOUDSPTXNX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='9-methyladenine'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-methylpiperidine',
    'C<sub>5</sub>H<sub>10</sub>NCH<sub>3</sub>',
    '',
    '626-67-5',
    'PAMIQIKDUOTOBW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='N-methylpiperidine'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '7900',
    'T',
    (SELECT id from species WHERE iupac='N-methylpiperidine'),
    (SELECT id from literature WHERE bibtexkey='722'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-methylpiperidine'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-methylpiperidine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-methylpiperidine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-methylpiperidine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6300',
    'Q',
    (SELECT id from species WHERE iupac='N-methylpiperidine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-methylpiperidine'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-methylpiperidine'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-methylpiperidine'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-methylpiperidine'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-methylpiperidine'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='N-methylpiperidine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6600',
    '?',
    (SELECT id from species WHERE iupac='N-methylpiperidine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'triethylenediamine',
    'C<sub>6</sub>H<sub>12</sub>N<sub>2</sub>',
    '',
    '280-57-9',
    'IMNIMPAHZVJRPE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='triethylenediamine'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at313K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triethylenediamine'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3426'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triethylenediamine'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-ethyl-4-methylimidazole',
    'C<sub>6</sub>H<sub>10</sub>N<sub>2</sub>',
    '',
    '931-36-2',
    'ULKLGIFJWFIQFF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-ethyl-4-methylimidazole'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at313K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-4-methylimidazole'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3426'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-4-methylimidazole'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-(aminomethyl)pyridine',
    'C<sub>6</sub>H<sub>8</sub>N<sub>2</sub>',
    '',
    '3731-52-0',
    'HDOUGSFASVGDCS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3-(aminomethyl)pyridine'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at313K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-(aminomethyl)pyridine'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3426'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-(aminomethyl)pyridine'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N,N''-dimethylpiperazine',
    'C<sub>6</sub>H<sub>14</sub>N<sub>2</sub>',
    '1,4-dimethylpiperazine',
    '106-58-1',
    'RXYPXQSKLGGKOL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '11000',
    'M',
    (SELECT id from species WHERE iupac='N,N''-dimethylpiperazine'),
    (SELECT id from literature WHERE bibtexkey='3584'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '11000',
    'T',
    (SELECT id from species WHERE iupac='N,N''-dimethylpiperazine'),
    (SELECT id from literature WHERE bibtexkey='2376'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cyromazine',
    'C<sub>6</sub>H<sub>10</sub>N<sub>6</sub>',
    '',
    '66215-27-8',
    'LVQDKIWDGQRHTE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>8</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cyromazine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>8</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cyromazine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyromazine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1H-benzotriazole',
    'C<sub>6</sub>H<sub>5</sub>N<sub>3</sub>',
    '1,2,3-benzotriazole',
    '95-14-7',
    'QRUDEWIWKLJBPS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1H-benzotriazole'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-piperazineethanamine',
    'C<sub>6</sub>H<sub>15</sub>N<sub>3</sub>',
    'N-(2-aminoethyl)piperazine',
    '140-31-8',
    'IMUDHTPIFIBORV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-piperazineethanamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methylpyridine',
    'C<sub>5</sub>H<sub>4</sub>NCH<sub>3</sub>',
    '2-picoline; &#945;-picoline',
    '109-06-8',
    'BSKHPKMHTQYZBB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;1</sup>',
    '6300',
    'L',
    (SELECT id from species WHERE iupac='2-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '6400',
    'M',
    (SELECT id from species WHERE iupac='2-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='719'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='719'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6400',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6300',
    '?',
    (SELECT id from species WHERE iupac='2-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='2-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1525ref719'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methylpyridine',
    'C<sub>5</sub>H<sub>4</sub>NCH<sub>3</sub>',
    '3-picoline; &#946;-picoline',
    '108-99-6',
    'ITQTTZVARXURQS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '6400',
    'L',
    (SELECT id from species WHERE iupac='3-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1073'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '6300',
    'M',
    (SELECT id from species WHERE iupac='3-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='719'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='719'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6400',
    'Q',
    (SELECT id from species WHERE iupac='3-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6300',
    '?',
    (SELECT id from species WHERE iupac='3-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='3-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1525ref719'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methylpyridine',
    'C<sub>5</sub>H<sub>4</sub>NCH<sub>3</sub>',
    '',
    '108-89-4',
    'FKNQCJSGGFJEIZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '6500',
    'L',
    (SELECT id from species WHERE iupac='4-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '6500',
    'M',
    (SELECT id from species WHERE iupac='4-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='719'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='719'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6400',
    'Q',
    (SELECT id from species WHERE iupac='4-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6500',
    '?',
    (SELECT id from species WHERE iupac='4-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2378'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2378like0917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='4-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1525ref719'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-cyanopyridine',
    'C<sub>6</sub>H<sub>4</sub>N<sub>2</sub>',
    '',
    '100-54-9',
    'GZPHSAQLYPIAIN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>1</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='3-cyanopyridine'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-cyanopyridine'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-cyanopyridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-cyanopyridine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-cyanopyridine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-cyanopyridine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-cyanopyridine'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-cyanopyridine'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-cyanopyridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-cyanopyridine',
    'C<sub>6</sub>H<sub>4</sub>N<sub>2</sub>',
    '',
    '100-48-1',
    'GPHQHTOMRSGBNZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='4-cyanopyridine'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-cyanopyridine'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-cyanopyridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-cyanopyridine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-cyanopyridine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-cyanopyridine'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-cyanopyridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-ethylpyrazine',
    'C<sub>4</sub>N<sub>2</sub>H<sub>3</sub>(C<sub>2</sub>H<sub>5</sub>)',
    '',
    '13925-00-3',
    'KVFIJIWMDBAGDP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-ethylpyrazine'),
    (SELECT id from literature WHERE bibtexkey='755'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylpyrazine'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylpyrazine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylpyrazine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylpyrazine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylpyrazine'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-ethylpyrazine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5-dimethylpyrazine',
    'C<sub>6</sub>H<sub>8</sub>N<sub>2</sub>',
    '',
    '123-32-0',
    'LCZUOKDVTBMCMX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,5-dimethylpyrazine'),
    (SELECT id from literature WHERE bibtexkey='2964'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,5-dimethylpyrazine'),
    (SELECT id from literature WHERE bibtexkey='3645'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,5-dimethylpyrazine'),
    (SELECT id from literature WHERE bibtexkey='2964'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethylpyrazine'),
    (SELECT id from literature WHERE bibtexkey='2964'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6-dimethylpyrazine',
    'C<sub>6</sub>H<sub>8</sub>N<sub>2</sub>',
    '3,5-dimethylpyrazine',
    '108-50-9',
    'HJFZAYHYIWGLNL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,6-dimethylpyrazine'),
    (SELECT id from literature WHERE bibtexkey='1073'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-ethylpiperidine',
    'C<sub>7</sub>H<sub>15</sub>N',
    '1-ethylpiperidine',
    '766-09-6',
    'HTLZVHNRZJPSMI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-ethylpiperidine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6600',
    'Q',
    (SELECT id from species WHERE iupac='N-ethylpiperidine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6600',
    '?',
    (SELECT id from species WHERE iupac='N-ethylpiperidine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1H-benzimidazole',
    'C<sub>7</sub>H<sub>6</sub>N<sub>2</sub>',
    '',
    '51-17-2',
    'HYZJCKYKOHLVJF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1H-benzimidazole'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-ethenylpyridine',
    'C<sub>7</sub>H<sub>7</sub>N',
    '2-vinylpyridine',
    '100-69-6',
    'KGIGUEBEKRSTEW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-ethenylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethenylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethenylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-ethenylpyridine',
    'C<sub>7</sub>H<sub>7</sub>N',
    '4-vinylpyridine',
    '100-43-6',
    'KFDVPJUYSDEJTH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-ethenylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethenylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethenylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-ethylpyridine',
    'C<sub>5</sub>H<sub>4</sub>NC<sub>2</sub>H<sub>5</sub>',
    '',
    '100-71-0',
    'NRGGMCIBEHEAIL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;1</sup>',
    '6700',
    'M',
    (SELECT id from species WHERE iupac='2-ethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='719'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='719'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6700',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-ethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7900',
    '?',
    (SELECT id from species WHERE iupac='2-ethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-ethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='2-ethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1525ref719'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethylpyridine',
    'C<sub>5</sub>H<sub>4</sub>NC<sub>2</sub>H<sub>5</sub>',
    '',
    '536-78-7',
    'MFEIKQPHQINPRI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;1</sup>',
    '6400',
    'M',
    (SELECT id from species WHERE iupac='3-ethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='719'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='719'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6700',
    'Q',
    (SELECT id from species WHERE iupac='3-ethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-ethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6200',
    '?',
    (SELECT id from species WHERE iupac='3-ethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-ethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='3-ethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1525ref719'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-ethylpyridine',
    'C<sub>5</sub>H<sub>4</sub>NC<sub>2</sub>H<sub>5</sub>',
    '',
    '536-75-4',
    'VJXRKZJMGVSXPX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '6300',
    'M',
    (SELECT id from species WHERE iupac='4-ethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='719'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='719'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6700',
    'Q',
    (SELECT id from species WHERE iupac='4-ethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-ethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-ethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6300',
    '?',
    (SELECT id from species WHERE iupac='4-ethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-ethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='4-ethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1525ref719'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethylpyridine',
    'C<sub>5</sub>H<sub>3</sub>N(CH<sub>3</sub>)<sub>2</sub>',
    '2,3-lutidine',
    '583-61-9',
    'HPYNZHMRTTWQTB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '6900',
    'M',
    (SELECT id from species WHERE iupac='2,3-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='719'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='719'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6200',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-Test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5800',
    '?',
    (SELECT id from species WHERE iupac='2,3-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='2,3-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1525ref719'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dimethylpyridine',
    'C<sub>5</sub>H<sub>3</sub>N(CH<sub>3</sub>)<sub>2</sub>',
    '2,4-lutidine',
    '108-47-4',
    'JYYNAJVZFGKDEQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,4-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2232'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '7100',
    'M',
    (SELECT id from species WHERE iupac='2,4-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='719'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='719'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6700',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,4-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,4-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6400',
    '?',
    (SELECT id from species WHERE iupac='2,4-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,4-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='2,4-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1525ref719'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5-dimethylpyridine',
    'C<sub>5</sub>H<sub>3</sub>N(CH<sub>3</sub>)<sub>2</sub>',
    '2,5-lutidine',
    '589-93-5',
    'XWKFPIODWVPXLX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '7000',
    'M',
    (SELECT id from species WHERE iupac='2,5-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='719'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='719'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6700',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,5-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6900',
    '?',
    (SELECT id from species WHERE iupac='2,5-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,5-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='2,5-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1525ref719'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6-dimethylpyridine',
    'C<sub>5</sub>H<sub>3</sub>N(CH<sub>3</sub>)<sub>2</sub>',
    '2,6-lutidine',
    '108-48-5',
    'OISVCGZHLKNMSJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;1</sup>',
    '7300',
    'L',
    (SELECT id from species WHERE iupac='2,6-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,6-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2232'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;1</sup>',
    '7300',
    'M',
    (SELECT id from species WHERE iupac='2,6-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='719'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='719'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6700',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,6-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,6-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6600',
    '?',
    (SELECT id from species WHERE iupac='2,6-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,6-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='2,6-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1525ref719'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4-dimethylpyridine',
    'C<sub>5</sub>H<sub>3</sub>N(CH<sub>3</sub>)<sub>2</sub>',
    '3,4-lutidine',
    '583-58-4',
    'NURQLCJSMXZBPC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '6800',
    'M',
    (SELECT id from species WHERE iupac='3,4-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='719'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='719'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6200',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,4-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6400',
    '?',
    (SELECT id from species WHERE iupac='3,4-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,4-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='3,4-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1525ref719'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,5-dimethylpyridine',
    'C<sub>5</sub>H<sub>3</sub>N(CH<sub>3</sub>)<sub>2</sub>',
    '3,5-lutidine',
    '591-22-0',
    'HWWYDZCSSYKIAD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '6800',
    'M',
    (SELECT id from species WHERE iupac='3,5-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='719'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='719'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6700',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,5-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6500',
    '?',
    (SELECT id from species WHERE iupac='3,5-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,5-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='3,5-dimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1525ref719'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-ethyl-2-methylpyridine',
    'C<sub>8</sub>H<sub>11</sub>N',
    '',
    '104-90-5',
    'NTSLROIKFLNUIJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='5-ethyl-2-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='5-ethyl-2-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-ethyl-2-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-ethyl-2-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-ethyl-2-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-ethyl-2-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-ethyl-2-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-ethyl-2-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-ethyl-2-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,6-trimethylpyridine',
    'C<sub>5</sub>H<sub>2</sub>N(CH<sub>3</sub>)<sub>3</sub>',
    '2,4,6-collidine',
    '108-75-8',
    'BWZVCCNYKMEVEX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4,6-trimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4,6-trimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4,6-trimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4,6-trimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'C',
    (SELECT id from species WHERE iupac='2,4,6-trimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7100',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '8600',
    '?',
    (SELECT id from species WHERE iupac='2,4,6-trimethylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'indole',
    'C<sub>8</sub>H<sub>7</sub>N',
    '',
    '120-72-9',
    'SIKJAQJRHWYJAI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='indole'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='indole'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='indole'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='indole'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='indole'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='indole'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='indole'),
    (SELECT id from literature WHERE bibtexkey='howard97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='indole'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='indole'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='indole'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='indole'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='indole'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9',
    '',
    '?',
    (SELECT id from species WHERE iupac='indole'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-ethyl-3,5-dimethylpyrazine',
    'C<sub>8</sub>H<sub>12</sub>N<sub>2</sub>',
    '',
    '13925-07-0',
    'JZBCTZLGKSYRSF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9',
    '8500',
    'M',
    (SELECT id from species WHERE iupac='2-ethyl-3,5-dimethylpyrazine'),
    (SELECT id from literature WHERE bibtexkey='3215'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3215-13925-07-0-ABC',
    '3215', 'The data from Wieland et&nbsp;al. (2015) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;12.48322 +7833.96799/T &#8722;2.23379&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3215-13925-07-0-ABC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-isobutylpyrazine',
    'C<sub>4</sub>N<sub>2</sub>H<sub>3</sub>C<sub>4</sub>H<sub>9</sub>',
    '',
    '29460-92-2',
    'YAIMUUJMEBJXAA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-isobutylpyrazine'),
    (SELECT id from literature WHERE bibtexkey='755'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-isobutylpyrazine'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-isobutylpyrazine'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-(1-methylpropyl)-pyrazine',
    'C<sub>8</sub>H<sub>12</sub>N<sub>2</sub>',
    '',
    '29460-93-3',
    'NFFQZEXYZVZKNN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(1-methylpropyl)-pyrazine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(1-methylpropyl)-pyrazine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-ethenyl-2-methylpyridine',
    'C<sub>8</sub>H<sub>9</sub>N',
    '',
    '140-76-1',
    'VJOWMORERYNYON-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-ethenyl-2-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-(1,1-dimethylethyl)-pyridine',
    'C<sub>9</sub>H<sub>13</sub>N',
    '4-<i>tert</i>-butylpyridine',
    '3978-81-2',
    'YSHMQTRICHYLGF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-(1,1-dimethylethyl)-pyridine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-(1,1-dimethylethyl)-pyridine'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;1</sup>',
    '7000',
    '?',
    (SELECT id from species WHERE iupac='4-(1,1-dimethylethyl)-pyridine'),
    (SELECT id from literature WHERE bibtexkey='2378'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2378like0917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nornicotine',
    'C<sub>9</sub>H<sub>12</sub>N<sub>2</sub>',
    '',
    '494-97-3',
    'MYKUKUCHPMASKF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nornicotine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-diamino-6-phenyl-1,3,5-triazine',
    'C<sub>9</sub>H<sub>9</sub>N<sub>5</sub>',
    '',
    '91-76-9',
    'GZVHEAJQGPRDLQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-diamino-6-phenyl-1,3,5-triazine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-methylindole',
    'C<sub>9</sub>H<sub>9</sub>N',
    '',
    '603-76-9',
    'BLRHMMGNCXNXJL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7',
    '',
    '?',
    (SELECT id from species WHERE iupac='N-methylindole'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methylindole',
    'C<sub>9</sub>H<sub>9</sub>N',
    'skatole',
    '83-34-1',
    'ZFRKQXVRDFCRJG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;5</sup>',
    '-2500',
    'M',
    (SELECT id from species WHERE iupac='3-methylindole'),
    (SELECT id from literature WHERE bibtexkey='3799'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-methylindole'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-diethyl-5-methylpyrazine',
    'C<sub>9</sub>H<sub>14</sub>N<sub>2</sub>',
    '',
    '18138-04-0',
    'PSINWXIDJYEXLO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3-diethyl-5-methylpyrazine'),
    (SELECT id from literature WHERE bibtexkey='2389'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benzo[b]pyridine',
    'C<sub>9</sub>H<sub>7</sub>N',
    'quinoline',
    '91-22-5',
    'SMWDFEZZVXVKRB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzo[b]pyridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzo[b]pyridine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzo[b]pyridine'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzo[b]pyridine'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzo[b]pyridine'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzo[b]pyridine'),
    (SELECT id from literature WHERE bibtexkey='3945'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4',
    '',
    'R',
    (SELECT id from species WHERE iupac='benzo[b]pyridine'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>1</sup>',
    '5400',
    'X',
    (SELECT id from species WHERE iupac='benzo[b]pyridine'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzo[b]pyridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzo[b]pyridine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzo[b]pyridine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzo[b]pyridine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7300',
    'Q',
    (SELECT id from species WHERE iupac='benzo[b]pyridine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzo[b]pyridine'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzo[b]pyridine'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzo[b]pyridine'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzo[b]pyridine'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzo[b]pyridine'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7300',
    '?',
    (SELECT id from species WHERE iupac='benzo[b]pyridine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5',
    '',
    '?',
    (SELECT id from species WHERE iupac='benzo[b]pyridine'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benzo[c]pyridine',
    'C<sub>9</sub>H<sub>7</sub>N',
    'isoquinoline',
    '119-65-3',
    'AWJUIBRHMBBTKR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzo[c]pyridine'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzo[c]pyridine'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7',
    '',
    'X',
    (SELECT id from species WHERE iupac='benzo[c]pyridine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzo[c]pyridine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzo[c]pyridine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8',
    '',
    '?',
    (SELECT id from species WHERE iupac='benzo[c]pyridine'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nicotine',
    'C<sub>10</sub>H<sub>14</sub>N<sub>2</sub>',
    '',
    '54-11-5',
    'SNICXCGAKADSCV-SNVBAGLBSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nicotine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2''-bipyridine',
    'C<sub>10</sub>H<sub>8</sub>N<sub>2</sub>',
    '',
    '366-18-7',
    'ROFVEXUMMXZLPA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2''-bipyridine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-642'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,4''-bipyridine',
    'C<sub>10</sub>H<sub>8</sub>N<sub>2</sub>',
    '',
    '553-26-4',
    'MWVTWFVJZLCBMC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4,4''-bipyridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4''-bipyridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methylquinoline',
    'C<sub>10</sub>H<sub>9</sub>N',
    '',
    '91-63-4',
    'SMUQFGGVLNAIOZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methylquinoline'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methylquinoline',
    'C<sub>10</sub>H<sub>9</sub>N',
    '',
    '491-35-0',
    'MUDSDYNRBDKLGK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylquinoline'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MEIQX',
    'C<sub>11</sub>H<sub>11</sub>N<sub>5</sub>',
    '2-amino-3,8-dimethylimidazo[4,5-f]quinoxaline',
    '77500-04-0',
    'DVCCCQNKIYNAKB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MEIQX'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-(phenylazo)-2,6-pyridinediamine',
    'C<sub>11</sub>H<sub>11</sub>N<sub>5</sub>',
    'phenazopyridine',
    '94-78-0',
    'QPFYXYFORQJZEC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-(phenylazo)-2,6-pyridinediamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-amino-9H-pyrido[2,3-b]indole',
    'C<sub>11</sub>H<sub>9</sub>N<sub>3</sub>',
    '',
    '26148-68-5',
    'FJTNLJLPLJDTRM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-amino-9H-pyrido[2,3-b]indole'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'carbazole',
    'C<sub>12</sub>H<sub>9</sub>N',
    '',
    '86-74-8',
    'UJOBWOGCFQCDNV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>1</sup>',
    '4300',
    'L',
    (SELECT id from species WHERE iupac='carbazole'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>1</sup>',
    '4300',
    'M',
    (SELECT id from species WHERE iupac='carbazole'),
    (SELECT id from literature WHERE bibtexkey='2819'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='carbazole'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='carbazole'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='carbazole'),
    (SELECT id from literature WHERE bibtexkey='3945'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='carbazole'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='carbazole'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='carbazole'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='carbazole'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'o-phenanthroline',
    'C<sub>12</sub>H<sub>8</sub>N<sub>2</sub>',
    '',
    '66-71-7',
    'DGEZNRSVGBDHLK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='o-phenanthroline'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='o-phenanthroline'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='o-phenanthroline'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='o-phenanthroline'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benzyladenine',
    'C<sub>12</sub>H<sub>11</sub>N<sub>5</sub>',
    '',
    '1214-39-7',
    'NWBJYWHLCVSVIJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>8</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzyladenine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='benzyladenine'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diquat',
    'C<sub>12</sub>H<sub>12</sub>N<sub>2</sub>',
    '',
    '2764-72-9',
    'SYJFEGQWDCRVNX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='diquat'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MEIQ',
    'C<sub>12</sub>H<sub>12</sub>N<sub>4</sub>',
    '2-amino-3,4-dimethylimidazo[4,5-f]quinoxaline',
    '77094-11-2',
    'GMGWMIJIGUYNAY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MEIQ'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pyrimethanil',
    'C<sub>12</sub>H<sub>13</sub>N<sub>3</sub>',
    '',
    '53112-28-0',
    'ZLIBICFPKPWGIZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>2</sup>',
    '15000',
    'M',
    (SELECT id from species WHERE iupac='pyrimethanil'),
    (SELECT id from literature WHERE bibtexkey='3506'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pyrimethanil'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='pyrimethanil'),
    (SELECT id from literature WHERE bibtexkey='tomlin98'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'from3506',
    '3506', 'Value given here as quoted by Feigenbrugel and Le Calvé (2021).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3506'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pyrimethanil'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pyrimethanil'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pyrimethanil'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'paraquat',
    'C<sub>12</sub>H<sub>14</sub>N<sub>2</sub>',
    '',
    '4685-14-7',
    'INFDPOAKFNIJBF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 2.4&times;10<sup>8</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='paraquat'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N,N-dimethyltryptamine',
    'C<sub>12</sub>H<sub>16</sub>N<sub>2</sub>',
    '',
    '61-50-7',
    'DMULVCHRPCFFGV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N-dimethyltryptamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benzo[f]quinoline',
    'C<sub>13</sub>H<sub>9</sub>N',
    '',
    '85-02-9',
    'HCAUQPZEWLULFJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzo[f]quinoline'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzo[f]quinoline'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2614_pc_problem'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzo[f]quinoline'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzo[f]quinoline'),
    (SELECT id from literature WHERE bibtexkey='3945'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzo[f]quinoline'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6-bis-(1,1-dimethylethyl)-pyridine',
    'C<sub>13</sub>H<sub>21</sub>N',
    '2,6-di-<i>tert</i>-butylpyridine',
    '585-48-8',
    'UWKQJZCTQGMHKD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;4</sup>',
    '6900',
    'M',
    (SELECT id from species WHERE iupac='2,6-bis-(1,1-dimethylethyl)-pyridine'),
    (SELECT id from literature WHERE bibtexkey='2378'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2378like0917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,6-bis-(1,1-dimethylethyl)-pyridine'),
    (SELECT id from literature WHERE bibtexkey='2378'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2378DTBP',
    '2378', 'Value calculated from the solubility of 9.4&times;10<sup>&#8722;3</sup>&nbsp;mol&nbsp;L<sup>&#8722;1</sup> and the vapor pressure of 0.255&nbsp;mmHg, as shown on pages 7142-7143 of Arnett and Chawla (1979). It is inconsistent with the entry in Table&nbsp;IV of that paper.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2378DTBP'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'PHIP',
    'C<sub>13</sub>H<sub>12</sub>N<sub>4</sub>',
    '2-amino-1-methyl-6-phenylimidazo[4,5-b]pyridine',
    '105650-23-5',
    'UQVKZNNCIHJZLS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='PHIP'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N,N''-diphenylguanidine',
    'C<sub>13</sub>H<sub>13</sub>N<sub>3</sub>',
    '',
    '102-06-7',
    'OWRCNXZUPFZXOS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N''-diphenylguanidine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'acridine',
    'C<sub>13</sub>H<sub>9</sub>N',
    '',
    '260-94-6',
    'DZBUGLKDJFMEHC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='acridine'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='acridine'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='acridine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phenanthridine',
    'C<sub>13</sub>H<sub>9</sub>N',
    '',
    '229-87-8',
    'RDOWQLZANAYVLL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='phenanthridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenanthridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'mepanipyrim',
    'C<sub>14</sub>H<sub>13</sub>N<sub>3</sub>',
    '',
    '110235-47-7',
    'CIFWZNRJIBNXRE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='mepanipyrim'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cyprodinil',
    'C<sub>14</sub>H<sub>15</sub>N<sub>3</sub>',
    '',
    '121552-61-2',
    'HAORKNGNJCEJBX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cyprodinil'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cyprodinil'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyprodinil'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'imiquimod',
    'C<sub>14</sub>H<sub>16</sub>N<sub>4</sub>',
    '',
    '99011-02-6',
    'DOUYETYNHWVLEO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='imiquimod'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ametoctradin',
    'C<sub>15</sub>H<sub>25</sub>N<sub>5</sub>',
    '',
    '865318-97-4',
    'GGKQIOFASHYUJZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ametoctradin'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ferimzone',
    'C<sub>15</sub>H<sub>18</sub>N<sub>4</sub>',
    '',
    '89269-64-7',
    'GOWLARCWZRESHU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ferimzone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ferimzone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benz[c]acridine',
    'C<sub>17</sub>H<sub>11</sub>N',
    '',
    '225-51-4',
    'OAPPEBNXKAKQGS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benz[c]acridine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '6-pentyl-1,2,3,4,7,8,9,10-octahydrophenanthridine',
    'C<sub>18</sub>H<sub>27</sub>N',
    '',
    '10594-03-3',
    'FNUATPIDZQSFPD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-pentyl-1,2,3,4,7,8,9,10-octahydrophenanthridine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-pentyl-1,2,3,4,7,8,9,10-octahydrophenanthridine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-pentyl-1,2,3,4,7,8,9,10-octahydrophenanthridine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-pentyl-1,2,3,4,7,8,9,10-octahydrophenanthridine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-diphenylmethylpiperidine',
    'C<sub>18</sub>H<sub>21</sub>N',
    'desoxypipradrol',
    '519-74-4',
    'RWTNXJXZVGHMGI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-diphenylmethylpiperidine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fenpropidin',
    'C<sub>19</sub>H<sub>31</sub>N',
    '',
    '67306-00-7',
    'MGNFYQILYYYUBS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>2</sup>',
    '6200',
    'M',
    (SELECT id from species WHERE iupac='fenpropidin'),
    (SELECT id from literature WHERE bibtexkey='3506'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HTdep_r2_lessthan_0.9'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='fenpropidin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='fenpropidin'),
    (SELECT id from literature WHERE bibtexkey='tomlin98'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3506'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fenpropidin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fenpropidin'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N,N-bis(2-ethylhexyl)-1H-1,2,4-triazole-1-methanamine',
    'C<sub>19</sub>H<sub>38</sub>N<sub>4</sub>',
    '',
    '91273-04-0',
    'AVBBHCMDRGQBNW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='N,N-bis(2-ethylhexyl)-1H-1,2,4-triazole-1-methanamine'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '7H-dibenzo[c,g]carbazole',
    'C<sub>20</sub>H<sub>13</sub>N',
    '',
    '194-59-2',
    'STJXCDGCXVZHDU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='7H-dibenzo[c,g]carbazole'),
    (SELECT id from literature WHERE bibtexkey='3945'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='7H-dibenzo[c,g]carbazole'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'porphyrin',
    'C<sub>20</sub>H<sub>14</sub>N<sub>4</sub>',
    'porphin',
    '101-60-0',
    'RKCAIXNGYQCCAL-YYOYBPFYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='porphyrin'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dibenz[a,j]acridine',
    'C<sub>21</sub>H<sub>13</sub>N',
    '',
    '224-42-0',
    'ANUCHZVCBDOPOX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibenz[a,j]acridine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dibenz[a,h]acridine',
    'C<sub>21</sub>H<sub>13</sub>N',
    '',
    '226-36-8',
    'JNCSIWAONQTVCF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibenz[a,h]acridine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3,5-tricyclohexylhexahydro-1,3,5-triazine',
    'C<sub>21</sub>H<sub>39</sub>N<sub>3</sub>',
    '',
    '6281-14-7',
    'ZLLRUEJANKJPQE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with nitrogen (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-tricyclohexylhexahydro-1,3,5-triazine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-tricyclohexylhexahydro-1,3,5-triazine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-tricyclohexylhexahydro-1,3,5-triazine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-tricyclohexylhexahydro-1,3,5-triazine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Nitriles (C, H, N)',
    (SELECT id from categories WHERE catname='Organic species with nitrogen (N)'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cyano radical',
    'CN',
    '',
    '2074-87-5',
    'JEVCWSUVFOYBFI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitriles (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;4</sup>',
    '1400',
    'T',
    (SELECT id from species WHERE iupac='cyano radical'),
    (SELECT id from literature WHERE bibtexkey='763'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='763'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hydrogen cyanide',
    'HCN',
    'hydrocyanic acid',
    '74-90-8',
    'LELOWRISYMNNSU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitriles (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;2</sup>',
    '8200',
    'L',
    (SELECT id from species WHERE iupac='hydrogen cyanide'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;2</sup>',
    '8200',
    'L',
    (SELECT id from species WHERE iupac='hydrogen cyanide'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '4400',
    'L',
    (SELECT id from species WHERE iupac='hydrogen cyanide'),
    (SELECT id from literature WHERE bibtexkey='3085'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '5000',
    'L',
    (SELECT id from species WHERE iupac='hydrogen cyanide'),
    (SELECT id from literature WHERE bibtexkey='540'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;2</sup>',
    '8200',
    'M',
    (SELECT id from species WHERE iupac='hydrogen cyanide'),
    (SELECT id from literature WHERE bibtexkey='3533'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='hydrogen cyanide'),
    (SELECT id from literature WHERE bibtexkey='1481'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='hydrogen cyanide'),
    (SELECT id from literature WHERE bibtexkey='1915'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;2</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='hydrogen cyanide'),
    (SELECT id from literature WHERE bibtexkey='714'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '4200',
    'T',
    (SELECT id from species WHERE iupac='hydrogen cyanide'),
    (SELECT id from literature WHERE bibtexkey='3540'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;2</sup>',
    '2900',
    'X',
    (SELECT id from species WHERE iupac='hydrogen cyanide'),
    (SELECT id from literature WHERE bibtexkey='kotlik74'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'from3533',
    '3533', 'Value given here as quoted by Ma et&nbsp;al. (2010a).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3533'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='hydrogen cyanide'),
    (SELECT id from literature WHERE bibtexkey='gaffney84'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from715'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='715pH4'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydrogen cyanide'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydrogen cyanide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydrogen cyanide'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydrogen cyanide'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydrogen cyanide'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='hydrogen cyanide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='hydrogen cyanide'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethanenitrile',
    'CH<sub>3</sub>CN',
    'acetonitrile',
    '75-05-8',
    'WEVYAHXRMPXWCK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitriles (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;1</sup>',
    '4000',
    'L',
    (SELECT id from species WHERE iupac='ethanenitrile'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;1</sup>',
    '4000',
    'L',
    (SELECT id from species WHERE iupac='ethanenitrile'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;1</sup>',
    '4300',
    'L',
    (SELECT id from species WHERE iupac='ethanenitrile'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;1</sup>',
    '4000',
    'L',
    (SELECT id from species WHERE iupac='ethanenitrile'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;1</sup>',
    '4000',
    'L',
    (SELECT id from species WHERE iupac='ethanenitrile'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '4200',
    'L',
    (SELECT id from species WHERE iupac='ethanenitrile'),
    (SELECT id from literature WHERE bibtexkey='3621'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;1</sup>',
    '4100',
    'L',
    (SELECT id from species WHERE iupac='ethanenitrile'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;1</sup>',
    '4000',
    'L',
    (SELECT id from species WHERE iupac='ethanenitrile'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '3500',
    'L',
    (SELECT id from species WHERE iupac='ethanenitrile'),
    (SELECT id from literature WHERE bibtexkey='629'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;1</sup>',
    '6300',
    'M',
    (SELECT id from species WHERE iupac='ethanenitrile'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;1</sup>',
    '4000',
    'M',
    (SELECT id from species WHERE iupac='ethanenitrile'),
    (SELECT id from literature WHERE bibtexkey='2524'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethanenitrile'),
    (SELECT id from literature WHERE bibtexkey='2963'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '3300',
    'M',
    (SELECT id from species WHERE iupac='ethanenitrile'),
    (SELECT id from literature WHERE bibtexkey='3609'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethanenitrile'),
    (SELECT id from literature WHERE bibtexkey='3646'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;1</sup>',
    '4100',
    'M',
    (SELECT id from species WHERE iupac='ethanenitrile'),
    (SELECT id from literature WHERE bibtexkey='617'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethanenitrile'),
    (SELECT id from literature WHERE bibtexkey='2457'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethanenitrile'),
    (SELECT id from literature WHERE bibtexkey='3675'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;1</sup>',
    '3900',
    'M',
    (SELECT id from species WHERE iupac='ethanenitrile'),
    (SELECT id from literature WHERE bibtexkey='483'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;1</sup>',
    '4100',
    'M',
    (SELECT id from species WHERE iupac='ethanenitrile'),
    (SELECT id from literature WHERE bibtexkey='632'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethanenitrile'),
    (SELECT id from literature WHERE bibtexkey='2580'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethanenitrile'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='ethanenitrile'),
    (SELECT id from literature WHERE bibtexkey='714'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethanenitrile'),
    (SELECT id from literature WHERE bibtexkey='gaffney84'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from715'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanenitrile'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanenitrile'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanenitrile'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanenitrile'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanenitrile'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanenitrile'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4200',
    'Q',
    (SELECT id from species WHERE iupac='ethanenitrile'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanenitrile'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanenitrile'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanenitrile'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanenitrile'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanenitrile'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethanenitrile'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethanenitrile'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4300',
    '?',
    (SELECT id from species WHERE iupac='ethanenitrile'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethanenitrile'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethanenitrile'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethanenitrile'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propanenitrile',
    'C<sub>2</sub>H<sub>5</sub>CN',
    'propionitrile',
    '107-12-0',
    'FVSKHRXBFJPNKK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitriles (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '4500',
    'L',
    (SELECT id from species WHERE iupac='propanenitrile'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '4800',
    'L',
    (SELECT id from species WHERE iupac='propanenitrile'),
    (SELECT id from literature WHERE bibtexkey='3621'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;1</sup>',
    '6200',
    'M',
    (SELECT id from species WHERE iupac='propanenitrile'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '4600',
    'M',
    (SELECT id from species WHERE iupac='propanenitrile'),
    (SELECT id from literature WHERE bibtexkey='2524'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='propanenitrile'),
    (SELECT id from literature WHERE bibtexkey='3609'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at303K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='propanenitrile'),
    (SELECT id from literature WHERE bibtexkey='2457'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='propanenitrile'),
    (SELECT id from literature WHERE bibtexkey='2232'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='propanenitrile'),
    (SELECT id from literature WHERE bibtexkey='713'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propanenitrile'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propanenitrile'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='propanenitrile'),
    (SELECT id from literature WHERE bibtexkey='howard90'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanenitrile'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanenitrile'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanenitrile'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanenitrile'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanenitrile'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanenitrile'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanenitrile'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propanenitrile'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propanenitrile'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propanenitrile'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propanenitrile'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'butanenitrile',
    'C<sub>3</sub>H<sub>7</sub>CN',
    'butyronitrile',
    '109-74-0',
    'KVNRLNFWIYMESJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitriles (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '5100',
    'L',
    (SELECT id from species WHERE iupac='butanenitrile'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '5100',
    'L',
    (SELECT id from species WHERE iupac='butanenitrile'),
    (SELECT id from literature WHERE bibtexkey='3621'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '5100',
    'M',
    (SELECT id from species WHERE iupac='butanenitrile'),
    (SELECT id from literature WHERE bibtexkey='2524'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='butanenitrile'),
    (SELECT id from literature WHERE bibtexkey='2930'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='butanenitrile'),
    (SELECT id from literature WHERE bibtexkey='2457'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='butanenitrile'),
    (SELECT id from literature WHERE bibtexkey='2232'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='butanenitrile'),
    (SELECT id from literature WHERE bibtexkey='713'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='butanenitrile'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='butanenitrile'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanenitrile'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanenitrile'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanenitrile'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanenitrile'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanenitrile'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanenitrile'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4900',
    'Q',
    (SELECT id from species WHERE iupac='butanenitrile'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanenitrile'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanenitrile'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-Test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanenitrile'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanenitrile'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butanenitrile'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='butanenitrile'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='butanenitrile'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4700',
    '?',
    (SELECT id from species WHERE iupac='butanenitrile'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='butanenitrile'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='butanenitrile'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methylpropanenitrile',
    'C<sub>4</sub>H<sub>7</sub>N',
    'isobutyronitrile',
    '78-82-0',
    'LRDFRRGEGBBSRN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitriles (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '5200',
    'L',
    (SELECT id from species WHERE iupac='2-methylpropanenitrile'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '4800',
    'L',
    (SELECT id from species WHERE iupac='2-methylpropanenitrile'),
    (SELECT id from literature WHERE bibtexkey='3621'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methylpropanenitrile'),
    (SELECT id from literature WHERE bibtexkey='2457'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropanenitrile'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropanenitrile'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4900',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpropanenitrile'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5100',
    '?',
    (SELECT id from species WHERE iupac='2-methylpropanenitrile'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pentanenitrile',
    'C<sub>4</sub>H<sub>9</sub>CN',
    'butyl cyanide; valeronitrile',
    '110-59-8',
    'RFFFKMOABOFIDF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitriles (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '6100',
    'L',
    (SELECT id from species WHERE iupac='pentanenitrile'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '5500',
    'L',
    (SELECT id from species WHERE iupac='pentanenitrile'),
    (SELECT id from literature WHERE bibtexkey='3621'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='pentanenitrile'),
    (SELECT id from literature WHERE bibtexkey='2457'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pentanenitrile'),
    (SELECT id from literature WHERE bibtexkey='2388'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentanenitrile'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentanenitrile'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentanenitrile'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentanenitrile'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentanenitrile'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pentanenitrile'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hexanenitrile',
    'C<sub>6</sub>H<sub>11</sub>N',
    '',
    '628-73-9',
    'AILKHAQXUAOOFU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitriles (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='hexanenitrile'),
    (SELECT id from literature WHERE bibtexkey='3621'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanenitrile'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'heptanenitrile',
    'C<sub>7</sub>H<sub>13</sub>N',
    '',
    '629-08-3',
    'SDAXRHHPNYTELL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitriles (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptanenitrile'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'octanenitrile',
    'C<sub>8</sub>H<sub>15</sub>N',
    '',
    '124-12-9',
    'YSIMAPNUZAVQER-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitriles (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='octanenitrile'),
    (SELECT id from literature WHERE bibtexkey='3621'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octanenitrile'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nonanenitrile',
    'C<sub>9</sub>H<sub>17</sub>N',
    '',
    '2243-27-8',
    'PLZZPPHAMDJOSR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitriles (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonanenitrile'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'decanenitrile',
    'C<sub>10</sub>H<sub>19</sub>N',
    '',
    '1975-78-6',
    'HBZDPWBWBJMYRY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitriles (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decanenitrile'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'undecanenitrile',
    'C<sub>11</sub>H<sub>21</sub>N',
    '',
    '2244-07-7',
    'SZKKNEOUHLFYNA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitriles (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='undecanenitrile'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cyclohexanecarbonitrile',
    'C<sub>7</sub>H<sub>11</sub>N',
    '',
    '766-05-2',
    'VBWIZSYFQSOUFQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitriles (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexanecarbonitrile'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethanedinitrile',
    'C<sub>2</sub>N<sub>2</sub>',
    'cyanogen',
    '460-19-5',
    'JMANVNJQNLATNU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitriles (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethanedinitrile'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethanedinitrile'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethanedinitrile'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanedinitrile'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanedinitrile'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanedinitrile'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanedinitrile'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethanedinitrile'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethanedinitrile'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pentanedinitrile',
    'C<sub>5</sub>H<sub>6</sub>N<sub>2</sub>',
    '',
    '544-13-8',
    'ZTOMUSMDRMJOTH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitriles (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>2</sup>',
    '7600',
    'L',
    (SELECT id from species WHERE iupac='pentanedinitrile'),
    (SELECT id from literature WHERE bibtexkey='3621'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hexanedinitrile',
    'C<sub>6</sub>H<sub>8</sub>N<sub>2</sub>',
    'adiponitrile',
    '111-69-3',
    'BTGRAWJCKBQKAO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitriles (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '8000',
    'L',
    (SELECT id from species WHERE iupac='hexanedinitrile'),
    (SELECT id from literature WHERE bibtexkey='3621'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexanedinitrile'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexanedinitrile'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexanedinitrile'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexanedinitrile'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanedinitrile'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanedinitrile'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methylpentanedinitrile',
    'C<sub>6</sub>H<sub>8</sub>N<sub>2</sub>',
    '',
    '4553-62-2',
    'FPPLREPCQJZDAQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitriles (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylpentanedinitrile'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tetramethylbutanedinitrile',
    'C<sub>8</sub>H<sub>12</sub>N<sub>2</sub>',
    '',
    '3333-52-6',
    'ZVQXQPNJHRNGID-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitriles (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetramethylbutanedinitrile'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-propenenitrile',
    'C<sub>3</sub>H<sub>3</sub>N',
    'acrylonitrile',
    '107-13-1',
    'NLHHRLWOUZZQLW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitriles (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '3900',
    'L',
    (SELECT id from species WHERE iupac='2-propenenitrile'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '6800',
    'M',
    (SELECT id from species WHERE iupac='2-propenenitrile'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-propenenitrile'),
    (SELECT id from literature WHERE bibtexkey='3609'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at303K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-propenenitrile'),
    (SELECT id from literature WHERE bibtexkey='3646'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-propenenitrile'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;2</sup>',
    '3400',
    'V',
    (SELECT id from species WHERE iupac='2-propenenitrile'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-propenenitrile'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-propenenitrile'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-propenenitrile'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '2800',
    'X',
    (SELECT id from species WHERE iupac='2-propenenitrile'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='2-propenenitrile'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='2-propenenitrile'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propenenitrile'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propenenitrile'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propenenitrile'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propenenitrile'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3600',
    'Q',
    (SELECT id from species WHERE iupac='2-propenenitrile'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-propenenitrile'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-propenenitrile'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3600',
    '?',
    (SELECT id from species WHERE iupac='2-propenenitrile'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-propenenitrile'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-butenenitrile',
    'C<sub>4</sub>H<sub>5</sub>N',
    'crotononitrile',
    '4786-20-3',
    'NKKMVIVFRUYPLQ-NSCUHMNNSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitriles (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-butenenitrile'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butenenitrile'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butenenitrile'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-butenenitrile',
    'C<sub>4</sub>H<sub>5</sub>N',
    'vinylacetonitrile',
    '109-75-1',
    'SJNALLRHIVGIBI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitriles (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '4900',
    'L',
    (SELECT id from species WHERE iupac='3-butenenitrile'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-2-propene nitrile',
    'C<sub>4</sub>H<sub>5</sub>N',
    'methacrylonitrile',
    '126-98-7',
    'GYCMBHHDWRMZGG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitriles (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '4200',
    'L',
    (SELECT id from species WHERE iupac='2-methyl-2-propene nitrile'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;2</sup>',
    '6700',
    'M',
    (SELECT id from species WHERE iupac='2-methyl-2-propene nitrile'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-2-propene nitrile'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-2-propene nitrile'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propene nitrile'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propene nitrile'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propene nitrile'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4000',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propene nitrile'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4600',
    '?',
    (SELECT id from species WHERE iupac='2-methyl-2-propene nitrile'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benzenenitrile',
    'C<sub>6</sub>H<sub>5</sub>CN',
    'benzonitrile',
    '100-47-0',
    'JFDZBHWFFUWGJE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitriles (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '5600',
    'L',
    (SELECT id from species WHERE iupac='benzenenitrile'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '5100',
    'M',
    (SELECT id from species WHERE iupac='benzenenitrile'),
    (SELECT id from literature WHERE bibtexkey='2987'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzenenitrile'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzenenitrile'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzenenitrile'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzenenitrile'),
    (SELECT id from literature WHERE bibtexkey='2165'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzenenitrile'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzenenitrile'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;1</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='benzenenitrile'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzenenitrile'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzenenitrile'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzenenitrile'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzenenitrile'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5900',
    'Q',
    (SELECT id from species WHERE iupac='benzenenitrile'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzenenitrile'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzenenitrile'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzenenitrile'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6400',
    '?',
    (SELECT id from species WHERE iupac='benzenenitrile'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='benzenenitrile'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at373K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='benzenenitrile'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at373K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='benzenenitrile'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-pyridinecarbonitrile',
    'C<sub>6</sub>H<sub>4</sub>N<sub>2</sub>',
    '',
    '100-70-9',
    'FFNVQNRYTPFDDP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitriles (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pyridinecarbonitrile'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3''-iminobispropanenitrile',
    'C<sub>6</sub>H<sub>9</sub>N<sub>3</sub>',
    '',
    '111-94-4',
    'SBAJRGRUGUQKAF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitriles (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3''-iminobispropanenitrile'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methylbenzonitrile',
    'C<sub>8</sub>H<sub>7</sub>N',
    'o-tolunitrile',
    '529-19-1',
    'NWPNXBQSRGKSJB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitriles (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylbenzonitrile'),
    (SELECT id from literature WHERE bibtexkey='2165'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methylbenzonitrile',
    'C<sub>8</sub>H<sub>7</sub>N',
    'm-tolunitrile',
    '620-22-4',
    'BOHCMQZJWOGWTA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitriles (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbenzonitrile'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbenzonitrile'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbenzonitrile'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbenzonitrile'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benzeneacetonitrile',
    'C<sub>8</sub>H<sub>7</sub>N',
    'phenylacetonitrile',
    '140-29-4',
    'SUSQOBVLVYHIEX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitriles (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '6800',
    'L',
    (SELECT id from species WHERE iupac='benzeneacetonitrile'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzeneacetonitrile'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzeneacetonitrile'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6200',
    'Q',
    (SELECT id from species WHERE iupac='benzeneacetonitrile'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5100',
    '?',
    (SELECT id from species WHERE iupac='benzeneacetonitrile'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-benzenedicarbonitrile',
    'C<sub>8</sub>H<sub>4</sub>N<sub>2</sub>',
    '',
    '91-15-6',
    'XQZYPMVTSDWCCE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitriles (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-benzenedicarbonitrile'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,7-dimethyl-2,6-octadienenitrile',
    'C<sub>10</sub>H<sub>15</sub>N',
    'geranyl nitrile',
    '5146-66-7',
    'HLCSDJLATUNSSI-JXMROGBWSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitriles (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3,7-dimethyl-2,6-octadienenitrile'),
    (SELECT id from literature WHERE bibtexkey='2955'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2''-azobis(2-methylbutyronitrile)',
    'C<sub>10</sub>H<sub>16</sub>N<sub>4</sub>',
    '',
    '13472-08-7',
    'AVTLBBWTUPQRAY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitriles (C, H, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2''-azobis(2-methylbutyronitrile)'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2''-azobis(2-methylbutyronitrile)'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2''-azobis(2-methylbutyronitrile)'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2''-azobis(2-methylbutyronitrile)'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Amines, amides, amino acids (C, H, O, N)',
    (SELECT id from categories WHERE catname='Organic species with nitrogen (N)'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'formamide',
    'CH<sub>3</sub>NO',
    '',
    '75-12-7',
    'ZHNUHDYFZUAESO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='formamide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='formamide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='formamide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl nitrite',
    'CH<sub>3</sub>ONO',
    '',
    '624-91-9',
    'BLLFVUPNHCTMSV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl nitrite'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'urea',
    'CH<sub>4</sub>N<sub>2</sub>O',
    '',
    '57-13-6',
    'XSQUKJJJFZCRTK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='urea'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='urea'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>7</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='urea'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>7</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='urea'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='urea'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethanolamine',
    'HOC<sub>2</sub>H<sub>4</sub>NH<sub>2</sub>',
    '',
    '141-43-5',
    'HZAXFHJVJLSVMW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>3</sup>',
    '8300',
    'M',
    (SELECT id from species WHERE iupac='ethanolamine'),
    (SELECT id from literature WHERE bibtexkey='3654'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3654'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethanolamine'),
    (SELECT id from literature WHERE bibtexkey='641'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanolamine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>2</sup>',
    '5800',
    '?',
    (SELECT id from species WHERE iupac='ethanolamine'),
    (SELECT id from literature WHERE bibtexkey='3584'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3584MEA',
    '3584,3654', 'Nguyen (2013) refer to Kim et&nbsp;al. (2008) as the source, but this value cannot be found there.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3584MEA'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1''-azodiformamide',
    'C<sub>2</sub>H<sub>4</sub>N<sub>4</sub>O<sub>2</sub>',
    '',
    '123-77-3',
    'XOZUGNYVDXMRKW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>7</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1''-azodiformamide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyl nitrite',
    'C<sub>2</sub>H<sub>5</sub>ONO',
    '',
    '109-95-5',
    'QQZWEECEMNQSTG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl nitrite'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'carbamic acid, methyl ester',
    'C<sub>2</sub>H<sub>5</sub>NO<sub>2</sub>',
    '',
    '598-55-0',
    'GTCAXTIRRLKXRU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='carbamic acid, methyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'acetaldoxime',
    'C<sub>2</sub>H<sub>5</sub>NO',
    'acetaldehyde oxime',
    '107-29-9',
    'FZENGILVLUJGJX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='acetaldoxime'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethanamide',
    'C<sub>2</sub>H<sub>5</sub>NO',
    'acetamide',
    '60-35-5',
    'DLFVBJFMPXGRIB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethanamide'),
    (SELECT id from literature WHERE bibtexkey='2379'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethanamide'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethanamide'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethanamide'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanamide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanamide'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanamide'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanamide'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanamide'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanamide'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanamide'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-methylmethanamide',
    'C<sub>2</sub>H<sub>5</sub>NO',
    'N-methylformamide',
    '123-39-7',
    'ATHHXGZTWNVVOU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '7200',
    'L',
    (SELECT id from species WHERE iupac='N-methylmethanamide'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '7200',
    'L',
    (SELECT id from species WHERE iupac='N-methylmethanamide'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '7200',
    'L',
    (SELECT id from species WHERE iupac='N-methylmethanamide'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '7600',
    'M',
    (SELECT id from species WHERE iupac='N-methylmethanamide'),
    (SELECT id from literature WHERE bibtexkey='2601'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='N-methylmethanamide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='N-methylmethanamide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-methylmethanamide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-methylmethanamide'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-methylmethanamide'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-nitrosodimethylamine',
    'C<sub>2</sub>H<sub>6</sub>N<sub>2</sub>O',
    '',
    '62-75-9',
    'UMFJAHHVKNCGLG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9',
    '',
    'L',
    (SELECT id from species WHERE iupac='N-nitrosodimethylamine'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9',
    '',
    'L',
    (SELECT id from species WHERE iupac='N-nitrosodimethylamine'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '13000',
    'M',
    (SELECT id from species WHERE iupac='N-nitrosodimethylamine'),
    (SELECT id from literature WHERE bibtexkey='3680'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1',
    '',
    'M',
    (SELECT id from species WHERE iupac='N-nitrosodimethylamine'),
    (SELECT id from literature WHERE bibtexkey='3524'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1',
    '6400',
    'M',
    (SELECT id from species WHERE iupac='N-nitrosodimethylamine'),
    (SELECT id from literature WHERE bibtexkey='3080'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2',
    '',
    'M',
    (SELECT id from species WHERE iupac='N-nitrosodimethylamine'),
    (SELECT id from literature WHERE bibtexkey='3082'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='N-nitrosodimethylamine'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-nitrosodimethylamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-nitrosodimethylamine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='N-nitrosodimethylamine'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methylnitrosourea',
    'C<sub>2</sub>H<sub>5</sub>N<sub>3</sub>O<sub>2</sub>',
    '',
    '684-93-5',
    'ZRKWMRDKSOPRRS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 1.9&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methylnitrosourea'),
    (SELECT id from literature WHERE bibtexkey='3082'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethanediamide',
    'C<sub>2</sub>H<sub>4</sub>N<sub>2</sub>O<sub>2</sub>',
    '',
    '471-46-5',
    'YIKSCQDJHCMVMK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethanediamide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanediamide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nitrosoazetidine',
    'C<sub>3</sub>H<sub>6</sub>N<sub>2</sub>O',
    '',
    '15216-10-1',
    'SNKTZBNDUVWOAZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 1.9&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='nitrosoazetidine'),
    (SELECT id from literature WHERE bibtexkey='3082'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methylnitrosoacetamide',
    'C<sub>3</sub>H<sub>6</sub>N<sub>2</sub>O<sub>2</sub>',
    '',
    '7417-67-6',
    'FFLFWNRFMZRFKU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methylnitrosoacetamide'),
    (SELECT id from literature WHERE bibtexkey='3082'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethylnitrosocyanamide',
    'C<sub>3</sub>H<sub>5</sub>N<sub>3</sub>O',
    '',
    '38434-77-4',
    'LMIMSGCBKHFTDY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethylnitrosocyanamide'),
    (SELECT id from literature WHERE bibtexkey='3082'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-propenamide',
    'C<sub>3</sub>H<sub>5</sub>NO',
    'acrylamide',
    '79-06-1',
    'HRPVXLWXLXDGHG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-propenamide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-propenamide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-propenamide'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-propenamide'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-propenamide'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-propenamide'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at303K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propenamide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propenamide'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propenamide'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propenamide'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propenamide'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '8400',
    'Q',
    (SELECT id from species WHERE iupac='2-propenamide'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7900',
    '?',
    (SELECT id from species WHERE iupac='2-propenamide'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methylvinylnitrosamine',
    'C<sub>3</sub>H<sub>6</sub>N<sub>2</sub>O',
    'N-nitrosomethylvinylamine',
    '4549-40-0',
    'AWZVYNHQGTZJIH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylvinylnitrosamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'urethane',
    'C<sub>3</sub>H<sub>7</sub>NO<sub>2</sub>',
    '',
    '51-79-6',
    'JOYRKODLDBILNP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='urethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='urethane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='urethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='urethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='urethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='urethane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propanamide',
    'C<sub>3</sub>H<sub>7</sub>NO',
    'propionamide',
    '79-05-0',
    'QLNJFJADRCOGBJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>3</sup>',
    '8800',
    'T',
    (SELECT id from species WHERE iupac='propanamide'),
    (SELECT id from literature WHERE bibtexkey='3674'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N,N-dimethylmethanamide',
    'C<sub>3</sub>H<sub>7</sub>NO',
    'N,N-dimethylformamide',
    '68-12-2',
    'ZMXDDKWLCZADIW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '6600',
    'L',
    (SELECT id from species WHERE iupac='N,N-dimethylmethanamide'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '6600',
    'L',
    (SELECT id from species WHERE iupac='N,N-dimethylmethanamide'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '7700',
    'L',
    (SELECT id from species WHERE iupac='N,N-dimethylmethanamide'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3518-68-12-2-consicheck',
    '3518', 'Values at 298&nbsp;K in Tables&nbsp;C2 and C5 of Brockbank (2013) are inconsistent, with 7&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3518-68-12-2-consicheck'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '7500',
    'M',
    (SELECT id from species WHERE iupac='N,N-dimethylmethanamide'),
    (SELECT id from literature WHERE bibtexkey='2601'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>2</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='N,N-dimethylmethanamide'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N-dimethylmethanamide'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N-dimethylmethanamide'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N-dimethylmethanamide'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N-dimethylmethanamide'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N-dimethylmethanamide'),
    (SELECT id from literature WHERE bibtexkey='2531'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-methylacetamide',
    'C<sub>3</sub>H<sub>7</sub>NO',
    '',
    '79-16-3',
    'OHLUUHNLEMFGTQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '7600',
    'L',
    (SELECT id from species WHERE iupac='N-methylacetamide'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '7600',
    'L',
    (SELECT id from species WHERE iupac='N-methylacetamide'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>3</sup>',
    '8900',
    'M',
    (SELECT id from species WHERE iupac='N-methylacetamide'),
    (SELECT id from literature WHERE bibtexkey='2601'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='N-methylacetamide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='N-methylacetamide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-methylacetamide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-methylacetamide'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-methyl-N-nitrosoethanamine',
    'C<sub>3</sub>H<sub>8</sub>N<sub>2</sub>O',
    'N-nitrosomethylethylamine',
    '10595-95-6',
    'RTDCJKARQCRONF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-methyl-N-nitrosoethanamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methoxyethanamine',
    'C<sub>3</sub>H<sub>9</sub>NO',
    '2-methoxyethylamine',
    '109-85-3',
    'ASUDFOJKTJLAIK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '7600',
    'T',
    (SELECT id from species WHERE iupac='2-methoxyethanamine'),
    (SELECT id from literature WHERE bibtexkey='2381'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-(methylamino)ethanol',
    'C<sub>3</sub>H<sub>9</sub>NO',
    '',
    '109-83-1',
    'OPKOKAMJFNKNAS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-(methylamino)ethanol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-amino-2-propanol',
    'C<sub>3</sub>H<sub>9</sub>NO',
    '',
    '78-96-6',
    'HXKKHQJGJAFBHI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-amino-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-642'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-amino-1-propanol',
    'C<sub>3</sub>H<sub>9</sub>NO',
    'alaninol',
    '6168-72-5',
    'BKMMTJMQCTUHRP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '7700',
    'M',
    (SELECT id from species WHERE iupac='2-amino-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3584'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-nitroso-N-methylurethane',
    'C<sub>4</sub>H<sub>8</sub>N<sub>2</sub>O<sub>3</sub>',
    'N-nitroso-N-methylurethane',
    '615-53-2',
    'CAUBWLYZCDDYEF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='N-nitroso-N-methylurethane'),
    (SELECT id from literature WHERE bibtexkey='3082'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'V',
    (SELECT id from species WHERE iupac='N-nitroso-N-methylurethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'V',
    (SELECT id from species WHERE iupac='N-nitroso-N-methylurethane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-nitroso-N-methylurethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-nitroso-N-methylurethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dinitrosopiperazine',
    'C<sub>4</sub>H<sub>8</sub>N<sub>4</sub>O<sub>2</sub>',
    '',
    '140-79-4',
    'WNSYEWGYAFFSSQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 1.9&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dinitrosopiperazine'),
    (SELECT id from literature WHERE bibtexkey='3082'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-amino-3(methylamino)propionic acid',
    'C<sub>4</sub>H<sub>10</sub>N<sub>2</sub>O<sub>2</sub>',
    '3-(methylamino)-(DL)-alanine',
    '16676-91-8',
    'UJVHVMNGOZXSOZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-amino-3(methylamino)propionic acid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-nitrosodiethanolamine',
    'C<sub>4</sub>H<sub>10</sub>N<sub>2</sub>O<sub>3</sub>',
    '',
    '1116-54-7',
    'YFCDLVPYFMHRQZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-nitrosodiethanolamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-nitrosodiethylamine',
    'C<sub>4</sub>H<sub>10</sub>N<sub>2</sub>O',
    '',
    '55-18-5',
    'WBNQDOYYEUMPFS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '3800',
    'M',
    (SELECT id from species WHERE iupac='N-nitrosodiethylamine'),
    (SELECT id from literature WHERE bibtexkey='3680'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6',
    '6300',
    'M',
    (SELECT id from species WHERE iupac='N-nitrosodiethylamine'),
    (SELECT id from literature WHERE bibtexkey='3080'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'M',
    (SELECT id from species WHERE iupac='N-nitrosodiethylamine'),
    (SELECT id from literature WHERE bibtexkey='3082'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-nitrosodiethylamine'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-nitrosodiethylamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-nitrosodiethylamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-nitrosodiethylamine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    '?',
    (SELECT id from species WHERE iupac='N-nitrosodiethylamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diethanolamine',
    'C<sub>4</sub>H<sub>11</sub>NO<sub>2</sub>',
    '',
    '111-42-2',
    'ZBCBWPMODOFKDW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>3</sup>',
    '1300',
    'M',
    (SELECT id from species WHERE iupac='diethanolamine'),
    (SELECT id from literature WHERE bibtexkey='3584'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diethanolamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diethanolamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethanolamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diglycolamine',
    'C<sub>4</sub>H<sub>11</sub>NO<sub>2</sub>',
    '',
    '929-06-6',
    'GIAFURWZWWWBQT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>3</sup>',
    '3700',
    'M',
    (SELECT id from species WHERE iupac='diglycolamine'),
    (SELECT id from literature WHERE bibtexkey='3584'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HTdep_r2_lessthan_0.9'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methoxy-1-propanamine',
    'C<sub>4</sub>H<sub>11</sub>NO',
    '3-methoxypropylamine',
    '5332-73-0',
    'FAXDZWQIWUSWJH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3-methoxy-1-propanamine'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at313K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>1</sup>',
    '8700',
    'T',
    (SELECT id from species WHERE iupac='3-methoxy-1-propanamine'),
    (SELECT id from literature WHERE bibtexkey='2381'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methoxy-1-propanamine'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3426'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methoxy-1-propanamine'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-amino-2-methyl-1-propanol',
    'C<sub>4</sub>H<sub>11</sub>NO',
    '',
    '124-68-5',
    'CBTVGIZVANVGBH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-amino-2-methyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at313K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>2</sup>',
    '8500',
    'M',
    (SELECT id from species WHERE iupac='2-amino-2-methyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3584'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-amino-2-methyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3426'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-amino-2-methyl-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N,N-dimethylaminoethanol',
    'C<sub>4</sub>H<sub>11</sub>NO',
    'dimethylethanolamine',
    '108-01-0',
    'UEEJHVSXFDXPFK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>1</sup>',
    '7900',
    'M',
    (SELECT id from species WHERE iupac='N,N-dimethylaminoethanol'),
    (SELECT id from literature WHERE bibtexkey='3584'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='N,N-dimethylaminoethanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N-dimethylaminoethanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-[(2-aminoethyl)amino]ethanol',
    'C<sub>4</sub>H<sub>12</sub>N<sub>2</sub>O',
    '',
    '111-41-1',
    'LHIJANUOQQMGNT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-[(2-aminoethyl)amino]ethanol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tetramethylammonium hydroxide',
    'C<sub>4</sub>H<sub>13</sub>NO',
    '',
    '75-59-2',
    'WGTYBPLFGIVFAS-UHFFFAOYSA-M',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetramethylammonium hydroxide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methacrylamide',
    'C<sub>4</sub>H<sub>7</sub>NO',
    '',
    '79-39-0',
    'FQPSGWSUVKBHSU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methacrylamide'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'acetone cyanohydrin',
    'C<sub>4</sub>H<sub>7</sub>NO',
    '',
    '75-86-5',
    'MWFMGBPGAXYFAR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='acetone cyanohydrin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'carbamic acid, 1-methylethyl ester',
    'C<sub>4</sub>H<sub>9</sub>NO<sub>2</sub>',
    '',
    '1746-77-6',
    'OVPLZYJGTGDFNB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='carbamic acid, 1-methylethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propylcarbamate',
    'C<sub>4</sub>H<sub>9</sub>NO<sub>2</sub>',
    '',
    '627-12-3',
    'YNTOKMNHRPSGFU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propylcarbamate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'butanamide',
    'C<sub>4</sub>H<sub>9</sub>NO',
    '',
    '541-35-5',
    'DNSISZSEWVHGLH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='butanamide'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N,N-dimethylacetamide',
    'C<sub>4</sub>H<sub>9</sub>NO',
    '',
    '127-19-5',
    'FXHOOIRPVKKKFG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>1</sup>',
    '7800',
    'L',
    (SELECT id from species WHERE iupac='N,N-dimethylacetamide'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>1</sup>',
    '7800',
    'L',
    (SELECT id from species WHERE iupac='N,N-dimethylacetamide'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>2</sup>',
    '8000',
    'L',
    (SELECT id from species WHERE iupac='N,N-dimethylacetamide'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>2</sup>',
    '8600',
    'M',
    (SELECT id from species WHERE iupac='N,N-dimethylacetamide'),
    (SELECT id from literature WHERE bibtexkey='2601'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N-dimethylacetamide'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N-dimethylacetamide'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N-dimethylacetamide'),
    (SELECT id from literature WHERE bibtexkey='2531'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-butanone, oxime',
    'C<sub>4</sub>H<sub>9</sub>NO',
    '',
    '96-29-7',
    'WHIVNJATOVLWBW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-butanone, oxime'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nitrosoethylurethane',
    'C<sub>5</sub>H<sub>10</sub>N<sub>2</sub>O<sub>3</sub>',
    'N-ethyl-N-nitrosourethane',
    '614-95-9',
    'RAUQLNDTFONODT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nitrosoethylurethane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N,N-diethylmethanamide',
    'C<sub>5</sub>H<sub>11</sub>NO',
    'N,N-diethylformamide',
    '617-84-5',
    'SUAKHGWARZSWIH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N-diethylmethanamide'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-nitroso-N-butylurea',
    'C<sub>5</sub>H<sub>11</sub>N<sub>3</sub>O<sub>2</sub>',
    '',
    '869-01-2',
    'LSWOCDLIYSKTRX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-nitroso-N-butylurea'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-methyldiethanolamine',
    'C<sub>5</sub>H<sub>13</sub>NO<sub>2</sub>',
    '',
    '105-59-9',
    'CRVGTESFCCXCTH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='N-methyldiethanolamine'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at313K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>3</sup>',
    '3800',
    'M',
    (SELECT id from species WHERE iupac='N-methyldiethanolamine'),
    (SELECT id from literature WHERE bibtexkey='3584'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>5</sup>',
    '12000',
    'M',
    (SELECT id from species WHERE iupac='N-methyldiethanolamine'),
    (SELECT id from literature WHERE bibtexkey='3654'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3654'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='N-methyldiethanolamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='N-methyldiethanolamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-methyldiethanolamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-methyldiethanolamine'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3426'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-methyldiethanolamine'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methylbutylnitrosamine',
    'C<sub>5</sub>H<sub>12</sub>N<sub>2</sub>O',
    '',
    '7068-83-9',
    'PKTSCJXWLVREKX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'M',
    (SELECT id from species WHERE iupac='methylbutylnitrosamine'),
    (SELECT id from literature WHERE bibtexkey='3082'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-(isopropylamino)ethanol',
    'C<sub>5</sub>H<sub>13</sub>NO',
    '',
    '109-56-8',
    'RILLZYSZSDGYGV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-(isopropylamino)ethanol'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at313K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(isopropylamino)ethanol'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3426'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(isopropylamino)ethanol'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-(dimethylamino)-1,2-propanediol',
    'C<sub>5</sub>H<sub>13</sub>NO<sub>2</sub>',
    '',
    '623-57-4',
    'QCMHUGYTOGXZIW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3-(dimethylamino)-1,2-propanediol'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at313K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-(dimethylamino)-1,2-propanediol'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3426'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-(dimethylamino)-1,2-propanediol'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-amino-2-ethyl-1,3-propanediol',
    'C<sub>5</sub>H<sub>13</sub>NO<sub>2</sub>',
    '',
    '115-70-8',
    'IOAOAKDONABGPZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-amino-2-ethyl-1,3-propanediol'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at313K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-amino-2-ethyl-1,3-propanediol'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3426'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-amino-2-ethyl-1,3-propanediol'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'daminozide',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>3</sub>',
    '',
    '1596-84-5',
    'NOQGZXFMHARMLW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='daminozide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='daminozide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='daminozide'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methylpentylnitrosamine',
    'C<sub>6</sub>H<sub>14</sub>N<sub>2</sub>O',
    '',
    '13256-07-0',
    'KSFCDINBDBFFSI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'M',
    (SELECT id from species WHERE iupac='methylpentylnitrosamine'),
    (SELECT id from literature WHERE bibtexkey='3082'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethylbutylnitrosamine',
    'C<sub>6</sub>H<sub>14</sub>N<sub>2</sub>O',
    '',
    '4549-44-4',
    'ZGMCNGHHUQZNIH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethylbutylnitrosamine'),
    (SELECT id from literature WHERE bibtexkey='3082'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nitrosohexamethyleneimine',
    'C<sub>6</sub>H<sub>12</sub>N<sub>2</sub>O',
    '',
    '932-83-2',
    'UZMVSVHUTOAPTD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='nitrosohexamethyleneimine'),
    (SELECT id from literature WHERE bibtexkey='3082'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6-dimethylnitrosomorpholine',
    'C<sub>6</sub>H<sub>12</sub>N<sub>2</sub>O<sub>2</sub>',
    '',
    '1456-28-6',
    'DPYMAXOKJUBANR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,6-dimethylnitrosomorpholine'),
    (SELECT id from literature WHERE bibtexkey='3082'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6-dimethyldinitrosopiperazine',
    'C<sub>6</sub>H<sub>12</sub>N<sub>4</sub>O<sub>2</sub>',
    '',
    '55380-34-2',
    'JIWAGFGPBKDFQN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 1.9&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,6-dimethyldinitrosopiperazine'),
    (SELECT id from literature WHERE bibtexkey='3082'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-(1-methylethyl)-2-propenamide',
    'C<sub>6</sub>H<sub>11</sub>NO',
    'N-isopropylacrylamide',
    '2210-25-5',
    'QNILTEGFHQSKFF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-(1-methylethyl)-2-propenamide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hexanamide',
    'C<sub>6</sub>H<sub>13</sub>NO',
    '',
    '628-02-4',
    'ALBYIUDWACNRRB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='hexanamide'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-butylacetamide',
    'C<sub>6</sub>H<sub>13</sub>NO',
    '',
    '1119-49-9',
    'GYLDXXLJMRTVSS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='N-butylacetamide'),
    (SELECT id from literature WHERE bibtexkey='2014'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-butylacetamide'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-(1-methylethyl)-N-nitroso-2-propanamine',
    'C<sub>6</sub>H<sub>14</sub>N<sub>2</sub>O',
    'nitrosodiisopropylamine',
    '601-77-4',
    'AUIKJTGFPFLMFP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'M',
    (SELECT id from species WHERE iupac='N-(1-methylethyl)-N-nitroso-2-propanamine'),
    (SELECT id from literature WHERE bibtexkey='3082'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-(1-methylethyl)-N-nitroso-2-propanamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-(1-methylethyl)-N-nitroso-2-propanamine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-nitrosodipropylamine',
    'C<sub>6</sub>H<sub>14</sub>N<sub>2</sub>O',
    'N,N-dipropylnitrosamine',
    '621-64-7',
    'YLKFDHTUAUWZPQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'M',
    (SELECT id from species WHERE iupac='N-nitrosodipropylamine'),
    (SELECT id from literature WHERE bibtexkey='3082'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '',
    'V',
    (SELECT id from species WHERE iupac='N-nitrosodipropylamine'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '',
    'V',
    (SELECT id from species WHERE iupac='N-nitrosodipropylamine'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'C',
    (SELECT id from species WHERE iupac='N-nitrosodipropylamine'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-nitrosodipropylamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-nitrosodipropylamine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-(2-hydroxyethyl)piperazine',
    'C<sub>6</sub>H<sub>14</sub>N<sub>2</sub>O',
    '',
    '103-76-4',
    'WFCSWCVEJLETKA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>3</sup>',
    '6400',
    'M',
    (SELECT id from species WHERE iupac='N-(2-hydroxyethyl)piperazine'),
    (SELECT id from literature WHERE bibtexkey='3584'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HTdep_r2_lessthan_0.9'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-ethyldiethanolamine',
    'C<sub>6</sub>H<sub>15</sub>NO<sub>2</sub>',
    '',
    '139-87-7',
    'AKNUHUCEWALCOI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-ethyldiethanolamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'triethanolamine',
    'C<sub>6</sub>H<sub>15</sub>NO<sub>3</sub>',
    '',
    '102-71-6',
    'GSEJCLTVZPLZKY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>7</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='triethanolamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>7</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='triethanolamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triethanolamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'o-aminophenol',
    'C<sub>6</sub>H<sub>7</sub>NO',
    '2-aminophenol',
    '95-55-6',
    'CDAWCLOXVUBKRW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='o-aminophenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-aminophenol',
    'C<sub>6</sub>H<sub>7</sub>NO',
    '',
    '123-30-8',
    'PLIKAWJENQZMHA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-aminophenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-aminophenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-aminophenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-aminophenol',
    'C<sub>6</sub>H<sub>7</sub>NO',
    '',
    '591-27-5',
    'CWLKGDAVCFYWJK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-aminophenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-(2-hydroxyethyl)morpholine',
    'C<sub>6</sub>H<sub>13</sub>NO<sub>2</sub>',
    '',
    '622-40-2',
    'KKFDCBRMNNSAAW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='4-(2-hydroxyethyl)morpholine'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at313K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-(2-hydroxyethyl)morpholine'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3426'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-(2-hydroxyethyl)morpholine'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-hydroxy-N-methylpiperidine',
    'C<sub>6</sub>H<sub>13</sub>NO',
    '',
    '106-52-5',
    'BAUWRHPMUVYFOD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='4-hydroxy-N-methylpiperidine'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at313K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-hydroxy-N-methylpiperidine'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3426'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-hydroxy-N-methylpiperidine'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimethylaminoethoxyethanol',
    'C<sub>6</sub>H<sub>15</sub>NO<sub>2</sub>',
    '',
    '1704-62-7',
    'YSAANLSYLSUVHB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dimethylaminoethoxyethanol'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at313K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>3</sup>',
    '8500',
    'M',
    (SELECT id from species WHERE iupac='dimethylaminoethoxyethanol'),
    (SELECT id from literature WHERE bibtexkey='3584'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylaminoethoxyethanol'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3426'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylaminoethoxyethanol'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-(diethylamino)ethanol',
    'C<sub>6</sub>H<sub>15</sub>NO',
    '',
    '100-37-8',
    'BFSVOASYOCHEOV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-(diethylamino)ethanol'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at313K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(diethylamino)ethanol'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3426'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(diethylamino)ethanol'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bis(2-methoxyethyl)amine',
    'C<sub>6</sub>H<sub>15</sub>NO<sub>2</sub>',
    '',
    '111-95-5',
    'IBZKBSXREAQDTO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='bis(2-methoxyethyl)amine'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at313K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis(2-methoxyethyl)amine'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3426'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis(2-methoxyethyl)amine'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cyclohexanone oxime',
    'C<sub>6</sub>H<sub>11</sub>NO',
    '',
    '100-64-1',
    'VEZUQRBDRNJBJY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cyclohexanone oxime'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexanone oxime'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'p-diaminoanisole',
    'C<sub>7</sub>H<sub>10</sub>N<sub>2</sub>O',
    '2-methoxy-1,4-benzenediamine',
    '5307-02-8',
    'HGUYBLVGLMAUFF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='p-diaminoanisole'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methoxy-1,3-benzenediamine',
    'C<sub>7</sub>H<sub>10</sub>N<sub>2</sub>O',
    '',
    '615-05-4',
    'BAHPQISAXRFLCL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methoxy-1,3-benzenediamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-cyano-N-[(ethylamino)carbonyl]-2-(methoxyimino)acetamide',
    'C<sub>7</sub>H<sub>10</sub>N<sub>4</sub>O<sub>3</sub>',
    'cymoxanil',
    '57966-95-7',
    'XERJKGMBORTKEO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-cyano-N-[(ethylamino)carbonyl]-2-(methoxyimino)acetamide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-cyano-N-[(ethylamino)carbonyl]-2-(methoxyimino)acetamide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-cyano-N-[(ethylamino)carbonyl]-2-(methoxyimino)acetamide'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'from3729',
    '3729', 'Value given here as quoted by Goodarzi et&nbsp;al. (2010).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-cyano-N-[(ethylamino)carbonyl]-2-(methoxyimino)acetamide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-cyano-N-[(ethylamino)carbonyl]-2-(methoxyimino)acetamide'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3729_BR',
    '3729', 'Goodarzi et&nbsp;al. (2010) compared several QSPR methods and found that the Levenberg-Marquardt algorithm with Bayesian regularization produces the best results. Values obtained with other methods can be found in their supplement.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3729_val',
    '', 'Value from the validation set.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-cyano-N-[(ethylamino)carbonyl]-2-(methoxyimino)acetamide'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH7'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-cyano-N-[(ethylamino)carbonyl]-2-(methoxyimino)acetamide'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3549-pH5',
    '', 'At pH = 5.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH5'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'isocyanatocyclohexane',
    'C<sub>7</sub>H<sub>11</sub>NO',
    '',
    '3173-53-3',
    'KQWGXHWJMSMDJJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isocyanatocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'L-theanine',
    'C<sub>7</sub>H<sub>14</sub>N<sub>2</sub>O<sub>3</sub>',
    '',
    '3081-61-6',
    'DATAGRPVKZEWHA-YFKPBYRVSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='L-theanine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tetryl',
    'C<sub>7</sub>H<sub>5</sub>N<sub>5</sub>O<sub>8</sub>',
    '',
    '479-45-8',
    'AGUIVNYEYSCPNI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetryl'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'anthranilic acid',
    'C<sub>7</sub>H<sub>7</sub>NO<sub>2</sub>',
    '',
    '118-92-3',
    'RWZYAGGXGHYGMB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='anthranilic acid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-aminobenzoic acid',
    'C<sub>7</sub>H<sub>7</sub>NO<sub>2</sub>',
    '',
    '99-05-8',
    'XFDUHJPVQKIXHO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-aminobenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-aminobenzoic acid',
    'C<sub>7</sub>H<sub>7</sub>NO<sub>2</sub>',
    '',
    '150-13-0',
    'ALYNCZNDIQEVRV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-aminobenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'salicylamide',
    'C<sub>7</sub>H<sub>7</sub>NO<sub>2</sub>',
    '',
    '65-45-2',
    'SKZKKFZAGNVIMN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='salicylamide'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='salicylamide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'mesalamine',
    'C<sub>7</sub>H<sub>7</sub>NO<sub>3</sub>',
    '',
    '89-57-6',
    'KBOPZPXVLCULAV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='mesalamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-phenylformamide',
    'C<sub>7</sub>H<sub>7</sub>NO',
    '',
    '103-70-8',
    'DYDNPESBYVVLBO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-phenylformamide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benzamide',
    'C<sub>7</sub>H<sub>7</sub>NO',
    '',
    '55-21-0',
    'KXDAEFPNCMNJSK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzamide'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2614_pc_problem'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzamide'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>4</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='benzamide'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzamide'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzamide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzamide'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzamide'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzamide'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='benzamide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='benzamide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-3072'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'anthranilamide',
    'C<sub>7</sub>H<sub>8</sub>N<sub>2</sub>O',
    '2-aminobenzamide',
    '88-68-6',
    'PXBFMLJZNCDSMP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='anthranilamide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-methyl-N-nitrosobenzenamine',
    'C<sub>7</sub>H<sub>8</sub>N<sub>2</sub>O',
    '',
    '614-00-6',
    'MAXCWSIJKVASQC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-methyl-N-nitrosobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methoxy-benzenamine',
    'C<sub>7</sub>H<sub>9</sub>NO',
    '2-methoxyaniline',
    '90-04-0',
    'VMPITZXILSNTON-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methoxy-benzenamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='2-methoxy-benzenamine'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methoxy-benzenamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methoxy-benzenamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methoxy-benzenamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methoxy-benzenamine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methoxy-benzenamine'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methoxy-benzenamine',
    'C<sub>7</sub>H<sub>9</sub>NO',
    '3-methoxyaniline',
    '536-90-3',
    'NCBZRJODKRCREW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>1</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='3-methoxy-benzenamine'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methoxy-benzenamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methoxy-benzenamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methoxy-benzenamine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methoxy-benzenamine'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methoxy-benzenamine'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methoxy-benzenamine',
    'C<sub>7</sub>H<sub>9</sub>NO',
    '4-methoxyaniline',
    '104-94-9',
    'BHAAPTBBJKJZER-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='4-methoxy-benzenamine'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='4-methoxy-benzenamine'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methoxy-benzenamine'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methoxy-benzenamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methoxy-benzenamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methoxy-benzenamine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methoxy-benzenamine'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methoxy-benzenamine'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-methoxy-benzenamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-(methylamino)phenol',
    'C<sub>7</sub>H<sub>9</sub>NO',
    'N-methyl-4-aminophenol',
    '150-75-4',
    'ZFIQGRISGKSVAG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-(methylamino)phenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-(diethylamino)-1,2-propanediol',
    'C<sub>7</sub>H<sub>17</sub>NO<sub>2</sub>',
    '',
    '621-56-7',
    'LTACQVCHVAUOKN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3-(diethylamino)-1,2-propanediol'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at313K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-(diethylamino)-1,2-propanediol'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3426'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-(diethylamino)-1,2-propanediol'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-(2-hydroxyethyl)piperidine',
    'C<sub>7</sub>H<sub>15</sub>NO',
    '2-piperidinoethanol',
    '3040-44-6',
    'KZTWONRVIPPDKH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-(2-hydroxyethyl)piperidine'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at313K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-(2-hydroxyethyl)piperidine'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3426'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-(2-hydroxyethyl)piperidine'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-piperidineethanol',
    'C<sub>7</sub>H<sub>15</sub>NO',
    '',
    '1484-84-0',
    'PTHDBHDZSMGHKF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-piperidineethanol'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at313K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-piperidineethanol'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3426'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-piperidineethanol'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'emylcamate',
    'C<sub>7</sub>H<sub>15</sub>NO<sub>2</sub>',
    '',
    '78-28-4',
    'SLWGJZPKHAXZQL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='emylcamate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='emylcamate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'defenuron',
    'C<sub>8</sub>H<sub>10</sub>N<sub>2</sub>O',
    '',
    '1007-36-9',
    'SQBHGDSDVWCPHN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='defenuron'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-methyl-N-nitrosobenzenemethanamine',
    'C<sub>8</sub>H<sub>10</sub>N<sub>2</sub>O',
    '',
    '937-40-6',
    'NGXUJKBJBFLCAR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='N-methyl-N-nitrosobenzenemethanamine'),
    (SELECT id from literature WHERE bibtexkey='3082'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-methyl-N-nitrosobenzenemethanamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-methyl-N-nitrosobenzenemethanamine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'norepinephrine',
    'C<sub>8</sub>H<sub>11</sub>NO<sub>3</sub>',
    '',
    '51-41-2',
    'SFLSHLFXELFNJZ-QMMMGPOBSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>13</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='norepinephrine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dimethoxyaniline',
    'C<sub>8</sub>H<sub>11</sub>NO<sub>2</sub>',
    '',
    '2735-04-8',
    'GEQNZVKIDIPGCO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,4-dimethoxyaniline'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methoxy-2-methylbenzenamine',
    'C<sub>8</sub>H<sub>11</sub>NO',
    'm-cresidine',
    '102-50-1',
    'CDGNLUSBENXDGG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methoxy-2-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'p-cresidine',
    'C<sub>8</sub>H<sub>11</sub>NO',
    '',
    '120-71-8',
    'WXWCDTXEKCVRRO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='p-cresidine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-nitrosodi-N-butylamine',
    'C<sub>8</sub>H<sub>18</sub>N<sub>2</sub>O',
    '',
    '924-16-3',
    'YGJHZCLPZAZIHH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='N-nitrosodi-N-butylamine'),
    (SELECT id from literature WHERE bibtexkey='3082'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-nitrosodi-N-butylamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-nitrosodi-N-butylamine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(diisopropylamino)-ethanol',
    'C<sub>8</sub>H<sub>19</sub>NO',
    '',
    '96-80-0',
    'ZYWUVGFIXPNBDL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'M',
    (SELECT id from species WHERE iupac='(diisopropylamino)-ethanol'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at313K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(diisopropylamino)-ethanol'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3426'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(diisopropylamino)-ethanol'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(diisopropylamino)-ethanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(diisopropylamino)-ethanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phthalamide',
    'C<sub>8</sub>H<sub>8</sub>N<sub>2</sub>O<sub>2</sub>',
    '',
    '88-96-0',
    'NAYYNDKKHOIIOD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phthalamide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'acetaminophen',
    'C<sub>8</sub>H<sub>9</sub>NO<sub>2</sub>',
    '',
    '103-90-2',
    'RZVAJINKPMORJF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='acetaminophen'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl anthranilate',
    'C<sub>8</sub>H<sub>9</sub>NO<sub>2</sub>',
    '',
    '134-20-3',
    'VAMXMNNIEUEQDV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl anthranilate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl anthranilate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl anthranilate'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl anthranilate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4''-aminoacetophenone',
    'C<sub>8</sub>H<sub>9</sub>NO',
    '4-acetylaniline',
    '99-92-3',
    'GPRYKVSEZCQIHD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4''-aminoacetophenone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-phenylacetamide',
    'C<sub>8</sub>H<sub>9</sub>NO',
    'acetanilide',
    '103-84-4',
    'FZERHIULMFGESH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='N-phenylacetamide'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-phenylacetamide'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-phenylacetamide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tropine',
    'C<sub>8</sub>H<sub>15</sub>NO',
    '',
    '120-29-6',
    'CYHOMWAPJJPNMW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='tropine'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at313K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tropine'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3426'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tropine'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bis[2-(N,N-dimethylamino)ethyl] ether',
    'C<sub>8</sub>H<sub>20</sub>N<sub>2</sub>O',
    '',
    '3033-62-3',
    'GTEXIOINCJRBIO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='bis[2-(N,N-dimethylamino)ethyl] ether'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at313K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis[2-(N,N-dimethylamino)ethyl] ether'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3426'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis[2-(N,N-dimethylamino)ethyl] ether'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methylcarbamic acid, 3-methylphenyl ester',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>2</sub>',
    'metolcarb',
    '1129-41-5',
    'VOEYXMAFNDNNED-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methylcarbamic acid, 3-methylphenyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phenylcarbamic acid, ethyl ester',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>2</sub>',
    '',
    '101-99-5',
    'LBKPGNUOUPTQKA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenylcarbamic acid, ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyl anthranilate',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>2</sub>',
    '',
    '87-25-2',
    'TWLLPUMZVVGILS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl anthranilate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benzocaine',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>2</sub>',
    '',
    '94-09-7',
    'BLFLLBZGZJTVJG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzocaine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-(4-aminophenyl)-1-propanone',
    'C<sub>9</sub>H<sub>11</sub>NO',
    '4-aminopropiophenone',
    '70-69-9',
    'FSWXOANXOQPCFF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-(4-aminophenyl)-1-propanone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(4-ethoxyphenyl)urea',
    'C<sub>9</sub>H<sub>12</sub>N<sub>2</sub>O<sub>2</sub>',
    'dulcin',
    '150-69-6',
    'GGLIEWRLXDLBBF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(4-ethoxyphenyl)urea'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fenuron',
    'C<sub>9</sub>H<sub>12</sub>N<sub>2</sub>O',
    '',
    '101-42-8',
    'XXOYNJXVWVNOOJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='fenuron'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='fenuron'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='fenuron'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='fenuron'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fenuron'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fenuron'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fenuron'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3729_test',
    '', 'Value from the test set.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_test'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'epinephrine',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>3</sub>',
    '',
    '51-43-4',
    'UCTWMZQNUQWSLP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>13</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='epinephrine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'meprobamate',
    'C<sub>9</sub>H<sub>18</sub>N<sub>2</sub>O<sub>4</sub>',
    '',
    '57-53-4',
    'NPPQSCRMBWNHMW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='meprobamate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propamocarb',
    'C<sub>9</sub>H<sub>20</sub>N<sub>2</sub>O<sub>2</sub>',
    '',
    '24579-73-5',
    'WZZLDXDUQPOXNW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propamocarb'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propamocarb'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propamocarb'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propamocarb'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propamocarb'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>8</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propamocarb'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'proximpham',
    'C<sub>10</sub>H<sub>12</sub>N<sub>2</sub>O<sub>2</sub>',
    '',
    '2828-42-4',
    'LATYTXGNKNKTDS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='proximpham'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dioxacarb',
    'C<sub>10</sub>H<sub>13</sub>NO<sub>4</sub>',
    '',
    '6988-21-2',
    'SDKQRNRRDYRQKY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dioxacarb'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dioxacarb'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dioxacarb'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phenol, 3,5-dimethyl-, methylcarbamate',
    'C<sub>10</sub>H<sub>13</sub>NO<sub>2</sub>',
    '3,5-xylyl methylcarbamate',
    '2655-14-3',
    'CVQODEWAPZVVBU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='phenol, 3,5-dimethyl-, methylcarbamate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenol, 3,5-dimethyl-, methylcarbamate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenol, 3,5-dimethyl-, methylcarbamate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='phenol, 3,5-dimethyl-, methylcarbamate'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phenylcarbamic acid, 1-methylethyl ester',
    'C<sub>10</sub>H<sub>13</sub>NO<sub>2</sub>',
    '',
    '122-42-9',
    'VXPLXMJHHKHSOA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='phenylcarbamic acid, 1-methylethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='phenylcarbamic acid, 1-methylethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenylcarbamic acid, 1-methylethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'xylylcarb',
    'C<sub>10</sub>H<sub>13</sub>NO<sub>2</sub>',
    '',
    '2425-10-7',
    'WCJYTPVNMWIZCG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='xylylcarb'),
    (SELECT id from literature WHERE bibtexkey='2538'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='xylylcarb'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='xylylcarb'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phenacetin',
    'C<sub>10</sub>H<sub>13</sub>NO<sub>2</sub>',
    '',
    '62-44-2',
    'CPJSUEIXXCENMM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='phenacetin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='phenacetin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenacetin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ephedrine',
    'C<sub>10</sub>H<sub>15</sub>NO',
    '',
    '299-42-3',
    'KWGRBVOPPLSCSI-PSASIEDQSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ephedrine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'm-cumenyl methylcarbamate',
    'C<sub>11</sub>H<sub>15</sub>NO<sub>2</sub>',
    '3-isopropylphenyl methyl carbamate',
    '64-00-6',
    'GYKXQTKSWLAUIT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='m-cumenyl methylcarbamate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propoxur',
    'C<sub>11</sub>H<sub>15</sub>NO<sub>3</sub>',
    '',
    '114-26-1',
    'ISRUGXGCCGIOQO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propoxur'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propoxur'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propoxur'),
    (SELECT id from literature WHERE bibtexkey='2967'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7',
    '',
    'V',
    (SELECT id from species WHERE iupac='propoxur'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='propoxur'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propoxur'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methocarbamol',
    'C<sub>11</sub>H<sub>15</sub>NO<sub>5</sub>',
    '',
    '532-03-6',
    'GNXFOGHNGIVQEH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methocarbamol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'aminocarb',
    'C<sub>11</sub>H<sub>16</sub>N<sub>2</sub>O<sub>2</sub>',
    '',
    '2032-59-9',
    'IMIDOCRTMDIQIJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='aminocarb'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='aminocarb'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'monodesmethylisoproturon',
    'C<sub>11</sub>H<sub>16</sub>N<sub>2</sub>O',
    '',
    '34123-57-4',
    'DOULWWSSZVEPIN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='monodesmethylisoproturon'),
    (SELECT id from literature WHERE bibtexkey='2836'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cycluron',
    'C<sub>11</sub>H<sub>22</sub>N<sub>2</sub>O',
    '',
    '2163-69-1',
    'DQZCVNGCTZLGAQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cycluron'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methylneodecanamide',
    'C<sub>11</sub>H<sub>23</sub>NO',
    '',
    '105726-67-8',
    'GELCOLZWXWHMIB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylneodecanamide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'isoprocarb',
    'C<sub>11</sub>H<sub>15</sub>NO<sub>2</sub>',
    '',
    '2631-40-5',
    'QBSJMKIUCUGGNG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='isoprocarb'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isoprocarb'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-(phenylazo)phenol',
    'C<sub>12</sub>H<sub>10</sub>N<sub>2</sub>O',
    '4-hydroxyazobenzene',
    '1689-82-3',
    'BEYOBVMPDRKTNR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-(phenylazo)phenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-(phenylazo)phenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-(phenylazo)phenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-naphthaleneacetamide',
    'C<sub>12</sub>H<sub>11</sub>NO',
    '',
    '86-86-2',
    'XFNJVKMNNVCYEK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-naphthaleneacetamide'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'carbetamide',
    'C<sub>12</sub>H<sub>16</sub>N<sub>2</sub>O<sub>3</sub>',
    '',
    '16118-49-3',
    'AMRQXHFXNZFDCH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'X',
    (SELECT id from species WHERE iupac='carbetamide'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='carbetamide'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='carbetamide'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-nitrosodiphenylamine',
    'C<sub>12</sub>H<sub>10</sub>N<sub>2</sub>O',
    'N,N-Diphenylnitrosamine',
    '86-30-6',
    'UBUCNCOMADRQHX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='N-nitrosodiphenylamine'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='N-nitrosodiphenylamine'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='N-nitrosodiphenylamine'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-nitrosodiphenylamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'carbaryl',
    'C<sub>12</sub>H<sub>11</sub>NO<sub>2</sub>',
    '',
    '63-25-2',
    'CVXBEEMKQHEXEN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 9.9&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='carbaryl'),
    (SELECT id from literature WHERE bibtexkey='2972'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='carbaryl'),
    (SELECT id from literature WHERE bibtexkey='2538'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='carbaryl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='carbaryl'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='carbaryl'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='carbaryl'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='carbaryl'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='carbaryl'),
    (SELECT id from literature WHERE bibtexkey='howard97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='carbaryl'),
    (SELECT id from literature WHERE bibtexkey='3073'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='carbaryl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='carbaryl'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='carbaryl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='carbaryl'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,4''-oxybisbenzenamine',
    'C<sub>12</sub>H<sub>12</sub>N<sub>2</sub>O',
    'bis(4-aminophenyl) ether',
    '101-80-4',
    'HLBLWEWZXPIGSM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4''-oxybisbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'carbofuran',
    'C<sub>12</sub>H<sub>15</sub>NO<sub>3</sub>',
    '',
    '1563-66-2',
    'DUEPRVBVGDRKAG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='carbofuran'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 9.9&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='carbofuran'),
    (SELECT id from literature WHERE bibtexkey='2972'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='carbofuran'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='carbofuran'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='carbofuran'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='carbofuran'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='carbofuran'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phenol, 3-methyl-5-(1-methylethyl)-, methylcarbamate',
    'C<sub>12</sub>H<sub>16</sub>NO<sub>2</sub>',
    'promecarb',
    '2631-37-0',
    'DTAPQAJKAFRNJB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='phenol, 3-methyl-5-(1-methylethyl)-, methylcarbamate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='phenol, 3-methyl-5-(1-methylethyl)-, methylcarbamate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenol, 3-methyl-5-(1-methylethyl)-, methylcarbamate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='phenol, 3-methyl-5-(1-methylethyl)-, methylcarbamate'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fenobucarb',
    'C<sub>12</sub>H<sub>17</sub>NO<sub>2</sub>',
    '',
    '3766-81-2',
    'DIRFUJHNVNOBMY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='fenobucarb'),
    (SELECT id from literature WHERE bibtexkey='2538'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='fenobucarb'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fenobucarb'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diethyltoluamide',
    'C<sub>12</sub>H<sub>17</sub>NO',
    'DEET',
    '134-62-3',
    'MMOXZBCLCQITDF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyltoluamide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N,N-dimethyl-N''-[4-(1-methylethyl)phenyl]-urea',
    'C<sub>12</sub>H<sub>18</sub>N<sub>2</sub>O',
    'isoproturon',
    '34123-59-6',
    'PUIYMUZLKQOUOZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='N,N-dimethyl-N''-[4-(1-methylethyl)phenyl]-urea'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='N,N-dimethyl-N''-[4-(1-methylethyl)phenyl]-urea'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='N,N-dimethyl-N''-[4-(1-methylethyl)phenyl]-urea'),
    (SELECT id from literature WHERE bibtexkey='2836'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='N,N-dimethyl-N''-[4-(1-methylethyl)phenyl]-urea'),
    (SELECT id from literature WHERE bibtexkey='2967'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N-dimethyl-N''-[4-(1-methylethyl)phenyl]-urea'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimorpholinodiethyl ether',
    'C<sub>12</sub>H<sub>24</sub>N<sub>2</sub>O<sub>3</sub>',
    '',
    '6425-39-4',
    'ZMSQJSMSLXVTKN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>3</sup>',
    '2600',
    'M',
    (SELECT id from species WHERE iupac='dimorpholinodiethyl ether'),
    (SELECT id from literature WHERE bibtexkey='3584'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'carisoprodol',
    'C<sub>12</sub>H<sub>24</sub>N<sub>2</sub>O<sub>4</sub>',
    '',
    '78-44-4',
    'OFZCIYFFPZCNJE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='carisoprodol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-hydroxy-4''-nitroazobenzene',
    'C<sub>12</sub>H<sub>9</sub>N<sub>3</sub>O<sub>3</sub>',
    '',
    '1435-60-5',
    'NRJPVIOTANUINF-YPKPFQOOSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-hydroxy-4''-nitroazobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-hydroxy-4''-nitroazobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dinitro-N-phenyl-benzenamine',
    'C<sub>12</sub>H<sub>9</sub>N<sub>3</sub>O<sub>4</sub>',
    '',
    '961-68-2',
    'RHTVQEPJVKUMPI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4-dinitro-N-phenyl-benzenamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dinitro-N-phenyl-benzenamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-(2,4-dinitrophenyl)-N-(4-hydroxyphenyl)amine',
    'C<sub>12</sub>H<sub>9</sub>N<sub>3</sub>O<sub>5</sub>',
    '',
    '119-15-3',
    'BCPQALWAROJVLE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='N-(2,4-dinitrophenyl)-N-(4-hydroxyphenyl)amine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-(2,4-dinitrophenyl)-N-(4-hydroxyphenyl)amine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'disperse orange 3',
    'C<sub>12</sub>H<sub>10</sub>N<sub>4</sub>O<sub>2</sub>',
    '',
    '730-40-5',
    'UNBOSJFEZZJZLR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='disperse orange 3'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='disperse orange 3'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diethylpropion',
    'C<sub>13</sub>H<sub>19</sub>NO',
    '',
    '90-84-6',
    'XXEPPPIWZFICOJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethylpropion'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'salbutamol',
    'C<sub>13</sub>H<sub>21</sub>NO<sub>3</sub>',
    'albuterol',
    '18559-94-9',
    'NDAUXUAQIAJITI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='salbutamol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'disperse blue 1',
    'C<sub>14</sub>H<sub>12</sub>N<sub>4</sub>O<sub>2</sub>',
    '',
    '2475-45-8',
    'JSFUMBWFPQSADC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='disperse blue 1'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3''-dimethoxybenzidine',
    'C<sub>14</sub>H<sub>16</sub>N<sub>2</sub>O<sub>2</sub>',
    '',
    '119-90-4',
    'JRBJSXQPQWSCCF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3''-dimethoxybenzidine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'aspartame',
    'C<sub>14</sub>H<sub>18</sub>N<sub>2</sub>O<sub>5</sub>',
    '',
    '22839-47-0',
    'IAOZJIPTCAWIRG-QWRGUYRKSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>12</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='aspartame'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dinobuton',
    'C<sub>14</sub>H<sub>18</sub>N<sub>2</sub>O<sub>7</sub>',
    'dessin',
    '973-21-7',
    'HDWLUGYOLUHEMN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dinobuton'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-(2-methylcyclohexyl)-N''-phenylurea',
    'C<sub>14</sub>H<sub>20</sub>N<sub>2</sub>O',
    'siduron',
    '1982-49-6',
    'JXVIIQLNUPXOII-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='N-(2-methylcyclohexyl)-N''-phenylurea'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'butralin',
    'C<sub>14</sub>H<sub>21</sub>N<sub>3</sub>O<sub>4</sub>',
    '',
    '33629-47-9',
    'SPNQRCTZKIBOAX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'V',
    (SELECT id from species WHERE iupac='butralin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'V',
    (SELECT id from species WHERE iupac='butralin'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'lauramine oxide',
    'C<sub>14</sub>H<sub>31</sub>NO',
    '',
    '1643-20-5',
    'SYELZBGXAIXKHU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='lauramine oxide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-aminoanthraquinone',
    'C<sub>14</sub>H<sub>9</sub>NO<sub>2</sub>',
    '',
    '117-79-3',
    'XOGPDSATLSAZEK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-aminoanthraquinone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-aminoanthraquinone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-aminoanthraquinone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-amino-9,10-anthracenedione',
    'C<sub>14</sub>H<sub>9</sub>NO<sub>2</sub>',
    '',
    '82-45-1',
    'KHUFHLFHOQVFGB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-amino-9,10-anthracenedione'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-amino-9,10-anthracenedione'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-amino-4-hydroxy-9,10-anthracenedione',
    'C<sub>14</sub>H<sub>9</sub>NO<sub>3</sub>',
    '',
    '116-85-8',
    'AQXYVFBSOOBBQV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-amino-4-hydroxy-9,10-anthracenedione'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-amino-4-hydroxy-9,10-anthracenedione'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4-diamino-9,10-anthracenedione',
    'C<sub>14</sub>H<sub>10</sub>N<sub>2</sub>O<sub>2</sub>',
    '',
    '128-95-0',
    'FBMQNRKSAWNXBT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-diamino-9,10-anthracenedione'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-diamino-9,10-anthracenedione'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N,N-dimethyl-4-[(4-nitrophenyl)azo]-benzenamine',
    'C<sub>14</sub>H<sub>14</sub>N<sub>4</sub>O<sub>2</sub>',
    '',
    '2491-74-9',
    'LSFRFLVWCKLQTO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='N,N-dimethyl-4-[(4-nitrophenyl)azo]-benzenamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N-dimethyl-4-[(4-nitrophenyl)azo]-benzenamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'karbutilate',
    'C<sub>14</sub>H<sub>21</sub>N<sub>3</sub>O<sub>3</sub>',
    '',
    '4849-32-5',
    'OWNAXTAAAQTBSP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>8</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='karbutilate'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diethofencarb',
    'C<sub>14</sub>H<sub>21</sub>NO<sub>4</sub>',
    '',
    '87130-20-9',
    'LNJNFVJKDJYTEU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diethofencarb'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethofencarb'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-amino-2-methyl-9,10-anthracenedione',
    'C<sub>15</sub>H<sub>11</sub>NO<sub>2</sub>',
    '1-amino-2-methylanthraquinone',
    '82-28-0',
    'ZLCUIOWQYBYEBG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-amino-2-methyl-9,10-anthracenedione'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-2-fluorenylacetamide',
    'C<sub>15</sub>H<sub>13</sub>NO',
    '2-acetylaminofluorene',
    '53-96-3',
    'CZIHNRWJTSTCEX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-2-fluorenylacetamide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tebutam',
    'C<sub>15</sub>H<sub>23</sub>NO',
    '',
    '35256-85-0',
    'RJKCKKDSSSRYCB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tebutam'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tebutam'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tebutam'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'isopropalin',
    'C<sub>15</sub>H<sub>23</sub>N<sub>3</sub>O<sub>4</sub>',
    '',
    '33820-53-0',
    'NEKOXWSIMFDGMA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='isopropalin'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dodine',
    'C<sub>15</sub>H<sub>33</sub>N<sub>3</sub>O<sub>2</sub>',
    'doguadine',
    '2439-10-3',
    'YIKWKLYQRFRGPM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dodine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dodine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dodine'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'metalaxyl',
    'C<sub>15</sub>H<sub>21</sub>NO<sub>4</sub>',
    '',
    '57837-19-1',
    'ZQEIXNIJLIKNTD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='metalaxyl'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='metalaxyl'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='metalaxyl'),
    (SELECT id from literature WHERE bibtexkey='2968'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'metalaxyl-m',
    'C<sub>15</sub>H<sub>21</sub>NO<sub>4</sub>',
    '',
    '70630-17-0',
    'ZQEIXNIJLIKNTD-GFCCVEGCSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='metalaxyl-m'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='metalaxyl-m'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='metalaxyl-m'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'metoprolol',
    'C<sub>15</sub>H<sub>25</sub>NO<sub>3</sub>',
    '',
    '37350-58-6',
    'IUBSYMUCCVWXPE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='metoprolol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-(methylamino)anthraquinone',
    'C<sub>15</sub>H<sub>11</sub>NO<sub>2</sub>',
    '',
    '82-38-2',
    'SVTDYSXXLJYUTM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-(methylamino)anthraquinone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-(methylamino)anthraquinone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4''-[(2-hydroxy-5-methylphenyl)azo]acetanilide',
    'C<sub>15</sub>H<sub>15</sub>N<sub>3</sub>O<sub>2</sub>',
    '',
    '2832-40-8',
    'PXOZAFXVEWKXED-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4''-[(2-hydroxy-5-methylphenyl)azo]acetanilide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4''-[(2-hydroxy-5-methylphenyl)azo]acetanilide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'desmedipham',
    'C<sub>16</sub>H<sub>16</sub>N<sub>2</sub>O<sub>4</sub>',
    '',
    '13684-56-5',
    'WZJZMXBKUWKXTQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='desmedipham'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phenmedipham',
    'C<sub>16</sub>H<sub>16</sub>N<sub>2</sub>O<sub>4</sub>',
    'betanal',
    '13684-63-4',
    'IDOWTHOLJBTAFI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>7</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='phenmedipham'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>7</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='phenmedipham'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='phenmedipham'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenmedipham'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenmedipham'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='phenmedipham'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fenam',
    'C<sub>16</sub>H<sub>17</sub>NO',
    '',
    '957-51-7',
    'QAHFOPIILNICLA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='fenam'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='fenam'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='fenam'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fenam'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'difenoxuron',
    'C<sub>16</sub>H<sub>18</sub>N<sub>2</sub>O<sub>3</sub>',
    '',
    '14214-32-5',
    'AMVYOVYGIJXTQB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='difenoxuron'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'butacarb',
    'C<sub>16</sub>H<sub>25</sub>NO<sub>2</sub>',
    '',
    '2655-19-8',
    'SLZWBCGZQRRUNG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butacarb'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'oseltamivir',
    'C<sub>16</sub>H<sub>28</sub>N<sub>2</sub>O<sub>4</sub>',
    '',
    '196618-13-0',
    'VSZGPKBBMSAYNT-RRFJBIMHSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='oseltamivir'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N,N-bis(2-hydroxyethyl)dodecanamide',
    'C<sub>16</sub>H<sub>33</sub>NO<sub>3</sub>',
    '',
    '120-40-1',
    'AOMUHOFOVNGZAN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N-bis(2-hydroxyethyl)dodecanamide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4-bis(methylamino)-9,10-anthracenedione',
    'C<sub>16</sub>H<sub>14</sub>N<sub>2</sub>O<sub>2</sub>',
    '',
    '2475-44-7',
    'QOSTVEDABRQTSU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-bis(methylamino)-9,10-anthracenedione'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-bis(methylamino)-9,10-anthracenedione'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'metominostrobin',
    'C<sub>16</sub>H<sub>16</sub>N<sub>2</sub>O<sub>3</sub>',
    '',
    '133408-50-1',
    'HIIRDDUVRXCDBN-SDXDJHTJSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='metominostrobin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='metominostrobin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-[(2-methoxyphenyl)azo]-2-naphthol',
    'C<sub>17</sub>H<sub>14</sub>N<sub>2</sub>O<sub>2</sub>',
    '',
    '1229-55-6',
    'ALLOLPOYFRLCCX-VHEBQXMUSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-[(2-methoxyphenyl)azo]-2-naphthol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'furalaxyl',
    'C<sub>17</sub>H<sub>19</sub>NO<sub>4</sub>',
    '',
    '57646-30-7',
    'CIEXPHRYOLIQQD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='furalaxyl'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fenoxycarb',
    'C<sub>17</sub>H<sub>19</sub>NO<sub>4</sub>',
    '',
    '72490-01-8',
    'HJUFTIJOISQSKQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='fenoxycarb'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='fenoxycarb'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>7</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='fenoxycarb'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='fenoxycarb'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fenoxycarb'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fenoxycarb'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fenoxycarb'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bifenazate',
    'C<sub>17</sub>H<sub>20</sub>N<sub>2</sub>O<sub>3</sub>',
    '',
    '149877-41-8',
    'VHLKTXFWDRXILV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='bifenazate'),
    (SELECT id from literature WHERE bibtexkey='macbean2012'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 9.9&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='bifenazate'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'napropamide',
    'C<sub>17</sub>H<sub>21</sub>NO<sub>2</sub>',
    '',
    '15299-99-7',
    'WXZVAROIGSFCFJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='napropamide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='napropamide'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'napropamide-M',
    'C<sub>17</sub>H<sub>21</sub>NO<sub>2</sub>',
    '',
    '41643-35-0',
    'WXZVAROIGSFCFJ-CYBMUJFWSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='napropamide-M'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'padimate O',
    'C<sub>17</sub>H<sub>27</sub>NO<sub>2</sub>',
    '',
    '21245-02-3',
    'WYWZRNAHINYAEF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='padimate O'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nadolol',
    'C<sub>17</sub>H<sub>27</sub>NO<sub>4</sub>',
    '',
    '42200-33-9',
    'VWPOSFSPZNDTMJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nadolol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6-di-<i>tert</i>-butyl-4-(dimethylaminomethyl)phenol',
    'C<sub>17</sub>H<sub>29</sub>NO',
    '',
    '88-27-7',
    'VMZVBRIIHDRYGK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-di-<i>tert</i>-butyl-4-(dimethylaminomethyl)phenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-di-<i>tert</i>-butyl-4-(dimethylaminomethyl)phenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-di-<i>tert</i>-butyl-4-(dimethylaminomethyl)phenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-di-<i>tert</i>-butyl-4-(dimethylaminomethyl)phenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'mepronil',
    'C<sub>17</sub>H<sub>19</sub>NO<sub>2</sub>',
    '',
    '55814-41-0',
    'BCTQJXQXJVLSIG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='mepronil'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='mepronil'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'daimuron',
    'C<sub>17</sub>H<sub>20</sub>N<sub>2</sub>O',
    '',
    '42609-52-9',
    'NNYRZQHKCHEXSD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='daimuron'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='daimuron'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'naptalam',
    'C<sub>18</sub>H<sub>13</sub>NO<sub>3</sub>',
    '',
    '132-66-1',
    'JXTHEWSKYLZVJC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 2.3&times;10<sup>10</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='naptalam'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'citrus red 2',
    'C<sub>18</sub>H<sub>16</sub>N<sub>2</sub>O<sub>3</sub>',
    '',
    '6358-53-8',
    'ULLJIFAIUSUJBP-ZZEZOPTASA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='citrus red 2'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'kresoxim-methyl',
    'C<sub>18</sub>H<sub>19</sub>NO<sub>4</sub>',
    '',
    '143390-89-0',
    'ZOTBXTZVPHCKPN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='kresoxim-methyl'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='kresoxim-methyl'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dinocap',
    'C<sub>18</sub>H<sub>24</sub>N<sub>2</sub>O<sub>6</sub>',
    '',
    '39300-45-3',
    'RNDNTTTUTQAXII-GORDUTHDSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dinocap'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'orysastrobin',
    'C<sub>18</sub>H<sub>25</sub>N<sub>5</sub>O<sub>5</sub>',
    '',
    '248593-16-0',
    'JHIPUJPTQJYEQK-ZLHHXESBSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='orysastrobin'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'spiroxamine',
    'C<sub>18</sub>H<sub>35</sub>NO<sub>2</sub>',
    '',
    '118134-30-8',
    'PUYXTUJWRLOUCW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='spiroxamine'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='spiroxamine'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'capsaicin',
    'C<sub>18</sub>H<sub>27</sub>NO<sub>3</sub>',
    '',
    '404-86-4',
    'YKPUWZUDDOIDPM-SOFGYWHQSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='capsaicin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'mandestrobin',
    'C<sub>19</sub>H<sub>23</sub>NO<sub>3</sub>',
    '',
    '173662-97-0',
    'PDPWCKVFIFAQIQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='mandestrobin'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimoxystrobin',
    'C<sub>19</sub>H<sub>22</sub>N<sub>2</sub>O<sub>3</sub>',
    '',
    '149961-52-4',
    'WXUZAHCNPWONDH-DYTRJAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dimoxystrobin'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(RS)-&#945;-2-naphthoxypropionanilide',
    'C<sub>19</sub>H<sub>17</sub>NO<sub>2</sub>',
    'naproanilide',
    '52570-16-8',
    'LVKTWOXHRYGDMM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(RS)-&#945;-2-naphthoxypropionanilide'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(RS)-&#945;-2-naphthoxypropionanilide'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phenylbutazone',
    'C<sub>19</sub>H<sub>20</sub>N<sub>2</sub>O<sub>2</sub>',
    '',
    '50-33-9',
    'VYMDGNCVAMGZFE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenylbutazone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phenisopham',
    'C<sub>19</sub>H<sub>22</sub>N<sub>2</sub>O<sub>4</sub>',
    '',
    '57375-63-0',
    'PWEOEHNGYFXZLI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='phenisopham'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'formoterol',
    'C<sub>19</sub>H<sub>24</sub>N<sub>2</sub>O<sub>4</sub>',
    '',
    '73573-87-2',
    'BPZSYCZIITTYBL-ORAYPTAESA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>17</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='formoterol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benalaxyl-m',
    'C<sub>20</sub>H<sub>23</sub>NO<sub>3</sub>',
    '',
    '98243-83-5',
    'CJPQIRJHIZUAQP-MRXNPFEDSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='benalaxyl-m'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benalaxyl',
    'C<sub>20</sub>H<sub>23</sub>NO<sub>3</sub>',
    '',
    '71626-11-4',
    'CJPQIRJHIZUAQP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benalaxyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benalaxyl'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benalaxyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='benalaxyl'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tralkoxydim',
    'C<sub>20</sub>H<sub>27</sub>NO<sub>3</sub>',
    '',
    '87820-88-0',
    'SOTLWPHEAQOHHC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tralkoxydim'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'neotame',
    'C<sub>20</sub>H<sub>30</sub>N<sub>2</sub>O<sub>5</sub>',
    '',
    '165450-17-9',
    'HLIAVLHNDJUHFG-HOTGVXAUSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='neotame'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'colchicine',
    'C<sub>22</sub>H<sub>25</sub>NO<sub>6</sub>',
    '',
    '64-86-8',
    'IAKHMKGGTNLKSZ-MRXNPFEDSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='colchicine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tebufenozide',
    'C<sub>22</sub>H<sub>28</sub>N<sub>2</sub>O<sub>2</sub>',
    '',
    '112410-23-8',
    'QYPNKSZPJQQLRK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tebufenozide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 1.5&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tebufenozide'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methoxyfenozide',
    'C<sub>22</sub>H<sub>28</sub>N<sub>2</sub>O<sub>3</sub>',
    '',
    '161050-58-4',
    'QCAWEPFNJXQPAN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methoxyfenozide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 6.1&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methoxyfenozide'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propoxyphene',
    'C<sub>22</sub>H<sub>29</sub>NO<sub>2</sub>',
    '',
    '469-62-5',
    'XLMALTXPSGQGBX-PGRDOPGGSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propoxyphene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(Z)-13-docosenamide',
    'C<sub>22</sub>H<sub>43</sub>NO',
    'erucamide',
    '112-84-5',
    'UAUDZVJPLUQNMU-KTKRTIGZSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(Z)-13-docosenamide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-642'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'butroxydim',
    'C<sub>24</sub>H<sub>33</sub>NO<sub>4</sub>',
    '',
    '138164-12-2',
    'ZOGDSYNXUXQGHF-XIEYBQDHSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='butroxydim'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-bis[4-(4-aminophenoxy)phenyl]propane',
    'C<sub>27</sub>H<sub>26</sub>N<sub>2</sub>O<sub>2</sub>',
    '',
    '13080-86-9',
    'KMKWGXGSGPYISJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-bis[4-(4-aminophenoxy)phenyl]propane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-bis[4-(4-aminophenoxy)phenyl]propane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-bis[4-(4-aminophenoxy)phenyl]propane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-bis[4-(4-aminophenoxy)phenyl]propane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4-bis[(4-methylphenyl)amino]-9,10-anthracenedione',
    'C<sub>28</sub>H<sub>22</sub>N<sub>2</sub>O<sub>2</sub>',
    'D&amp;C Green No. 6',
    '128-80-3',
    'TVRGPOFMYCMNRB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-bis[(4-methylphenyl)amino]-9,10-anthracenedione'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'mifepristone',
    'C<sub>29</sub>H<sub>35</sub>NO<sub>2</sub>',
    '',
    '84371-65-3',
    'VKHAHZOOUSRJNA-GCNJZUOMSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='mifepristone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2''-anilino-6''-[ethyl(3-methylbutyl)amino]-3''-methylspiro[isobenzofuran-1(3H),9''-[9H]xanthene]-3-one',
    'C<sub>34</sub>H<sub>34</sub>N<sub>2</sub>O<sub>3</sub>',
    '',
    '70516-41-5',
    'HUSIBQLZEMMTCQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2''-anilino-6''-[ethyl(3-methylbutyl)amino]-3''-methylspiro[isobenzofuran-1(3H),9''-[9H]xanthene]-3-one'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2''-anilino-6''-[ethyl(3-methylbutyl)amino]-3''-methylspiro[isobenzofuran-1(3H),9''-[9H]xanthene]-3-one'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2''-anilino-6''-[ethyl(3-methylbutyl)amino]-3''-methylspiro[isobenzofuran-1(3H),9''-[9H]xanthene]-3-one'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2''-anilino-6''-[ethyl(3-methylbutyl)amino]-3''-methylspiro[isobenzofuran-1(3H),9''-[9H]xanthene]-3-one'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'spinetoram',
    'C<sub>42</sub>H<sub>69</sub>NO<sub>10</sub>',
    '',
    '935545-74-7',
    'GOENIMGKWNZVDA-OAMCMWGQSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='spinetoram'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH5'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='spinetoram'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH5'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='spinetoram'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3549-pH10',
    '', 'At pH = 10.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH10'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='spinetoram'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='spinetoram'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH7'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='spinetoram'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH7'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='spinetoram'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH10'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='spinetoram'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'spinosad',
    'C<sub>42</sub>H<sub>71</sub>NO<sub>9</sub>',
    '',
    '168316-95-8',
    'RQOIAWYOVOXMST-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='spinosad'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='spinosad'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'emamectin benzoate',
    'C<sub>56</sub>H<sub>81</sub>NO<sub>15</sub>',
    '',
    '155569-91-8',
    'GCKZANITAMOIAR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='emamectin benzoate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='emamectin benzoate'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3549-pH9',
    '', 'At pH = 9.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH9'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='emamectin benzoate'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH7'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='emamectin benzoate'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH5'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'glutamic acid',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>4</sub>',
    '',
    '617-65-2',
    'WHUUTDBJXJRKMK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='glutamic acid'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='glutamic acid'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='glutamic acid'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>10</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='glutamic acid'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'asparagine',
    'C<sub>4</sub>H<sub>8</sub>N<sub>2</sub>O<sub>3</sub>',
    '',
    '70-47-3',
    'DCXYFEDJOCDNAF-UWTATZPHSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>10</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='asparagine'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'serine',
    'C<sub>3</sub>H<sub>7</sub>NO<sub>3</sub>',
    '',
    '302-84-1',
    'MTCFGRXMJLQNBG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>10</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='serine'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'glutamine',
    'C<sub>5</sub>H<sub>10</sub>N<sub>2</sub>O<sub>3</sub>',
    '',
    '56-85-9',
    'ZDXPYRJPNDTMRX-GSVOUGTGSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='glutamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>10</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='glutamine'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'glycine',
    'C<sub>2</sub>H<sub>5</sub>NO<sub>2</sub>',
    '',
    '56-40-6',
    'DHMQDGOQFOQNFH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>11</sup>',
    '16000',
    'V',
    (SELECT id from species WHERE iupac='glycine'),
    (SELECT id from literature WHERE bibtexkey='2231'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>5</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='glycine'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'arginine',
    'C<sub>6</sub>H<sub>14</sub>N<sub>4</sub>O<sub>2</sub>',
    '',
    '74-79-3',
    'ODKSFYDXXFIFQN-SCSAIBSYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>14</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='arginine'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'alanine',
    'C<sub>3</sub>H<sub>7</sub>NO<sub>2</sub>',
    '',
    '302-72-7',
    'QNAYBMKLOCPYGJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>10</sup>',
    '16000',
    'V',
    (SELECT id from species WHERE iupac='alanine'),
    (SELECT id from literature WHERE bibtexkey='2231'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>5</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='alanine'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'leucine',
    'C<sub>6</sub>H<sub>13</sub>NO<sub>2</sub>',
    '',
    '328-39-2',
    'ROHFNLRQFUQHCH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Amines, amides, amino acids (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>5</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='leucine'),
    (SELECT id from literature WHERE bibtexkey='588'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='588'));
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Heterocycles with oxygen and nitrogen (C, H, O, N)',
    (SELECT id from categories WHERE catname='Organic species with nitrogen (N)'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cyanuric acid',
    'C<sub>3</sub>H<sub>3</sub>N<sub>3</sub>O<sub>3</sub>',
    '',
    '108-80-5',
    'ZFSLODLOARCGLH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyanuric acid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyanuric acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyanuric acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyanuric acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyanuric acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'isoxazole',
    'C<sub>3</sub>H<sub>3</sub>NO',
    '',
    '288-14-2',
    'CTAPFRYPJLPFDF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='isoxazole'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isoxazole'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isoxazole'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isoxazole'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'glycidamide',
    'C<sub>3</sub>H<sub>5</sub>NO<sub>2</sub>',
    '',
    '5694-00-8',
    'FMAZQSYXRGRESX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='glycidamide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cyclonite',
    'C<sub>3</sub>H<sub>6</sub>N<sub>6</sub>O<sub>6</sub>',
    '',
    '121-82-4',
    'XTFIVUDBNACUBN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cyclonite'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-methyl-3-(2H)-isoxazolone',
    'C<sub>4</sub>H<sub>5</sub>NO<sub>2</sub>',
    'hymexazol',
    '10004-44-1',
    'KGVPNLBXJKTABS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='5-methyl-3-(2H)-isoxazolone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-3-(2H)-isoxazolone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-3-(2H)-isoxazolone'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-3-(2H)-isoxazolone'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='5-methyl-3-(2H)-isoxazolone'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-amino-1H-pyridazin-6-one',
    'C<sub>4</sub>H<sub>5</sub>N<sub>3</sub>O',
    'maleic hydrazide',
    '10071-13-3',
    'MMZLICVOTDAZOX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-amino-1H-pyridazin-6-one'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'maleic hydrazide',
    'C<sub>4</sub>H<sub>4</sub>N<sub>2</sub>O<sub>2</sub>',
    '',
    '123-33-1',
    'BGRDGMRNKXEXQD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='maleic hydrazide'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'allantoin',
    'C<sub>4</sub>H<sub>6</sub>N<sub>4</sub>O<sub>3</sub>',
    '',
    '97-59-6',
    'POJWUDADGALRAB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>12</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='allantoin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-pyrrolidinone',
    'C<sub>4</sub>H<sub>7</sub>NO',
    '',
    '616-45-5',
    'HNJBEVLQSNELDL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-pyrrolidinone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-pyrrolidinone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pyrrolidinone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-nitrosomorpholine',
    'C<sub>4</sub>H<sub>8</sub>N<sub>2</sub>O<sub>2</sub>',
    '',
    '59-89-2',
    'ZKXDGKXYMTYWTB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='4-nitrosomorpholine'),
    (SELECT id from literature WHERE bibtexkey='3082'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nitrosomorpholine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nitrosomorpholine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-nitrosopyrrolidine',
    'C<sub>4</sub>H<sub>8</sub>N<sub>2</sub>O',
    '',
    '930-55-2',
    'WNYADZVDBIBLJJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '8500',
    'M',
    (SELECT id from species WHERE iupac='N-nitrosopyrrolidine'),
    (SELECT id from literature WHERE bibtexkey='3080'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='N-nitrosopyrrolidine'),
    (SELECT id from literature WHERE bibtexkey='3082'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-nitrosopyrrolidine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cyclotetramethylenetetranitramine',
    'C<sub>4</sub>H<sub>8</sub>N<sub>8</sub>O<sub>8</sub>',
    '',
    '2691-41-0',
    'UZGLIIJVICEWHF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclotetramethylenetetranitramine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-oxa-4-azacyclohexane',
    'C<sub>4</sub>H<sub>9</sub>NO',
    'morpholine',
    '110-91-8',
    'YNAVUWVOSKDBBP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>2</sup>',
    '7800',
    'M',
    (SELECT id from species WHERE iupac='1-oxa-4-azacyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3584'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-oxa-4-azacyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-oxa-4-azacyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>1</sup>',
    '8400',
    'T',
    (SELECT id from species WHERE iupac='1-oxa-4-azacyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2376'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-oxa-4-azacyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-oxa-4-azacyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-oxa-4-azacyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-oxa-4-azacyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-Test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-oxa-4-azacyclohexane'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-oxa-4-azacyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-aziridineethanol',
    'C<sub>4</sub>H<sub>9</sub>NO',
    '',
    '1072-52-2',
    'VYONOYYDEFODAJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-aziridineethanol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-ethyl-3-methoxypyrazine',
    'C<sub>4</sub>N<sub>2</sub>H<sub>3</sub>(C<sub>2</sub>H<sub>5</sub>)OCH<sub>3</sub>',
    '',
    '25680-58-4',
    'DPCILIMHENXHQX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-ethyl-3-methoxypyrazine'),
    (SELECT id from literature WHERE bibtexkey='755'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-3-methoxypyrazine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethyl-3-methoxypyrazine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-isobutyl-3-methoxypyrazine',
    'C<sub>4</sub>N<sub>2</sub>H<sub>3</sub>(C<sub>4</sub>H<sub>9</sub>)OCH<sub>3</sub>',
    '',
    '24683-00-9',
    'UXFSPRAGHGMRSQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-isobutyl-3-methoxypyrazine'),
    (SELECT id from literature WHERE bibtexkey='1922'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-isobutyl-3-methoxypyrazine'),
    (SELECT id from literature WHERE bibtexkey='755'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-isobutyl-3-methoxypyrazine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-nitrosopiperidine',
    'C<sub>5</sub>H<sub>10</sub>N<sub>2</sub>O',
    '',
    '100-75-4',
    'UWSDONTXWQOZFN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='N-nitrosopiperidine'),
    (SELECT id from literature WHERE bibtexkey='3082'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-nitrosopiperidine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-nitrosopiperidine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-nitrosopiperidine'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'butyl carbamate',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>2</sub>',
    '',
    '592-35-8',
    'SKKTUOZKZKCGTB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl carbamate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-1-oxa-4-azacyclohexane',
    'C<sub>5</sub>H<sub>11</sub>NO',
    'N-methylmorpholine; 4-methylmorpholine',
    '109-02-4',
    'SJRJJKPEHAURKC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0',
    '',
    'M',
    (SELECT id from species WHERE iupac='4-methyl-1-oxa-4-azacyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at313K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '10000',
    'M',
    (SELECT id from species WHERE iupac='4-methyl-1-oxa-4-azacyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3685'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '8300',
    'T',
    (SELECT id from species WHERE iupac='4-methyl-1-oxa-4-azacyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2376'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1-oxa-4-azacyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3426'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1-oxa-4-azacyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1-oxa-4-azacyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1-oxa-4-azacyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1-oxa-4-azacyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1-oxa-4-azacyclohexane'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'allopurinol',
    'C<sub>5</sub>H<sub>4</sub>N<sub>4</sub>O',
    '',
    '315-30-0',
    'OFCNXPDARWKPPY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='allopurinol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methoxypyridine',
    'C<sub>5</sub>H<sub>4</sub>NOCH<sub>3</sub>',
    '',
    '620-08-6',
    'XQABVLBGNWBWIV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7100',
    '?',
    (SELECT id from species WHERE iupac='4-methoxypyridine'),
    (SELECT id from literature WHERE bibtexkey='2378'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2378like0917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-methyl-2-pyrrolidone',
    'C<sub>5</sub>H<sub>9</sub>NO',
    '',
    '872-50-4',
    'SECXISVLQFMRJM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>3</sup>',
    '11000',
    'L',
    (SELECT id from species WHERE iupac='N-methyl-2-pyrrolidone'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '9100',
    'M',
    (SELECT id from species WHERE iupac='N-methyl-2-pyrrolidone'),
    (SELECT id from literature WHERE bibtexkey='2826'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='N-methyl-2-pyrrolidone'),
    (SELECT id from literature WHERE bibtexkey='2837'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-methyl-2-pyrrolidone'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-methyl-2-pyrrolidone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-methyl-2-pyrrolidone'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='N-methyl-2-pyrrolidone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5,5-dimethyl-2,4-imidazolidinedione',
    'C<sub>5</sub>H<sub>8</sub>N<sub>2</sub>O<sub>2</sub>',
    '',
    '77-71-4',
    'YIROYDNZEPTFOL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5,5-dimethyl-2,4-imidazolidinedione'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5,5-dimethyl-2,4-imidazolidinedione'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5,5-dimethyl-2,4-imidazolidinedione'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5,5-dimethyl-2,4-imidazolidinedione'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5,5-dimethyl-2,4-imidazolidinedione'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyluracil',
    'C<sub>5</sub>H<sub>6</sub>N<sub>2</sub>O<sub>2</sub>',
    '',
    '615-77-0',
    'XBCXJKGHPABGSD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-methyluracil'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyluracil'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-azacycloheptanone',
    'C<sub>6</sub>H<sub>11</sub>NO',
    'caprolactam',
    '105-60-2',
    'JBKVHLHDHHXQEQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-azacycloheptanone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-azacycloheptanone'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-azacycloheptanone'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-acetylpyrrolidine',
    'C<sub>6</sub>H<sub>11</sub>NO',
    '',
    '4030-18-6',
    'LNWWQYYLZVZXKS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='N-acetylpyrrolidine'),
    (SELECT id from literature WHERE bibtexkey='2014'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'glucosamine',
    'C<sub>6</sub>H<sub>13</sub>NO<sub>5</sub>',
    '',
    '3416-24-8',
    'MSWZFWKMSRAUBD-IVMDWMLBSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='glucosamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-ethylmorpholine',
    'C<sub>6</sub>H<sub>13</sub>NO',
    '',
    '100-74-3',
    'HVCNXQOWACZAFN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-ethylmorpholine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-formylpyridine',
    'C<sub>6</sub>H<sub>5</sub>NO',
    '',
    '500-22-1',
    'QJZUKDFHGGYHMC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>1</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='3-formylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-formylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-formylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-formylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-formylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-formylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-formylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-Test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-formylpyridine'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-formylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-formylpyridine',
    'C<sub>6</sub>H<sub>5</sub>NO',
    '',
    '872-85-5',
    'BGUWFUQJCDRPTL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>1</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='4-formylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-formylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-formylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-formylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-formylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-formylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-formylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-formylpyridine'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-formylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'niacinamide',
    'C<sub>6</sub>H<sub>6</sub>N<sub>2</sub>O',
    '',
    '98-92-0',
    'DFPAKSUCGFBDDF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='niacinamide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'metronidazole',
    'C<sub>6</sub>H<sub>9</sub>N<sub>3</sub>O<sub>3</sub>',
    '',
    '443-48-1',
    'VAOCPAMSLUNLGC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='metronidazole'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nicotinic acid',
    'C<sub>6</sub>H<sub>5</sub>NO<sub>2</sub>',
    '',
    '59-67-6',
    'PVNIIMVLHYAWGP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nicotinic acid'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'isonicotinic acid',
    'C<sub>6</sub>H<sub>5</sub>NO<sub>2</sub>',
    '',
    '55-22-1',
    'TWBYWOBDOCUKOW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isonicotinic acid'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methylthymine',
    'C<sub>6</sub>H<sub>8</sub>N<sub>2</sub>O<sub>2</sub>',
    '',
    '4160-72-9',
    'GKMIDMKPBOUSBQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-methylthymine'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'glydant',
    'C<sub>7</sub>H<sub>12</sub>N<sub>2</sub>O<sub>4</sub>',
    '1,3-dimethylol-5,5-dimethylhydantoin',
    '6440-58-0',
    'WSDISUOETYTPRL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='glydant'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-quinuclidinol',
    'C<sub>7</sub>H<sub>13</sub>NO',
    '',
    '1619-34-7',
    'IVLICPVPXWEGCA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3-quinuclidinol'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at313K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-quinuclidinol'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3426'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-quinuclidinol'),
    (SELECT id from literature WHERE bibtexkey='3426'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-quinuclidinol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dinotefuran',
    'C<sub>7</sub>H<sub>14</sub>N<sub>4</sub>O<sub>3</sub>',
    '',
    '165252-70-0',
    'YKBZOVFACRVRJN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>8</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dinotefuran'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3-benzotriazin-4(1H)-one',
    'C<sub>7</sub>H<sub>5</sub>N<sub>3</sub>O',
    '',
    '90-16-4',
    'DMSSTTLDFWKBSX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-benzotriazin-4(1H)-one'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-acetylpyridine',
    'C<sub>7</sub>H<sub>7</sub>NO',
    '',
    '1122-54-9',
    'WMQUKDQWMMOHSA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='4-acetylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-acetylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-acetylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-acetylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-acetylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-acetylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-acetylpyridine'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-acetylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-acetylpyridine',
    'C<sub>7</sub>H<sub>7</sub>NO',
    '',
    '350-03-8',
    'WEGYGNROSJDEIW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>2</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='3-acetylpyridine'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-acetylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-acetylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-acetylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-acetylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-acetylpyridine'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-acetylpyridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'theophylline',
    'C<sub>7</sub>H<sub>8</sub>N<sub>4</sub>O<sub>2</sub>',
    '',
    '58-55-9',
    'ZFXYFBGIUFBOJW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='theophylline'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'theobromine',
    'C<sub>7</sub>H<sub>8</sub>N<sub>4</sub>O<sub>2</sub>',
    '',
    '83-67-0',
    'YAPQBXQYLJRXSA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='theobromine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-pyridineethanol',
    'C<sub>7</sub>H<sub>9</sub>NO',
    '',
    '103-74-2',
    'BXGYBSJAZFGIPX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pyridineethanol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'caffeine',
    'C<sub>8</sub>H<sub>10</sub>N<sub>4</sub>O<sub>2</sub>',
    '',
    '58-08-2',
    'RYYVLZVUVIJVGH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='caffeine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'acyclovir',
    'C<sub>8</sub>H<sub>11</sub>N<sub>5</sub>O<sub>3</sub>',
    '',
    '59277-89-3',
    'MKUXAQIIEYXACX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>16</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='acyclovir'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methoxy-3-(1-methylethyl)-pyrazine',
    'C<sub>8</sub>H<sub>12</sub>N<sub>2</sub>O',
    '',
    '25773-40-4',
    'NTOPKICPEQUPPH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methoxy-3-(1-methylethyl)-pyrazine'),
    (SELECT id from literature WHERE bibtexkey='3719'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3719-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methoxy-3-(1-methylethyl)-pyrazine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'simeton',
    'C<sub>8</sub>H<sub>15</sub>N<sub>5</sub>O',
    '',
    '673-04-1',
    'HKAMKLBXTLTVCN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='simeton'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='simeton'),
    (SELECT id from literature WHERE bibtexkey='2526'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-isobutylmorpholine',
    'C<sub>8</sub>H<sub>17</sub>NO',
    '',
    '10315-98-7',
    'QKVSMSABRNCNRS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '8100',
    'Q',
    (SELECT id from species WHERE iupac='N-isobutylmorpholine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6000',
    '?',
    (SELECT id from species WHERE iupac='N-isobutylmorpholine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phthalimide',
    'C<sub>8</sub>H<sub>5</sub>NO<sub>2</sub>',
    '',
    '85-41-6',
    'XKJCHHZQLQNZHY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phthalimide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'furazolidone',
    'C<sub>8</sub>H<sub>7</sub>N<sub>3</sub>O<sub>5</sub>',
    '',
    '67-45-8',
    'PLHJDBGFXBMTGZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='furazolidone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,6-tetrahydrophthalimide',
    'C<sub>8</sub>H<sub>9</sub>NO<sub>2</sub>',
    '',
    '85-40-5',
    'CIFFBTOJCKSRJY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,6-tetrahydrophthalimide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-nitrosonornicotine',
    'C<sub>9</sub>H<sub>11</sub>N<sub>3</sub>O',
    '',
    '16543-55-8',
    'XKABJYQDMJTNGQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-nitrosonornicotine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '9-[(1,3-dihydroxy-2-propoxy)methyl]guanine',
    'C<sub>9</sub>H<sub>13</sub>N<sub>5</sub>O<sub>4</sub>',
    'ganciclovir',
    '82410-32-0',
    'IRSCQMHQWWYFCW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>17</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='9-[(1,3-dihydroxy-2-propoxy)methyl]guanine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-<i>sec</i>-butyl-3-methoxypyrazine',
    'C<sub>9</sub>H<sub>14</sub>N<sub>2</sub>O',
    '',
    '24168-70-5',
    'QMQDJVIJVPEQHE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-<i>sec</i>-butyl-3-methoxypyrazine'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'atraton',
    'C<sub>9</sub>H<sub>17</sub>N<sub>5</sub>O',
    '',
    '1610-17-9',
    'PXWUKZGIHQRDHL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='atraton'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='atraton'),
    (SELECT id from literature WHERE bibtexkey='2526'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='atraton'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-hydroxy-2,2,6,6-tetramethyl-1-piperidinyloxy',
    'C<sub>9</sub>H<sub>18</sub>NO<sub>2</sub>',
    '',
    '2226-96-2',
    'UZFMOKQJFYMBGY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-hydroxy-2,2,6,6-tetramethyl-1-piperidinyloxy'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '8-hydroxyquinoline',
    'C<sub>9</sub>H<sub>7</sub>NO',
    '',
    '148-24-3',
    'MCJGNVYPOGVAJF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='8-hydroxyquinoline'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='8-hydroxyquinoline'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='8-hydroxyquinoline'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='8-hydroxyquinoline'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'carbendazim',
    'C<sub>9</sub>H<sub>9</sub>N<sub>3</sub>O<sub>2</sub>',
    '',
    '10605-21-7',
    'TWFZGCMQGLPBSX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='carbendazim'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='carbendazim'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'metamitron',
    'C<sub>10</sub>H<sub>10</sub>N<sub>4</sub>O',
    '',
    '41394-05-2',
    'VHCNQEUWZYOAEV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='metamitron'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>6</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='metamitron'),
    (SELECT id from literature WHERE bibtexkey='1931'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='metamitron'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='metamitron'),
    (SELECT id from literature WHERE bibtexkey='1931'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='metamitron'),
    (SELECT id from literature WHERE bibtexkey='1931'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='metamitron'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pymetrozin',
    'C<sub>10</sub>H<sub>11</sub>N<sub>5</sub>O',
    '',
    '123312-89-0',
    'QHMTXANCGGJZRX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pymetrozin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-oxo-N-phenylbutanamide',
    'C<sub>10</sub>H<sub>11</sub>NO<sub>2</sub>',
    'acetoacetanilide',
    '102-01-2',
    'DYRDKSSFIWVSNM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-oxo-N-phenylbutanamide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3''-didehydro-3''-deoxythymidine (stavudine)',
    'C<sub>10</sub>H<sub>12</sub>N<sub>2</sub>O<sub>4</sub>',
    'stavudine',
    '3056-17-5',
    'XNKLLVCARDGLGL-JGVFFNPUSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3''-didehydro-3''-deoxythymidine (stavudine)'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cotinine',
    'C<sub>10</sub>H<sub>12</sub>N<sub>2</sub>O',
    '',
    '486-56-6',
    'UIKROCXWUNQSPJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cotinine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-(N-nitroso-N-methylamino)-1-(3-pyridyl)-1-butanone',
    'C<sub>10</sub>H<sub>13</sub>N<sub>3</sub>O<sub>2</sub>',
    '',
    '64091-91-4',
    'FLAQQSHRLBFIEZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-(N-nitroso-N-methylamino)-1-(3-pyridyl)-1-butanone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '9-(4-hydroxy-3-hydroxymethylbut-1-yl)guanine',
    'C<sub>10</sub>H<sub>15</sub>N<sub>5</sub>O<sub>3</sub>',
    'penciclovir',
    '39809-25-1',
    'JNTOCHDNEULJHD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>26</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='9-(4-hydroxy-3-hydroxymethylbut-1-yl)guanine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'anatoxin A',
    'C<sub>10</sub>H<sub>15</sub>NO',
    '',
    '64285-06-9',
    'SGNXVBOIDPPRJJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='anatoxin A'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimetilan',
    'C<sub>10</sub>H<sub>16</sub>N<sub>4</sub>O<sub>3</sub>',
    '',
    '644-64-4',
    'RDBIYWSVMRVKSG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimetilan'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'isolan',
    'C<sub>10</sub>H<sub>17</sub>N<sub>3</sub>O<sub>2</sub>',
    '',
    '119-38-0',
    'RNNBHZYEKNHLKT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isolan'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'amicarbazone',
    'C<sub>10</sub>H<sub>19</sub>N<sub>5</sub>O<sub>2</sub>',
    '',
    '129909-90-6',
    'ORFPWVRKFLOQHK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='amicarbazone'),
    (SELECT id from literature WHERE bibtexkey='macbean2012'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'prometone',
    'C<sub>10</sub>H<sub>19</sub>N<sub>5</sub>O',
    'prometon',
    '1610-18-0',
    'ISEUFVQQFVOBCY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='prometone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='prometone'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='prometone'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='prometone'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='prometone'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='prometone'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='prometone'),
    (SELECT id from literature WHERE bibtexkey='2526'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'secbumeton',
    'C<sub>10</sub>H<sub>19</sub>N<sub>5</sub>O',
    '',
    '26259-45-0',
    'ZJMZZNVGNSWOOM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='secbumeton'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='secbumeton'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='secbumeton'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='secbumeton'),
    (SELECT id from literature WHERE bibtexkey='2526'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='secbumeton'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'terbumeton',
    'C<sub>10</sub>H<sub>19</sub>N<sub>5</sub>O',
    '',
    '33693-04-8',
    'BCQMBFHBDZVHKU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='terbumeton'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='terbumeton'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='terbumeton'),
    (SELECT id from literature WHERE bibtexkey='2526'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'kinetin',
    'C<sub>10</sub>H<sub>9</sub>N<sub>5</sub>O',
    '',
    '525-79-1',
    'QANMHLXAZMSUEX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='kinetin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'isouron',
    'C<sub>10</sub>H<sub>17</sub>N<sub>3</sub>O<sub>2</sub>',
    '',
    '55861-78-4',
    'JLLJHQLUZAKJFH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='isouron'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isouron'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fuberidazole',
    'C<sub>11</sub>H<sub>8</sub>N<sub>2</sub>O',
    '',
    '3878-19-1',
    'UYJUZNLFJAWNEZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fuberidazole'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'carbadox',
    'C<sub>11</sub>H<sub>10</sub>N<sub>4</sub>O<sub>4</sub>',
    '',
    '6804-07-5',
    'OVGGLBAWFMIPPY-WUXMJOGZSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>17</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='carbadox'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bendiocarb',
    'C<sub>11</sub>H<sub>13</sub>NO<sub>4</sub>',
    '',
    '22781-23-3',
    'XEGGRYVFLWGFHI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bendiocarb'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bendiocarb'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bendiocarb'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bendiocarb'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,5-trimethylphenol, methylcarbamate',
    'C<sub>11</sub>H<sub>15</sub>NO<sub>2</sub>',
    '2,3,5-trimethacarb',
    '2655-15-4',
    'NYOKZHDTNBDPOB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,5-trimethylphenol, methylcarbamate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'butalbital',
    'C<sub>11</sub>H<sub>16</sub>N<sub>2</sub>O<sub>3</sub>',
    '',
    '77-26-9',
    'UZVHFVZFNXBMQJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butalbital'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dexrazoxane',
    'C<sub>11</sub>H<sub>16</sub>N<sub>4</sub>O<sub>4</sub>',
    '',
    '24584-09-6',
    'BMKDZUISNHGIBY-ZETCQYMHSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>13</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dexrazoxane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pentobarbital',
    'C<sub>11</sub>H<sub>18</sub>N<sub>2</sub>O<sub>3</sub>',
    '',
    '76-74-4',
    'WEXRUCMBJFQVBZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentobarbital'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pirimor',
    'C<sub>11</sub>H<sub>18</sub>N<sub>4</sub>O<sub>2</sub>',
    'pirimicarb',
    '23103-98-2',
    'YFGYUFNIOHWBOB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pirimor'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pirimor'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pirimor'),
    (SELECT id from literature WHERE bibtexkey='2973'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pirimor'),
    (SELECT id from literature WHERE bibtexkey='2967'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pirimor'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pirimor'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3549-pH5.2',
    '', 'At pH = 5.2.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH5.2'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pirimor'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3549-pH7.4',
    '', 'At pH = 7.4.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH7.4'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pirimor'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3549-pH9.3',
    '', 'At pH = 9.3.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH9.3'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pirimor'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethirimol',
    'C<sub>11</sub>H<sub>19</sub>N<sub>3</sub>O',
    '',
    '23947-60-6',
    'BBXXLROWFHWFQY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethirimol'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pyroquilon',
    'C<sub>11</sub>H<sub>11</sub>NO',
    '',
    '57369-32-1',
    'XRJLAOUDSILTFT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pyroquilon'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fenfuram',
    'C<sub>12</sub>H<sub>11</sub>NO<sub>2</sub>',
    '',
    '24691-80-3',
    'JFSPBVWPKOEZCB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='fenfuram'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'oxabetrinil',
    'C<sub>12</sub>H<sub>12</sub>N<sub>2</sub>O<sub>3</sub>',
    '',
    '74782-23-3',
    'WFVUIONFJOAYPK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='oxabetrinil'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phenobarbital',
    'C<sub>12</sub>H<sub>12</sub>N<sub>2</sub>O<sub>3</sub>',
    '',
    '50-06-6',
    'DDBREPKUVSBGFI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenobarbital'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'triaziquone',
    'C<sub>12</sub>H<sub>13</sub>N<sub>3</sub>O<sub>2</sub>',
    '',
    '68-76-8',
    'PXSOHRWMIRDKMP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triaziquone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'triallyl cyanurate',
    'C<sub>12</sub>H<sub>15</sub>N<sub>3</sub>O<sub>3</sub>',
    '',
    '101-37-1',
    'BJELTSYBAHKXRW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triallyl cyanurate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triallyl cyanurate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triallyl cyanurate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triallyl cyanurate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'entecavir',
    'C<sub>12</sub>H<sub>15</sub>N<sub>5</sub>O<sub>3</sub>',
    '',
    '142217-69-4',
    'QDGZDCVAUDNJFG-FXQIFTODSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>15</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='entecavir'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'metaxalone',
    'C<sub>12</sub>H<sub>15</sub>NO<sub>3</sub>',
    '',
    '1665-48-1',
    'IMWZZHHPURKASS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='metaxalone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phendimetrazine',
    'C<sub>12</sub>H<sub>17</sub>NO',
    '',
    '634-03-7',
    'MFOCDFTXLCYLKU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phendimetrazine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hexazinone',
    'C<sub>12</sub>H<sub>20</sub>N<sub>4</sub>O<sub>2</sub>',
    '',
    '51235-04-2',
    'CAWXEEYDBZRFPE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 9.9&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='hexazinone'),
    (SELECT id from literature WHERE bibtexkey='2972'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexazinone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'picaridin',
    'C<sub>12</sub>H<sub>23</sub>NO<sub>3</sub>',
    '',
    '119515-38-7',
    'QLHULAHOXSSASE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='picaridin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'lenacil',
    'C<sub>13</sub>H<sub>18</sub>N<sub>2</sub>O<sub>2</sub>',
    '',
    '2164-08-1',
    'ZTMKADLOSYKWCA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='lenacil'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='lenacil'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='lenacil'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pyrinuron',
    'C<sub>13</sub>H<sub>12</sub>N<sub>4</sub>O<sub>3</sub>',
    'pyriminil',
    '53558-25-1',
    'CLKZWXHKFXZIMA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pyrinuron'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'melatonin',
    'C<sub>13</sub>H<sub>16</sub>N<sub>2</sub>O<sub>2</sub>',
    '',
    '73-31-4',
    'DRLFMBDRBRZALE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='melatonin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dibenz[b,f]][1,4]oxazepine',
    'C<sub>13</sub>H<sub>9</sub>NO',
    '',
    '257-07-8',
    'NPUACKRELIJTFM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibenz[b,f]][1,4]oxazepine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'oxadixyl',
    'C<sub>14</sub>H<sub>18</sub>N<sub>2</sub>O<sub>4</sub>',
    '',
    '77732-09-3',
    'UWVQIROCRJWDKL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='oxadixyl'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benomyl',
    'C<sub>14</sub>H<sub>18</sub>N<sub>4</sub>O<sub>3</sub>',
    '',
    '17804-35-2',
    'RIOXQFHNBCKOKP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benomyl'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benomyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benomyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='benomyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'trimethoprim',
    'C<sub>14</sub>H<sub>18</sub>N<sub>4</sub>O<sub>3</sub>',
    '',
    '738-70-5',
    'IEDVJHCEMCRBQM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trimethoprim'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethoxyquin',
    'C<sub>14</sub>H<sub>19</sub>NO',
    '',
    '91-53-2',
    'DECIPOUIJURFOJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethoxyquin'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'famciclovir',
    'C<sub>14</sub>H<sub>19</sub>N<sub>5</sub>O<sub>4</sub>',
    '',
    '104227-87-4',
    'GGXKWVWZWMLJEH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='famciclovir'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'furmecyclox',
    'C<sub>14</sub>H<sub>21</sub>NO<sub>3</sub>',
    '',
    '60568-05-0',
    'QTDRLOKFLJJHTG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='furmecyclox'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'oxcarbazepine',
    'C<sub>15</sub>H<sub>12</sub>N<sub>2</sub>O<sub>2</sub>',
    '',
    '28721-07-5',
    'CTRLABGOLIVAIY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='oxcarbazepine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phenytoin',
    'C<sub>15</sub>H<sub>12</sub>N<sub>2</sub>O<sub>2</sub>',
    '',
    '57-41-0',
    'CXOFVDLJLONNDW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenytoin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'carbamazepine',
    'C<sub>15</sub>H<sub>12</sub>N<sub>2</sub>O',
    '',
    '298-46-4',
    'FFGPTBGBLSHEPO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='carbamazepine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propylthiouracil',
    'C<sub>15</sub>H<sub>12</sub>N<sub>2</sub>O',
    '',
    '51-52-5',
    'KNAHARQHSZJURB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propylthiouracil'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ancymidol',
    'C<sub>15</sub>H<sub>16</sub>N<sub>2</sub>O<sub>2</sub>',
    '',
    '12771-68-5',
    'HUTDUHSNJYTCAR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ancymidol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ancymidol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ancymidol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ancymidol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'imazethapyr',
    'C<sub>15</sub>H<sub>19</sub>N<sub>3</sub>O<sub>3</sub>',
    '',
    '81335-77-5',
    'XVOKUMIPKHGGTN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='imazethapyr'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'imazamox',
    'C<sub>15</sub>H<sub>19</sub>N<sub>3</sub>O<sub>4</sub>',
    '',
    '114311-32-9',
    'NUPJIGQFXCQJBK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>13</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='imazamox'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>11</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='imazamox'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cycloheximide',
    'C<sub>15</sub>H<sub>23</sub>NO<sub>4</sub>',
    '',
    '66-81-9',
    'YPHMISFOHDHNIV-FSZOTQKASA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cycloheximide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'oxymatrine',
    'C<sub>15</sub>H<sub>24</sub>N<sub>2</sub>O<sub>2</sub>',
    '',
    '16837-52-8',
    'XVPBINOPNYFXID-LHDUFFHYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>12</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='oxymatrine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'triapenthenol',
    'C<sub>15</sub>H<sub>25</sub>N<sub>3</sub>O',
    '',
    '76608-88-3',
    'CNFMJLVJDNGPHR-UKTHLTGXSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='triapenthenol'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'mebendazole',
    'C<sub>16</sub>H<sub>13</sub>N<sub>3</sub>O<sub>3</sub>',
    '',
    '31431-39-7',
    'OPXLLQIJSORQAM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='mebendazole'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'imazamethabenz-methyl',
    'C<sub>16</sub>H<sub>20</sub>N<sub>2</sub>O<sub>3</sub>',
    '',
    '81405-85-8',
    'FFCCBBNQPIMUJI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='imazamethabenz-methyl'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nifedipine',
    'C<sub>17</sub>H<sub>18</sub>N<sub>2</sub>O<sub>6</sub>',
    '',
    '21829-25-4',
    'HYIMSNHJOBLJNT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nifedipine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'oxymorphone',
    'C<sub>17</sub>H<sub>19</sub>NO<sub>4</sub>',
    '',
    '76-41-5',
    'UQCNKQCJZOAFTQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>13</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='oxymorphone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'desomorphine',
    'C<sub>17</sub>H<sub>21</sub>NO<sub>2</sub>',
    '',
    '427-00-9',
    'LNNWVNGFPYWNQE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='desomorphine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cocaine',
    'C<sub>17</sub>H<sub>21</sub>NO<sub>4</sub>',
    '',
    '50-36-2',
    'ZPUCINDJVBIVPJ-PFSRBDOWSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cocaine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cocaine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cocaine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-(2-ethylhexyl)-5-norbornene-2,3-dicarboximide',
    'C<sub>17</sub>H<sub>25</sub>NO<sub>2</sub>',
    '',
    '113-48-4',
    'WLLGXSLBOPFWQV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-(2-ethylhexyl)-5-norbornene-2,3-dicarboximide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'imazaquin',
    'C<sub>17</sub>H<sub>17</sub>N<sub>3</sub>O<sub>3</sub>',
    '',
    '81335-37-7',
    'CABMTIJINOIHOD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>11</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='imazaquin'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(E)-pyriminobac-methyl',
    'C<sub>17</sub>H<sub>19</sub>N<sub>3</sub>O<sub>6</sub>',
    '',
    '147411-69-6',
    'USSIUIGPBLPCDF-KEBDBYFISA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(E)-pyriminobac-methyl'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(Z)-pyriminobac-methyl',
    'C<sub>17</sub>H<sub>19</sub>N<sub>3</sub>O<sub>6</sub>',
    '',
    '147411-70-9',
    'USSIUIGPBLPCDF-JMIUGGIZSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(Z)-pyriminobac-methyl'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'imiprothrin',
    'C<sub>17</sub>H<sub>22</sub>N<sub>2</sub>O<sub>4</sub>',
    '',
    '72963-72-5',
    'VPRAQYXPZIFIOH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='imiprothrin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='imiprothrin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'iprovalicarb',
    'C<sub>18</sub>H<sub>28</sub>N<sub>2</sub>O<sub>3</sub>',
    '',
    '140923-17-7',
    'NWUWYYSKZYIQAE-LBAUFKAWSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='iprovalicarb'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'quinophthalone',
    'C<sub>18</sub>H<sub>11</sub>NO<sub>2</sub>',
    '',
    '8003-22-3',
    'IZMJMCDDWKSTTK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='quinophthalone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pefurazoate',
    'C<sub>18</sub>H<sub>23</sub>N<sub>3</sub>O<sub>4</sub>',
    '',
    '101903-30-4',
    'WBTYBAGIHOISOQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pefurazoate'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tetramethrin',
    'C<sub>19</sub>H<sub>25</sub>NO<sub>4</sub>',
    '',
    '7696-12-0',
    'CXBMCYHAMVGWJQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8',
    '',
    'V',
    (SELECT id from species WHERE iupac='tetramethrin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'isoxaben',
    'C<sub>19</sub>H<sub>25</sub>NO<sub>4</sub>',
    '',
    '82558-50-7',
    'PMHURSZHKKJGBM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='isoxaben'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='isoxaben'),
    (SELECT id from literature WHERE bibtexkey='macbean2012'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isoxaben'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='isoxaben'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'alfuzosin',
    'C<sub>19</sub>H<sub>27</sub>N<sub>5</sub>O<sub>4</sub>',
    '',
    '81403-80-7',
    'WNMJYKCGWZFFKR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>14</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='alfuzosin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6-dimethyl-4-tridecylmorpholine',
    'C<sub>19</sub>H<sub>39</sub>NO',
    'tridemorph',
    '24602-86-6',
    'YTOPFCCWCSOHFV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,6-dimethyl-4-tridecylmorpholine'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pyriproxyfen',
    'C<sub>20</sub>H<sub>19</sub>NO<sub>3</sub>',
    '',
    '95737-68-1',
    'NHDHVHZZCFYRSB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pyriproxyfen'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 1.4&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pyriproxyfen'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at296K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'papaverine',
    'C<sub>20</sub>H<sub>21</sub>NO<sub>4</sub>',
    '',
    '58-74-2',
    'XQYZDYMELSJDRZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='papaverine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fenazaquin',
    'C<sub>20</sub>H<sub>22</sub>N<sub>2</sub>O',
    '',
    '120928-09-8',
    'DMYHGDXADUDKCQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='fenazaquin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='fenazaquin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fenazaquin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fenazaquin'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bitertanol',
    'C<sub>20</sub>H<sub>23</sub>N<sub>3</sub>O<sub>2</sub>',
    '',
    '55179-31-2',
    'VGPIBGGRCVEHQZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bitertanol'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bitertanol diastereoisomer a',
    'C<sub>20</sub>H<sub>23</sub>N<sub>3</sub>O<sub>2</sub>',
    '',
    '70585-36-3',
    'VGPIBGGRCVEHQZ-OALUTQOASA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bitertanol diastereoisomer a'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bitertanol diastereoisomer b',
    'C<sub>20</sub>H<sub>23</sub>N<sub>3</sub>O<sub>2</sub>',
    '',
    '70585-38-5',
    'VGPIBGGRCVEHQZ-RBUKOAKNSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bitertanol diastereoisomer b'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'naltrexone',
    'C<sub>20</sub>H<sub>23</sub>NO<sub>4</sub>',
    '',
    '16590-41-3',
    'DQCKKXVULJGBQN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>13</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='naltrexone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'D-lysergic acid N,N-diethylamide',
    'C<sub>20</sub>H<sub>25</sub>N<sub>3</sub>O',
    'LSD',
    '50-37-3',
    'VAYOSLLFUXYJDT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D-lysergic acid N,N-diethylamide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ibogaine',
    'C<sub>20</sub>H<sub>26</sub>N<sub>2</sub>O',
    '',
    '83-74-9',
    'HSIBGVUMFOSJPD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ibogaine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fenpropimorph',
    'C<sub>20</sub>H<sub>33</sub>NO',
    '',
    '67564-91-4',
    'RYAUSSKQMZRMAI-ALOPSCKCSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2',
    '',
    'V',
    (SELECT id from species WHERE iupac='fenpropimorph'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='fenpropimorph'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fenpropimorph'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fenpropimorph'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'strychnine',
    'C<sub>21</sub>H<sub>22</sub>N<sub>2</sub>O<sub>2</sub>',
    '',
    '57-24-9',
    'QMGVPVSNSZLJIA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='strychnine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nalmefene',
    'C<sub>21</sub>H<sub>25</sub>NO<sub>3</sub>',
    '',
    '55096-26-9',
    'WJBLNOPPDWQMCH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nalmefene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benztropine',
    'C<sub>21</sub>H<sub>25</sub>NO',
    '',
    '86-13-5',
    'GIJXKZJWITVLHI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benztropine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'stanozolol',
    'C<sub>21</sub>H<sub>32</sub>N<sub>2</sub>O',
    '',
    '10418-03-8',
    'LKAJKIOFIWVMDJ-KIWJEFSTSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='stanozolol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'spirotetramat',
    'C<sub>21</sub>H<sub>27</sub>NO<sub>5</sub>',
    '',
    '203313-25-1',
    'CLSVJBIHYWPGQY-GGYDESQDSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='spirotetramat'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH7'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='spirotetramat'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3549-pH4',
    '', 'At pH = 4.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH4'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='spirotetramat'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH9'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diacetylmorphine',
    'C<sub>21</sub>H<sub>23</sub>NO<sub>5</sub>',
    'heroin',
    '561-27-3',
    'GVGLGOZIDCSQPN-PVHGPHFFSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>7</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diacetylmorphine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diacetylmorphine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pyrametostrobin',
    'C<sub>21</sub>H<sub>23</sub>N<sub>3</sub>O<sub>4</sub>',
    '',
    '915410-70-7',
    'DWTVBEZBWMDXIY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pyrametostrobin'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'azoxystrobin',
    'C<sub>22</sub>H<sub>17</sub>N<sub>3</sub>O<sub>5</sub>',
    '',
    '131860-33-8',
    'WFDXOXNFNRHQEC-GHRIWEEISA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>8</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='azoxystrobin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>8</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='azoxystrobin'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'famoxadone',
    'C<sub>22</sub>H<sub>18</sub>N<sub>2</sub>O<sub>4</sub>',
    '',
    '131807-57-3',
    'PCCSBWNGDMYFCW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='famoxadone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='famoxadone'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tadalafil',
    'C<sub>22</sub>H<sub>19</sub>N<sub>3</sub>O<sub>4</sub>',
    '',
    '171596-29-5',
    'WOXKDUGGOYFFRN-IIBYNOLFSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>12</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tadalafil'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bisacodyl',
    'C<sub>22</sub>H<sub>19</sub>NO<sub>4</sub>',
    '',
    '603-50-9',
    'KHOITXIGCFIULA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bisacodyl'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fentanyl',
    'C<sub>22</sub>H<sub>28</sub>N<sub>2</sub>O',
    '',
    '437-38-7',
    'PJMPHNIQZUBGLI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fentanyl'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-(triphenylmethyl)morpholine',
    'C<sub>23</sub>H<sub>23</sub>NO',
    'trifenmorph',
    '1420-06-0',
    'ZJMLMBICUVVJDX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-(triphenylmethyl)morpholine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-(triphenylmethyl)morpholine'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'brucine',
    'C<sub>23</sub>H<sub>26</sub>N<sub>2</sub>O<sub>4</sub>',
    '',
    '357-57-3',
    'RRKTZKIUPZVBMF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='brucine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'mycophenolate mofetil',
    'C<sub>23</sub>H<sub>31</sub>NO<sub>7</sub>',
    '',
    '128794-94-5',
    'RTGDFNSFWBGLEC-SYZQJQIISA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='mycophenolate mofetil'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pinoxaden',
    'C<sub>23</sub>H<sub>32</sub>N<sub>2</sub>O<sub>4</sub>',
    '',
    '243973-20-8',
    'MGOHCFMYLBAPRN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pinoxaden'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pinoxaden'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fenpyroximate',
    'C<sub>24</sub>H<sub>27</sub>N<sub>3</sub>O<sub>4</sub>',
    '',
    '134098-61-6',
    'YYJNOYZRYGDPNH-MFKUBSTISA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6',
    '',
    'V',
    (SELECT id from species WHERE iupac='fenpyroximate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6',
    '',
    'X',
    (SELECT id from species WHERE iupac='fenpyroximate'),
    (SELECT id from literature WHERE bibtexkey='macbean2012'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fenpyroximate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'valsartan',
    'C<sub>24</sub>H<sub>29</sub>N<sub>5</sub>O<sub>3</sub>',
    '',
    '137862-53-4',
    'ACWBQPMHZXGDFX-QFIPXVFZSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>12</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='valsartan'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'donepezil',
    'C<sub>24</sub>H<sub>29</sub>NO<sub>3</sub>',
    '',
    '120014-06-4',
    'ADEBPBSSDYVVLD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='donepezil'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chromafenozide',
    'C<sub>24</sub>H<sub>30</sub>N<sub>2</sub>O<sub>3</sub>',
    '',
    '143807-66-3',
    'HPNSNYBUADCFDR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chromafenozide'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH7'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chromafenozide'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH4'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chromafenozide'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH9'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cyenopyrafen',
    'C<sub>24</sub>H<sub>31</sub>N<sub>3</sub>O<sub>2</sub>',
    '',
    '560121-52-0',
    'APJLTUBHYCOZJI-VZCXRCSSSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cyenopyrafen'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-[4-[4-(2-benzoxazolyl)styryl]phenyl]-5-methylbenzoxazole',
    'C<sub>29</sub>H<sub>20</sub>N<sub>2</sub>O<sub>2</sub>',
    '',
    '5242-49-9',
    'SOTPOQQKAUOHRO-BQYQJAHWSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-[4-[4-(2-benzoxazolyl)styryl]phenyl]-5-methylbenzoxazole'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-[4-[4-(2-benzoxazolyl)styryl]phenyl]-5-methylbenzoxazole'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-[4-[4-(2-benzoxazolyl)styryl]phenyl]-5-methylbenzoxazole'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-[4-[4-(2-benzoxazolyl)styryl]phenyl]-5-methylbenzoxazole'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-(2H-benzotriazol-2-yl)-4,6-bis(1-methyl-1-phenylethyl)phenol',
    'C<sub>30</sub>H<sub>29</sub>N<sub>3</sub>O',
    '',
    '70321-86-7',
    'OLFNXLXEGXRUOI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(2H-benzotriazol-2-yl)-4,6-bis(1-methyl-1-phenylethyl)phenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(2H-benzotriazol-2-yl)-4,6-bis(1-methyl-1-phenylethyl)phenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(2H-benzotriazol-2-yl)-4,6-bis(1-methyl-1-phenylethyl)phenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(2H-benzotriazol-2-yl)-4,6-bis(1-methyl-1-phenylethyl)phenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fenpicoxamid',
    'C<sub>31</sub>H<sub>38</sub>N<sub>2</sub>O<sub>11</sub>',
    '',
    '517875-34-2',
    'QGTOTYJSCYHYFK-RBODFLQRSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fenpicoxamid'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'norbormide',
    'C<sub>33</sub>H<sub>25</sub>N<sub>3</sub>O<sub>3</sub>',
    '',
    '991-42-4',
    'DNTHHIVFNQZZRD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>17</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='norbormide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'reserpine',
    'C<sub>33</sub>H<sub>40</sub>N<sub>2</sub>O<sub>9</sub>',
    '',
    '50-55-5',
    'QEVHRUUCFGRFIF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>17</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='reserpine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'telmisartan',
    'C<sub>33</sub>H<sub>30</sub>N<sub>4</sub>O<sub>2</sub>',
    '',
    '144701-48-4',
    'RMMXLENWKUUMAY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>14</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='telmisartan'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'telaprevir',
    'C<sub>36</sub>H<sub>53</sub>N<sub>7</sub>O<sub>6</sub>',
    '',
    '402957-28-2',
    'BBAWEDCPNXPBQM-GDEBMMAJSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>25</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='telaprevir'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'lopinavir',
    'C<sub>37</sub>H<sub>48</sub>N<sub>4</sub>O<sub>5</sub>',
    '',
    '192725-17-0',
    'KJHKTHWMRKYKJE-WRHCQWCJSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>22</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='lopinavir'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'atazanavir',
    'C<sub>38</sub>H<sub>52</sub>N<sub>6</sub>O<sub>7</sub>',
    '',
    '198904-31-3',
    'AXRYRYVKAWYZBR-GASGPIRDSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>26</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='atazanavir'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tylosin',
    'C<sub>46</sub>H<sub>77</sub>NO<sub>17</sub>',
    '',
    '1401-69-0',
    'WBPYTXDJUQJLPQ-SNQVITFCSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>32</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tylosin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nystatin',
    'C<sub>47</sub>H<sub>75</sub>NO<sub>17</sub>',
    '',
    '1400-61-9',
    'VQOXZBDYSJBXMA-QFHUWGMOSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nystatin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3,5-tris(3,5-di-<i>tert</i>-butyl-4-hydroxybenzyl)-1,3,5-triazinane-2,4,6-trione',
    'C<sub>48</sub>H<sub>69</sub>N<sub>3</sub>O<sub>6</sub>',
    '',
    '27676-62-6',
    'VNQNXQYZMPJLQX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Heterocycles with oxygen and nitrogen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>20</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-tris(3,5-di-<i>tert</i>-butyl-4-hydroxybenzyl)-1,3,5-triazinane-2,4,6-trione'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>12</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-tris(3,5-di-<i>tert</i>-butyl-4-hydroxybenzyl)-1,3,5-triazinane-2,4,6-trione'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-tris(3,5-di-<i>tert</i>-butyl-4-hydroxybenzyl)-1,3,5-triazinane-2,4,6-trione'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>14</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-tris(3,5-di-<i>tert</i>-butyl-4-hydroxybenzyl)-1,3,5-triazinane-2,4,6-trione'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Nitrates (RONO<sub>2</sub>)',
    (SELECT id from categories WHERE catname='Organic species with nitrogen (N)'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'urea nitrate',
    'CH<sub>5</sub>N<sub>3</sub>O<sub>4</sub>',
    '',
    '124-47-0',
    'AYTGUZPQPXGYFS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='urea nitrate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl nitrate',
    'CH<sub>3</sub>ONO<sub>2</sub>',
    '',
    '598-58-3',
    'LRMHVVPPGGOAJQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '4700',
    'L',
    (SELECT id from species WHERE iupac='methyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '4700',
    'L',
    (SELECT id from species WHERE iupac='methyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '4700',
    'L',
    (SELECT id from species WHERE iupac='methyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '4700',
    'L',
    (SELECT id from species WHERE iupac='methyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '4700',
    'M',
    (SELECT id from species WHERE iupac='methyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='541'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='methyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='19'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4900',
    'Q',
    (SELECT id from species WHERE iupac='methyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4800',
    '?',
    (SELECT id from species WHERE iupac='methyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyl nitrate',
    'C<sub>2</sub>H<sub>5</sub>ONO<sub>2</sub>',
    '',
    '625-58-1',
    'IDNUEBSJWINEMI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '5400',
    'L',
    (SELECT id from species WHERE iupac='ethyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '5400',
    'L',
    (SELECT id from species WHERE iupac='ethyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '5400',
    'L',
    (SELECT id from species WHERE iupac='ethyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '5400',
    'L',
    (SELECT id from species WHERE iupac='ethyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '5400',
    'M',
    (SELECT id from species WHERE iupac='ethyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='541'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-propyl nitrate',
    'C<sub>3</sub>H<sub>7</sub>ONO<sub>2</sub>',
    '',
    '627-13-4',
    'JNTOKFNBDFMTIV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '5500',
    'L',
    (SELECT id from species WHERE iupac='1-propyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '5500',
    'L',
    (SELECT id from species WHERE iupac='1-propyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '5500',
    'L',
    (SELECT id from species WHERE iupac='1-propyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '5500',
    'L',
    (SELECT id from species WHERE iupac='1-propyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;3</sup>',
    '5600',
    'L',
    (SELECT id from species WHERE iupac='1-propyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;3</sup>',
    '4600',
    'M',
    (SELECT id from species WHERE iupac='1-propyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='1024'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '5500',
    'M',
    (SELECT id from species WHERE iupac='1-propyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='541'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-propyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='1024'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-propyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-propyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-propyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-propyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-propyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-propyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-propyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-propyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-propyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-propyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5600',
    'Q',
    (SELECT id from species WHERE iupac='1-propyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-propyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4600',
    '?',
    (SELECT id from species WHERE iupac='1-propyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-propyl nitrate',
    'C<sub>3</sub>H<sub>7</sub>ONO<sub>2</sub>',
    'isopropyl nitrate',
    '1712-64-7',
    'GAPFWGOSHOCNBM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;3</sup>',
    '5400',
    'L',
    (SELECT id from species WHERE iupac='2-propyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;3</sup>',
    '5400',
    'L',
    (SELECT id from species WHERE iupac='2-propyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;3</sup>',
    '5400',
    'L',
    (SELECT id from species WHERE iupac='2-propyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;3</sup>',
    '5400',
    'L',
    (SELECT id from species WHERE iupac='2-propyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;3</sup>',
    '5400',
    'L',
    (SELECT id from species WHERE iupac='2-propyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;3</sup>',
    '4300',
    'M',
    (SELECT id from species WHERE iupac='2-propyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='1024'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;3</sup>',
    '5400',
    'M',
    (SELECT id from species WHERE iupac='2-propyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='541'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-propyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='1024'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4600',
    'Q',
    (SELECT id from species WHERE iupac='2-propyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-propyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4300',
    '?',
    (SELECT id from species WHERE iupac='2-propyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-butyl nitrate',
    'C<sub>4</sub>H<sub>9</sub>ONO<sub>2</sub>',
    '',
    '928-45-0',
    'QQHZPQUHCAKSOL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '5800',
    'L',
    (SELECT id from species WHERE iupac='1-butyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '5800',
    'L',
    (SELECT id from species WHERE iupac='1-butyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '5800',
    'L',
    (SELECT id from species WHERE iupac='1-butyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '5800',
    'L',
    (SELECT id from species WHERE iupac='1-butyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;3</sup>',
    '6000',
    'L',
    (SELECT id from species WHERE iupac='1-butyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;3</sup>',
    '5200',
    'M',
    (SELECT id from species WHERE iupac='1-butyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='1024'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '5800',
    'M',
    (SELECT id from species WHERE iupac='1-butyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='541'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '6000',
    'M',
    (SELECT id from species WHERE iupac='1-butyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='533'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-butyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='1024'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5900',
    'Q',
    (SELECT id from species WHERE iupac='1-butyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-butyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5800',
    '?',
    (SELECT id from species WHERE iupac='1-butyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-butyl nitrate',
    'C<sub>4</sub>H<sub>9</sub>ONO<sub>2</sub>',
    '',
    '924-52-7',
    'DYONNFFVDNILGI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;3</sup>',
    '5400',
    'L',
    (SELECT id from species WHERE iupac='2-butyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;3</sup>',
    '5400',
    'L',
    (SELECT id from species WHERE iupac='2-butyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;3</sup>',
    '5400',
    'L',
    (SELECT id from species WHERE iupac='2-butyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;3</sup>',
    '5400',
    'L',
    (SELECT id from species WHERE iupac='2-butyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;3</sup>',
    '6100',
    'L',
    (SELECT id from species WHERE iupac='2-butyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-butyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='1024'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;3</sup>',
    '5400',
    'M',
    (SELECT id from species WHERE iupac='2-butyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='541'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;3</sup>',
    '5600',
    'M',
    (SELECT id from species WHERE iupac='2-butyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='533'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-butyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='1024'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4900',
    'Q',
    (SELECT id from species WHERE iupac='2-butyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5400',
    '?',
    (SELECT id from species WHERE iupac='2-butyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'isobutyl nitrate',
    'C<sub>4</sub>H<sub>9</sub>ONO<sub>2</sub>',
    '',
    '543-29-3',
    'LNNXFUZKZLXPOF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;3</sup>',
    '5200',
    'M',
    (SELECT id from species WHERE iupac='isobutyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='541'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isobutyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isobutyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isobutyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isobutyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isobutyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isobutyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isobutyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isobutyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isobutyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isobutyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='isobutyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-pentyl nitrate',
    'C<sub>5</sub>H<sub>11</sub>ONO<sub>2</sub>',
    'amyl nitrate',
    '1002-16-0',
    'HSNWZBCBUUSSQD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;3</sup>',
    '6300',
    'M',
    (SELECT id from species WHERE iupac='1-pentyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='1024'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-pentyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='541'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-pentyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='1024'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6300',
    'Q',
    (SELECT id from species WHERE iupac='1-pentyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-pentyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6300',
    '?',
    (SELECT id from species WHERE iupac='1-pentyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-pentyl nitrate',
    'C<sub>5</sub>H<sub>11</sub>ONO<sub>2</sub>',
    'MCM:PEBNO3',
    '21981-48-6',
    'RWRBSYOTDDOXKC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;3</sup>',
    '6400',
    'L',
    (SELECT id from species WHERE iupac='2-pentyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;3</sup>',
    '5100',
    'M',
    (SELECT id from species WHERE iupac='2-pentyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='1024'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '6300',
    'M',
    (SELECT id from species WHERE iupac='2-pentyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='541'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-pentyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='1024'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '6000',
    'Q',
    (SELECT id from species WHERE iupac='2-pentyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5300',
    'Q',
    (SELECT id from species WHERE iupac='2-pentyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-pentyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5100',
    '?',
    (SELECT id from species WHERE iupac='2-pentyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-pentyl nitrate',
    'C<sub>5</sub>H<sub>13</sub>ONO<sub>2</sub>',
    '',
    '82944-59-0',
    'WQZKKVJFBZPJSU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '5300',
    'M',
    (SELECT id from species WHERE iupac='3-pentyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='1024'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-pentyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='1024'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-pentyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-pentyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-pentyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-pentyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-pentyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-pentyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-pentyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-pentyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-pentyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-pentyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5300',
    'Q',
    (SELECT id from species WHERE iupac='3-pentyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-pentyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5300',
    '?',
    (SELECT id from species WHERE iupac='3-pentyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-1-butanol nitrate',
    'C<sub>5</sub>H<sub>11</sub>ONO<sub>2</sub>',
    'isoamyl nitrate',
    '543-87-3',
    'NTHGIYFSMNNHSC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;3</sup>',
    '5900',
    'M',
    (SELECT id from species WHERE iupac='3-methyl-1-butanol nitrate'),
    (SELECT id from literature WHERE bibtexkey='1024'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-butanol nitrate'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-butanol nitrate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-butanol nitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-butanol nitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-butanol nitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-butanol nitrate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-butanol nitrate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6300',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-butanol nitrate'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-methyl-1-butanol nitrate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5900',
    '?',
    (SELECT id from species WHERE iupac='3-methyl-1-butanol nitrate'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pentaerythritol tetranitrate',
    'C<sub>5</sub>H<sub>8</sub>N<sub>4</sub>O<sub>12</sub>',
    '',
    '78-11-5',
    'TZRXHJWUDPFEEY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pentaerythritol tetranitrate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'X',
    (SELECT id from species WHERE iupac='pentaerythritol tetranitrate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentaerythritol tetranitrate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentaerythritol tetranitrate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentaerythritol tetranitrate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentaerythritol tetranitrate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentaerythritol tetranitrate'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-hexyl nitrate',
    'C<sub>6</sub>H<sub>13</sub>ONO<sub>2</sub>',
    '',
    '20633-11-8',
    'AGDYNDJUZRMYRG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;3</sup>',
    '6700',
    'M',
    (SELECT id from species WHERE iupac='1-hexyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='1024'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hexyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='1024'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6600',
    'Q',
    (SELECT id from species WHERE iupac='1-hexyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-hexyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6700',
    '?',
    (SELECT id from species WHERE iupac='1-hexyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-nitrooxyethanol',
    'HOC<sub>2</sub>H<sub>4</sub>ONO<sub>2</sub>',
    '',
    '16051-48-2',
    'HTKIMWYSDZQQBP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2-nitrooxyethanol'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2-nitrooxyethanol'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2-nitrooxyethanol'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2-nitrooxyethanol'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>2</sup>',
    '8600',
    'M',
    (SELECT id from species WHERE iupac='2-nitrooxyethanol'),
    (SELECT id from literature WHERE bibtexkey='548'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-nitrooxyethanol'),
    (SELECT id from literature WHERE bibtexkey='541'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrooxyethanol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrooxyethanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrooxyethanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrooxyethanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrooxyethanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrooxyethanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrooxyethanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrooxyethanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrooxyethanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrooxyethanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '9200',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrooxyethanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-nitrooxyethanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '8700',
    '?',
    (SELECT id from species WHERE iupac='2-nitrooxyethanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-nitrooxy-2-propanol',
    'C<sub>3</sub>H<sub>7</sub>O<sub>4</sub>N',
    '',
    '20266-65-3',
    'OMDFJTSKBNDDRM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-nitrooxy-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-nitrooxy-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-nitrooxy-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-nitrooxy-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '10000',
    'M',
    (SELECT id from species WHERE iupac='1-nitrooxy-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='548'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-nitrooxy-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='541'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '541iso',
    '541', 'Kames and Schurath (1992) were unable to assign the values to the isomers.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='541iso'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-nitrooxy-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='541'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='541iso'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitrooxy-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitrooxy-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitrooxy-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitrooxy-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitrooxy-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitrooxy-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitrooxy-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitrooxy-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitrooxy-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitrooxy-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-nitrooxy-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-nitrooxy-1-propanol',
    'C<sub>3</sub>H<sub>7</sub>O<sub>4</sub>N',
    '',
    '20266-74-4',
    'HGCMMKIIGJXXMW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2-nitrooxy-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2-nitrooxy-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2-nitrooxy-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2-nitrooxy-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>1</sup>',
    '8800',
    'M',
    (SELECT id from species WHERE iupac='2-nitrooxy-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='548'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-nitrooxy-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='541'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='541iso'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-nitrooxy-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='541'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='541iso'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrooxy-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrooxy-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrooxy-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrooxy-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrooxy-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrooxy-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrooxy-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrooxy-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrooxy-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrooxy-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-nitrooxy-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-nitrooxy-2-butanol',
    'C<sub>4</sub>H<sub>9</sub>O<sub>4</sub>N',
    '',
    '147794-11-4',
    'KNUQGVIXAYDSOX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-nitrooxy-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='1217'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at291K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>1</sup>',
    '9200',
    'M',
    (SELECT id from species WHERE iupac='1-nitrooxy-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='548'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitrooxy-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitrooxy-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitrooxy-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitrooxy-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitrooxy-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitrooxy-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitrooxy-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitrooxy-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitrooxy-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitrooxy-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-nitrooxy-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-nitrooxy-1-butanol',
    'C<sub>4</sub>H<sub>9</sub>O<sub>4</sub>N',
    '',
    '147794-12-5',
    'YXMNEYKMHSBVTD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-nitrooxy-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='1217'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at291K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>1</sup>',
    '9600',
    'M',
    (SELECT id from species WHERE iupac='2-nitrooxy-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='548'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrooxy-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrooxy-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrooxy-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrooxy-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrooxy-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrooxy-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrooxy-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrooxy-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrooxy-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrooxy-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-nitrooxy-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-nitrooxy-3-butanol',
    'C<sub>4</sub>H<sub>9</sub>O<sub>4</sub>N',
    '',
    '147794-10-3',
    'CGFCSKMZZXPWEY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '9500',
    'M',
    (SELECT id from species WHERE iupac='2-nitrooxy-3-butanol'),
    (SELECT id from literature WHERE bibtexkey='548'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrooxy-3-butanol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrooxy-3-butanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrooxy-3-butanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrooxy-3-butanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrooxy-3-butanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrooxy-3-butanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrooxy-3-butanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrooxy-3-butanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrooxy-3-butanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrooxy-3-butanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-nitrooxy-3-butanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-nitrooxy-1-butanol',
    'C<sub>4</sub>H<sub>9</sub>O<sub>4</sub>N',
    '',
    '',
    'FOHXKGXDMSQVTH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3-nitrooxy-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='1217'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at291K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-nitrooxy-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-nitrooxy-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-nitrooxy-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-nitrooxy-1-butanol',
    'C<sub>4</sub>H<sub>9</sub>O<sub>4</sub>N',
    '',
    '22911-39-3',
    'FBOGSWRRYABFKU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='4-nitrooxy-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='1217'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at291K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nitrooxy-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nitrooxy-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nitrooxy-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-nitrooxy-2-butanol',
    'C<sub>4</sub>H<sub>9</sub>O<sub>4</sub>N',
    '3-hydroxy-1-nitrooxy-butane',
    '141299-18-5',
    'WUKDMTQXKGFHBU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='4-nitrooxy-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='1217'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at291K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nitrooxy-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nitrooxy-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nitrooxy-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-nitrooxy-1-pentanol',
    'C<sub>5</sub>H<sub>11</sub>O<sub>4</sub>N',
    '',
    '',
    'SVIFKHUNGQLAEN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='4-nitrooxy-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1217'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at291K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nitrooxy-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nitrooxy-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nitrooxy-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-nitrooxy-1-pentanol',
    'C<sub>5</sub>H<sub>11</sub>O<sub>4</sub>N',
    '',
    '',
    'DVOSRLSVEOCANS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='5-nitrooxy-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3766_O1',
    '3766', 'Ebert et&nbsp;al. (2023) present "curated experimental" Henry''s law constants from the literature but do not provide any references. It is only mentioned that the value is from a single original paper and measured directly.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_O1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-nitrooxy-2-pentanol',
    'C<sub>5</sub>H<sub>11</sub>O<sub>4</sub>N',
    'MCM:HO2C5NO3',
    '',
    'RIQPKERROQFFJK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='5-nitrooxy-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='1217'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at291K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '9900',
    'Q',
    (SELECT id from species WHERE iupac='5-nitrooxy-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-nitrooxy-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-nitrooxy-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-nitrooxy-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-nitrooxy-2-propanone',
    'CH<sub>3</sub>COCH<sub>2</sub>ONO<sub>2</sub>',
    'nitrooxyacetone',
    '6745-71-7',
    'ISWXYJQANHQYSR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-nitrooxy-2-propanone'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-nitrooxy-2-propanone'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-nitrooxy-2-propanone'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-nitrooxy-2-propanone'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-nitrooxy-2-propanone'),
    (SELECT id from literature WHERE bibtexkey='541'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitrooxy-2-propanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitrooxy-2-propanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitrooxy-2-propanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitrooxy-2-propanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitrooxy-2-propanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitrooxy-2-propanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitrooxy-2-propanone'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ISOP1N6CO',
    'C<sub>5</sub>H<sub>7</sub>NO<sub>5</sub>',
    '',
    '',
    'XXORYENTKCFFSM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>5</sup>',
    '14000',
    'Q',
    (SELECT id from species WHERE iupac='ISOP1N6CO'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'C52COCONO2',
    'C<sub>5</sub>H<sub>7</sub>NO<sub>5</sub>',
    '',
    '',
    'QJXLMYNMVOSKND-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>1</sup>',
    '11000',
    'Q',
    (SELECT id from species WHERE iupac='C52COCONO2'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ISOP1N23O4CO',
    'C<sub>5</sub>H<sub>7</sub>NO<sub>5</sub>',
    '',
    '',
    'WBVYILWVTRBTDJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '12000',
    'Q',
    (SELECT id from species WHERE iupac='ISOP1N23O4CO'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ROO6R7ONO2',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>5</sub>',
    '',
    '',
    'COKJDYWOSQONMU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>4</sup>',
    '13000',
    'Q',
    (SELECT id from species WHERE iupac='ROO6R7ONO2'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-heptyl nitrate',
    'C<sub>7</sub>H<sub>15</sub>NO<sub>3</sub>',
    'C7H15ONO2',
    '',
    'HHXLSUKHLTZWKR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '6600',
    'Q',
    (SELECT id from species WHERE iupac='2-heptyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'C7OHONO2',
    'C<sub>7</sub>H<sub>15</sub>NO<sub>4</sub>',
    '',
    '',
    'MZJHMUSTUUJGSJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '11000',
    'Q',
    (SELECT id from species WHERE iupac='C7OHONO2'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'C622CONO2',
    'C<sub>7</sub>H<sub>11</sub>NO<sub>5</sub>',
    '',
    '',
    'DJCVHBPUJHAWIU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>2</sup>',
    '14000',
    'Q',
    (SELECT id from species WHERE iupac='C622CONO2'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-octyl nitrate',
    'C<sub>8</sub>H<sub>17</sub>NO<sub>3</sub>',
    'C8H17ONO2',
    '',
    'QCOKASLKYUXYJH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8',
    '7000',
    'Q',
    (SELECT id from species WHERE iupac='2-octyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'C8OHONO2',
    'C<sub>8</sub>H<sub>17</sub>NO<sub>4</sub>',
    '',
    '',
    'UEQWMROPIQKFIM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0',
    '11000',
    'Q',
    (SELECT id from species WHERE iupac='C8OHONO2'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'C824ONO2',
    'C<sub>8</sub>H<sub>13</sub>NO<sub>5</sub>',
    '',
    '',
    'YMYILPYDFNRVBZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>6</sup>',
    '14000',
    'Q',
    (SELECT id from species WHERE iupac='C824ONO2'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'C819ONO2',
    'C<sub>8</sub>H<sub>13</sub>NO<sub>6</sub>',
    '',
    '',
    'XLUWXWLWQTYVOF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>6</sup>',
    '16000',
    'Q',
    (SELECT id from species WHERE iupac='C819ONO2'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'C92ONO2',
    'C<sub>9</sub>H<sub>15</sub>NO<sub>5</sub>',
    '',
    '',
    'PNFDSIMYWKOAKE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>5</sup>',
    '15000',
    'Q',
    (SELECT id from species WHERE iupac='C92ONO2'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'NORLIMONO2',
    'C<sub>9</sub>H<sub>15</sub>NO<sub>6</sub>',
    '',
    '',
    'MUTWZANDXPDWFF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>8</sup>',
    '16000',
    'Q',
    (SELECT id from species WHERE iupac='NORLIMONO2'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'C822CONO2',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>5</sub>',
    '',
    '',
    'RVFLVBTUEWAABB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>1</sup>',
    '13000',
    'Q',
    (SELECT id from species WHERE iupac='C822CONO2'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'C817CONO2',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>6</sub>',
    '',
    '',
    'LHFXXFGIVAQFTO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>5</sup>',
    '15000',
    'Q',
    (SELECT id from species WHERE iupac='C817CONO2'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'C9CONO2',
    'C<sub>10</sub>H<sub>15</sub>NO<sub>5</sub>',
    '',
    '',
    'FNVMVXZLPDKVAS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>1</sup>',
    '20000',
    'Q',
    (SELECT id from species WHERE iupac='C9CONO2'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'LIMONO2',
    'C<sub>10</sub>H<sub>15</sub>NO<sub>5</sub>',
    '',
    '',
    'DEKWHDOXDJNWRD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>4</sup>',
    '14000',
    'Q',
    (SELECT id from species WHERE iupac='LIMONO2'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-ethanediol dinitrate',
    'O<sub>3</sub>NCH<sub>2</sub>CH<sub>2</sub>ONO<sub>2</sub>',
    '1,2-ethane dinitrate',
    '628-96-6',
    'UQXKXGWGFRWILX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,2-ethanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,2-ethanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,2-ethanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,2-ethanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-ethanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='998'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'sameas978',
    '978', 'The same data were also published in Fischer and Ballschmiter (1998a).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='sameas978'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-ethanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='541'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-ethanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-ethanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-ethanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-ethanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-ethanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-propanediol dinitrate',
    'C<sub>3</sub>H<sub>6</sub>(ONO<sub>2</sub>)<sub>2</sub>',
    '1,2-propane dinitrate',
    '6423-43-4',
    'PSXCGTLGGVDWFU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,2-propanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,2-propanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,2-propanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,2-propanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-propanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='998'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='sameas978'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-propanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='541'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-propanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-propanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-propanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-propanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-propanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3-propanediol dinitrate',
    'C<sub>3</sub>H<sub>6</sub>N<sub>2</sub>O<sub>6</sub>',
    '',
    '3457-90-7',
    'KOSAMXZBGUIISK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,3-propanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3500-3457-90-7',
    '3500', 'The formula of 1,3-propanediol dinitrate is incorrectly given as "O<sub>2</sub>NO<sub>2</sub>CH<sub>2</sub>CH<sub>2</sub>CH<sub>2</sub>ONO<sub>2</sub>" by Burkholder et&nbsp;al. (2019).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3500-3457-90-7'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,3-propanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3245-3457-90-7',
    '3245', 'The formula of 1,3-propanediol dinitrate is incorrectly given as "O<sub>2</sub>NO<sub>2</sub>CH<sub>2</sub>CH<sub>2</sub>CH<sub>2</sub>ONO<sub>2</sub>" by Burkholder et&nbsp;al. (2015).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3245-3457-90-7'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,3-propanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='998'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='sameas978'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-propanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-propanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-propanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-propanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3-propanetriol trinitrate',
    'C<sub>3</sub>H<sub>5</sub>N<sub>3</sub>O<sub>9</sub>',
    'nitroglycerin',
    '55-63-0',
    'SNIOPGDIGTZGOP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3-propanetriol trinitrate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,2,3-propanetriol trinitrate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-propanetriol trinitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-propanetriol trinitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-propanetriol trinitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-propanetriol trinitrate'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-propanetriol trinitrate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2,3-propanetriol trinitrate'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-butanediol dinitrate',
    'C<sub>4</sub>H<sub>8</sub>N<sub>2</sub>O<sub>6</sub>',
    '',
    '20820-41-1',
    'CTISQZXTUUHJNC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-butanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='998'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='sameas978'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-butanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-butanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-butanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3-butanediol dinitrate',
    'C<sub>4</sub>H<sub>8</sub>N<sub>2</sub>O<sub>6</sub>',
    '',
    '6423-44-5',
    'DGFBULNMARLFTH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,3-butanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='998'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='sameas978'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-butanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-butanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-butanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4-butanediol dinitrate',
    'C<sub>4</sub>H<sub>8</sub>N<sub>2</sub>O<sub>6</sub>',
    '',
    '3457-91-8',
    'QELUAJBXJAWSRC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,4-butanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='998'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='sameas978'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-butanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-butanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-butanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-butanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-butanediol dinitrate',
    'C<sub>4</sub>H<sub>8</sub>N<sub>2</sub>O<sub>6</sub>',
    '',
    '6423-45-6',
    'RVDDYBGRQLZMSB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3-butanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='998'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='sameas978'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-butanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-butanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-butanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-pentanediol dinitrate',
    'C<sub>5</sub>H<sub>10</sub>N<sub>2</sub>O<sub>6</sub>',
    '',
    '89365-05-9',
    'MZWHVGLDAWPHHW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-pentanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='998'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='sameas978'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4-pentanediol dinitrate',
    'C<sub>5</sub>H<sub>10</sub>N<sub>2</sub>O<sub>6</sub>',
    '',
    '25385-63-1',
    'IUTIKUKYGRINOD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,4-pentanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='998'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='sameas978'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,5-pentanediol dinitrate',
    'C<sub>5</sub>H<sub>10</sub>N<sub>2</sub>O<sub>6</sub>',
    '',
    '3457-92-9',
    'MIYIEPHJPVBSEV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,5-pentanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='998'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='sameas978'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,5-pentanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,5-pentanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,5-pentanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(2R,4S)-2,4-pentanediol dinitrate',
    'C<sub>5</sub>H<sub>10</sub>N<sub>2</sub>O<sub>6</sub>',
    '<i>cis</i>-2,4-pentanediol dinitrate',
    '208252-05-5',
    '',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='(2R,4S)-2,4-pentanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='998'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='sameas978'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(2R,4R)-2,4-pentanediol dinitrate',
    'C<sub>5</sub>H<sub>10</sub>N<sub>2</sub>O<sub>6</sub>',
    '<i>trans</i>-2,4-pentanediol dinitrate',
    '208252-04-4',
    '',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='(2R,4R)-2,4-pentanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='998'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='sameas978'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-hexanediol dinitrate',
    'C<sub>6</sub>H<sub>12</sub>N<sub>2</sub>O<sub>6</sub>',
    '',
    '110539-07-6',
    'UJKJGCZXZPXTGS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-hexanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='998'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='sameas978'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,5-hexanediol dinitrate',
    'C<sub>6</sub>H<sub>12</sub>N<sub>2</sub>O<sub>6</sub>',
    '',
    '206443-83-6',
    'PGDWEAOSOZNKFU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,5-hexanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='998'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='sameas978'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,6-hexanediol dinitrate',
    'C<sub>6</sub>H<sub>12</sub>N<sub>2</sub>O<sub>6</sub>',
    '',
    '3457-93-0',
    'GCVAYIWGKFFWEU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,6-hexanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='998'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='sameas978'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5-hexanediol dinitrate',
    'C<sub>6</sub>H<sub>12</sub>N<sub>2</sub>O<sub>6</sub>',
    '',
    '99115-63-6',
    'ISSLCMSTXXUOEU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,5-hexanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='998'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='sameas978'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-hexanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-hexanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-hexanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(1R,2S)-1,2-cyclohexanediol dinitrate',
    'C<sub>6</sub>H<sub>10</sub>N<sub>2</sub>O<sub>6</sub>',
    '<i>cis</i>-1,2-cyclohexanediol dinitrate',
    '32342-28-2',
    '',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'M',
    (SELECT id from species WHERE iupac='(1R,2S)-1,2-cyclohexanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='998'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='sameas978'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(1R,2R)-1,2-cyclohexanediol dinitrate',
    'C<sub>6</sub>H<sub>10</sub>N<sub>2</sub>O<sub>6</sub>',
    '<i>trans</i>-1,2-cyclohexanediol dinitrate',
    '32342-29-3',
    '',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='(1R,2R)-1,2-cyclohexanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='998'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='sameas978'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(1R,3S)-1,3-cyclohexanediol dinitrate',
    'C<sub>6</sub>H<sub>10</sub>N<sub>2</sub>O<sub>6</sub>',
    '<i>cis</i>-1,3-cyclohexanediol dinitrate',
    '170994-36-2',
    '',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4',
    '',
    'M',
    (SELECT id from species WHERE iupac='(1R,3S)-1,3-cyclohexanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='998'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='sameas978'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(1R,3R)-1,3-cyclohexanediol dinitrate',
    'C<sub>6</sub>H<sub>10</sub>N<sub>2</sub>O<sub>6</sub>',
    '<i>trans</i>-1,3-cyclohexanediol dinitrate',
    '170994-41-9',
    '',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='(1R,3R)-1,3-cyclohexanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='998'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='sameas978'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,7-heptanediol dinitrate',
    'C<sub>7</sub>H<sub>14</sub>N<sub>2</sub>O<sub>6</sub>',
    '',
    '3457-94-1',
    'KIERETFMVSIXIJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,7-heptanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='998'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='sameas978'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(1R,2R)-1,2-cycloheptanediol dinitrate',
    'C<sub>7</sub>H<sub>12</sub>N<sub>2</sub>O<sub>6</sub>',
    '<i>trans</i>-1,2-cycloheptanediol dinitrate',
    '208252-06-6',
    '',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='(1R,2R)-1,2-cycloheptanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='998'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='sameas978'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-octanediol dinitrate',
    'C<sub>8</sub>H<sub>16</sub>N<sub>2</sub>O<sub>6</sub>',
    '',
    '121222-48-8',
    'RLNKMZWMCSTIEM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-octanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='998'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='sameas978'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,8-octanediol dinitrate',
    'C<sub>8</sub>H<sub>16</sub>N<sub>2</sub>O<sub>6</sub>',
    '',
    '3457-95-2',
    'BVIHOKFRPSZJEI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,8-octanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='998'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='sameas978'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-decanediol dinitrate',
    'C<sub>10</sub>H<sub>20</sub>N<sub>2</sub>O<sub>6</sub>',
    '',
    '60123-40-2',
    'KKNGVXOJDIUADE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-decanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='998'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='sameas978'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,10-decanediol dinitrate',
    'C<sub>10</sub>H<sub>20</sub>N<sub>2</sub>O<sub>6</sub>',
    '',
    '3457-97-4',
    'RHUZOYMELURURD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,10-decanediol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='998'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='sameas978'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diethylene glycol dinitrate',
    'C<sub>4</sub>H<sub>8</sub>N<sub>2</sub>O<sub>7</sub>',
    '',
    '693-21-0',
    'LYAGTVMJGHTIDH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diethylene glycol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethylene glycol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethylene glycol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethylene glycol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethylene glycol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethylene glycol dinitrate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ISOP1N2ONO2',
    'C<sub>5</sub>H<sub>8</sub>N<sub>2</sub>O<sub>6</sub>',
    '',
    '',
    'FQSKJUXVWIFNKX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '9400',
    'Q',
    (SELECT id from species WHERE iupac='ISOP1N2ONO2'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'EPXISOPNONO2',
    'C<sub>5</sub>H<sub>8</sub>N<sub>2</sub>O<sub>7</sub>',
    '',
    '',
    'UAFKAIYDADHRMX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>1</sup>',
    '13000',
    'Q',
    (SELECT id from species WHERE iupac='EPXISOPNONO2'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ISOP1N23O4ONO2',
    'C<sub>5</sub>H<sub>8</sub>N<sub>2</sub>O<sub>7</sub>',
    '',
    '',
    'FSZUIXLMCRZJMS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>1</sup>',
    '13000',
    'Q',
    (SELECT id from species WHERE iupac='ISOP1N23O4ONO2'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ISOP1N5ONO2',
    'C<sub>5</sub>H<sub>8</sub>N<sub>2</sub>O<sub>7</sub>',
    '',
    '',
    'WRGRJJOKHABEJT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>4</sup>',
    '13000',
    'Q',
    (SELECT id from species WHERE iupac='ISOP1N5ONO2'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'LIMAB15ONO22',
    'C<sub>10</sub>H<sub>18</sub>N<sub>2</sub>O<sub>8</sub>',
    '',
    '',
    'UNHNJOVXNACOSQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>7</sup>',
    '18000',
    'Q',
    (SELECT id from species WHERE iupac='LIMAB15ONO22'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'peroxyacetyl nitrate',
    'CH<sub>3</sub>COOONO<sub>2</sub>',
    'PAN',
    '2278-22-0',
    'VGQXTTSVLMQFHM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '5700',
    'L',
    (SELECT id from species WHERE iupac='peroxyacetyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '5700',
    'L',
    (SELECT id from species WHERE iupac='peroxyacetyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '5700',
    'L',
    (SELECT id from species WHERE iupac='peroxyacetyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2828'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '5700',
    'L',
    (SELECT id from species WHERE iupac='peroxyacetyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '5700',
    'L',
    (SELECT id from species WHERE iupac='peroxyacetyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '5800',
    'L',
    (SELECT id from species WHERE iupac='peroxyacetyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='1182'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '5600',
    'M',
    (SELECT id from species WHERE iupac='peroxyacetyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3769'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '4800',
    'M',
    (SELECT id from species WHERE iupac='peroxyacetyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3531'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='peroxyacetyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='624'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '6500',
    'M',
    (SELECT id from species WHERE iupac='peroxyacetyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='502'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='peroxyacetyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='513'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at283K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='peroxyacetyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='gaffney84'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from715'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '5900',
    'C',
    (SELECT id from species WHERE iupac='peroxyacetyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='34'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='peroxyacetyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='19'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='peroxyacetyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='peroxyacetyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='peroxyacetyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='peroxyacetyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='peroxyacetyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='peroxyacetyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='peroxyacetyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='peroxyacetyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='peroxyacetyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='peroxyacetyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4800',
    'Q',
    (SELECT id from species WHERE iupac='peroxyacetyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='peroxyacetyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6300',
    '?',
    (SELECT id from species WHERE iupac='peroxyacetyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    '?',
    (SELECT id from species WHERE iupac='peroxyacetyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='669'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '669',
    '624,669', 'Comparing the value with that from the cited publication (Kames and Schurath, 1995), it can be seen that the unit and the temperature listed in Table&nbsp;3 of Warneck et&nbsp;al. (1996) are incorrect.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='669'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='peroxyacetyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='672'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '672-2278-22-0',
    '624,672', 'The data from Kames and Schurath (1995) for peroxyacetyl nitrate are incorrectly cited by Schurath et&nbsp;al. (1996).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='672-2278-22-0'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'peroxypropionyl nitrate',
    'C<sub>2</sub>H<sub>5</sub>COOONO<sub>2</sub>',
    'PPN',
    '5796-89-4',
    'TXINBPKSWKFMNB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '6000',
    'M',
    (SELECT id from species WHERE iupac='peroxypropionyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3769'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='peroxypropionyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='624'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='peroxypropionyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='peroxypropionyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='peroxypropionyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='peroxypropionyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='peroxypropionyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='peroxypropionyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    '?',
    (SELECT id from species WHERE iupac='peroxypropionyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='669'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='669'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='peroxypropionyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='672'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '672-5796-89-4',
    '624,672', 'The data from Kames and Schurath (1995) for peroxypropionyl nitrate are incorrectly cited by Schurath et&nbsp;al. (1996).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='672-5796-89-4'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nitro butaneperoxoate',
    'C<sub>3</sub>H<sub>7</sub>COOONO<sub>2</sub>',
    'PnBN',
    '27746-48-1',
    'HZUMMZVMNQSPFF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='nitro butaneperoxoate'),
    (SELECT id from literature WHERE bibtexkey='624'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nitro butaneperoxoate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nitro butaneperoxoate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nitro butaneperoxoate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nitro butaneperoxoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nitro butaneperoxoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nitro butaneperoxoate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    '?',
    (SELECT id from species WHERE iupac='nitro butaneperoxoate'),
    (SELECT id from literature WHERE bibtexkey='669'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='669'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='nitro butaneperoxoate'),
    (SELECT id from literature WHERE bibtexkey='672'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '672-27746-48-1',
    '624,672', 'The data from Kames and Schurath (1995) for peroxy-n-butyl nitrate are incorrectly cited by Schurath et&nbsp;al. (1996).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='672-27746-48-1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'peroxy-2-propenoyl nitrate',
    'CH<sub>2</sub>C(CH<sub>3</sub>)COOONO<sub>2</sub>',
    'peroxymethacryloyl nitrate; MPAN',
    '88181-75-3',
    'LLZWPQFQEBKRLX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='peroxy-2-propenoyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='624'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='peroxy-2-propenoyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='peroxy-2-propenoyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='peroxy-2-propenoyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='peroxy-2-propenoyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='669'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='669'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='peroxy-2-propenoyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='672'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '672-88181-75-3',
    '624,672', 'The data from Kames and Schurath (1995) for peroxymethacryloyl nitrate are incorrectly cited by Schurath et&nbsp;al. (1996).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='672-88181-75-3'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'peroxy-isobutyryl nitrate',
    'C<sub>3</sub>H<sub>7</sub>COOONO<sub>2</sub>',
    'PiBN',
    '65424-60-4',
    'BDNFHGUXBRZLRQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='peroxy-isobutyryl nitrate'),
    (SELECT id from literature WHERE bibtexkey='624'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='peroxy-isobutyryl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='peroxy-isobutyryl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='peroxy-isobutyryl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='peroxy-isobutyryl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='peroxy-isobutyryl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='peroxy-isobutyryl nitrate'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    '?',
    (SELECT id from species WHERE iupac='peroxy-isobutyryl nitrate'),
    (SELECT id from literature WHERE bibtexkey='669'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='669'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='peroxy-isobutyryl nitrate'),
    (SELECT id from literature WHERE bibtexkey='672'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '672-65424-60-4',
    '624,672', 'The data from Kames and Schurath (1995) for peroxy-i-butyl nitrate are incorrectly cited by Schurath et&nbsp;al. (1996).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='672-65424-60-4'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'furoyl peroxynitrate',
    'C<sub>5</sub>H<sub>3</sub>NO<sub>6</sub>',
    'fur-PAN',
    '',
    'NMNZVYLGOWCHOD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;2</sup>',
    '8800',
    'M',
    (SELECT id from species WHERE iupac='furoyl peroxynitrate'),
    (SELECT id from literature WHERE bibtexkey='3726'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='furoyl peroxynitrate'),
    (SELECT id from literature WHERE bibtexkey='3726'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3726',
    '2546', 'Estimate based on Raventos-Duran et&nbsp;al. (2010).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3726'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CH3O2NO2',
    'CH<sub>3</sub>NO<sub>4</sub>',
    '',
    '',
    'LCFGXMPUQSXLCQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3O2NO2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3O2NO2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3O2NO2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ETHO2HNO3',
    'C<sub>2</sub>H<sub>5</sub>NO<sub>5</sub>',
    '',
    '',
    'IYCQDYYQELIXMU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETHO2HNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETHO2HNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETHO2HNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NO3CH2CO3H',
    'C<sub>2</sub>H<sub>3</sub>NO<sub>6</sub>',
    '',
    '',
    'VLCOOHYMNNDETJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NO3CH2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NO3CH2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NO3CH2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NO3CH2PAN',
    'C<sub>2</sub>H<sub>2</sub>N<sub>2</sub>O<sub>8</sub>',
    '',
    '',
    'CSNUPQYBRZIENU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NO3CH2PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NO3CH2PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NO3CH2PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ACRPAN',
    'C<sub>3</sub>H<sub>3</sub>NO<sub>5</sub>',
    '',
    '157258-66-7',
    'SFKRQQJZRXQGLC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACRPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACRPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACRPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACRPAN'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACRPAN'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACRPAN'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PR1O2HNO3',
    'C<sub>3</sub>H<sub>7</sub>NO<sub>5</sub>',
    '',
    '',
    'FROUFTMXOYPVCX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PR1O2HNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PR1O2HNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PR1O2HNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PR2O2HNO3',
    'C<sub>3</sub>H<sub>7</sub>NO<sub>5</sub>',
    '',
    '',
    'UHIVGIHVGRYUPL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PR2O2HNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PR2O2HNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PR2O2HNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PRNO3CO3H',
    'C<sub>3</sub>H<sub>5</sub>NO<sub>6</sub>',
    '',
    '',
    'FMRKJWQAPYMRJD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRNO3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRNO3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRNO3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PRNO3PAN',
    'C<sub>3</sub>H<sub>4</sub>N<sub>2</sub>O<sub>8</sub>',
    '',
    '',
    'ZLJYZUGEJFPONP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRNO3PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRNO3PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRNO3PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BU1ENO3OOH',
    'C<sub>4</sub>H<sub>9</sub>NO<sub>5</sub>',
    '',
    '',
    'MFTWJXGCASCYHP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BU1ENO3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BU1ENO3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BU1ENO3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C3DBPAN',
    'C<sub>4</sub>H<sub>5</sub>NO<sub>5</sub>',
    '',
    '',
    'YVSVRLGWMDVSPN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3DBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3DBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3DBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C42NO33OOH',
    'C<sub>4</sub>H<sub>9</sub>NO<sub>5</sub>',
    '',
    '',
    'CGBCWMNQUOIZIB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C42NO33OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C42NO33OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C42NO33OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C43NO34OOH',
    'C<sub>4</sub>H<sub>9</sub>NO<sub>5</sub>',
    '',
    '',
    'BQDGWSCZHPCGGT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C43NO34OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C43NO34OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C43NO34OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4PAN9',
    'C<sub>4</sub>H<sub>4</sub>N<sub>2</sub>O<sub>8</sub>',
    '',
    '',
    'SHASFEZZYJNCIM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4PAN9'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4PAN9'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4PAN9'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MPRANO3OOH',
    'C<sub>4</sub>H<sub>9</sub>NO<sub>5</sub>',
    '',
    '',
    'DTPMQEMACNJTBJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MPRANO3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MPRANO3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MPRANO3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MPRBNO3OOH',
    'C<sub>4</sub>H<sub>9</sub>NO<sub>5</sub>',
    '',
    '',
    'RCQWCNCMOFDCKD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MPRBNO3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MPRBNO3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MPRBNO3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MPRBNO3PAN',
    'C<sub>4</sub>H<sub>6</sub>N<sub>2</sub>O<sub>8</sub>',
    '',
    '',
    'RAYRXKOIFAVDJK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MPRBNO3PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MPRBNO3PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MPRBNO3PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MPRNO3CO3H',
    'C<sub>4</sub>H<sub>7</sub>NO<sub>6</sub>',
    '',
    '',
    'HDNCPEGDTKOFQI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MPRNO3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MPRNO3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MPRNO3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NBUTDAOOH',
    'C<sub>4</sub>H<sub>7</sub>NO<sub>5</sub>',
    '',
    '',
    'ZIAMBHNGSMXNCM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBUTDAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBUTDAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBUTDAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NBUTDBNO3',
    'C<sub>4</sub>H<sub>6</sub>N<sub>2</sub>O<sub>6</sub>',
    '',
    '',
    'GCQJZAFTGYZGDG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBUTDBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBUTDBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBUTDBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NBUTDBOOH',
    'C<sub>4</sub>H<sub>7</sub>NO<sub>5</sub>',
    '',
    '',
    'SSNXKZNERJCDKO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBUTDBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBUTDBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBUTDBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NC3CO3H',
    'C<sub>4</sub>H<sub>5</sub>NO<sub>6</sub>',
    '',
    '',
    'ZXNVOGOFZJSFAE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TC4H9NO3',
    'C<sub>4</sub>H<sub>9</sub>NO<sub>3</sub>',
    '',
    '926-05-6',
    'AZAKMLHUDVIDFN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TC4H9NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TC4H9NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TC4H9NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TC4H9NO3'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TC4H9NO3'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TC4H9NO3'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C3ME3PAN',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>5</sub>',
    '',
    '',
    'OLNWAQLSTCXURT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3ME3PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3ME3PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3ME3PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C3MNO3CO3H',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>6</sub>',
    '',
    '',
    'UNTXQXBLSROXLI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3MNO3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3MNO3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3MNO3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C3MNO3PAN',
    'C<sub>5</sub>H<sub>8</sub>N<sub>2</sub>O<sub>8</sub>',
    '',
    '',
    'ULZBZSVLLIBTGC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3MNO3PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3MNO3PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3MNO3PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C43NO3CO3H',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>6</sub>',
    '',
    '',
    'KYFRJEXZVMOAMN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C43NO3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C43NO3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C43NO3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C43NO3PAN',
    'C<sub>5</sub>H<sub>8</sub>N<sub>2</sub>O<sub>8</sub>',
    '',
    '',
    'WPFKHDFVFPXDFZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C43NO3PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C43NO3PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C43NO3PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4M2NO3OOH',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>5</sub>',
    '',
    '',
    'BOAAVKBCMOPNIQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4M2NO3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4M2NO3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4M2NO3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4MNO31OOH',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>5</sub>',
    '',
    '',
    'LRRBWUKXCGVENZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4MNO31OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4MNO31OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4MNO31OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4MNO32OOH',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>5</sub>',
    '',
    '',
    'HXNZNKRZULBVRO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4MNO32OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4MNO32OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4MNO32OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4NO32MOOH',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>5</sub>',
    '',
    '',
    'HCKTYRRBEFAEAC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4NO32MOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4NO32MOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4NO32MOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4NO3CO3H',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>6</sub>',
    '',
    '',
    'JPUVYTOGMBAUBQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4NO3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4NO3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4NO3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4NO3M1OOH',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>5</sub>',
    '',
    '',
    'MWSZSODDMCBKIX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4NO3M1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4NO3M1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4NO3M1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4NO3M2OOH',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>5</sub>',
    '',
    '',
    'QXHHHGYKLMZJBA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4NO3M2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4NO3M2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4NO3M2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4NO3PAN',
    'C<sub>5</sub>H<sub>8</sub>N<sub>2</sub>O<sub>8</sub>',
    '',
    '',
    'GGZFCBHNGNBLNW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4NO3PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4NO3PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4NO3PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C51NO32OOH',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>5</sub>',
    '',
    '',
    'YPLQKABNDDXYJG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C51NO32OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C51NO32OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C51NO32OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C52NO31OOH',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>5</sub>',
    '',
    '',
    'DCAGTGOPLFTTTQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C52NO31OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C52NO31OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C52NO31OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C52NO33OOH',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>5</sub>',
    '',
    '',
    'FQGADFCNSPWVJM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C52NO33OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C52NO33OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C52NO33OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C53NO32OOH',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>5</sub>',
    '',
    '',
    'STNFTACLRXEYDM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C53NO32OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C53NO32OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C53NO32OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5PAN18',
    'C<sub>5</sub>H<sub>6</sub>N<sub>2</sub>O<sub>8</sub>',
    '',
    '',
    'JYUXMKSXMIBDSN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN18'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN18'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN18'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5PAN4',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>5</sub>',
    '',
    '',
    'LGNOWHJLTKBAFC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN4'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN4'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN4'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5PAN6',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>5</sub>',
    '',
    '',
    'VQRIYOXAZWZCOV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN6'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN6'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN6'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPEANO3',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>3</sub>',
    '',
    '',
    'QSSWLPYLLKHHLB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPEANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPEANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPEANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPEBNO3',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>3</sub>',
    '',
    '',
    'OTVLXFGCWJFXJU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPEBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPEBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPEBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPECNO3',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>3</sub>',
    '',
    '',
    'UENFRVTUGZKXNH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPECNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPECNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPECNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NC4CO3H',
    'C<sub>5</sub>H<sub>7</sub>NO<sub>6</sub>',
    '',
    '',
    'SLKHOLOIOGBFQB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC4CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC4CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC4CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NEOPNO3',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>3</sub>',
    '',
    '',
    'YJGBGWFCCCQXIM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NEOPNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NEOPNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NEOPNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NISOPNO3',
    'C<sub>5</sub>H<sub>8</sub>N<sub>2</sub>O<sub>6</sub>',
    '',
    '',
    'JGJBVRGABXKDRR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6',
    '9400',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NISOPNO3'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NISOPNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NISOPNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NISOPNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NISOPOOH',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>5</sub>',
    '',
    '',
    'IRFXVIPRKCCSLU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>2</sup>',
    '11000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NISOPOOH'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NISOPOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NISOPOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NISOPOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PPEN',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>5</sub>',
    '',
    '',
    'UUYNBJNAIGBJAO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PPEN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PPEN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PPEN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C42MNO3OOH',
    'C<sub>6</sub>H<sub>13</sub>NO<sub>5</sub>',
    '',
    '',
    'KKTQLMUUOWWZBO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C42MNO3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C42MNO3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C42MNO3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C62NO33OOH',
    'C<sub>6</sub>H<sub>13</sub>NO<sub>5</sub>',
    '',
    '',
    'PJRWVMFJYMZPCW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C62NO33OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C62NO33OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C62NO33OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C63NO32OOH',
    'C<sub>6</sub>H<sub>13</sub>NO<sub>5</sub>',
    '',
    '',
    'RLIDOIUHNSZVBK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C63NO32OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C63NO32OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C63NO32OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C65NO36OOH',
    'C<sub>6</sub>H<sub>13</sub>NO<sub>5</sub>',
    '',
    '',
    'ZVRSMGCQHDCSBC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C65NO36OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C65NO36OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C65NO36OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C65NO3CO3H',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>6</sub>',
    '',
    '',
    'RASQUKWKKRVIQJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C65NO3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C65NO3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C65NO3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C65NO3PAN',
    'C<sub>6</sub>H<sub>10</sub>N<sub>2</sub>O<sub>8</sub>',
    '',
    '',
    'PNNYZMYYAAWSJH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C65NO3PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C65NO3PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C65NO3PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C66NO35OOH',
    'C<sub>6</sub>H<sub>13</sub>NO<sub>5</sub>',
    '',
    '',
    'YPVNGNKLOFDKIF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C66NO35OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C66NO35OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C66NO35OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6PAN10',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>5</sub>',
    '',
    '',
    'INNSDEOCGQAUTR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN10'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN10'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN10'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6PAN15',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>5</sub>',
    '',
    '',
    'GWYKJYISUPTXQD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN15'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN15'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN15'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6PAN17',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>5</sub>',
    '',
    '',
    'CUMLTNLXWSMQLS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN17'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN17'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN17'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6PAN18',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>5</sub>',
    '',
    '',
    'FPWBUKNMBKRQCI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN18'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN18'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN18'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6PAN3',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>5</sub>',
    '',
    '',
    'BRVOFEXYGAZHOW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CHEXNO3',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>3</sub>',
    '',
    '',
    'HLYOOCIMLHNMOG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHEXNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHEXNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHEXNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HEXBNO3',
    'C<sub>6</sub>H<sub>13</sub>NO<sub>3</sub>',
    '',
    '',
    'JLGBOJJVQLNMGV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;4</sup>',
    '6300',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEXBNO3'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEXBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEXBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEXBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HEXCNO3',
    'C<sub>6</sub>H<sub>13</sub>NO<sub>3</sub>',
    '',
    '',
    'OJOZCOXRANAOPV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEXCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEXCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEXCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:M22C43NO3',
    'C<sub>6</sub>H<sub>13</sub>NO<sub>3</sub>',
    '',
    '',
    'YUZOHIKIQPTSGJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M22C43NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M22C43NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M22C43NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:M22C4NO3',
    'C<sub>6</sub>H<sub>13</sub>NO<sub>3</sub>',
    '',
    '',
    'JOWPFKXUGRKJFA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M22C4NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M22C4NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M22C4NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:M23C43NO3',
    'C<sub>6</sub>H<sub>13</sub>NO<sub>3</sub>',
    '',
    '',
    'PMABLOPIFVACLQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M23C43NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M23C43NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M23C43NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:M23C4NO3',
    'C<sub>6</sub>H<sub>13</sub>NO<sub>3</sub>',
    '',
    '',
    'HHRFTVZVEUIWEO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M23C4NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M23C4NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M23C4NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:M2PEANO3',
    'C<sub>6</sub>H<sub>13</sub>NO<sub>3</sub>',
    '',
    '',
    'CETUNBADQVCCRS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2PEANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2PEANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2PEANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:M2PEBNO3',
    'C<sub>6</sub>H<sub>13</sub>NO<sub>3</sub>',
    '',
    '',
    'AYWPQHSAUPNICG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2PEBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2PEBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2PEBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:M2PECNO3',
    'C<sub>6</sub>H<sub>13</sub>NO<sub>3</sub>',
    '',
    '',
    'ZLERWGPAWILHHJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2PECNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2PECNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2PECNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:M2PEDNO3',
    'C<sub>6</sub>H<sub>13</sub>NO<sub>3</sub>',
    '',
    '',
    'LFIPHSRTIDHJFT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2PEDNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2PEDNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2PEDNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:M33C4NO3',
    'C<sub>6</sub>H<sub>13</sub>NO<sub>3</sub>',
    '',
    '',
    'DENSRMRCUIZNMK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M33C4NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M33C4NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M33C4NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:M3PEANO3',
    'C<sub>6</sub>H<sub>13</sub>NO<sub>3</sub>',
    '',
    '',
    'HRVRJIMBNILCGN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M3PEANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M3PEANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M3PEANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:M3PEBNO3',
    'C<sub>6</sub>H<sub>13</sub>NO<sub>3</sub>',
    '',
    '',
    'IEHIEWLLOPOHIZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M3PEBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M3PEBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M3PEBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:M3PECNO3',
    'C<sub>6</sub>H<sub>13</sub>NO<sub>3</sub>',
    '',
    '',
    'GFKONLNVJRACGN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M3PECNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M3PECNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M3PECNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PHXN',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>5</sub>',
    '',
    '',
    'ITHMZXMFOKWUTQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PHXN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PHXN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PHXN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HEPTNO3',
    'C<sub>7</sub>H<sub>15</sub>NO<sub>3</sub>',
    '',
    '',
    'RFSNRWONUSBTJN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEPTNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEPTNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEPTNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:M2HEXANO3',
    'C<sub>7</sub>H<sub>15</sub>NO<sub>3</sub>',
    '',
    '',
    'YZGBSAOHUZMZSL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2HEXANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2HEXANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2HEXANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:M2HEXBNO3',
    'C<sub>7</sub>H<sub>15</sub>NO<sub>3</sub>',
    '',
    '',
    'CORAYZMLWQTCOE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2HEXBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2HEXBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2HEXBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:M3HEXANO3',
    'C<sub>7</sub>H<sub>15</sub>NO<sub>3</sub>',
    '',
    '',
    'ZIINVFVZOGZDQJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M3HEXANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M3HEXANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M3HEXANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:M3HEXBNO3',
    'C<sub>7</sub>H<sub>15</sub>NO<sub>3</sub>',
    '',
    '',
    'ADYNXMRWYWNUDX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M3HEXBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M3HEXBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M3HEXBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PHPTN',
    'C<sub>7</sub>H<sub>13</sub>NO<sub>5</sub>',
    '',
    '',
    'XCJVDRQLXVBBEC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PHPTN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PHPTN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PHPTN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C8BCNO3',
    'C<sub>8</sub>H<sub>13</sub>NO<sub>3</sub>',
    '',
    '',
    'OSNOKXIMBITXOJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8BCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8BCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8BCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OCTNO3',
    'C<sub>8</sub>H<sub>17</sub>NO<sub>3</sub>',
    '',
    '',
    'KDICWCURMCOQTP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OCTNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OCTNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OCTNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NONNO3',
    'C<sub>9</sub>H<sub>19</sub>NO<sub>3</sub>',
    '',
    '',
    'YXUXBXICIGKFLH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NONNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NONNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NONNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DECNO3',
    'C<sub>10</sub>H<sub>21</sub>NO<sub>3</sub>',
    '',
    '',
    'VRGDYCVXNCXQKR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DECNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DECNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DECNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NAPINAOOH',
    'C<sub>10</sub>H<sub>17</sub>NO<sub>5</sub>',
    '',
    '',
    'IKGBGFRUISEOBM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NAPINAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NAPINAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NAPINAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NAPINBOOH',
    'C<sub>10</sub>H<sub>17</sub>NO<sub>5</sub>',
    '',
    '',
    'RUHGEBIMHPPSGQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NAPINBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NAPINBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NAPINBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NBPINAOOH',
    'C<sub>10</sub>H<sub>17</sub>NO<sub>5</sub>',
    '',
    '',
    'VJCKFKSOBAWLFB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBPINAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBPINAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBPINAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NBPINBOOH',
    'C<sub>10</sub>H<sub>17</sub>NO<sub>5</sub>',
    '',
    '',
    'AWECGRRBHMAEGP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBPINBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBPINBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBPINBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NC91CO3H',
    'C<sub>10</sub>H<sub>15</sub>NO<sub>6</sub>',
    '',
    '',
    'TWWSFGIBZQJYPL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC91CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC91CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC91CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NC91PAN',
    'C<sub>10</sub>H<sub>14</sub>N<sub>2</sub>O<sub>8</sub>',
    '',
    '',
    'LCMKIEFNSOTVJY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC91PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC91PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC91PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NLIMOOH',
    'C<sub>10</sub>H<sub>17</sub>NO<sub>5</sub>',
    '',
    '',
    'HSXYRSLOXSIYGP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NLIMOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NLIMOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NLIMOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:UDECNO3',
    'C<sub>11</sub>H<sub>23</sub>NO<sub>3</sub>',
    '',
    '',
    'KGEKWWIIMVPQKA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:UDECNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:UDECNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:UDECNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DDECNO3',
    'C<sub>12</sub>H<sub>25</sub>NO<sub>3</sub>',
    '',
    '',
    'BVAQOKLOUKLOJD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DDECNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DDECNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DDECNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NBCOOH',
    'C<sub>15</sub>H<sub>25</sub>NO<sub>5</sub>',
    '',
    '',
    'BEFFZATUSVKAHP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6H5CH2NO3',
    'C<sub>7</sub>H<sub>7</sub>NO<sub>3</sub>',
    '',
    '',
    'WOIVNLSVAKYSKX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6H5CH2NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6H5CH2NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6H5CH2NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PBZN',
    'C<sub>7</sub>H<sub>5</sub>NO<sub>5</sub>',
    '',
    '',
    'ONDCXZPWEKXYJE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBZN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBZN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBZN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6H5C2NO3',
    'C<sub>8</sub>H<sub>9</sub>NO<sub>3</sub>',
    '',
    '',
    'REJUUAZLLYKBCW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6H5C2NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6H5C2NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6H5C2NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6H5CH2PAN',
    'C<sub>8</sub>H<sub>7</sub>NO<sub>5</sub>',
    '',
    '',
    'KKRIGRPRRNIVGL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6H5CH2PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6H5CH2PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6H5CH2PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MXYLNO3',
    'C<sub>8</sub>H<sub>9</sub>NO<sub>3</sub>',
    '',
    '',
    'OIEIRDPNAPXLBC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYLNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYLNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYLNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MXYLPAN',
    'C<sub>8</sub>H<sub>7</sub>NO<sub>5</sub>',
    '',
    '',
    'HJGURQOGPAEQPE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYLPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYLPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYLPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NSTYRENOOH',
    'C<sub>8</sub>H<sub>9</sub>NO<sub>5</sub>',
    '',
    '',
    'LKBHTMHNYICJQS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NSTYRENOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NSTYRENOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NSTYRENOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OXYLNO3',
    'C<sub>8</sub>H<sub>9</sub>NO<sub>3</sub>',
    '',
    '',
    'WKRHODAGVPDBTG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYLNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYLNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYLNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OXYLPAN',
    'C<sub>8</sub>H<sub>7</sub>NO<sub>5</sub>',
    '',
    '',
    'TXXXSKKGTSQWKQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYLPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYLPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYLPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PXYLNO3',
    'C<sub>8</sub>H<sub>9</sub>NO<sub>3</sub>',
    '',
    '',
    'SHZSDLPSACZYMH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYLNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYLNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYLNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PXYLPAN',
    'C<sub>8</sub>H<sub>7</sub>NO<sub>5</sub>',
    '',
    '',
    'ZGFUWGCXWYZODV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYLPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYLPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYLPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ETOLNO3',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>3</sub>',
    '',
    '',
    'LYNFROWVHACAMO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETOLNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETOLNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETOLNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PHC3NO3',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>3</sub>',
    '',
    '',
    'IFDAHDBLKMQHMM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PHC3NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PHC3NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PHC3NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PHIC3NO3',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>3</sub>',
    '',
    '',
    'YCCLKZYFPBVILU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PHIC3NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PHIC3NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PHIC3NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TM123BNO3',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>3</sub>',
    '',
    '',
    'GDXSVUXDQKEMHM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM123BNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM123BNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM123BNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TM123BPAN',
    'C<sub>9</sub>H<sub>9</sub>NO<sub>5</sub>',
    '',
    '',
    'VMALQUVLPIFIEM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM123BPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM123BPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM123BPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TM124BNO3',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>3</sub>',
    '',
    '',
    'VLXWVVSZKXVGNM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124BNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124BNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124BNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TM124BPAN',
    'C<sub>9</sub>H<sub>9</sub>NO<sub>5</sub>',
    '',
    '',
    'SSMPYZHCWJGIJH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124BPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124BPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124BPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TMBNO3',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>3</sub>',
    '',
    '',
    'CHDZRXQPKVNDRJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TMBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TMBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TMBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TMBPAN',
    'C<sub>9</sub>H<sub>9</sub>NO<sub>5</sub>',
    '',
    '',
    'QURBGWBLEPWFEF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TMBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TMBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TMBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DM35EBNO3',
    'C<sub>10</sub>H<sub>13</sub>NO<sub>3</sub>',
    '',
    '',
    'CZPIEIXHJQQIGZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DM35EBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DM35EBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DM35EBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EMPHPAN',
    'C<sub>10</sub>H<sub>11</sub>NO<sub>5</sub>',
    '',
    '',
    'DPRDWMVUHNTRQI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EMPHPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EMPHPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EMPHPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DE35TNO3',
    'C<sub>11</sub>H<sub>15</sub>NO<sub>3</sub>',
    '',
    '',
    'XLLLSPDIGUQFTC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DE35TNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DE35TNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DE35TNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PHAN',
    'C<sub>2</sub>H<sub>3</sub>NO<sub>6</sub>',
    '',
    '',
    'KMDWHTZYVJXWAH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PHAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PHAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PHAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:A2PAN',
    'C<sub>3</sub>H<sub>5</sub>NO<sub>7</sub>',
    '',
    '',
    'RQFAVCUBLOXLKI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:A2PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:A2PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:A2PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C3PAN1',
    'C<sub>3</sub>H<sub>5</sub>NO<sub>6</sub>',
    '',
    '',
    'ZDHDBTZUUXEIQG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3PAN1'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3PAN1'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3PAN1'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO1C3NO3',
    'C<sub>3</sub>H<sub>7</sub>NO<sub>4</sub>',
    '',
    '100502-66-7',
    'PTMLFFXFTRSBJW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO1C3NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO1C3NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO1C3NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO1C3NO3'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO1C3NO3'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO1C3NO3'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPROPOLPAN',
    'C<sub>3</sub>H<sub>5</sub>NO<sub>6</sub>',
    '',
    '',
    'VGQGEUUGHUVAJJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPROPOLPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPROPOLPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPROPOLPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BUTDANO3',
    'C<sub>4</sub>H<sub>7</sub>NO<sub>4</sub>',
    '',
    '',
    'JVISETCEJQRRQM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BUTDANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BUTDANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BUTDANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BUTDBNO3',
    'C<sub>4</sub>H<sub>7</sub>NO<sub>4</sub>',
    '',
    '',
    'MVWTUBMDIKBQOB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BUTDBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BUTDBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BUTDBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4PAN1',
    'C<sub>4</sub>H<sub>7</sub>NO<sub>6</sub>',
    '',
    '',
    'ZAYFYZJEFHQRME-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4PAN1'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4PAN1'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4PAN1'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4PAN2',
    'C<sub>4</sub>H<sub>7</sub>NO<sub>7</sub>',
    '',
    '',
    'KFPIYXZEKUAVMP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4PAN2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4PAN2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4PAN2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4PAN3',
    'C<sub>4</sub>H<sub>7</sub>NO<sub>6</sub>',
    '',
    '',
    'PIBQEVCOTXTKAE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4PAN3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4PAN3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4PAN3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4PAN4',
    'C<sub>4</sub>H<sub>7</sub>NO<sub>6</sub>',
    '',
    '',
    'NXHSYZWHYBOEBH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4PAN4'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4PAN4'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4PAN4'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4PAN5',
    'C<sub>4</sub>H<sub>7</sub>NO<sub>6</sub>',
    '',
    '',
    'BZGCEXLIVXRKKX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4PAN5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4PAN5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4PAN5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4PAN7',
    'C<sub>4</sub>H<sub>5</sub>NO<sub>6</sub>',
    '',
    '',
    'YKQOPDHVAHDODD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4PAN7'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4PAN7'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4PAN7'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4PAN8',
    'C<sub>4</sub>H<sub>5</sub>NO<sub>6</sub>',
    '',
    '',
    'QZCDOTFCQHJUGH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4PAN8'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4PAN8'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4PAN8'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C56NO3',
    'C<sub>4</sub>H<sub>9</sub>NO<sub>5</sub>',
    '',
    '',
    'XYUWBXDQANMXIL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C56NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C56NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C56NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HMPAN',
    'C<sub>4</sub>H<sub>5</sub>NO<sub>6</sub>',
    '',
    '',
    'XPXMBKPWAOWOBP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HMPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HMPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HMPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO13C4NO3',
    'C<sub>4</sub>H<sub>9</sub>NO<sub>5</sub>',
    '',
    '',
    'IOYLZWMTXYBAPI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO13C4NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO13C4NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO13C4NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO3C3PAN',
    'C<sub>4</sub>H<sub>7</sub>NO<sub>6</sub>',
    '',
    '',
    'JGMDPJZYJFPSOE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C3PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C3PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C3PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IBUTOLBNO3',
    'C<sub>4</sub>H<sub>9</sub>NO<sub>4</sub>',
    '',
    '',
    'ILMPSGIQBJFTRG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IBUTOLBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IBUTOLBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IBUTOLBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IBUTOLCNO3',
    'C<sub>4</sub>H<sub>9</sub>NO<sub>4</sub>',
    '',
    '',
    'OARBGYKXUANYLR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IBUTOLCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IBUTOLCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IBUTOLCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MACRNBPAN',
    'C<sub>4</sub>H<sub>6</sub>N<sub>2</sub>O<sub>9</sub>',
    '',
    '',
    'HHPQSZXZUAZGAQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MACRNBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MACRNBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MACRNBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MACRNCO3H',
    'C<sub>4</sub>H<sub>7</sub>NO<sub>7</sub>',
    '',
    '',
    'VCAMMMQHKHRNFT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MACRNCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MACRNCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MACRNCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MACRNPAN',
    'C<sub>4</sub>H<sub>6</sub>N<sub>2</sub>O<sub>9</sub>',
    '',
    '',
    'YVNHVFURNFQJQM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MACRNPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MACRNPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MACRNPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NBUTDAOH',
    'C<sub>4</sub>H<sub>7</sub>NO<sub>4</sub>',
    '',
    '',
    'ZANUSWCYRLKDAN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBUTDAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBUTDAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBUTDAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TBUTOLNO3',
    'C<sub>4</sub>H<sub>9</sub>NO<sub>4</sub>',
    '',
    '',
    'SPXXYWSDFUWLEP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TBUTOLNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TBUTOLNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TBUTOLNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C3M3OH2PAN',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>6</sub>',
    '',
    '',
    'NSGPYXAFGPXNMV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3M3OH2PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3M3OH2PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3M3OH2PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C46PAN',
    'C<sub>5</sub>H<sub>7</sub>NO<sub>6</sub>',
    '',
    '',
    'WDMYRNZGJSFESH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C46PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C46PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C46PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4OH2CPAN',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>7</sub>',
    '',
    '',
    'INCMEOVDRBCULR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4OH2CPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4OH2CPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4OH2CPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4OHPAN',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>6</sub>',
    '',
    '',
    'GAAOIPAQIRGTBI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4OHPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4OHPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4OHPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C524NO3',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>5</sub>',
    '',
    '',
    'IRMGDWDXIVCKPE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C524NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C524NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C524NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C52NO3',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>4</sub>',
    '',
    '',
    'NBCYUKLMSBOGIC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C52NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C52NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C52NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C54NO3',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>5</sub>',
    '',
    '',
    'OXSZOTYJVSIXIT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C54NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C54NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C54NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C57NO3CO3H',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>8</sub>',
    '',
    '',
    'BPRAPKBGVRGZEK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C57NO3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C57NO3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C57NO3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C57NO3PAN',
    'C<sub>5</sub>H<sub>8</sub>N<sub>2</sub>O<sub>10</sub>',
    '',
    '',
    'QHZGCLHPLOENFL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C57NO3PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C57NO3PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C57NO3PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C58NO3CO3H',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>8</sub>',
    '',
    '',
    'NFQMHUFQLLKQQS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C58NO3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C58NO3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C58NO3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C58NO3PAN',
    'C<sub>5</sub>H<sub>8</sub>N<sub>2</sub>O<sub>10</sub>',
    '',
    '',
    'VIMTZSSJOGPGII-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C58NO3PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C58NO3PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C58NO3PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5PAN10',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>7</sub>',
    '',
    '',
    'YRCMXGZRWLAVBH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN10'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN10'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN10'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5PAN11',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>6</sub>',
    '',
    '',
    'ISSHIIFFUOEHLT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN11'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN11'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN11'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5PAN12',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>7</sub>',
    '',
    '',
    'VRGURBHINCFLEI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN12'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN12'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN12'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5PAN13',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>7</sub>',
    '',
    '',
    'GDYHQRWKNLRCBR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN13'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN13'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN13'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5PAN14',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>6</sub>',
    '',
    '',
    'KAYGTWBSLGDXRV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN14'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN14'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN14'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5PAN15',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>6</sub>',
    '',
    '',
    'DDVUSZKFLFMJLG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN15'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN15'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN15'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5PAN17',
    'C<sub>5</sub>H<sub>7</sub>NO<sub>6</sub>',
    '',
    '',
    'WOHMTHRFBCBPEN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN17'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN17'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN17'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5PAN19',
    'C<sub>5</sub>H<sub>7</sub>NO<sub>6</sub>',
    '',
    '',
    'SXXBKHKGTQGHOF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN19'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN19'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN19'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5PAN1',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>6</sub>',
    '',
    '',
    'BXAPPDLQCWAVAO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN1'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN1'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN1'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5PAN3',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>6</sub>',
    '',
    '',
    'GANOVMQBFKDCJS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5PAN5',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>6</sub>',
    '',
    '',
    'SNADUXVVPGYKTN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5PAN8',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>6</sub>',
    '',
    '',
    'AVADEHRLOLZNNT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN8'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN8'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN8'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H2M3C4NO3',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>4</sub>',
    '',
    '',
    'KRCHLCXLZXFPMO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M3C4NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M3C4NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M3C4NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HM22C3NO3',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>4</sub>',
    '',
    '',
    'GJZIQWDDCYOUOR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM22C3NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM22C3NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM22C3NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HM2C43NO3',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>4</sub>',
    '',
    '',
    'OLLXHFMQLUGEEM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM2C43NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM2C43NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM2C43NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HM33C3NO3',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>4</sub>',
    '',
    '',
    'LCUGTHWCLWAZIN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM33C3NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM33C3NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM33C3NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO13C5NO3',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>5</sub>',
    '',
    '',
    'HRXGEJHIRPMYKD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO13C5NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO13C5NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO13C5NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO24C5NO3',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>5</sub>',
    '',
    '',
    'GDKLMXJUXHUPHP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO24C5NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO24C5NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO24C5NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO2C54NO3',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>4</sub>',
    '',
    '',
    'BDOVYOMPHMUDCA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C54NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C54NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C54NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO2M2C4NO3',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>4</sub>',
    '',
    '',
    'JLEBTGVTEJACMC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2M2C4NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2M2C4NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2M2C4NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO3C5NO3',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>4</sub>',
    '',
    '',
    'VSJMKXXNGJNYTF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C5NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C5NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C5NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:INAHCO3H',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>8</sub>',
    '',
    '',
    'NANYPKIUOGNJFQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INAHCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INAHCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INAHCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:INAHPAN',
    'C<sub>5</sub>H<sub>8</sub>N<sub>2</sub>O<sub>10</sub>',
    '',
    '',
    'ISRNXRSYOJKFEQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INAHPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INAHPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INAHPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:INAHPCO3H',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>9</sub>',
    '',
    '',
    'ZYWYMWCOZFANRV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>12</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INAHPCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INAHPCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INAHPCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:INAHPPAN',
    'C<sub>5</sub>H<sub>8</sub>N<sub>2</sub>O<sub>11</sub>',
    '',
    '',
    'ZXVKOORKVQYPPA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INAHPPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INAHPPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INAHPPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:INANCO3H',
    'C<sub>5</sub>H<sub>8</sub>N<sub>2</sub>O<sub>10</sub>',
    '',
    '',
    'HKZKRKUNOXITIG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INANCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INANCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INANCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:INANO3',
    'C<sub>5</sub>H<sub>10</sub>N<sub>2</sub>O<sub>8</sub>',
    '',
    '',
    'VVVQXVVEBQASSQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:INANPAN',
    'C<sub>5</sub>H<sub>7</sub>N<sub>3</sub>O<sub>12</sub>',
    '',
    '',
    'PTXQCTHWIXKTGJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INANPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INANPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INANPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:INAOH',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>6</sub>',
    '',
    '',
    'KOIOFJRFFFLZDV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INAOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:INAOOH',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>7</sub>',
    '',
    '',
    'JIJPRURLLPNXAY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:INB1HPCO3H',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>9</sub>',
    '',
    '',
    'UQVCIXBCKWUTPD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>12</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INB1HPCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INB1HPCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INB1HPCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:INB1HPPAN',
    'C<sub>5</sub>H<sub>8</sub>N<sub>2</sub>O<sub>11</sub>',
    '',
    '',
    'MXDOILKWVFGWCS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INB1HPPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INB1HPPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INB1HPPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:INB1NACO3H',
    'C<sub>5</sub>H<sub>8</sub>N<sub>2</sub>O<sub>10</sub>',
    '',
    '',
    'IWCHPIGOQCZQCT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INB1NACO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INB1NACO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INB1NACO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:INB1NAPAN',
    'C<sub>5</sub>H<sub>7</sub>N<sub>3</sub>O<sub>12</sub>',
    '',
    '',
    'NYNQOGZUUKXJDZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INB1NAPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INB1NAPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INB1NAPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:INB1NBCO3H',
    'C<sub>5</sub>H<sub>8</sub>N<sub>2</sub>O<sub>10</sub>',
    '',
    '',
    'KPBUCMMBNBINOH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INB1NBCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INB1NBCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INB1NBCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:INB1NBPAN',
    'C<sub>5</sub>H<sub>7</sub>N<sub>3</sub>O<sub>12</sub>',
    '',
    '',
    'JLOMTJWSNAHKLK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INB1NBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INB1NBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INB1NBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:INB1NO3',
    'C<sub>5</sub>H<sub>10</sub>N<sub>2</sub>O<sub>8</sub>',
    '',
    '',
    'JJLGQNDDHJZYHP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INB1NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INB1NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INB1NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:INB1OH',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>6</sub>',
    '',
    '',
    'CMMIHJKAMSCCNX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INB1OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INB1OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INB1OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:INB1OOH',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>7</sub>',
    '',
    '',
    'QLIFJAFKYUVUMD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INB1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INB1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INB1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:INB2OOH',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>7</sub>',
    '',
    '',
    'KNHLEPZPJYMJKZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INB2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INB2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INB2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:INCNCO3H',
    'C<sub>5</sub>H<sub>8</sub>N<sub>2</sub>O<sub>10</sub>',
    '',
    '',
    'OBBLXUYPBVASEH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INCNCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INCNCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INCNCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:INCNO3',
    'C<sub>5</sub>H<sub>10</sub>N<sub>2</sub>O<sub>8</sub>',
    '',
    '',
    'YANCNBBJBURWKL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:INCNPAN',
    'C<sub>5</sub>H<sub>7</sub>N<sub>3</sub>O<sub>12</sub>',
    '',
    '',
    'MINPDRSMAYIHHB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INCNPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INCNPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INCNPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:INCOH',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>6</sub>',
    '',
    '',
    'CLYWBEAWDTVRBE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:INCOOH',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>7</sub>',
    '',
    '',
    'LZOWWVNBCGLMRZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:INDHCO3H',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>8</sub>',
    '',
    '',
    'QUYOEJZVAFIYRP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INDHCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INDHCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INDHCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:INDHPAN',
    'C<sub>5</sub>H<sub>8</sub>N<sub>2</sub>O<sub>10</sub>',
    '',
    '',
    'WUJYJPIJVADQSX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INDHPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INDHPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INDHPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:INDHPCO3H',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>9</sub>',
    '',
    '',
    'XHWXDLVQLOECHL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>12</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INDHPCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INDHPCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INDHPCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:INDHPPAN',
    'C<sub>5</sub>H<sub>8</sub>N<sub>2</sub>O<sub>11</sub>',
    '',
    '',
    'MNXVJBKQIAYCJC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INDHPPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INDHPPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INDHPPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:INDOH',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>6</sub>',
    '',
    '',
    'HMAKIHHEIIANEM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INDOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INDOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INDOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:INDOOH',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>7</sub>',
    '',
    '',
    'MAYHMSJZSHQSOH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INDOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INDOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INDOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ISOPANO3',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>4</sub>',
    '',
    '',
    'ISDFXKLTMWDHJL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ISOPANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ISOPANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ISOPANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ISOPBNO3',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>4</sub>',
    '',
    '',
    'CIXVZPWFWFMUOH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ISOPBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ISOPBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ISOPBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ISOPCNO3',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>4</sub>',
    '',
    '',
    'IDJHVSOIJITEQU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ISOPCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ISOPCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ISOPCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ISOPDNO3',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>4</sub>',
    '',
    '',
    'PYTOMGVARIWPAT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ISOPDNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ISOPDNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ISOPDNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:M2BU2OLNO3',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>4</sub>',
    '',
    '',
    'AGMVBVSNQJHQAX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2BU2OLNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2BU2OLNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2BU2OLNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:M2BUOL2NO3',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>4</sub>',
    '',
    '',
    'RQINUHXDGZGUIX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2BUOL2NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2BUOL2NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2BUOL2NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:M3BU2OLNO3',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>4</sub>',
    '',
    '',
    'HJMHUJWXCZNPJL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M3BU2OLNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M3BU2OLNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M3BU2OLNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MBOANO3',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>5</sub>',
    '',
    '',
    'SMFXIBRHTKUPLI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MBOANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MBOANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MBOANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MBOBNO3',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>5</sub>',
    '',
    '',
    'DYXSFFPMZZUQFC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MBOBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MBOBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MBOBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ME2BUOLNO3',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>4</sub>',
    '',
    '',
    'SBGDAJKUHMJEMT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ME2BUOLNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ME2BUOLNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ME2BUOLNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ME3BUOLNO3',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>4</sub>',
    '',
    '',
    'YWTWLHUMBHVVJS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ME3BUOLNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ME3BUOLNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ME3BUOLNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NC4OHCO3H',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>7</sub>',
    '',
    '',
    'PAYOKBFCVVFNAB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC4OHCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC4OHCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC4OHCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NC4OHCPAN',
    'C<sub>5</sub>H<sub>8</sub>N<sub>2</sub>O<sub>9</sub>',
    '',
    '',
    'JNBJPCXCCYUJJV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC4OHCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC4OHCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC4OHCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NC524NO3',
    'C<sub>5</sub>H<sub>10</sub>N<sub>2</sub>O<sub>9</sub>',
    '',
    '',
    'NSZZUBPWOYNZJW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC524NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC524NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC524NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NC524OH',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>7</sub>',
    '',
    '',
    'ZZGZKDXCMVGDSK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC524OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC524OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC524OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NC524OOH',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>8</sub>',
    '',
    '',
    'IVLBZHUBMDVGDP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>13</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC524OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC524OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC524OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NMBOAOOH',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>6</sub>',
    '',
    '',
    'JWWMAKNKCQEFPZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NMBOAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NMBOAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NMBOAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NMBOBOOH',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>6</sub>',
    '',
    '',
    'ZVOCBPRLBFFNTM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NMBOBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NMBOBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NMBOBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PE1ENEANO3',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>4</sub>',
    '',
    '',
    'VVLSYMLJBKJHQI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PE1ENEANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PE1ENEANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PE1ENEANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PE1ENEBNO3',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>4</sub>',
    '',
    '',
    'ZAYLQHAUCSLXCO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PE1ENEBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PE1ENEBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PE1ENEBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PE2ENEANO3',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>4</sub>',
    '',
    '',
    'SNSYWPGYFWSVQC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PE2ENEANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PE2ENEANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PE2ENEANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PE2ENEBNO3',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>4</sub>',
    '',
    '',
    'FSHUAFNCTFMDNJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PE2ENEBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PE2ENEBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PE2ENEBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PROL11MNO3',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>4</sub>',
    '',
    '',
    'XLOGQOLFBMMDEL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PROL11MNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PROL11MNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PROL11MNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PROL1MPAN',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>6</sub>',
    '',
    '',
    'KGIFHBAEXLJKCU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PROL1MPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PROL1MPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PROL1MPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BZBIPERNO3',
    'C<sub>6</sub>H<sub>7</sub>NO<sub>6</sub>',
    '',
    '',
    'RBJPNJQUNYROJW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BZBIPERNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BZBIPERNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BZBIPERNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4ME2OHNO3',
    'C<sub>6</sub>H<sub>13</sub>NO<sub>4</sub>',
    '',
    '',
    'KWGTWPROGIVFDL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4ME2OHNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4ME2OHNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4ME2OHNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C518PAN',
    'C<sub>6</sub>H<sub>9</sub>NO<sub>6</sub>',
    '',
    '',
    'SMGAVNKPBYTONP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C518PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C518PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C518PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C622NO3',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>4</sub>',
    '',
    '',
    'UCAFMJJTBHTENA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>1</sup>',
    '11000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C622NO3'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C622NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C622NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C622NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C624NO3',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>4</sub>',
    '',
    '',
    'NPRBCQJDIIBUMY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C624NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C624NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C624NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C64OH5NO3',
    'C<sub>6</sub>H<sub>13</sub>NO<sub>4</sub>',
    '',
    '',
    'SZVWRLIYDKPIRS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C64OH5NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C64OH5NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C64OH5NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C65OH4NO3',
    'C<sub>6</sub>H<sub>13</sub>NO<sub>4</sub>',
    '',
    '',
    'ZZPOFDLVCBSRPC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C65OH4NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C65OH4NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C65OH4NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C66NO35OH',
    'C<sub>6</sub>H<sub>13</sub>NO<sub>4</sub>',
    '',
    '',
    'FGVUHVRIXFWTDQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C66NO35OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C66NO35OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C66NO35OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6OH5NO3',
    'C<sub>6</sub>H<sub>13</sub>NO<sub>4</sub>',
    '',
    '',
    'WNZDORMXFCCFFY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6OH5NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6OH5NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6OH5NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6PAN11',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>6</sub>',
    '',
    '',
    'MMZOJEONIKVQSZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN11'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN11'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN11'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6PAN13',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>6</sub>',
    '',
    '',
    'UVFJOYDNGFNBNV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN13'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN13'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN13'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6PAN14',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>6</sub>',
    '',
    '',
    'OFISHWPBQMHPEB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN14'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN14'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN14'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6PAN19',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>6</sub>',
    '',
    '',
    'ZTVAXWHNQKLGPW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN19'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN19'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN19'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6PAN1',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>6</sub>',
    '',
    '',
    'INIWXNWKFGUMOJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN1'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN1'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN1'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6PAN20',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>6</sub>',
    '',
    '',
    'HBAXDJNNSYEITK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN20'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN20'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN20'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6PAN21',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>6</sub>',
    '',
    '',
    'PXGXPDBWNDXFTJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN21'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN21'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN21'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6PAN22',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>6</sub>',
    '',
    '',
    'YIFZDOMLXOKIHL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN22'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN22'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN22'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6PAN23',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>6</sub>',
    '',
    '',
    'OODNPGDDVDMKSB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN23'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN23'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN23'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6PAN4',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>6</sub>',
    '',
    '',
    'ZWWUNLHZACGCEV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN4'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN4'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN4'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6PAN8',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>6</sub>',
    '',
    '',
    'UOLRWSMDFSCHJH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN8'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN8'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN8'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CYHXOLANO3',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>4</sub>',
    '',
    '',
    'GVSCAKVHXWAQQJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CYHXOLANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CYHXOLANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CYHXOLANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H13M3C5NO3',
    'C<sub>6</sub>H<sub>13</sub>NO<sub>5</sub>',
    '',
    '',
    'ZRQJKBICSYYJDC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H13M3C5NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H13M3C5NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H13M3C5NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H1MC5NO3',
    'C<sub>6</sub>H<sub>13</sub>NO<sub>4</sub>',
    '',
    '',
    'YQESDLQNDPCVPT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H1MC5NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H1MC5NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H1MC5NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H2MC5NO3',
    'C<sub>6</sub>H<sub>13</sub>NO<sub>4</sub>',
    '',
    '',
    'OQOPDPWKHFKGPO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2MC5NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2MC5NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2MC5NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H3M3C5NO3',
    'C<sub>6</sub>H<sub>13</sub>NO<sub>4</sub>',
    '',
    '',
    'KFPWVQORUDKTSF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3M3C5NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3M3C5NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3M3C5NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HM22C4NO3',
    'C<sub>6</sub>H<sub>13</sub>NO<sub>4</sub>',
    '',
    '',
    'VALJBIPPHZOXME-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM22C4NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM22C4NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM22C4NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HM23C4NO3',
    'C<sub>6</sub>H<sub>13</sub>NO<sub>4</sub>',
    '',
    '',
    'VYFSYIPQAVXJDI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM23C4NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM23C4NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM23C4NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HM33C4NO3',
    'C<sub>6</sub>H<sub>13</sub>NO<sub>4</sub>',
    '',
    '',
    'HUEIARDLQBFSAX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM33C4NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM33C4NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HM33C4NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO1C6NO3',
    'C<sub>6</sub>H<sub>13</sub>NO<sub>4</sub>',
    '',
    '',
    'ITCMBKDCMKPMFX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO1C6NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO1C6NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO1C6NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO1MC5NO3',
    'C<sub>6</sub>H<sub>13</sub>NO<sub>4</sub>',
    '',
    '',
    'HKEZUADWXQLOIL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO1MC5NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO1MC5NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO1MC5NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO2C6NO3',
    'C<sub>6</sub>H<sub>13</sub>NO<sub>4</sub>',
    '',
    '',
    'PAWWQEMXBSLVJC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '10000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C6NO3'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C6NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C6NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2C6NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO2M2C5NO3',
    'C<sub>6</sub>H<sub>13</sub>NO<sub>4</sub>',
    '',
    '',
    'VYPLOHRVLBPDEY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2M2C5NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2M2C5NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2M2C5NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO2MC5NO3',
    'C<sub>6</sub>H<sub>13</sub>NO<sub>4</sub>',
    '',
    '',
    'HYCOTEZKEHIINQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2MC5NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2MC5NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO2MC5NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO3C6NO3',
    'C<sub>6</sub>H<sub>13</sub>NO<sub>4</sub>',
    '',
    '',
    'DLCRGHMYOOYQLW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C6NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C6NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C6NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NDNPHENOOH',
    'C<sub>6</sub>H<sub>5</sub>N<sub>3</sub>O<sub>12</sub>',
    '',
    '',
    'CXGWHQULUCBXTG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>15</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NDNPHENOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NDNPHENOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NDNPHENOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NNCATECOOH',
    'C<sub>6</sub>H<sub>6</sub>N<sub>2</sub>O<sub>11</sub>',
    '',
    '',
    'SEZKEDQZGXKDIE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>16</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NNCATECOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NNCATECOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NNCATECOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NPHENOH',
    'C<sub>6</sub>H<sub>7</sub>NO<sub>7</sub>',
    '',
    '',
    'RMHIEAGXGVAIOV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPHENOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPHENOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPHENOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NPHENOOH',
    'C<sub>6</sub>H<sub>7</sub>NO<sub>8</sub>',
    '',
    '',
    'AMKSGTJAMDYUMG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPHENOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPHENOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPHENOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C622PAN',
    'C<sub>7</sub>H<sub>11</sub>NO<sub>6</sub>',
    '',
    '',
    'YZCFVDKMDQZEJM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C622PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C622PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C622PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C624PAN',
    'C<sub>7</sub>H<sub>11</sub>NO<sub>6</sub>',
    '',
    '',
    'GVGFFJILZZBAQC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C624PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C624PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C624PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C720NO3',
    'C<sub>7</sub>H<sub>11</sub>NO<sub>4</sub>',
    '',
    '',
    'VRUSDNGIDALYSE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C720NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C720NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C720NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7PAN1',
    'C<sub>7</sub>H<sub>13</sub>NO<sub>6</sub>',
    '',
    '',
    'HWQKKNUBUUPBAM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7PAN1'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7PAN1'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7PAN1'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7PAN2',
    'C<sub>7</sub>H<sub>13</sub>NO<sub>6</sub>',
    '',
    '',
    'LEPHBBVBSNQAKS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7PAN2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7PAN2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7PAN2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H2M2C65NO3',
    'C<sub>7</sub>H<sub>15</sub>NO<sub>4</sub>',
    '',
    '',
    'CAEJQFHLOCBFOE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M2C65NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M2C65NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M2C65NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H2M4C65NO3',
    'C<sub>7</sub>H<sub>15</sub>NO<sub>4</sub>',
    '',
    '',
    'GNQNFXQMHRYYMA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M4C65NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M4C65NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M4C65NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H2M5C65NO3',
    'C<sub>7</sub>H<sub>15</sub>NO<sub>4</sub>',
    '',
    '',
    'JWGQNCMAKPVWAL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M5C65NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M5C65NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2M5C65NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H3M3C6NO3',
    'C<sub>7</sub>H<sub>15</sub>NO<sub>4</sub>',
    '',
    '',
    'HWCRTHIHVAVLJX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3M3C6NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3M3C6NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3M3C6NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO3C76NO3',
    'C<sub>7</sub>H<sub>15</sub>NO<sub>4</sub>',
    '',
    '',
    'FLDFLEPRHCTYNR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C76NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C76NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C76NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MNNCATCOOH',
    'C<sub>7</sub>H<sub>8</sub>N<sub>2</sub>O<sub>11</sub>',
    '',
    '',
    'QARZHCGSBCBWKI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>16</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MNNCATCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MNNCATCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MNNCATCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NCRESOH',
    'C<sub>7</sub>H<sub>9</sub>NO<sub>7</sub>',
    '',
    '',
    'DNQMNVUMZARJRH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NCRESOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NCRESOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NCRESOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NCRESOOH',
    'C<sub>7</sub>H<sub>9</sub>NO<sub>8</sub>',
    '',
    '',
    'CBYLLFTZDVJCIH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NCRESOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NCRESOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NCRESOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NDNCRESOOH',
    'C<sub>7</sub>H<sub>7</sub>N<sub>3</sub>O<sub>12</sub>',
    '',
    '',
    'LRLYMWFOIDHJSH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>14</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NDNCRESOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NDNCRESOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NDNCRESOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TLBIPERNO3',
    'C<sub>7</sub>H<sub>9</sub>NO<sub>6</sub>',
    '',
    '',
    'BBVQCFWACDVWPL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TLBIPERNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TLBIPERNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TLBIPERNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C8PAN1',
    'C<sub>8</sub>H<sub>15</sub>NO<sub>6</sub>',
    '',
    '',
    'JRARROZAJMGAPP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8PAN1'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8PAN1'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8PAN1'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EBZBPERNO3',
    'C<sub>8</sub>H<sub>11</sub>NO<sub>6</sub>',
    '',
    '',
    'GVVNXZZYBMLIBS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBZBPERNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBZBPERNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBZBPERNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ENNCATCOOH',
    'C<sub>8</sub>H<sub>10</sub>N<sub>2</sub>O<sub>11</sub>',
    '',
    '',
    'SUCBZAKUUVBJMN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>15</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ENNCATCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ENNCATCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ENNCATCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO3C86NO3',
    'C<sub>8</sub>H<sub>17</sub>NO<sub>4</sub>',
    '',
    '',
    'WNECKFLKAYSMQF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C86NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C86NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C86NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MXNNCATOOH',
    'C<sub>8</sub>H<sub>10</sub>N<sub>2</sub>O<sub>11</sub>',
    '',
    '',
    'SNJAPGUPFXVMJK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>15</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXNNCATOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXNNCATOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXNNCATOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MXYBIPENO3',
    'C<sub>8</sub>H<sub>11</sub>NO<sub>6</sub>',
    '',
    '',
    'QFCKPTYGEYQVET-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYBIPENO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYBIPENO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYBIPENO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NDNEBZLOOH',
    'C<sub>8</sub>H<sub>9</sub>N<sub>3</sub>O<sub>12</sub>',
    '',
    '',
    'XZASAIPCUIAVQG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>14</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NDNEBZLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NDNEBZLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NDNEBZLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NDNMXYLOOH',
    'C<sub>8</sub>H<sub>9</sub>N<sub>3</sub>O<sub>12</sub>',
    '',
    '',
    'AAXPRTISYYDKLT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>14</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NDNMXYLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NDNMXYLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NDNMXYLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NDNOXYLOOH',
    'C<sub>8</sub>H<sub>9</sub>N<sub>3</sub>O<sub>12</sub>',
    '',
    '',
    'SEMBUWBKKSEFTL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>14</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NDNOXYLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NDNOXYLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NDNOXYLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NDNPXYLOOH',
    'C<sub>8</sub>H<sub>9</sub>N<sub>3</sub>O<sub>12</sub>',
    '',
    '',
    'YXONGYHUJBRFJO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>14</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NDNPXYLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NDNPXYLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NDNPXYLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NEBNZOLOH',
    'C<sub>8</sub>H<sub>11</sub>NO<sub>7</sub>',
    '',
    '',
    'GKEIZOZEJLMBMT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NEBNZOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NEBNZOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NEBNZOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NEBNZOLOOH',
    'C<sub>8</sub>H<sub>11</sub>NO<sub>8</sub>',
    '',
    '',
    'DZFBJORWJYJOSR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NEBNZOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NEBNZOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NEBNZOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NMXYOLOH',
    'C<sub>8</sub>H<sub>11</sub>NO<sub>7</sub>',
    '',
    '',
    'SFEIDLQIDXHPNL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NMXYOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NMXYOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NMXYOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NMXYOLOOH',
    'C<sub>8</sub>H<sub>11</sub>NO<sub>8</sub>',
    '',
    '',
    'ZTRVHLWFIBLUPT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NMXYOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NMXYOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NMXYOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NOXYOLOH',
    'C<sub>8</sub>H<sub>11</sub>NO<sub>7</sub>',
    '',
    '',
    'UBRWKHDWLQNZCI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOXYOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOXYOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOXYOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NOXYOLOOH',
    'C<sub>8</sub>H<sub>11</sub>NO<sub>8</sub>',
    '',
    '',
    'UHJNRWMXKFNWGQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOXYOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOXYOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOXYOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NPXYOLOH',
    'C<sub>8</sub>H<sub>11</sub>NO<sub>7</sub>',
    '',
    '',
    'DMOUSJNYQFTOEV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPXYOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPXYOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPXYOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NPXYOLOOH',
    'C<sub>8</sub>H<sub>11</sub>NO<sub>8</sub>',
    '',
    '',
    'XNVGITFEYRRJBZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPXYOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPXYOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPXYOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OXNNCATOOH',
    'C<sub>8</sub>H<sub>10</sub>N<sub>2</sub>O<sub>11</sub>',
    '',
    '',
    'GYUDSTHOULZHIU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>16</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXNNCATOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXNNCATOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXNNCATOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OXYBIPENO3',
    'C<sub>8</sub>H<sub>11</sub>NO<sub>6</sub>',
    '',
    '',
    'QQSYVIZUYAXYBZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYBIPENO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYBIPENO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYBIPENO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PXNNCATOOH',
    'C<sub>8</sub>H<sub>10</sub>N<sub>2</sub>O<sub>11</sub>',
    '',
    '',
    'PMLOPKQQVRFHBT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>15</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXNNCATOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXNNCATOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXNNCATOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PXYBIPENO3',
    'C<sub>8</sub>H<sub>11</sub>NO<sub>6</sub>',
    '',
    '',
    'DHJHBQWQGWNRCX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYBIPENO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYBIPENO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYBIPENO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C9PAN1',
    'C<sub>9</sub>H<sub>17</sub>NO<sub>6</sub>',
    '',
    '',
    'XXDOIRAKHRPRCF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C9PAN1'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C9PAN1'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C9PAN1'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO3C96NO3',
    'C<sub>9</sub>H<sub>19</sub>NO<sub>4</sub>',
    '',
    '',
    'IBTJZAOBCFQTAU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C96NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C96NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C96NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPBZBPRNO3',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>6</sub>',
    '',
    '',
    'VLTHUNWGYHRCPS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBZBPRNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBZBPRNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBZBPRNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPNNCATOOH',
    'C<sub>9</sub>H<sub>12</sub>N<sub>2</sub>O<sub>11</sub>',
    '',
    '',
    'QCQAPHFHFZPQHQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>15</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPNNCATOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPNNCATOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPNNCATOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:METLBIPNO3',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>6</sub>',
    '',
    '',
    'VQZACYIDHNLNBQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METLBIPNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METLBIPNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METLBIPNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MTNNCATOOH',
    'C<sub>9</sub>H<sub>12</sub>N<sub>2</sub>O<sub>11</sub>',
    '',
    '',
    'ILPSXJBNDMCAEH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>15</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTNNCATOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTNNCATOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTNNCATOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NDNIPBLOOH',
    'C<sub>9</sub>H<sub>11</sub>N<sub>3</sub>O<sub>12</sub>',
    '',
    '',
    'HEZPBZRCUHPAHJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>14</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NDNIPBLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NDNIPBLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NDNIPBLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NDNMETLOOH',
    'C<sub>9</sub>H<sub>11</sub>N<sub>3</sub>O<sub>12</sub>',
    '',
    '',
    'GVOHWVMFRUNQQB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>14</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NDNMETLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NDNMETLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NDNMETLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NDNOETLOOH',
    'C<sub>9</sub>H<sub>11</sub>N<sub>3</sub>O<sub>12</sub>',
    '',
    '',
    'DLTVFZDBANLVJD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>14</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NDNOETLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NDNOETLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NDNOETLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NDNPBZLOOH',
    'C<sub>9</sub>H<sub>11</sub>N<sub>3</sub>O<sub>12</sub>',
    '',
    '',
    'JBFCRLZRPRJLGG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>14</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NDNPBZLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NDNPBZLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NDNPBZLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NDNPETLOOH',
    'C<sub>9</sub>H<sub>11</sub>N<sub>3</sub>O<sub>12</sub>',
    '',
    '',
    'HIQGLTMZAYSJOX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>14</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NDNPETLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NDNPETLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NDNPETLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NDNT123OOH',
    'C<sub>9</sub>H<sub>11</sub>N<sub>3</sub>O<sub>12</sub>',
    '',
    '',
    'UGLBOUATFGGZQD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>14</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NDNT123OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NDNT123OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NDNT123OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NDNT124OOH',
    'C<sub>9</sub>H<sub>11</sub>N<sub>3</sub>O<sub>12</sub>',
    '',
    '',
    'JFYUNHMAYFMSCF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>14</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NDNT124OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NDNT124OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NDNT124OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NIPBNZOLOH',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>7</sub>',
    '',
    '',
    'IAYADIRZIVDBNK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NIPBNZOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NIPBNZOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NIPBNZOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NIPBZOLOOH',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>8</sub>',
    '',
    '',
    'UJRLUYDBOZESDX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NIPBZOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NIPBZOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NIPBZOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NMETOLOH',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>7</sub>',
    '',
    '',
    'JUUDFVZFULKTPV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NMETOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NMETOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NMETOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NMETOLOOH',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>8</sub>',
    '',
    '',
    'CCCPQNSHVNXETJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NMETOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NMETOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NMETOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NOETOLOH',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>7</sub>',
    '',
    '',
    'RRTVORKFFCXYCH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOETOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOETOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOETOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NOETOLOOH',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>8</sub>',
    '',
    '',
    'CGRZNCSNBNPNBR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOETOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOETOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOETOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NPBNZOLOH',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>7</sub>',
    '',
    '',
    'PSGNFPQCVGIEDF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPBNZOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPBNZOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPBNZOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NPBNZOLOOH',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>8</sub>',
    '',
    '',
    'SNFHXCYEBCZPSO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPBNZOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPBNZOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPBNZOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NPETOLOH',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>7</sub>',
    '',
    '',
    'ILVSHXKPUYWBMX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPETOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPETOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPETOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NPETOLOOH',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>8</sub>',
    '',
    '',
    'BKSLAYLCQMXSES-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPETOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPETOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPETOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NTM123LOOH',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>8</sub>',
    '',
    '',
    'BTWUGVBELCWISQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NTM123LOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NTM123LOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NTM123LOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NTM123OLOH',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>7</sub>',
    '',
    '',
    'DXGFZPSQDYIOOU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NTM123OLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NTM123OLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NTM123OLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NTM124LOOH',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>8</sub>',
    '',
    '',
    'JDMNMHRINWGUFB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NTM124LOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NTM124LOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NTM124LOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NTM124OLOH',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>7</sub>',
    '',
    '',
    'RASHBSOBGFFOLP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NTM124OLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NTM124OLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NTM124OLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NTM135LOOH',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>8</sub>',
    '',
    '',
    'AUGMYCIDZMPUKI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NTM135LOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NTM135LOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NTM135LOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NTM135OLOH',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>7</sub>',
    '',
    '',
    'RAAKFDOLNJCXRG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NTM135OLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NTM135OLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NTM135OLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OETLBIPNO3',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>6</sub>',
    '',
    '',
    'FQBYEMVYEQQXMF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OETLBIPNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OETLBIPNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OETLBIPNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OTNNCATOOH',
    'C<sub>9</sub>H<sub>12</sub>N<sub>2</sub>O<sub>11</sub>',
    '',
    '',
    'QVFSJCAPJVJPQJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>15</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OTNNCATOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OTNNCATOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OTNNCATOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PBZBPERNO3',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>6</sub>',
    '',
    '',
    'XWXMYNZXCPDSAQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBZBPERNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBZBPERNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBZBPERNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PETLBIPNO3',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>6</sub>',
    '',
    '',
    'SOIPWHDZHXSJJN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PETLBIPNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PETLBIPNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PETLBIPNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PNNCATCOOH',
    'C<sub>9</sub>H<sub>12</sub>N<sub>2</sub>O<sub>11</sub>',
    '',
    '',
    'VZHROOMDTDJZFR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>15</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PNNCATCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PNNCATCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PNNCATCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PTNNCATOOH',
    'C<sub>9</sub>H<sub>12</sub>N<sub>2</sub>O<sub>11</sub>',
    '',
    '',
    'DSPOEZNZVSBNSI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>15</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PTNNCATOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PTNNCATOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PTNNCATOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:T123NCTOOH',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>9</sub>',
    '',
    '',
    'QTWHDHJHZAXHRP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>16</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:T123NCTOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:T123NCTOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:T123NCTOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:T123NNCOOH',
    'C<sub>9</sub>H<sub>12</sub>N<sub>2</sub>O<sub>11</sub>',
    '',
    '',
    'DNVSLQYQQCSWFT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>15</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:T123NNCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:T123NNCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:T123NNCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:T124NCTOOH',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>9</sub>',
    '',
    '',
    'TXEYLBVXEVQRAA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>17</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:T124NCTOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:T124NCTOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:T124NCTOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:T124NNCOOH',
    'C<sub>9</sub>H<sub>12</sub>N<sub>2</sub>O<sub>11</sub>',
    '',
    '',
    'ATYVZJLHFNLHKS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>15</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:T124NNCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:T124NNCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:T124NNCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TM123BPNO3',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>6</sub>',
    '',
    '',
    'RQYOJMSOWIZBID-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM123BPNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM123BPNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM123BPNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TM124BPNO3',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>6</sub>',
    '',
    '',
    'KUPKWWJOBRXSMW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124BPNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124BPNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124BPNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TM135BPNO3',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>6</sub>',
    '',
    '',
    'VYQMVFHQGVVJTP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM135BPNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM135BPNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM135BPNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:APINANO3',
    'C<sub>10</sub>H<sub>17</sub>NO<sub>4</sub>',
    '',
    '',
    'YITBNQHGOKCTCE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:APINANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:APINANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:APINANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:APINBNO3',
    'C<sub>10</sub>H<sub>17</sub>NO<sub>4</sub>',
    '',
    '',
    'AFJBVFUZFQZZRG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:APINBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:APINBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:APINBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:APINCNO3',
    'C<sub>10</sub>H<sub>17</sub>NO<sub>4</sub>',
    '',
    '',
    'IHZLDCJLQGWYSD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:APINCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:APINCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:APINCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BPINANO3',
    'C<sub>10</sub>H<sub>17</sub>NO<sub>4</sub>',
    '',
    '',
    'LIKORQJDVXFFRR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BPINANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BPINANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BPINANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BPINBNO3',
    'C<sub>10</sub>H<sub>17</sub>NO<sub>4</sub>',
    '',
    '',
    'PIICVRQEXAAMFO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BPINBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BPINBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BPINBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BPINCNO3',
    'C<sub>10</sub>H<sub>17</sub>NO<sub>4</sub>',
    '',
    '',
    'IVSZOCZGKNSHLW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BPINCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BPINCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BPINCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C10PAN1',
    'C<sub>10</sub>H<sub>19</sub>NO<sub>6</sub>',
    '',
    '',
    'PVQDOCOVRZVCAL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C10PAN1'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C10PAN1'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C10PAN1'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C918PAN',
    'C<sub>10</sub>H<sub>15</sub>NO<sub>6</sub>',
    '',
    '',
    'GIWCNEZLGDWGNI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C918PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C918PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C918PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DMEBIPNO3',
    'C<sub>10</sub>H<sub>15</sub>NO<sub>6</sub>',
    '',
    '',
    'LWYZBKFMLLCHQU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMEBIPNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMEBIPNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMEBIPNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO3C106NO3',
    'C<sub>10</sub>H<sub>21</sub>NO<sub>4</sub>',
    '',
    '',
    'LRSOGLAVONYUMB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C106NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C106NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C106NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:LIMANO3',
    'C<sub>10</sub>H<sub>17</sub>NO<sub>4</sub>',
    '',
    '',
    'LZDKYYHMAURBIK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>1</sup>',
    '12000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMANO3'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:LIMBNO3',
    'C<sub>10</sub>H<sub>17</sub>NO<sub>4</sub>',
    '',
    '',
    'WIRXFNWUDJEZSG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:LIMCNO3',
    'C<sub>10</sub>H<sub>17</sub>NO<sub>4</sub>',
    '',
    '',
    'ZELLOEPLERCREX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>1</sup>',
    '19000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMCNO3'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NDMEPHOLOH',
    'C<sub>10</sub>H<sub>15</sub>NO<sub>7</sub>',
    '',
    '',
    'XEZYIWLRTFENIO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NDMEPHOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NDMEPHOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NDMEPHOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NDMEPLOOH',
    'C<sub>10</sub>H<sub>15</sub>NO<sub>8</sub>',
    '',
    '',
    'CUWVWZNCHDONFF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NDMEPLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NDMEPLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NDMEPLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DETLBIPNO3',
    'C<sub>11</sub>H<sub>17</sub>NO<sub>6</sub>',
    '',
    '',
    'HUKONYHKUULPQM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DETLBIPNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DETLBIPNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DETLBIPNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO3C116NO3',
    'C<sub>11</sub>H<sub>23</sub>NO<sub>4</sub>',
    '',
    '',
    'ZSRHOFPLHKNYIP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C116NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C116NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C116NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NDEMPHOLOH',
    'C<sub>11</sub>H<sub>17</sub>NO<sub>7</sub>',
    '',
    '',
    'SFAWLNJVZQJDAW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NDEMPHOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NDEMPHOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NDEMPHOLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NDEMPLOOH',
    'C<sub>11</sub>H<sub>17</sub>NO<sub>8</sub>',
    '',
    '',
    'KQXYYOILDOZYPH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NDEMPLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NDEMPLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NDEMPLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HO3C126NO3',
    'C<sub>12</sub>H<sub>25</sub>NO<sub>4</sub>',
    '',
    '',
    'NBVYOETUGSGBPE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C126NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C126NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HO3C126NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BCANO3',
    'C<sub>15</sub>H<sub>25</sub>NO<sub>4</sub>',
    '',
    '',
    'DXJZLWPVAKABFC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BCBNO3',
    'C<sub>15</sub>H<sub>25</sub>NO<sub>4</sub>',
    '',
    '',
    'GGDFBGYMWXIISJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BCCNO3',
    'C<sub>15</sub>H<sub>25</sub>NO<sub>4</sub>',
    '',
    '',
    'AJHNYRDSMBHFTD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:GLYPAN',
    'C<sub>2</sub>HNO<sub>6</sub>',
    '',
    '',
    'WWNQODGUPABTBB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:GLYPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:GLYPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:GLYPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NO3CH2CHO',
    'C<sub>2</sub>H<sub>3</sub>NO<sub>4</sub>',
    '',
    '',
    'ABUBKAMLUVOXSP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NO3CH2CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NO3CH2CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NO3CH2CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C3PAN2',
    'C<sub>3</sub>H<sub>3</sub>NO<sub>6</sub>',
    '',
    '',
    'JCWPFKBPQPIIIA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3PAN2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3PAN2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3PAN2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CHOPRNO3',
    'C<sub>3</sub>H<sub>5</sub>NO<sub>4</sub>',
    '',
    '',
    'IIFXHQMWCHWMFS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOPRNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOPRNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOPRNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BUTAL2NO3',
    'C<sub>4</sub>H<sub>7</sub>NO<sub>4</sub>',
    '',
    '',
    'JTMAFXAEAWTSPM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BUTAL2NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BUTAL2NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BUTAL2NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BUTALNO3',
    'C<sub>4</sub>H<sub>7</sub>NO<sub>4</sub>',
    '',
    '',
    'YGQOBBYMNDZOFN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BUTALNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BUTALNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BUTALNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4CONO3OOH',
    'C<sub>4</sub>H<sub>7</sub>NO<sub>6</sub>',
    '',
    '',
    'OPYZRKWHBYWVFV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4CONO3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4CONO3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4CONO3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4NO3COOOH',
    'C<sub>4</sub>H<sub>7</sub>NO<sub>6</sub>',
    '',
    '',
    'LPNJZRUFCUXQKM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4NO3COOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4NO3COOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4NO3COOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CHOC2PAN',
    'C<sub>4</sub>H<sub>5</sub>NO<sub>6</sub>',
    '',
    '',
    'RNHARUXEGCOCNU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOC2PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOC2PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOC2PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CONM2CHO',
    'C<sub>4</sub>H<sub>5</sub>NO<sub>5</sub>',
    '',
    '',
    'UXLHNUQVUCPVFF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CONM2CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CONM2CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CONM2CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CONM2CO3H',
    'C<sub>4</sub>H<sub>5</sub>NO<sub>7</sub>',
    '',
    '',
    'KDPSYMPAERQTCV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CONM2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CONM2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CONM2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CONM2PAN',
    'C<sub>4</sub>H<sub>4</sub>N<sub>2</sub>O<sub>9</sub>',
    '',
    '',
    'PRUSZGKEVUCSBM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CONM2PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CONM2PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CONM2PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IBUALANO3',
    'C<sub>4</sub>H<sub>7</sub>NO<sub>4</sub>',
    '',
    '',
    'BBEYVRKCPRBWGK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IBUALANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IBUALANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IBUALANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IBUDIALPAN',
    'C<sub>4</sub>H<sub>5</sub>NO<sub>6</sub>',
    '',
    '',
    'ANKFJODHGNELSW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IBUDIALPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IBUDIALPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IBUDIALPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MALDIALPAN',
    'C<sub>4</sub>H<sub>3</sub>NO<sub>6</sub>',
    '',
    '',
    'JVYQADFHFGBZRY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MALDIALPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MALDIALPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MALDIALPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MPRBNO3CHO',
    'C<sub>4</sub>H<sub>7</sub>NO<sub>4</sub>',
    '',
    '',
    'ZFRSNPXDNOXJAQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MPRBNO3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MPRBNO3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MPRBNO3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NC3CHO',
    'C<sub>4</sub>H<sub>5</sub>NO<sub>4</sub>',
    '',
    '',
    'IRCIUAVPVOGPAB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C3M3CHONO3',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>4</sub>',
    '',
    '',
    'FSONNVXXYIKSKL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3M3CHONO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3M3CHONO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3M3CHONO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C3MCODBPAN',
    'C<sub>5</sub>H<sub>5</sub>NO<sub>6</sub>',
    '',
    '',
    'ABUKHSDGKGHQTM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3MCODBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3MCODBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3MCODBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C3MNO3CHO',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>4</sub>',
    '',
    '',
    'IIGIHDSEOSVDKL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3MNO3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3MNO3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3MNO3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4CHOBNO3',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>4</sub>',
    '',
    '',
    'IRTPVYBICUATCF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4CHOBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4CHOBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4CHOBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4NO3CHO',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>4</sub>',
    '',
    '',
    'WGTULXFSTHCAFV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4NO3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4NO3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4NO3CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C514NO3',
    'C<sub>5</sub>H<sub>7</sub>NO<sub>5</sub>',
    '',
    '',
    'CEGGSEAULUFJEH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C514NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C514NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C514NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C52NO31CO',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>4</sub>',
    '',
    '',
    'OIPNOUWHATXHHM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C52NO31CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C52NO31CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C52NO31CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO1M22PAN',
    'C<sub>5</sub>H<sub>7</sub>NO<sub>6</sub>',
    '',
    '',
    'JNBWLVYXFYINSW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO1M22PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO1M22PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO1M22PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MC3CODBPAN',
    'C<sub>5</sub>H<sub>5</sub>NO<sub>6</sub>',
    '',
    '',
    'AENWJVOXGCGHKR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MC3CODBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MC3CODBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MC3CODBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NC4CHO',
    'C<sub>5</sub>H<sub>7</sub>NO<sub>4</sub>',
    '',
    '',
    'FHQODWHGFJXLCS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC4CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C522PAN',
    'C<sub>6</sub>H<sub>7</sub>NO<sub>6</sub>',
    '',
    '',
    'BLDVCFQHUDZGIY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C522PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C522PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C522PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C65NO36CHO',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>4</sub>',
    '',
    '',
    'AWOTULOVYXZRSX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C65NO36CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C65NO36CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C65NO36CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CHOC4PAN',
    'C<sub>6</sub>H<sub>9</sub>NO<sub>6</sub>',
    '',
    '',
    'LKJHECXHBJSEQK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOC4PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOC4PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOC4PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO1C6NO3',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>4</sub>',
    '',
    '',
    'BSOUFWBHIRXMPX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO1C6NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO1C6NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO1C6NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C615PAN',
    'C<sub>7</sub>H<sub>9</sub>NO<sub>7</sub>',
    '',
    '',
    'QXDOZRAOCVERTF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C615PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C615PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C615PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C729NO3',
    'C<sub>7</sub>H<sub>11</sub>NO<sub>4</sub>',
    '',
    '',
    'IVMGVFSKIJXXOW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C729NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C729NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C729NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C729PAN',
    'C<sub>8</sub>H<sub>11</sub>NO<sub>6</sub>',
    '',
    '',
    'UQYKHYVNMQUYAN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C729PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C729PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C729PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C810NO3',
    'C<sub>8</sub>H<sub>13</sub>NO<sub>5</sub>',
    '',
    '',
    'CHBSGOHAWLCLGZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C810NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C810NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C810NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C822NO3',
    'C<sub>8</sub>H<sub>13</sub>NO<sub>4</sub>',
    '',
    '',
    'JWAJNALJDDSHOA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>1</sup>',
    '10000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C822NO3'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C822NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C822NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C822NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C830NO3',
    'C<sub>8</sub>H<sub>13</sub>NO<sub>4</sub>',
    '',
    '',
    'FXBNRUYCAFEPCZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C830NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C830NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C830NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C831NO3',
    'C<sub>8</sub>H<sub>13</sub>NO<sub>5</sub>',
    '',
    '',
    'OVEOYJGENOZMLJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C831NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C831NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C831NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C89NO3',
    'C<sub>8</sub>H<sub>13</sub>NO<sub>4</sub>',
    '',
    '',
    'JVGNHSSLWSUTIF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C89NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C89NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C89NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NC826OOH',
    'C<sub>8</sub>H<sub>13</sub>NO<sub>7</sub>',
    '',
    '',
    'LIEZCAAIBRALIF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC826OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC826OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC826OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C822PAN',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>6</sub>',
    '',
    '',
    'AEOJBADXVLGVNE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C822PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C822PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C822PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C830PAN',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>6</sub>',
    '',
    '',
    'NSAJKAFLWKCEMC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C830PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C830PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C830PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C89PAN',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>6</sub>',
    '',
    '',
    'MAIUDZACSGCMBD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C89PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C89PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C89PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NC91CHO',
    'C<sub>10</sub>H<sub>15</sub>NO<sub>4</sub>',
    '',
    '',
    'AVQCYYCZMFYNOE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC91CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC91CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC91CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C126NO3',
    'C<sub>12</sub>H<sub>19</sub>NO<sub>4</sub>',
    '',
    '',
    'LCRFSVKVQOPOBC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C126NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C126NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C126NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C126PAN',
    'C<sub>13</sub>H<sub>19</sub>NO<sub>6</sub>',
    '',
    '',
    'TVUSLNPYCCAOKX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C126PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C126PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C126PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C136NO3',
    'C<sub>13</sub>H<sub>21</sub>NO<sub>4</sub>',
    '',
    '',
    'FAQBCXSJSFDOSN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C136NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C136NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C136NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NC1313OOH',
    'C<sub>13</sub>H<sub>21</sub>NO<sub>7</sub>',
    '',
    '',
    'AIWUKZRYSUWIQN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC1313OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC1313OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC1313OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C136PAN',
    'C<sub>14</sub>H<sub>21</sub>NO<sub>6</sub>',
    '',
    '',
    'HVYQJFOLIDVKQK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C136PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C136PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C136PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C42AOH',
    'C<sub>3</sub>H<sub>5</sub>NO<sub>5</sub>',
    '',
    '',
    'CQVFGUOZVNZZAM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C42AOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C42AOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C42AOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HCOCOHPAN',
    'C<sub>3</sub>H<sub>3</sub>NO<sub>7</sub>',
    '',
    '',
    'GGQYFRDCXKQQIA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HCOCOHPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HCOCOHPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HCOCOHPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C41NO3',
    'C<sub>4</sub>H<sub>7</sub>NO<sub>6</sub>',
    '',
    '',
    'SGYMVPWBXCYWGY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C41NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C41NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C41NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C42OH',
    'C<sub>4</sub>H<sub>7</sub>NO<sub>6</sub>',
    '',
    '',
    'OIAGCOLJHCONRV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C42OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C42OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C42OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C42OOH',
    'C<sub>4</sub>H<sub>7</sub>NO<sub>7</sub>',
    '',
    '',
    'KUKJNXCETLVUQA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C42OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C42OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C42OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4OCCOHNO3',
    'C<sub>4</sub>H<sub>7</sub>NO<sub>5</sub>',
    '',
    '',
    'NEHFOAWUQWHZTI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4OCCOHNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4OCCOHNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4OCCOHNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:COCCOHNO3',
    'C<sub>4</sub>H<sub>7</sub>NO<sub>5</sub>',
    '',
    '',
    'HMCDHWALZVCNKO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:COCCOHNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:COCCOHNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:COCCOHNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:COHM2PAN',
    'C<sub>4</sub>H<sub>5</sub>NO<sub>7</sub>',
    '',
    '',
    'UXUAXYPQPQSXRR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:COHM2PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:COHM2PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:COHM2PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MACRNB',
    'C<sub>4</sub>H<sub>7</sub>NO<sub>5</sub>',
    '',
    '',
    'DLZDCWJOERFHAS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MACRNB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MACRNB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MACRNB'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MACRNO3',
    'C<sub>4</sub>H<sub>7</sub>NO<sub>5</sub>',
    '',
    '',
    'ALINXPRBVMXOGH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MACRNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MACRNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MACRNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4M2ALOHNO3',
    'C<sub>5</sub>H<sub>7</sub>NO<sub>6</sub>',
    '',
    '',
    'UOGOTHSJBRKVRR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4M2ALOHNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4M2ALOHNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4M2ALOHNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C510OH',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>6</sub>',
    '',
    '',
    'ZCOZZYNQPKXJEJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C510OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C510OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C510OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C510OOH',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>7</sub>',
    '',
    '',
    'GGBWELVRYZRQMP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C510OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C510OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C510OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C57NO3',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>6</sub>',
    '',
    '',
    'KHAJTJUOMDNQGW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C57NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C57NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C57NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C58NO3',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>6</sub>',
    '',
    '',
    'UZUIBKBJXOKLGO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C58NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C58NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C58NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DNC524CO',
    'C<sub>5</sub>H<sub>8</sub>N<sub>2</sub>O<sub>9</sub>',
    '',
    '',
    'WXHJTLSKHGDJHS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNC524CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNC524CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNC524CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HNC524CO',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>7</sub>',
    '',
    '',
    'UHQMTOKWUFCERL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HNC524CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HNC524CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HNC524CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HPNC524CO',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>8</sub>',
    '',
    '',
    'QASKBBWYYSGCPQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>12</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HPNC524CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HPNC524CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HPNC524CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:INAHCHO',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>6</sub>',
    '',
    '',
    'GJDCYRXOLZPRRL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INAHCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INAHCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INAHCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:INAHPCHO',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>7</sub>',
    '',
    '',
    'WOIAKHQAPCBXNP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INAHPCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INAHPCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INAHPCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:INANCHO',
    'C<sub>5</sub>H<sub>8</sub>N<sub>2</sub>O<sub>8</sub>',
    '',
    '',
    'AOWQROMNZIXQRL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INANCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INANCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INANCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:INB1HPCHO',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>7</sub>',
    '',
    '',
    'PPUPDRIHXISUBS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INB1HPCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INB1HPCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INB1HPCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:INB1NACHO',
    'C<sub>5</sub>H<sub>8</sub>N<sub>2</sub>O<sub>8</sub>',
    '',
    '',
    'FPDRKJBIBBHIBW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INB1NACHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INB1NACHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INB1NACHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:INB1NBCHO',
    'C<sub>5</sub>H<sub>8</sub>N<sub>2</sub>O<sub>8</sub>',
    '',
    '',
    'DIJODJNNHWDXRN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INB1NBCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INB1NBCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INB1NBCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:INCNCHO',
    'C<sub>5</sub>H<sub>8</sub>N<sub>2</sub>O<sub>8</sub>',
    '',
    '',
    'QYWHAZCEYLWYSZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INCNCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INCNCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INCNCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:INDHCHO',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>6</sub>',
    '',
    '',
    'LXJORHVMGZGMRK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INDHCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INDHCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INDHCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:INDHPCHO',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>7</sub>',
    '',
    '',
    'NKPKKBYOCYFEQQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INDHPCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INDHPCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INDHPCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MMALNACO3H',
    'C<sub>5</sub>H<sub>7</sub>NO<sub>8</sub>',
    '',
    '',
    'WWJYGONDDIBFHK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MMALNACO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MMALNACO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MMALNACO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MMALNAPAN',
    'C<sub>5</sub>H<sub>6</sub>N<sub>2</sub>O<sub>10</sub>',
    '',
    '',
    'JNHZFZYBXYVXPX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MMALNAPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MMALNAPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MMALNAPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MMALNBCO3H',
    'C<sub>5</sub>H<sub>7</sub>NO<sub>8</sub>',
    '',
    '',
    'ASZGKTQVJXPLHM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MMALNBCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MMALNBCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MMALNBCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MMALNBPAN',
    'C<sub>5</sub>H<sub>6</sub>N<sub>2</sub>O<sub>10</sub>',
    '',
    '',
    'QNDDWZGVLTYMIK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MMALNBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MMALNBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MMALNBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NMBOBCO',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>5</sub>',
    '',
    '',
    'ZWLCCOCHHFERQT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NMBOBCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NMBOBCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NMBOBCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1H4C5PAN',
    'C<sub>6</sub>H<sub>9</sub>NO<sub>7</sub>',
    '',
    '',
    'XKXYOEFJYDLELH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1H4C5PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1H4C5PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1H4C5PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C623NO3',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>6</sub>',
    '',
    '',
    'UTKYBRKMQKBGOV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C623NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C623NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C623NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C67NO3',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>5</sub>',
    '',
    '',
    'MTROCBFSNOSSFX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C67NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C67NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C67NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C68NO3',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>5</sub>',
    '',
    '',
    'DFCRZDMTYDUCKH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C68NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C68NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C68NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO1H63NO3',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>5</sub>',
    '',
    '',
    'QWPYKWKOPQKYFO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO1H63NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO1H63NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO1H63NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NC623OH',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>6</sub>',
    '',
    '',
    'LIALSLHETRNECK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC623OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC623OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC623OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NC623OOH',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>7</sub>',
    '',
    '',
    'LUCHFEJMQFYPEG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC623OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC623OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC623OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C728NO3',
    'C<sub>7</sub>H<sub>13</sub>NO<sub>6</sub>',
    '',
    '',
    'CDBHNFBQKSTCON-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>8</sup>',
    '17000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C728NO3'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C728NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C728NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C728NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C730NO3',
    'C<sub>7</sub>H<sub>13</sub>NO<sub>6</sub>',
    '',
    '',
    'RVWIAVBELSCRER-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>9</sup>',
    '17000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C730NO3'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C730NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C730NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C730NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NC728OH',
    'C<sub>7</sub>H<sub>13</sub>NO<sub>6</sub>',
    '',
    '',
    'RMGZPHZIJLBXBA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC728OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC728OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC728OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NC728OOH',
    'C<sub>7</sub>H<sub>13</sub>NO<sub>7</sub>',
    '',
    '',
    'NMPAVXKBWDGSMK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC728OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC728OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC728OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NC730OH',
    'C<sub>7</sub>H<sub>13</sub>NO<sub>6</sub>',
    '',
    '',
    'ZPFRZNAADTZJOS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC730OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC730OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC730OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NC730OOH',
    'C<sub>7</sub>H<sub>13</sub>NO<sub>7</sub>',
    '',
    '',
    'LJYXGYOAXKBDIY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC730OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC730OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC730OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C826NO3',
    'C<sub>8</sub>H<sub>13</sub>NO<sub>6</sub>',
    '',
    '',
    'HYUHCBAMOFNBPC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C826NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C826NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C826NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NC826OH',
    'C<sub>8</sub>H<sub>13</sub>NO<sub>6</sub>',
    '',
    '',
    'UXZRCYKYQRKKOI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC826OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC826OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC826OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C127NO3',
    'C<sub>12</sub>H<sub>19</sub>NO<sub>5</sub>',
    '',
    '',
    'RZJFRKYKWJUXLW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C127NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C127NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C127NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1311NO3',
    'C<sub>13</sub>H<sub>21</sub>NO<sub>5</sub>',
    '',
    '',
    'HIIZKUNLVYOKLJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1311NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1311NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1311NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1313NO3',
    'C<sub>13</sub>H<sub>21</sub>NO<sub>6</sub>',
    '',
    '',
    'SXMORIYKGFOKAB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1313NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1313NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1313NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NC1313OH',
    'C<sub>13</sub>H<sub>21</sub>NO<sub>6</sub>',
    '',
    '',
    'RAUQQNONBFDDJB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC1313OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC1313OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC1313OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C3NO3COOOH',
    'C<sub>3</sub>H<sub>5</sub>NO<sub>6</sub>',
    '',
    '',
    'JXBSDKIVLYRFTK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3NO3COOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3NO3COOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3NO3COOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CH3COPAN',
    'C<sub>3</sub>H<sub>3</sub>NO<sub>6</sub>',
    '',
    '',
    'BNYSUSDQQIWDSZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3COPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3COPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3COPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BUTONENO3',
    'C<sub>4</sub>H<sub>7</sub>NO<sub>4</sub>',
    '',
    '',
    'KFRUNLQRYXGRRS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BUTONENO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BUTONENO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BUTONENO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO23C4NO3',
    'C<sub>4</sub>H<sub>5</sub>NO<sub>5</sub>',
    '',
    '',
    'RSORCZUYAJEINP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO23C4NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO23C4NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO23C4NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO2C3PAN',
    'C<sub>4</sub>H<sub>5</sub>NO<sub>6</sub>',
    '',
    '',
    'VXGDXYQGFKIYIJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2C3PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2C3PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2C3PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO2N3CO3H',
    'C<sub>4</sub>H<sub>5</sub>NO<sub>7</sub>',
    '',
    '',
    'PLOOSZKRSUJKKF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2N3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2N3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2N3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO2N3PAN',
    'C<sub>4</sub>H<sub>4</sub>N<sub>2</sub>O<sub>9</sub>',
    '',
    '',
    'RXUYCSQEPKEYNB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2N3PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2N3PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2N3PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-oxobutyl nitrate',
    'C<sub>4</sub>H<sub>7</sub>NO<sub>4</sub>',
    '',
    '138779-12-1',
    'OVISQPFXRZOZFI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-oxobutyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-oxobutyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-oxobutyl nitrate'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:COC4NO3OOH',
    'C<sub>4</sub>H<sub>7</sub>NO<sub>6</sub>',
    '',
    '',
    'AEHFBVVGPAXMNG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:COC4NO3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:COC4NO3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:COC4NO3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MEKANO3',
    'C<sub>4</sub>H<sub>7</sub>NO<sub>4</sub>',
    '',
    '',
    'SQFMCLNZTZWUJY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MEKANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MEKANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MEKANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NMVK',
    'C<sub>4</sub>H<sub>5</sub>NO<sub>4</sub>',
    '',
    '',
    'YTEQPVIDLVIVHW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NMVK'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NMVK'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NMVK'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4M2NO3ONE',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>4</sub>',
    '',
    '',
    'DIMIHFOKCQZMGY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4M2NO3ONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4M2NO3ONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4M2NO3ONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4M3NO3ONE',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>4</sub>',
    '',
    '',
    'SAHLZHFOPIFWKH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4M3NO3ONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4M3NO3ONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4M3NO3ONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4MCNO3OOH',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>6</sub>',
    '',
    '',
    'AOCDDMVLVLTZNT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4MCNO3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4MCNO3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4MCNO3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C51NO324CO',
    'C<sub>5</sub>H<sub>7</sub>NO<sub>5</sub>',
    '',
    '',
    'KIDZPQUIRFWTHY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C51NO324CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C51NO324CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C51NO324CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C51NO32CO',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>4</sub>',
    '',
    '',
    'TTZVKGPORDTQGG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C51NO32CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C51NO32CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C51NO32CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C52NO33CO',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>4</sub>',
    '',
    '',
    'VOCQUTRGVIAJPG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C52NO33CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C52NO33CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C52NO33CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C53NO324CO',
    'C<sub>5</sub>H<sub>7</sub>NO<sub>5</sub>',
    '',
    '',
    'QYJXVKSLJJQONK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C53NO324CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C53NO324CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C53NO324CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C53NO32CO',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>4</sub>',
    '',
    '',
    'LVGYWFUEHRGRSS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C53NO32CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C53NO32CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C53NO32CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5CONO3OOH',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>6</sub>',
    '',
    '',
    'ZDTBCADGPXXLKE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5CONO3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5CONO3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5CONO3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5COO2NO2',
    'C<sub>5</sub>H<sub>5</sub>NO<sub>6</sub>',
    '',
    '',
    'BZPLAICQOBBIOR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5COO2NO2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5COO2NO2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5COO2NO2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5NO3O4OOH',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>6</sub>',
    '',
    '',
    'CASCWEIOXSCVGJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5NO3O4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5NO3O4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5NO3O4OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5NO3OAOOH',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>6</sub>',
    '',
    '',
    'FLHIUJMTRYIPLY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5NO3OAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5NO3OAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5NO3OAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5ONO34OOH',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>6</sub>',
    '',
    '',
    'LOZNRBAEPWQBFW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5ONO34OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5ONO34OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5ONO34OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5PAN16',
    'C<sub>5</sub>H<sub>7</sub>NO<sub>6</sub>',
    '',
    '',
    'IZEBTYZDWKBBFQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN16'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN16'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN16'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5PAN2',
    'C<sub>5</sub>H<sub>7</sub>NO<sub>6</sub>',
    '',
    '',
    'XMORPXKVSPHXDA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5PAN7',
    'C<sub>5</sub>H<sub>7</sub>NO<sub>6</sub>',
    '',
    '',
    'VONRVKPFQAOOPX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN7'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN7'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN7'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5PAN9',
    'C<sub>5</sub>H<sub>5</sub>NO<sub>7</sub>',
    '',
    '',
    'HJZPHZLLKGPYCO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN9'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN9'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5PAN9'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DIEKBNO3',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>4</sub>',
    '',
    '',
    'WKTFKAAKLZJYGP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DIEKBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DIEKBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DIEKBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:INANCOCO3H',
    'C<sub>5</sub>H<sub>6</sub>N<sub>2</sub>O<sub>10</sub>',
    '',
    '',
    'OKQCOTADQFFQES-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INANCOCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INANCOCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INANCOCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:INANCOPAN',
    'C<sub>5</sub>H<sub>5</sub>N<sub>3</sub>O<sub>12</sub>',
    '',
    '',
    'OHHXWPYTKFCNFA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INANCOPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INANCOPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INANCOPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MIPKBNO3',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>4</sub>',
    '',
    '',
    'PNKPSVUHDDVFRC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIPKBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIPKBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIPKBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MPRKNO3',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>4</sub>',
    '',
    '',
    'GMHWHQCXUOCSQQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MPRKNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MPRKNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MPRKNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C3COCPAN',
    'C<sub>6</sub>H<sub>9</sub>NO<sub>6</sub>',
    '',
    '',
    'QAGGXZNGFPYUOO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3COCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3COCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3COCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4MCODBPAN',
    'C<sub>6</sub>H<sub>7</sub>NO<sub>6</sub>',
    '',
    '',
    'OBEVNDXPXGMJPT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4MCODBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4MCODBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4MCODBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C62NO335CO',
    'C<sub>6</sub>H<sub>9</sub>NO<sub>5</sub>',
    '',
    '',
    'ABDNFJAHWTWRFH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C62NO335CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C62NO335CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C62NO335CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C62NO33CO',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>4</sub>',
    '',
    '',
    'OBVLXHVNJQTRAU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C62NO33CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C62NO33CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C62NO33CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C63NO32CO',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>4</sub>',
    '',
    '',
    'QSKMGJAWRGUYGL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C63NO32CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C63NO32CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C63NO32CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C64NO335CO',
    'C<sub>6</sub>H<sub>9</sub>NO<sub>5</sub>',
    '',
    '',
    'CHGSCHAFWLLPDM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C64NO335CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C64NO335CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C64NO335CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C66NO35CO',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>4</sub>',
    '',
    '',
    'NNYDFJRPKYRBEY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C66NO35CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C66NO35CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C66NO35CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6CO134PAN',
    'C<sub>6</sub>H<sub>7</sub>NO<sub>7</sub>',
    '',
    '',
    'OIZONYBQGYIWDV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO134PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO134PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO134PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6CONO3OOH',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>6</sub>',
    '',
    '',
    'JAMSWIXAFBYGGR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CONO3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CONO3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CONO3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6DCARBPAN',
    'C<sub>6</sub>H<sub>7</sub>NO<sub>6</sub>',
    '',
    '',
    'QTAROYORLXCHIO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6DCARBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6DCARBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6DCARBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6NO324CO',
    'C<sub>6</sub>H<sub>9</sub>NO<sub>5</sub>',
    '',
    '',
    'ZLHGCQIPJTVAEP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6NO324CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6NO324CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6NO324CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6NO3COOOH',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>6</sub>',
    '',
    '',
    'HQTZSBFILMVSJZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6NO3COOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6NO3COOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6NO3COOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6PAN12',
    'C<sub>6</sub>H<sub>9</sub>NO<sub>6</sub>',
    '',
    '',
    'LSIJQLAUAXHOJI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN12'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN12'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN12'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6PAN16',
    'C<sub>6</sub>H<sub>9</sub>NO<sub>6</sub>',
    '',
    '',
    'JDUNWYCOIXFXGK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN16'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN16'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN16'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6PAN2',
    'C<sub>6</sub>H<sub>9</sub>NO<sub>6</sub>',
    '',
    '',
    'BSRDZZSTWMTZHH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6PAN5',
    'C<sub>6</sub>H<sub>9</sub>NO<sub>6</sub>',
    '',
    '',
    'AYORGEAGFIRFHW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN5'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6PAN6',
    'C<sub>6</sub>H<sub>9</sub>NO<sub>6</sub>',
    '',
    '',
    'STXATUQYWORJHN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN6'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN6'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN6'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6PAN7',
    'C<sub>6</sub>H<sub>7</sub>NO<sub>7</sub>',
    '',
    '',
    'FEUNFERSGUKVTQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN7'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN7'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN7'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CONO3C6OOH',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>6</sub>',
    '',
    '',
    'BPHZXGKZHPQLPB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CONO3C6OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CONO3C6OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CONO3C6OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CYHXONANO3',
    'C<sub>6</sub>H<sub>9</sub>NO<sub>4</sub>',
    '',
    '',
    'VLCBNIODXGFPBM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CYHXONANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CYHXONANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CYHXONANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ECO3PAN',
    'C<sub>6</sub>H<sub>5</sub>NO<sub>8</sub>',
    '',
    '',
    'GLZSBLKUFXIYNN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ECO3PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ECO3PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ECO3PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EIPKBNO3',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>4</sub>',
    '',
    '',
    'QPLZWEVCYZLYTL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EIPKBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EIPKBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EIPKBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HEX2ONANO3',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>4</sub>',
    '',
    '',
    'OZSNHPHDGAJMHG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEX2ONANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEX2ONANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEX2ONANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HEX2ONBNO3',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>4</sub>',
    '',
    '',
    'JYVFNKYOALTNTA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEX2ONBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEX2ONBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEX2ONBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HEX3ONANO3',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>4</sub>',
    '',
    '',
    'KTYGBCIWLHIEKP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEX3ONANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEX3ONANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEX3ONANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HEX3ONDNO3',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>4</sub>',
    '',
    '',
    'PRTKDFINSKNZSU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEX3ONDNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEX3ONDNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HEX3ONDNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:M2BKANO3',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>4</sub>',
    '',
    '',
    'NYAAKBDXIQFYDD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2BKANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2BKANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:M2BKANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MC4CODBPAN',
    'C<sub>6</sub>H<sub>7</sub>NO<sub>6</sub>',
    '',
    '',
    'WHFHKQLMYAOVSY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MC4CODBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MC4CODBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MC4CODBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MIBKANO3',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>4</sub>',
    '',
    '',
    'PKJJSCYTBLHEMI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIBKANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIBKANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIBKANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MTBKNO3',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>4</sub>',
    '',
    '',
    'OYSBYTCKEAIMOW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBKNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBKNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBKNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NBZQOOH',
    'C<sub>6</sub>H<sub>5</sub>NO<sub>7</sub>',
    '',
    '',
    'NXGPVQDYDGLWQQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBZQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBZQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBZQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C627PAN',
    'C<sub>7</sub>H<sub>9</sub>NO<sub>7</sub>',
    '',
    '',
    'FQVTWXYWQQSSRX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C627PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C627PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C627PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7ADCPAN',
    'C<sub>7</sub>H<sub>9</sub>NO<sub>6</sub>',
    '',
    '',
    'OFKNKTFVVCSQBW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7ADCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7ADCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7ADCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7DCPAN',
    'C<sub>7</sub>H<sub>9</sub>NO<sub>6</sub>',
    '',
    '',
    'ZGBUEZLBCHGZPP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7DCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7DCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7DCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7DDCPAN',
    'C<sub>7</sub>H<sub>9</sub>NO<sub>6</sub>',
    '',
    '',
    'WCHGYJHJZMHIAR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7DDCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7DDCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7DDCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7PAN3',
    'C<sub>7</sub>H<sub>7</sub>NO<sub>8</sub>',
    '',
    '',
    'XMNXEIJPBOBVEP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7PAN3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7PAN3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7PAN3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IC7DCPAN',
    'C<sub>7</sub>H<sub>9</sub>NO<sub>6</sub>',
    '',
    '',
    'NZLPHNCQTJFNGH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IC7DCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IC7DCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IC7DCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NC71CO',
    'C<sub>7</sub>H<sub>7</sub>NO<sub>6</sub>',
    '',
    '',
    'CDHAVACRDDMHGZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC71CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC71CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC71CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NC71OOH',
    'C<sub>7</sub>H<sub>9</sub>NO<sub>7</sub>',
    '',
    '',
    'CIJBWMVCSXGACJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC71OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC71OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC71OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NC72OOH',
    'C<sub>7</sub>H<sub>7</sub>NO<sub>8</sub>',
    '',
    '',
    'RYHDNZNGTUJGAD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC72OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC72OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC72OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NPTLQOOH',
    'C<sub>7</sub>H<sub>7</sub>NO<sub>7</sub>',
    '',
    '',
    'WIZJVJIMHIROQF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPTLQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPTLQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPTLQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5DBEPAN',
    'C<sub>8</sub>H<sub>9</sub>NO<sub>7</sub>',
    '',
    '',
    'OYOZKJOWUFGKRQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5DBEPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5DBEPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5DBEPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5EDBPAN',
    'C<sub>8</sub>H<sub>9</sub>NO<sub>7</sub>',
    '',
    '',
    'KNPMBKOCKIUXFV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5EDBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5EDBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5EDBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C727PAN',
    'C<sub>8</sub>H<sub>11</sub>NO<sub>7</sub>',
    '',
    '',
    'WBGZRMCIPBEEGH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C727PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C727PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C727PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7CODBPAN',
    'C<sub>8</sub>H<sub>11</sub>NO<sub>6</sub>',
    '',
    '',
    'QVHZZCVTEAGIPK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7CODBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7CODBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7CODBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C817NO3',
    'C<sub>8</sub>H<sub>13</sub>NO<sub>5</sub>',
    '',
    '',
    'ZONZWPKPCIWKRN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>4</sup>',
    '12000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C817NO3'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C817NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C817NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C817NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NMXYQOOH',
    'C<sub>8</sub>H<sub>9</sub>NO<sub>7</sub>',
    '',
    '',
    'MDRQMTCFLWPCNU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NMXYQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NMXYQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NMXYQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NOXYQOOH',
    'C<sub>8</sub>H<sub>9</sub>NO<sub>7</sub>',
    '',
    '',
    'SFYCEAPRSKIFCS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOXYQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOXYQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOXYQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NPEBQOOH',
    'C<sub>8</sub>H<sub>9</sub>NO<sub>7</sub>',
    '',
    '',
    'HZFUWULOZSGVHH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPEBQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPEBQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPEBQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NPXYQOOH',
    'C<sub>8</sub>H<sub>9</sub>NO<sub>7</sub>',
    '',
    '',
    'LMPSHWMXIGVDOI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPXYQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPXYQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPXYQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C816PAN',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>6</sub>',
    '',
    '',
    'JXXOSNUALVJMQL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C816PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C816PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C816PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C817PAN',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>7</sub>',
    '',
    '',
    'AGDIJRUETYYZKI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C817PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C817PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C817PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C827PAN',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>7</sub>',
    '',
    '',
    'QMDLSNSKOZAILD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C827PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C827PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C827PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C828PAN',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>8</sub>',
    '',
    '',
    'LCFHBKSAGMTDCX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C828PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C828PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C828PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C88PAN',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>7</sub>',
    '',
    '',
    'KLGKHKJTYFCRCN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C88PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C88PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C88PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C917NO3',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>5</sub>',
    '',
    '',
    'KVWUPUMJPKRVQS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C917NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C917NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C917NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C923NO3',
    'C<sub>9</sub>H<sub>15</sub>NO<sub>4</sub>',
    '',
    '',
    'JEWJQSHMOKPQHI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>1</sup>',
    '11000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C923NO3'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C923NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C923NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C923NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C928NO3',
    'C<sub>9</sub>H<sub>15</sub>NO<sub>5</sub>',
    '',
    '',
    'HCHMIBGRYQMLLZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C928NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C928NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C928NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C96NO3',
    'C<sub>9</sub>H<sub>15</sub>NO<sub>4</sub>',
    '',
    '',
    'MMTOEOITRCIZDG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C96NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C96NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C96NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C9DCNO3',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>5</sub>',
    '',
    '',
    'TURIVFFHDFEFMU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C9DCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C9DCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C9DCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C9PAN2',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>6</sub>',
    '',
    '',
    'VXDDXZNSSANCGN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C9PAN2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C9PAN2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C9PAN2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NIPRBQOOH',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>7</sub>',
    '',
    '',
    'KGZDDJNUZZWZIJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NIPRBQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NIPRBQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NIPRBQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NLMKAOOH',
    'C<sub>9</sub>H<sub>15</sub>NO<sub>6</sub>',
    '',
    '',
    'ZOTFHCKOVMRARL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NLMKAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NLMKAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NLMKAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NMETLQOOH',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>7</sub>',
    '',
    '',
    'FSVFAZAPMWXECG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NMETLQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NMETLQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NMETLQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NOETLQOOH',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>7</sub>',
    '',
    '',
    'GHGZYHLEQYQZHR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOETLQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOETLQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOETLQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NOPINANO3',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>4</sub>',
    '',
    '',
    'JEOFIBHUYPQAJL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOPINANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOPINANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOPINANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NOPINBNO3',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>4</sub>',
    '',
    '',
    'QGVNTXJLRAHBMW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOPINBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOPINBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOPINBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NOPINCNO3',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>4</sub>',
    '',
    '',
    'CLMUTFVSCXCGKI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOPINCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOPINCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOPINCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NPETLQOOH',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>7</sub>',
    '',
    '',
    'IMJMJNZTMWKOFO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPETLQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPETLQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPETLQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NPPRBQOOH',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>7</sub>',
    '',
    '',
    'MMAZKJNYHBQGDL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPPRBQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPPRBQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPPRBQOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NTM124QOOH',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>7</sub>',
    '',
    '',
    'ZMXXAPJGXNLYQU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NTM124QOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NTM124QOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NTM124QOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1011NO3',
    'C<sub>10</sub>H<sub>17</sub>NO<sub>4</sub>',
    '',
    '',
    'KLQCUGBDZZARMU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1011NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1011NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1011NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C10PAN2',
    'C<sub>10</sub>H<sub>15</sub>NO<sub>6</sub>',
    '',
    '',
    'XGWGKMXMXMPDAK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C10PAN2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C10PAN2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C10PAN2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C923PAN',
    'C<sub>10</sub>H<sub>15</sub>NO<sub>6</sub>',
    '',
    '',
    'ZVYIPTRRRFMSSU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C923PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C923PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C923PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C928PAN',
    'C<sub>10</sub>H<sub>15</sub>NO<sub>7</sub>',
    '',
    '',
    'MIISGCVMOACDOR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C928PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C928PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C928PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NC101CO',
    'C<sub>10</sub>H<sub>15</sub>NO<sub>4</sub>',
    '',
    '',
    'BCIULZBFFUODJR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC101CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC101CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC101CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NC101OOH',
    'C<sub>10</sub>H<sub>15</sub>NO<sub>6</sub>',
    '',
    '',
    'AQVSRLWLNUXIOL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC101OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC101OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC101OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NC102OOH',
    'C<sub>10</sub>H<sub>15</sub>NO<sub>7</sub>',
    '',
    '',
    'ZNOCONLMTXMLFU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC102OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC102OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC102OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1011PAN',
    'C<sub>11</sub>H<sub>17</sub>NO<sub>6</sub>',
    '',
    '',
    'PRDFPHJPDVZXHH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1011PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1011PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1011PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C131NO3',
    'C<sub>13</sub>H<sub>21</sub>NO<sub>5</sub>',
    '',
    '',
    'HFRDBZMTZNPZMV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C131NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C131NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C131NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C131PAN',
    'C<sub>14</sub>H<sub>21</sub>NO<sub>7</sub>',
    '',
    '',
    'YHMAABVAIQVHRP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C131PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C131PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C131PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C141NO3',
    'C<sub>14</sub>H<sub>23</sub>NO<sub>4</sub>',
    '',
    '',
    'JPXQKVXALDMDKF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C141NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C141NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C141NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NBCKOOH',
    'C<sub>14</sub>H<sub>23</sub>NO<sub>6</sub>',
    '',
    '',
    'IMGMBHKHHVQTQK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBCKOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBCKOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBCKOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C141PAN',
    'C<sub>15</sub>H<sub>23</sub>NO<sub>6</sub>',
    '',
    '',
    'PGNAVHCNSKAOHZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C141PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C141PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C141PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4PAN10',
    'C<sub>4</sub>H<sub>5</sub>NO<sub>8</sub>',
    '',
    '',
    'JOAGXXIRMSWAAZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4PAN10'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4PAN10'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4PAN10'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4PAN6',
    'C<sub>4</sub>H<sub>5</sub>NO<sub>7</sub>',
    '',
    '',
    'QRAIBPAZBCTEOB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4PAN6'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4PAN6'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4PAN6'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO3C4NO3OH',
    'C<sub>4</sub>H<sub>7</sub>NO<sub>5</sub>',
    '',
    '',
    'HZFDSYFRCPAXEA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO3C4NO3OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO3C4NO3OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO3C4NO3OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HMVKANO3',
    'C<sub>4</sub>H<sub>7</sub>NO<sub>5</sub>',
    '',
    '',
    'UFDPWCOBIOWDKA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HMVKANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HMVKANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HMVKANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HMVKNO3',
    'C<sub>4</sub>H<sub>7</sub>NO<sub>6</sub>',
    '',
    '',
    'NCLLRWDJHCXXDR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HMVKNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HMVKNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HMVKNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HNBIACET',
    'C<sub>4</sub>H<sub>5</sub>NO<sub>6</sub>',
    '',
    '',
    'HPGBXXMJBUDRLY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HNBIACET'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HNBIACET'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HNBIACET'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HNMVKOH',
    'C<sub>4</sub>H<sub>7</sub>NO<sub>6</sub>',
    '',
    '',
    'KPZZNRQGHDTQNJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HNMVKOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HNMVKOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HNMVKOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HNMVKOOH',
    'C<sub>4</sub>H<sub>7</sub>NO<sub>7</sub>',
    '',
    '',
    'CTKAFSDGNPEZFZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HNMVKOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HNMVKOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HNMVKOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MVKNO3',
    'C<sub>4</sub>H<sub>7</sub>NO<sub>5</sub>',
    '',
    '',
    'SCJOQBCZNBCTOQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MVKNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MVKNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MVKNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MVKOHANO3',
    'C<sub>4</sub>H<sub>7</sub>NO<sub>6</sub>',
    '',
    '',
    'DMSMZXCVKMBQGA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MVKOHANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MVKOHANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MVKOHANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4MCONO3OH',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>5</sub>',
    '',
    '',
    'VRAOJUVNSLNISW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4MCONO3OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4MCONO3OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4MCONO3OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C517NO3',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>5</sub>',
    '',
    '',
    'DLLRFAPEEPVGBN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C517NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C517NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C517NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C51NO3',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>5</sub>',
    '',
    '',
    'OMTWKQRBUUWUQB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C51NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C51NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C51NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5NO3CO4OH',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>5</sub>',
    '',
    '',
    'GEKIHWHZVPPEBT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5NO3CO4OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5NO3CO4OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5NO3CO4OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO2OH3MPAN',
    'C<sub>5</sub>H<sub>7</sub>NO<sub>7</sub>',
    '',
    '',
    'KOFNDQLSBTYFBZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2OH3MPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2OH3MPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO2OH3MPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CO3H4PAN',
    'C<sub>5</sub>H<sub>7</sub>NO<sub>7</sub>',
    '',
    '',
    'KVXLZPRANFUVNJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO3H4PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO3H4PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CO3H4PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H1C23C4PAN',
    'C<sub>5</sub>H<sub>5</sub>NO<sub>8</sub>',
    '',
    '',
    'ZNIKVNWPMOTSJK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H1C23C4PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H1C23C4PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H1C23C4PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H3C2C4PAN',
    'C<sub>5</sub>H<sub>7</sub>NO<sub>7</sub>',
    '',
    '',
    'UDPFGHOTTZCMEQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3C2C4PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3C2C4PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3C2C4PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HMVKBPAN',
    'C<sub>5</sub>H<sub>7</sub>NO<sub>7</sub>',
    '',
    '',
    'VVIGYLNPENSKGX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HMVKBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HMVKBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HMVKBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:INANCO',
    'C<sub>5</sub>H<sub>8</sub>N<sub>2</sub>O<sub>8</sub>',
    '',
    '',
    'IESHUNGXVKLDSS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INANCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INANCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INANCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:INB1CO',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>6</sub>',
    '',
    '',
    'ASROEBVFUUHBLI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INB1CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INB1CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INB1CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:INCCO',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>6</sub>',
    '',
    '',
    'HXWBEXHMXOXGKY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INCCO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4COMOHPAN',
    'C<sub>6</sub>H<sub>7</sub>NO<sub>8</sub>',
    '',
    '',
    'KHOZKKAVCHSHMN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4COMOHPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4COMOHPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4COMOHPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4MOHOPAN',
    'C<sub>6</sub>H<sub>9</sub>NO<sub>7</sub>',
    '',
    '',
    'LVRCIQOIMYLYHB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4MOHOPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4MOHOPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4MOHOPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C517PAN',
    'C<sub>6</sub>H<sub>9</sub>NO<sub>7</sub>',
    '',
    '',
    'BRUHFHISVNPPNB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C517PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C517PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C517PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C519PAN',
    'C<sub>6</sub>H<sub>9</sub>NO<sub>7</sub>',
    '',
    '',
    'QFUOUYQJXYVTOO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C519PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C519PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C519PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5O45OHPAN',
    'C<sub>6</sub>H<sub>9</sub>NO<sub>7</sub>',
    '',
    '',
    'VCYALMFEDUSLKE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5O45OHPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5O45OHPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5O45OHPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C610NO3',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>5</sub>',
    '',
    '',
    'KOUUCDJHLKRSEQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C610NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C610NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C610NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C614NO3',
    'C<sub>6</sub>H<sub>9</sub>NO<sub>6</sub>',
    '',
    '',
    'QPXWFZAVXNBNFW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C614NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C614NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C614NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C61NO3',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>5</sub>',
    '',
    '',
    'SYDWDJOZRNVKSU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C61NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C61NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C61NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C63NO3',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>5</sub>',
    '',
    '',
    'RHTCZESJRHZQFA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C63NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C63NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C63NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C64NO3',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>5</sub>',
    '',
    '',
    'IYYWGRLOLOMZAZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C64NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C64NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C64NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6CONO34OH',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>5</sub>',
    '',
    '',
    'OLTUAQAPCXKDOJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CONO34OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CONO34OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CONO34OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6NO3CO4OH',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>5</sub>',
    '',
    '',
    'WWUUDQUMERSNEM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6NO3CO4OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6NO3CO4OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6NO3CO4OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6NO3CO5OH',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>5</sub>',
    '',
    '',
    'IZBQRALUURUKJG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6NO3CO5OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6NO3CO5OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6NO3CO5OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6PAN9',
    'C<sub>6</sub>H<sub>9</sub>NO<sub>7</sub>',
    '',
    '',
    'NJFFIXOWLQJQIZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN9'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN9'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6PAN9'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MIBKAOHNO3',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>5</sub>',
    '',
    '',
    'YCHDRSSXCQCYSO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIBKAOHNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIBKAOHNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MIBKAOHNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C61CPAN',
    'C<sub>7</sub>H<sub>9</sub>NO<sub>8</sub>',
    '',
    '',
    'FWCVDVIZOKXUGJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C61CPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C61CPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C61CPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C62CPAN',
    'C<sub>7</sub>H<sub>9</sub>NO<sub>8</sub>',
    '',
    '',
    'LHOMRHYSYFWOPZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C62CPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C62CPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C62CPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C712NO3',
    'C<sub>7</sub>H<sub>13</sub>NO<sub>5</sub>',
    '',
    '',
    'RPPGGLBPWJPSSV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C712NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C712NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C712NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C719NO3',
    'C<sub>7</sub>H<sub>11</sub>NO<sub>6</sub>',
    '',
    '',
    'IXGSPJJVHFTXPK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C719NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C719NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C719NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C72NO3',
    'C<sub>7</sub>H<sub>13</sub>NO<sub>5</sub>',
    '',
    '',
    'MWIGFUUCEWIWBB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C72NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C72NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C72NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C77NO3',
    'C<sub>7</sub>H<sub>13</sub>NO<sub>5</sub>',
    '',
    '',
    'KZCKPUAVFWISTB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C77NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C77NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C77NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H3C25C6PAN',
    'C<sub>7</sub>H<sub>9</sub>NO<sub>8</sub>',
    '',
    '',
    'GUUOCMMOMFUPSI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3C25C6PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3C25C6PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3C25C6PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6MOHCOPAN',
    'C<sub>8</sub>H<sub>9</sub>NO<sub>8</sub>',
    '',
    '',
    'PDGRPGJWHYLYKK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6MOHCOPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6MOHCOPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6MOHCOPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7CO2OHPAN',
    'C<sub>8</sub>H<sub>9</sub>NO<sub>8</sub>',
    '',
    '',
    'MICPXOSCTLYWLE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7CO2OHPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7CO2OHPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7CO2OHPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C829NO3',
    'C<sub>8</sub>H<sub>13</sub>NO<sub>6</sub>',
    '',
    '',
    'CDMYSTRAPZWSHD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C829NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C829NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C829NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C82NO3',
    'C<sub>8</sub>H<sub>15</sub>NO<sub>5</sub>',
    '',
    '',
    'HUKHBWOLGKLCRF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C82NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C82NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C82NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6EO2OHPAN',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>8</sub>',
    '',
    '',
    'YGQCKHJQVYPZEV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6EO2OHPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6EO2OHPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6EO2OHPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7MJPPAN',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>8</sub>',
    '',
    '',
    'XJDHGIQDEMCTOX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7MJPPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7MJPPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7MJPPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7MOHCOPAN',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>8</sub>',
    '',
    '',
    'SORJSZWEJQTGJA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7MOHCOPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7MOHCOPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7MOHCOPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C927NO3',
    'C<sub>9</sub>H<sub>15</sub>NO<sub>5</sub>',
    '',
    '',
    'RKOGSSYMWVPWJW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C927NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C927NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C927NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C93NO3',
    'C<sub>9</sub>H<sub>17</sub>NO<sub>5</sub>',
    '',
    '',
    'OEEOAFFOONSSLD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C93NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C93NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C93NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C98NO3',
    'C<sub>9</sub>H<sub>15</sub>NO<sub>6</sub>',
    '',
    '',
    'PQCIVFJRBSNULM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C98NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C98NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C98NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:LMKANO3',
    'C<sub>9</sub>H<sub>15</sub>NO<sub>5</sub>',
    '',
    '',
    'OCTKYXAOGSBZDD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LMKANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LMKANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LMKANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:LMKBNO3',
    'C<sub>9</sub>H<sub>15</sub>NO<sub>5</sub>',
    '',
    '',
    'MVWAQQXSBOJSHS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LMKBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LMKBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LMKBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C103NO3',
    'C<sub>10</sub>H<sub>19</sub>NO<sub>5</sub>',
    '',
    '',
    'NTZGBOUJHFKYIP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C103NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C103NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C103NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C920PAN',
    'C<sub>10</sub>H<sub>15</sub>NO<sub>7</sub>',
    '',
    '',
    'JPFVAVYDZBUWDH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C920PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C920PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C920PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C113NO3',
    'C<sub>11</sub>H<sub>21</sub>NO<sub>5</sub>',
    '',
    '',
    'XIMKJTRLGBXFHP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C113NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C113NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C113NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C123NO3',
    'C<sub>12</sub>H<sub>23</sub>NO<sub>5</sub>',
    '',
    '',
    'MVMJPHZGIRWSLB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C123NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C123NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C123NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C133NO3',
    'C<sub>13</sub>H<sub>21</sub>NO<sub>7</sub>',
    '',
    '',
    'ODJJFBKGWDLDSF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C133NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C133NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C133NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BCKANO3',
    'C<sub>14</sub>H<sub>23</sub>NO<sub>5</sub>',
    '',
    '',
    'YULYIMMPXZFYHU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCKANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCKANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCKANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BCKBNO3',
    'C<sub>14</sub>H<sub>23</sub>NO<sub>5</sub>',
    '',
    '',
    'VHSFPWDPGIOBJY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCKBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCKBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCKBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C142NO3',
    'C<sub>14</sub>H<sub>23</sub>NO<sub>5</sub>',
    '',
    '',
    'AZGAJOUTVTYWPD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C142NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C142NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C142NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C143NO3',
    'C<sub>14</sub>H<sub>23</sub>NO<sub>6</sub>',
    '',
    '',
    'NNHMCYUMVAAOGX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C143NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C143NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C143NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NMGLYOX',
    'C<sub>3</sub>H<sub>3</sub>NO<sub>5</sub>',
    '',
    '',
    'OPXOPVKLHYDIMX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NMGLYOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NMGLYOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NMGLYOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C312COPAN',
    'C<sub>4</sub>H<sub>3</sub>NO<sub>7</sub>',
    '',
    '',
    'RRBQALAYWSLXKO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C312COPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C312COPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C312COPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4CONO3CO',
    'C<sub>4</sub>H<sub>5</sub>NO<sub>5</sub>',
    '',
    '',
    'RXLGSPGPVVHCFU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4CONO3CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4CONO3CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4CONO3CO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NCO23CHO',
    'C<sub>4</sub>H<sub>3</sub>NO<sub>6</sub>',
    '',
    '',
    'VZDGBDWMYVQZKU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NCO23CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NCO23CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NCO23CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4CO2DBPAN',
    'C<sub>5</sub>H<sub>3</sub>NO<sub>7</sub>',
    '',
    '',
    'BTFAHSUMXINULH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4CO2DBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4CO2DBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4CO2DBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4M22CONO3',
    'C<sub>5</sub>H<sub>7</sub>NO<sub>5</sub>',
    '',
    '',
    'FQGALMJVSZOCNN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4M22CONO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4M22CONO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4M22CONO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C512NO3',
    'C<sub>5</sub>H<sub>7</sub>NO<sub>5</sub>',
    '',
    '',
    'OAONLGDTCNNTSO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C512NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C512NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C512NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CHOC3COPAN',
    'C<sub>5</sub>H<sub>5</sub>NO<sub>7</sub>',
    '',
    '',
    'MEMYBUIJIAQZMF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOC3COPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOC3COPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOC3COPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:INANCOCHO',
    'C<sub>5</sub>H<sub>6</sub>N<sub>2</sub>O<sub>8</sub>',
    '',
    '',
    'ALBXLNVOOLMBSV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INANCOCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INANCOCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INANCOCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C511PAN',
    'C<sub>6</sub>H<sub>7</sub>NO<sub>7</sub>',
    '',
    '',
    'ADLPISUKTIUEBV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C511PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C511PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C511PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5124COPAN',
    'C<sub>6</sub>H<sub>5</sub>NO<sub>8</sub>',
    '',
    '',
    'DHCQJQARWDKNBK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5124COPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5124COPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5124COPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C512PAN',
    'C<sub>6</sub>H<sub>7</sub>NO<sub>7</sub>',
    '',
    '',
    'OLSCQSOEJBIJSE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C512PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C512PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C512PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C515PAN',
    'C<sub>6</sub>H<sub>5</sub>NO<sub>8</sub>',
    '',
    '',
    'QIUJGMPSWRWOQB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C515PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C515PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C515PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5CO2DBPAN',
    'C<sub>6</sub>H<sub>5</sub>NO<sub>7</sub>',
    '',
    '',
    'LCULQJDFGZNNJC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5CO2DBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5CO2DBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5CO2DBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5DBCO2PAN',
    'C<sub>6</sub>H<sub>5</sub>NO<sub>7</sub>',
    '',
    '',
    'QMYFWHUFARKUQS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5DBCO2PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5DBCO2PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5DBCO2PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C626NO3',
    'C<sub>6</sub>H<sub>9</sub>NO<sub>5</sub>',
    '',
    '',
    'OCVBVQJPDKPHST-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C626NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C626NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C626NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6COCHOPAN',
    'C<sub>6</sub>H<sub>7</sub>NO<sub>7</sub>',
    '',
    '',
    'YGLXJUWEIHLTAS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6COCHOPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6COCHOPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6COCHOPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4DBM2PAN',
    'C<sub>7</sub>H<sub>7</sub>NO<sub>7</sub>',
    '',
    '',
    'LSIPSXVETZQMNK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4DBM2PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4DBM2PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4DBM2PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C617PAN',
    'C<sub>7</sub>H<sub>9</sub>NO<sub>7</sub>',
    '',
    '',
    'PZZHENCPCXAAMZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C617PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C617PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C617PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C618PAN',
    'C<sub>7</sub>H<sub>9</sub>NO<sub>7</sub>',
    '',
    '',
    'TUYXNXVHKYYCNT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C618PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C618PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C618PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C626PAN',
    'C<sub>7</sub>H<sub>9</sub>NO<sub>7</sub>',
    '',
    '',
    'JTOZIQOFBRFINW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C626PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C626PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C626PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C717NO3',
    'C<sub>7</sub>H<sub>9</sub>NO<sub>6</sub>',
    '',
    '',
    'YBNFZHXBUOLIKA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C717NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C717NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C717NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C718NO3',
    'C<sub>7</sub>H<sub>11</sub>NO<sub>5</sub>',
    '',
    '',
    'WMUFPKACUPNARK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C718NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C718NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C718NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C731NO3',
    'C<sub>7</sub>H<sub>11</sub>NO<sub>5</sub>',
    '',
    '',
    'WJSMASANGLXUCK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C731NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C731NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C731NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7CO2DBPAN',
    'C<sub>7</sub>H<sub>7</sub>NO<sub>7</sub>',
    '',
    '',
    'FJSOTAPJABBDID-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7CO2DBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7CO2DBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7CO2DBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NC61CO3H',
    'C<sub>7</sub>H<sub>7</sub>NO<sub>9</sub>',
    '',
    '',
    'RCADYDMYBSYTRH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>12</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC61CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC61CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC61CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NC6PAN1',
    'C<sub>7</sub>H<sub>6</sub>N<sub>2</sub>O<sub>11</sub>',
    '',
    '',
    'LNWBMFOWVOYBBT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC6PAN1'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC6PAN1'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC6PAN1'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4DBMEPAN',
    'C<sub>8</sub>H<sub>9</sub>NO<sub>7</sub>',
    '',
    '',
    'JDCDQJWNYIFIQT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4DBMEPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4DBMEPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4DBMEPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C718PAN',
    'C<sub>8</sub>H<sub>11</sub>NO<sub>7</sub>',
    '',
    '',
    'IZJQRCOOVGKQNV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C718PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C718PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C718PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C731PAN',
    'C<sub>8</sub>H<sub>11</sub>NO<sub>7</sub>',
    '',
    '',
    'BCDBCVPVNWUZKV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C731PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C731PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C731PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C8CO2DBPAN',
    'C<sub>8</sub>H<sub>9</sub>NO<sub>7</sub>',
    '',
    '',
    'IPAWZRQBQOFPJA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8CO2DBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8CO2DBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8CO2DBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C8DBCO2PAN',
    'C<sub>8</sub>H<sub>9</sub>NO<sub>7</sub>',
    '',
    '',
    'ZDCAPCKMKJMPHV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8DBCO2PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8DBCO2PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8DBCO2PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C87PAN',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>8</sub>',
    '',
    '',
    'KZPDHKTVZKNFJF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C87PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C87PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C87PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C915NO3',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>5</sub>',
    '',
    '',
    'CFOCUCLSGKHNEG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C915NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C915NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C915NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C916NO3',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>6</sub>',
    '',
    '',
    'VOXWFVUGDBUBCW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C916NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C916NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C916NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C918NO3',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>5</sub>',
    '',
    '',
    'AMOFMDWAGAYJCS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C918NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C918NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C918NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C919NO3',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>6</sub>',
    '',
    '',
    'DCZHYWWXGROBKB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C919NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C919NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C919NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C930NO3',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>6</sub>',
    '',
    '',
    'DDSHYSHFPVKRPI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C930NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C930NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C930NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1010NO3',
    'C<sub>10</sub>H<sub>15</sub>NO<sub>5</sub>',
    '',
    '',
    'GVXIDPZAUKXFPR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1010NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1010NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1010NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1012NO3',
    'C<sub>10</sub>H<sub>17</sub>NO<sub>5</sub>',
    '',
    '',
    'XKIZNDJDYSDNBL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1012NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1012NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1012NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C106NO3',
    'C<sub>10</sub>H<sub>15</sub>NO<sub>6</sub>',
    '',
    '',
    'DSEFLMWIAZKUSJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C106NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C106NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C106NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C108NO3',
    'C<sub>10</sub>H<sub>15</sub>NO<sub>6</sub>',
    '',
    '',
    'MVSLQVXNIWKHQS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C108NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C108NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C108NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NLIMALOOH',
    'C<sub>10</sub>H<sub>17</sub>NO<sub>7</sub>',
    '',
    '',
    'NTLQQKIUYMIZPN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NLIMALOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NLIMALOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NLIMALOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PINALNO3',
    'C<sub>10</sub>H<sub>15</sub>NO<sub>5</sub>',
    '',
    '',
    'FNTMCASBPWQXGD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PINALNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PINALNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PINALNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C116NO3',
    'C<sub>11</sub>H<sub>17</sub>NO<sub>5</sub>',
    '',
    '',
    'AWSJYNTZBDMUKU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C116NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C116NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C116NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C116PAN',
    'C<sub>12</sub>H<sub>17</sub>NO<sub>7</sub>',
    '',
    '',
    'IHJLCJPVFFZKMO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C116PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C116PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C116PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1210NO3',
    'C<sub>12</sub>H<sub>19</sub>NO<sub>5</sub>',
    '',
    '',
    'IJHSXQWUSMROBJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1210NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1210NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1210NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1210PAN',
    'C<sub>13</sub>H<sub>19</sub>NO<sub>7</sub>',
    '',
    '',
    'PWZZEUPXUFAYML-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1210PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1210PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1210PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NBCALOOH',
    'C<sub>15</sub>H<sub>25</sub>NO<sub>7</sub>',
    '',
    '',
    'TUYLAULXHOKFAG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBCALOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBCALOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBCALOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H3NCO2CHO',
    'C<sub>4</sub>H<sub>5</sub>NO<sub>6</sub>',
    '',
    '',
    'VCTGKRYJUDQYFK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3NCO2CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3NCO2CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H3NCO2CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HMVKNGLYOX',
    'C<sub>4</sub>H<sub>5</sub>NO<sub>6</sub>',
    '',
    '',
    'VDDXFUNTPSDTJP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HMVKNGLYOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HMVKNGLYOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HMVKNGLYOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:INB1GLYOX',
    'C<sub>5</sub>H<sub>7</sub>NO<sub>6</sub>',
    '',
    '',
    'NAZCWKUVRXJZPX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INB1GLYOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INB1GLYOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INB1GLYOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:INCGLYOX',
    'C<sub>5</sub>H<sub>7</sub>NO<sub>6</sub>',
    '',
    '',
    'DGCXGPGOOTUCCO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INCGLYOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INCGLYOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INCGLYOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5CO2OHPAN',
    'C<sub>6</sub>H<sub>5</sub>NO<sub>8</sub>',
    '',
    '',
    'MLSWEUDOYVEBFO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5CO2OHPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5CO2OHPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5CO2OHPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C6CO2OHPAN',
    'C<sub>7</sub>H<sub>7</sub>NO<sub>8</sub>',
    '',
    '',
    'GITGCCFTTYJWBT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO2OHPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO2OHPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C6CO2OHPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5M2OHOPAN',
    'C<sub>8</sub>H<sub>9</sub>NO<sub>8</sub>',
    '',
    '',
    'MJYXUWCXTAYXTN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5M2OHOPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5M2OHOPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5M2OHOPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C7OHCO2PAN',
    'C<sub>8</sub>H<sub>9</sub>NO<sub>8</sub>',
    '',
    '',
    'WKRTWLVIFYOGIB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7OHCO2PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7OHCO2PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C7OHCO2PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C5MEJPAN',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>8</sub>',
    '',
    '',
    'KTOTUVLJTIGMKC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5MEJPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5MEJPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C5MEJPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C8CO2OHPAN',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>8</sub>',
    '',
    '',
    'UEMVFSSSLHUULZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8CO2OHPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8CO2OHPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8CO2OHPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C8OHCO2PAN',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>8</sub>',
    '',
    '',
    'GUTUSTBTBKWXHL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8OHCO2PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8OHCO2PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C8OHCO2PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:LIMALNO3',
    'C<sub>10</sub>H<sub>17</sub>NO<sub>6</sub>',
    '',
    '',
    'FDBNDHKWTKEDSC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>8</sup>',
    '23000',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMALNO3'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMALNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMALNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:LIMALNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NLIMALOH',
    'C<sub>10</sub>H<sub>17</sub>NO<sub>6</sub>',
    '',
    '',
    'NNOYMJCUDKQQLW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NLIMALOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NLIMALOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NLIMALOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C117NO3',
    'C<sub>11</sub>H<sub>17</sub>NO<sub>6</sub>',
    '',
    '',
    'VRGCJRKSASUXOA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C117NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C117NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C117NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C118NO3',
    'C<sub>11</sub>H<sub>17</sub>NO<sub>7</sub>',
    '',
    '',
    'RHEKUCZWBZRVBN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C118NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C118NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C118NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1215NO3',
    'C<sub>12</sub>H<sub>19</sub>NO<sub>7</sub>',
    '',
    '',
    'HIFZNEWSKKHKQF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1215NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1215NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1215NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C128NO3',
    'C<sub>12</sub>H<sub>19</sub>NO<sub>6</sub>',
    '',
    '',
    'XVMHBNQZULJJQH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C128NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C128NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C128NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1312NO3',
    'C<sub>13</sub>H<sub>21</sub>NO<sub>6</sub>',
    '',
    '',
    'LCWPKTPKZZROTF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1312NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1312NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1312NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BCALNO3',
    'C<sub>15</sub>H<sub>25</sub>NO<sub>6</sub>',
    '',
    '',
    'KJHBLMRUHUAACD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCALNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCALNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCALNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NBCALOH',
    'C<sub>15</sub>H<sub>25</sub>NO<sub>6</sub>',
    '',
    '',
    'YUOPYTDNMDNILJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBCALOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBCALOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBCALOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NO3CH2CO2H',
    'C<sub>2</sub>H<sub>3</sub>NO<sub>5</sub>',
    '',
    '',
    'VHOVOPOBBVJMEP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NO3CH2CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NO3CH2CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NO3CH2CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PRNO3CO2H',
    'C<sub>3</sub>H<sub>5</sub>NO<sub>5</sub>',
    '',
    '',
    'DVOPCQDTEPKYKW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRNO3CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRNO3CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRNO3CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MPRNO3CO2H',
    'C<sub>4</sub>H<sub>7</sub>NO<sub>5</sub>',
    '',
    '',
    'MSBKTJKUKRRTOZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MPRNO3CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MPRNO3CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MPRNO3CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NC3CO2H',
    'C<sub>4</sub>H<sub>5</sub>NO<sub>5</sub>',
    '',
    '',
    'IYBHCPMQXJSPPT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC3CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC3CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC3CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C3MNO3CO2H',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>5</sub>',
    '',
    '',
    'CCKPHGGNTPAJHG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3MNO3CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3MNO3CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C3MNO3CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C43NO3CO2H',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>5</sub>',
    '',
    '',
    'PAJLSJNKCRUQAA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C43NO3CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C43NO3CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C43NO3CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C4NO3CO2H',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>5</sub>',
    '',
    '',
    'LHOHBJOUNVJDSQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4NO3CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4NO3CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C4NO3CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NC4CO2H',
    'C<sub>5</sub>H<sub>7</sub>NO<sub>5</sub>',
    '',
    '',
    'ZKTRJZJYWMAEEY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC4CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC4CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC4CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C65NO3CO2H',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>5</sub>',
    '',
    '',
    'JEDGAPUZBUOYQF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C65NO3CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C65NO3CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C65NO3CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C721PAN',
    'C<sub>8</sub>H<sub>11</sub>NO<sub>7</sub>',
    '',
    '',
    'OMUZIQDFMVGNTC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C721PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C721PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C721PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C811NO3',
    'C<sub>8</sub>H<sub>13</sub>NO<sub>5</sub>',
    '',
    '',
    'WYXUZPCNBFFDRO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C811NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C811NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C811NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C823NO3',
    'C<sub>8</sub>H<sub>13</sub>NO<sub>5</sub>',
    '',
    '',
    'QAJOXMTYFQHFPC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C823NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C823NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C823NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C811PAN',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>7</sub>',
    '',
    '',
    'BOYXRVFXWMBNIT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C811PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C811PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C811PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C823PAN',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>7</sub>',
    '',
    '',
    'GRHNTSHNCZZYLE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C823PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C823PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C823PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C137NO3',
    'C<sub>13</sub>H<sub>21</sub>NO<sub>5</sub>',
    '',
    '',
    'CQGOUXQAADNZJX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C137NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C137NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C137NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C137PAN',
    'C<sub>14</sub>H<sub>21</sub>NO<sub>7</sub>',
    '',
    '',
    'KJDMPVAHMJBAAO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C137PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C137PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C137PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MACRNBCO2H',
    'C<sub>4</sub>H<sub>7</sub>NO<sub>6</sub>',
    '',
    '',
    'WQOIEXBGIWRREH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MACRNBCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MACRNBCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MACRNBCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MACRNCO2H',
    'C<sub>4</sub>H<sub>7</sub>NO<sub>6</sub>',
    '',
    '',
    'GPIMHHNLFCYMAO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MACRNCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MACRNCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MACRNCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C57NO3CO2H',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>7</sub>',
    '',
    '',
    'VNPCVOYEGJTTSH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C57NO3CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C57NO3CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C57NO3CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C58NO3CO2H',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>7</sub>',
    '',
    '',
    'QOEJXJLKIMUJIJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C58NO3CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C58NO3CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C58NO3CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:INAHCO2H',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>7</sub>',
    '',
    '',
    'KDGUUBLLRPAORR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INAHCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INAHCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INAHCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:INAHPCO2H',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>8</sub>',
    '',
    '',
    'CHIYBIMSWIBBRD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INAHPCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INAHPCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INAHPCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:INANCO2H',
    'C<sub>5</sub>H<sub>8</sub>N<sub>2</sub>O<sub>9</sub>',
    '',
    '',
    'QEPBKMYMBRWSSY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INANCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INANCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INANCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:INB1HPCO2H',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>8</sub>',
    '',
    '',
    'XWZUZABUMCCUCE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INB1HPCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INB1HPCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INB1HPCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:INB1NACO2H',
    'C<sub>5</sub>H<sub>8</sub>N<sub>2</sub>O<sub>9</sub>',
    '',
    '',
    'FONBWUWRCYYCPB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INB1NACO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INB1NACO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INB1NACO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:INB1NBCO2H',
    'C<sub>5</sub>H<sub>8</sub>N<sub>2</sub>O<sub>9</sub>',
    '',
    '',
    'YGORAHXKOXOIMV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INB1NBCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INB1NBCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INB1NBCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:INCNCO2H',
    'C<sub>5</sub>H<sub>8</sub>N<sub>2</sub>O<sub>9</sub>',
    '',
    '',
    'LXTUVHDUSAOJOD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INCNCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INCNCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INCNCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C139NO3',
    'C<sub>13</sub>H<sub>21</sub>NO<sub>7</sub>',
    '',
    '',
    'UFNZJLDHNJULFY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C139NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C139NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C139NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CONM2CO2H',
    'C<sub>4</sub>H<sub>5</sub>NO<sub>6</sub>',
    '',
    '',
    'LTGNKSWVEYSUMY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CONM2CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CONM2CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CONM2CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MMALNACO2H',
    'C<sub>5</sub>H<sub>7</sub>NO<sub>7</sub>',
    '',
    '',
    'REHIBMNEJUPYOU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MMALNACO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MMALNACO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MMALNACO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MMALNBCO2H',
    'C<sub>5</sub>H<sub>7</sub>NO<sub>7</sub>',
    '',
    '',
    'RAMGTVAYJVLLRG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MMALNBCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MMALNBCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MMALNBCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:INANCOCO2H',
    'C<sub>5</sub>H<sub>6</sub>N<sub>2</sub>O<sub>9</sub>',
    '',
    '',
    'XEVMEFHPLZUFAK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INANCOCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INANCOCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:INANCOCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C732NO3',
    'C<sub>7</sub>H<sub>11</sub>NO<sub>6</sub>',
    '',
    '',
    'SXYZBZXZNRYERD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C732NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C732NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C732NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C732PAN',
    'C<sub>8</sub>H<sub>11</sub>NO<sub>8</sub>',
    '',
    '',
    'WNUKRJOERGBBRT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C732PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C732PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C732PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1211NO3',
    'C<sub>12</sub>H<sub>19</sub>NO<sub>6</sub>',
    '',
    '',
    'DQVGSELEPUBBSS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1211NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1211NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1211NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1211PAN',
    'C<sub>13</sub>H<sub>19</sub>NO<sub>8</sub>',
    '',
    '',
    'IROGWMVYBREROI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1211PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1211PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1211PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C813NO3',
    'C<sub>8</sub>H<sub>13</sub>NO<sub>7</sub>',
    '',
    '',
    'GYZVFQOTJWTWBE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C813NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C813NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C813NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1212NO3',
    'C<sub>12</sub>H<sub>19</sub>NO<sub>8</sub>',
    '',
    '',
    'NTNWJSADTNTFHH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1212NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1212NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1212NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1213NO3',
    'C<sub>12</sub>H<sub>19</sub>NO<sub>8</sub>',
    '',
    '',
    'FRAJAIDKFGOMCR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1213NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1213NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1213NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1310NO3',
    'C<sub>13</sub>H<sub>21</sub>NO<sub>7</sub>',
    '',
    '',
    'YNRLOWIUKIUEHR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1310NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1310NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1310NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C151NO3',
    'C<sub>15</sub>H<sub>25</sub>NO<sub>7</sub>',
    '',
    '',
    'BHPYCCPMXIBJRO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C151NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C151NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C151NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CHOOCH2NO3',
    'C<sub>2</sub>H<sub>3</sub>NO<sub>5</sub>',
    '',
    '',
    'OAQKKIQKQLJUJT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOOCH2NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOOCH2NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOOCH2NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CHOOMPAN',
    'C<sub>3</sub>H<sub>3</sub>NO<sub>7</sub>',
    '',
    '',
    'XZTQWYQUABOKPG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOOMPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOOMPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOOMPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ETHFORMNO3',
    'C<sub>3</sub>H<sub>5</sub>NO<sub>5</sub>',
    '',
    '',
    'DOXRBPLNMOIQGP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETHFORMNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETHFORMNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETHFORMNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:METACETNO3',
    'C<sub>3</sub>H<sub>5</sub>NO<sub>5</sub>',
    '',
    '',
    'HRSAJZJMUADCNM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METACETNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METACETNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METACETNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MMCFNO3',
    'C<sub>3</sub>H<sub>3</sub>NO<sub>7</sub>',
    '',
    '',
    'IFMSYUVMGRDEMV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MMCFNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MMCFNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MMCFNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ACEC2H4NO3',
    'C<sub>4</sub>H<sub>7</sub>NO<sub>5</sub>',
    '',
    '',
    'QOXSFWPQUXLCPI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACEC2H4NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACEC2H4NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACEC2H4NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ACETMEPAN',
    'C<sub>4</sub>H<sub>5</sub>NO<sub>7</sub>',
    '',
    '',
    'QMSGSFOWAUFKPL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACETMEPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACETMEPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACETMEPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:COO2C3PAN',
    'C<sub>4</sub>H<sub>5</sub>NO<sub>7</sub>',
    '',
    '',
    'YQMLKDOXYNVTNM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:COO2C3PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:COO2C3PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:COO2C3PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ETACETNO3',
    'C<sub>4</sub>H<sub>7</sub>NO<sub>5</sub>',
    '',
    '',
    'KORDSAOMZNGUAL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETACETNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETACETNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETACETNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPRFORMNO3',
    'C<sub>4</sub>H<sub>7</sub>NO<sub>5</sub>',
    '',
    '',
    'DZSICYNSKFSRMV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRFORMNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRFORMNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRFORMNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NBZFUOOH',
    'C<sub>4</sub>H<sub>5</sub>NO<sub>7</sub>',
    '',
    '',
    'TXWHLSUKLWEERR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBZFUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBZFUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBZFUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ACCOMEPAN',
    'C<sub>5</sub>H<sub>5</sub>NO<sub>8</sub>',
    '',
    '',
    'ZQOVYYMCAFZVPL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACCOMEPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACCOMEPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACCOMEPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ACETC2PAN',
    'C<sub>5</sub>H<sub>7</sub>NO<sub>7</sub>',
    '',
    '',
    'VMVPPLVFXDAZML-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACETC2PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACETC2PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACETC2PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:COO2C4PAN',
    'C<sub>5</sub>H<sub>7</sub>NO<sub>7</sub>',
    '',
    '',
    'GBAXNZCSCJEGAE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:COO2C4PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:COO2C4PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:COO2C4PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPRACBNO3',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>5</sub>',
    '',
    '',
    'ZEVCPCUWRCOHCL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRACBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRACBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRACBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPRACBPAN',
    'C<sub>5</sub>H<sub>7</sub>NO<sub>7</sub>',
    '',
    '',
    'UJCZQTHKWBYHPW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRACBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRACBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRACBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPRACNO3',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>5</sub>',
    '',
    '',
    'JAQKAPGOMZJVBI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRACNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRACNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPRACNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MTBEAALNO3',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>5</sub>',
    '',
    '',
    'NIMOOIUOXYQIIM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBEAALNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBEAALNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBEAALNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MTBEAALPAN',
    'C<sub>5</sub>H<sub>7</sub>NO<sub>7</sub>',
    '',
    '',
    'WKTKTTPKCZOXAQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBEAALPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBEAALPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBEAALPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NPRACANO3',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>5</sub>',
    '',
    '',
    'FPQZKAXTSOKJRB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPRACANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPRACANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPRACANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NPRACBNO3',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>5</sub>',
    '',
    '',
    'HTKMYQNNJMTEJQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPRACBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPRACBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPRACBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NPRACCNO3',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>5</sub>',
    '',
    '',
    'PSJLJILPBUYXRJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPRACCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPRACCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPRACCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NPXYFUOOH',
    'C<sub>5</sub>H<sub>7</sub>NO<sub>7</sub>',
    '',
    '',
    'ARRSNVVNYKGUFK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPXYFUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPXYFUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPXYFUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NTLFUOOH',
    'C<sub>5</sub>H<sub>7</sub>NO<sub>7</sub>',
    '',
    '',
    'OAXQEILKHMZHNV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NTLFUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NTLFUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NTLFUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MCOOTBNO3',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>5</sub>',
    '',
    '',
    'BCWPDUXSEGSVPT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MCOOTBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MCOOTBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MCOOTBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NBUACANO3',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>5</sub>',
    '',
    '',
    'GNPRUWODPALWHJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBUACANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBUACANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBUACANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NBUACBNO3',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>5</sub>',
    '',
    '',
    'UFOXFUDLAIUTHC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBUACBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBUACBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBUACBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NBUACCNO3',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>5</sub>',
    '',
    '',
    'PYXJHVBEHHCABK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBUACCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBUACCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBUACCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NDMMALYOOH',
    'C<sub>6</sub>H<sub>7</sub>NO<sub>8</sub>',
    '',
    '',
    'RZSLUQVSVWAZFJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NDMMALYOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NDMMALYOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NDMMALYOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NEBFUOOH',
    'C<sub>6</sub>H<sub>9</sub>NO<sub>7</sub>',
    '',
    '',
    'CZSCMTWZZQSKMX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NEBFUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NEBFUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NEBFUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NMXYFUOOH',
    'C<sub>6</sub>H<sub>9</sub>NO<sub>7</sub>',
    '',
    '',
    'URYSYTGABCBDCM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NMXYFUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NMXYFUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NMXYFUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NOXYFUOOH',
    'C<sub>6</sub>H<sub>9</sub>NO<sub>7</sub>',
    '',
    '',
    'CPPAIMSHWPDUBG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOXYFUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOXYFUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOXYFUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NTMB1FUOOH',
    'C<sub>6</sub>H<sub>9</sub>NO<sub>7</sub>',
    '',
    '',
    'WRMOSOIHGVCRMO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NTMB1FUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NTMB1FUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NTMB1FUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PRCOOMPAN',
    'C<sub>6</sub>H<sub>9</sub>NO<sub>7</sub>',
    '',
    '',
    'NSDDFRROKVQLRJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRCOOMPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRCOOMPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PRCOOMPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:SBUACANO3',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>5</sub>',
    '',
    '',
    'FWAMAOJLVLFAOA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:SBUACANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:SBUACANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:SBUACANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:SBUACBNO3',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>5</sub>',
    '',
    '',
    'FVMFJLQQOIKLHP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:SBUACBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:SBUACBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:SBUACBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TBUACPAN',
    'C<sub>6</sub>H<sub>9</sub>NO<sub>7</sub>',
    '',
    '',
    'WTCUHXTZKDYOTB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TBUACPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TBUACPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TBUACPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NIPBFUOOH',
    'C<sub>7</sub>H<sub>11</sub>NO<sub>7</sub>',
    '',
    '',
    'MJSJHBOZYWKETN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NIPBFUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NIPBFUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NIPBFUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NMEBFUOOH',
    'C<sub>7</sub>H<sub>11</sub>NO<sub>7</sub>',
    '',
    '',
    'LKMBYBKEMVMSAU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NMEBFUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NMEBFUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NMEBFUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NPBFUOOH',
    'C<sub>7</sub>H<sub>11</sub>NO<sub>7</sub>',
    '',
    '',
    'DGKCEZHRNXTHAZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPBFUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPBFUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPBFUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NTMB2FUOOH',
    'C<sub>7</sub>H<sub>11</sub>NO<sub>7</sub>',
    '',
    '',
    'IRLXCLTZUJZGMJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NTMB2FUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NTMB2FUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NTMB2FUOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1013NO3',
    'C<sub>10</sub>H<sub>17</sub>NO<sub>5</sub>',
    '',
    '',
    'TWKDJCLTDHUPBZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1013NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1013NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1013NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1013PAN',
    'C<sub>11</sub>H<sub>17</sub>NO<sub>7</sub>',
    '',
    '',
    'QVQKWVAIHQGLJY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1013PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1013PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1013PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C1014NO3',
    'C<sub>10</sub>H<sub>17</sub>NO<sub>6</sub>',
    '',
    '',
    'OQZDTLQTCPZSBL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1014NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1014NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C1014NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C152NO3',
    'C<sub>15</sub>H<sub>25</sub>NO<sub>7</sub>',
    '',
    '',
    'VUWXYQDBWQFZDF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C152NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C152NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C152NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NBZFUONE',
    'C<sub>4</sub>H<sub>3</sub>NO<sub>6</sub>',
    '',
    '',
    'LXADUFLCRLLGHU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBZFUONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBZFUONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NBZFUONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C23O3CPAN',
    'C<sub>5</sub>H<sub>5</sub>NO<sub>8</sub>',
    '',
    '',
    'BCRDXKGRUUAZSU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23O3CPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23O3CPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23O3CPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ACBUONANO3',
    'C<sub>6</sub>H<sub>9</sub>NO<sub>6</sub>',
    '',
    '',
    'PDSBHIWVTCGSAN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACBUONANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACBUONANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ACBUONANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C23O3MCPAN',
    'C<sub>6</sub>H<sub>7</sub>NO<sub>8</sub>',
    '',
    '',
    'MJYWDTPJLIMPPV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23O3MCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23O3MCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23O3MCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NEBFUONE',
    'C<sub>6</sub>H<sub>7</sub>NO<sub>6</sub>',
    '',
    '',
    'LZGWKDALCOZNIJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NEBFUONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NEBFUONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NEBFUONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C23O3ECPAN',
    'C<sub>7</sub>H<sub>9</sub>NO<sub>8</sub>',
    '',
    '',
    'SOMJWLUSPZTMJM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23O3ECPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23O3ECPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C23O3ECPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NIPBFUONE',
    'C<sub>7</sub>H<sub>9</sub>NO<sub>6</sub>',
    '',
    '',
    'OEYHEYBMUYSQHE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NIPBFUONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NIPBFUONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NIPBFUONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NPBFUONE',
    'C<sub>7</sub>H<sub>9</sub>NO<sub>6</sub>',
    '',
    '',
    'WTNUMEKWPLLNDJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPBFUONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPBFUONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPBFUONE'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CH3OCH2NO3',
    'C<sub>2</sub>H<sub>5</sub>NO<sub>4</sub>',
    '',
    '',
    'VHAYDBAVTGOZLW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3OCH2NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3OCH2NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3OCH2NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DMMANO3',
    'C<sub>3</sub>H<sub>7</sub>NO<sub>5</sub>',
    '',
    '',
    'ZKGVKOFAVUIIEY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMMANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMMANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMMANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DMMBNO3',
    'C<sub>3</sub>H<sub>7</sub>NO<sub>5</sub>',
    '',
    '',
    'ADJOFNYUECRONI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMMBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMMBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMMBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ETOMENO3',
    'C<sub>3</sub>H<sub>7</sub>NO<sub>3</sub>',
    '',
    '',
    'ZMUPMMOTQUHRHQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETOMENO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETOMENO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETOMENO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MEMOXYPAN',
    'C<sub>3</sub>H<sub>5</sub>NO<sub>6</sub>',
    '',
    '',
    'JBHGAGLULWBGCW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MEMOXYPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MEMOXYPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MEMOXYPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DIETETNO3',
    'C<sub>4</sub>H<sub>9</sub>NO<sub>4</sub>',
    '',
    '',
    'CAMRTYJYAQGENN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DIETETNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DIETETNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DIETETNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ETOC2NO3',
    'C<sub>4</sub>H<sub>9</sub>NO<sub>4</sub>',
    '',
    '',
    'GDNQXPDYGNUKII-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETOC2NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETOC2NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETOC2NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ETOMEPAN',
    'C<sub>4</sub>H<sub>7</sub>NO<sub>6</sub>',
    '',
    '',
    'CCYZAMBLJVQHMC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETOMEPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETOMEPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETOMEPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPROC21NO3',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>4</sub>',
    '',
    '',
    'YQGFTPNVRZNXAP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPROC21NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPROC21NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPROC21NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MTBEANO3',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>4</sub>',
    '',
    '',
    'NXHUJDLNRCHXIE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBEANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBEANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBEANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MTBEBNO3',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>4</sub>',
    '',
    '',
    'HWZCMFJGZXOLOM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBEBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBEBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBEBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MTBEBPAN',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>6</sub>',
    '',
    '',
    'PQCDPGWYIKXNFH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBEBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBEBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTBEBPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BOXMPAN',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>6</sub>',
    '',
    '',
    'CPESEOWHBGRFRT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXMPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXMPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXMPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DIIPRETNO3',
    'C<sub>6</sub>H<sub>13</sub>NO<sub>4</sub>',
    '',
    '',
    'RYKOUPKPIPKSCM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DIIPRETNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DIIPRETNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DIIPRETNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ETBEANO3',
    'C<sub>6</sub>H<sub>13</sub>NO<sub>4</sub>',
    '',
    '',
    'WGHLTNOFPVNDHK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETBEANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETBEANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETBEANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ETBEAPAN',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>6</sub>',
    '',
    '',
    'ZFJPSAIQYMAFAB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETBEAPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETBEAPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETBEAPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ETBEBNO3',
    'C<sub>6</sub>H<sub>13</sub>NO<sub>4</sub>',
    '',
    '',
    'BIDDBAQEKWTVIC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETBEBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETBEBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETBEBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ETBECNO3',
    'C<sub>6</sub>H<sub>13</sub>NO<sub>4</sub>',
    '',
    '',
    'MGOGEALWXAMIEO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETBECNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETBECNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETBECNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ETBECPAN',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>6</sub>',
    '',
    '',
    'JICVHVAZXJWJCM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETBECPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETBECPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ETBECPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPROMC2NO3',
    'C<sub>6</sub>H<sub>13</sub>NO<sub>4</sub>',
    '',
    '',
    'XJQWDDGHWZGMDK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPROMC2NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPROMC2NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPROMC2NO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPROMCPAN',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>6</sub>',
    '',
    '',
    'SFYHCJJQTXJNNN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPROMCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPROMCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPROMCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MO2EOLANO3',
    'C<sub>3</sub>H<sub>7</sub>NO<sub>5</sub>',
    '',
    '',
    'FJVLHDUAJQRZPG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MO2EOLANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MO2EOLANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MO2EOLANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MO2EOLBNO3',
    'C<sub>3</sub>H<sub>7</sub>NO<sub>5</sub>',
    '',
    '',
    'QPXHYMSZINTGRC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MO2EOLBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MO2EOLBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MO2EOLBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EOX2OLANO3',
    'C<sub>4</sub>H<sub>9</sub>NO<sub>5</sub>',
    '',
    '',
    'UVLBVBPSPHSYND-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EOX2OLANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EOX2OLANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EOX2OLANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EOX2OLBNO3',
    'C<sub>4</sub>H<sub>9</sub>NO<sub>5</sub>',
    '',
    '',
    'DLOZDRFLLIHYBD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EOX2OLBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EOX2OLBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EOX2OLBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:H2C3OCNO3',
    'C<sub>4</sub>H<sub>9</sub>NO<sub>5</sub>',
    '',
    '',
    'VJBSYBJCULHXOZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2C3OCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2C3OCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:H2C3OCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PR2OHMONO3',
    'C<sub>4</sub>H<sub>9</sub>NO<sub>5</sub>',
    '',
    '',
    'YOBYTHKQRGEURN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PR2OHMONO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PR2OHMONO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PR2OHMONO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IEAPAN',
    'C<sub>5</sub>H<sub>7</sub>NO<sub>7</sub>',
    '',
    '',
    'NFJKKZSQGXUZSI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IEAPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IEAPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IEAPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IECPAN',
    'C<sub>5</sub>H<sub>7</sub>NO<sub>7</sub>',
    '',
    '',
    'UMKIAKGFUATPHT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IECPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IECPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IECPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BOXEOHANO3',
    'C<sub>6</sub>H<sub>13</sub>NO<sub>5</sub>',
    '',
    '',
    'NBMGDPHUZJHVTA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXEOHANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXEOHANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXEOHANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BOXEOHBNO3',
    'C<sub>6</sub>H<sub>13</sub>NO<sub>5</sub>',
    '',
    '',
    'YIIBDLSBOAJITL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXEOHBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXEOHBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXEOHBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BOXPOLANO3',
    'C<sub>7</sub>H<sub>15</sub>NO<sub>5</sub>',
    '',
    '',
    'QDPFCROPCZKQGS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXPOLANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXPOLANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXPOLANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BOXPOLBNO3',
    'C<sub>7</sub>H<sub>15</sub>NO<sub>5</sub>',
    '',
    '',
    'UNWFJVCQCSAFHA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXPOLBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXPOLBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXPOLBNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BCSOZNO3',
    'C<sub>15</sub>H<sub>25</sub>NO<sub>7</sub>',
    '',
    '',
    'HGUJSQZJFHDFKY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCSOZNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCSOZNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BCSOZNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EPXDLPAN',
    'C<sub>4</sub>H<sub>3</sub>NO<sub>7</sub>',
    '',
    '',
    'VASNFLPKLUXZKF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXDLPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXDLPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXDLPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EPXMDLPAN',
    'C<sub>5</sub>H<sub>5</sub>NO<sub>7</sub>',
    '',
    '',
    'KZASOTCYMWAOFE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXMDLPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXMDLPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXMDLPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BZEMUCPAN',
    'C<sub>6</sub>H<sub>5</sub>NO<sub>7</sub>',
    '',
    '',
    'RFFCGVCNFANFMQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BZEMUCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BZEMUCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BZEMUCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EPXM2DLPAN',
    'C<sub>6</sub>H<sub>7</sub>NO<sub>7</sub>',
    '',
    '',
    'KYBHJMDXHJGYTK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXM2DLPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXM2DLPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXM2DLPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EPXMEDLPAN',
    'C<sub>7</sub>H<sub>9</sub>NO<sub>7</sub>',
    '',
    '',
    'XUUSESMFYTYXHU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXMEDLPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXMEDLPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXMEDLPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OXYMUCPAN',
    'C<sub>8</sub>H<sub>9</sub>NO<sub>7</sub>',
    '',
    '',
    'VIRSPYOLFRMIKR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYMUCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYMUCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYMUCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OETLMUCPAN',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>7</sub>',
    '',
    '',
    'PYAKBDFKVOPHPS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OETLMUCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OETLMUCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OETLMUCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BZEMUCNO3',
    'C<sub>6</sub>H<sub>7</sub>NO<sub>7</sub>',
    '',
    '',
    'UGJSRYKPNYMSMJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BZEMUCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BZEMUCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BZEMUCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OXYMUCNO3',
    'C<sub>8</sub>H<sub>11</sub>NO<sub>7</sub>',
    '',
    '',
    'PMXJWIAVDRSVOJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYMUCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYMUCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXYMUCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OETLMUCNO3',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>7</sub>',
    '',
    '',
    'KUQUSIKCNRTUGT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OETLMUCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OETLMUCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OETLMUCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EPXKTMPAN',
    'C<sub>6</sub>H<sub>7</sub>NO<sub>7</sub>',
    '',
    '',
    'DBXZZDVADSLSOS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXKTMPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXKTMPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXKTMPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EPXMKTPAN',
    'C<sub>6</sub>H<sub>7</sub>NO<sub>7</sub>',
    '',
    '',
    'UTKXQAWEMGMHOV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXMKTPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXMKTPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXMKTPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BOXPROANO3',
    'C<sub>7</sub>H<sub>13</sub>NO<sub>5</sub>',
    '',
    '',
    'FWQXAWHLSYKKGA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXPROANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXPROANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BOXPROANO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EPXEKTPAN',
    'C<sub>7</sub>H<sub>9</sub>NO<sub>7</sub>',
    '',
    '',
    'ZMAMXAXJQIDKIS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXEKTPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXEKTPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EPXEKTPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TLEMUCPAN',
    'C<sub>7</sub>H<sub>7</sub>NO<sub>7</sub>',
    '',
    '',
    'AUCFXVOKAUAJMN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TLEMUCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TLEMUCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TLEMUCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EBZMUCPAN',
    'C<sub>8</sub>H<sub>9</sub>NO<sub>7</sub>',
    '',
    '',
    'IJCUBYYAOSTAFY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBZMUCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBZMUCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBZMUCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MXYMUCPAN',
    'C<sub>8</sub>H<sub>9</sub>NO<sub>7</sub>',
    '',
    '',
    'FZEVZMXGRRYMCK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYMUCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYMUCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYMUCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PXYMUCPAN',
    'C<sub>8</sub>H<sub>9</sub>NO<sub>7</sub>',
    '',
    '',
    'JEHOQLADMHJYMP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYMUCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYMUCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYMUCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPBZMUCPAN',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>7</sub>',
    '',
    '',
    'JAYKUYZEOSXCLM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBZMUCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBZMUCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBZMUCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:METLMUCPAN',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>7</sub>',
    '',
    '',
    'ZBESLNAUTTYMKY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METLMUCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METLMUCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METLMUCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PBZMUCPAN',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>7</sub>',
    '',
    '',
    'BNKFVONIJIEPHK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBZMUCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBZMUCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBZMUCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PETLMUCPAN',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>7</sub>',
    '',
    '',
    'ZDDBRQJYUBFFIJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PETLMUCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PETLMUCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PETLMUCPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TM124MUPAN',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>7</sub>',
    '',
    '',
    'TXJRVENADFPPLH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124MUPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124MUPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124MUPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TM135MUPAN',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>7</sub>',
    '',
    '',
    'APWJKVMWYCHHEO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM135MUPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM135MUPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM135MUPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DMEBMUPAN',
    'C<sub>10</sub>H<sub>13</sub>NO<sub>7</sub>',
    '',
    '',
    'OJIPANRKTQADST-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMEBMUPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMEBMUPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMEBMUPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DETLMUPAN',
    'C<sub>11</sub>H<sub>15</sub>NO<sub>7</sub>',
    '',
    '',
    'WGGPAZKPQBFIGY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DETLMUPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DETLMUPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DETLMUPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TM123MUNO3',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>7</sub>',
    '',
    '',
    'CNKHLWZBBXJTJR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM123MUNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM123MUNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM123MUNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TLEMUCNO3',
    'C<sub>7</sub>H<sub>9</sub>NO<sub>7</sub>',
    '',
    '',
    'KLAQKLFQZHHGRD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TLEMUCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TLEMUCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TLEMUCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EBZMUCNO3',
    'C<sub>8</sub>H<sub>11</sub>NO<sub>7</sub>',
    '',
    '',
    'ZZJNOSBMORNYPY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBZMUCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBZMUCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBZMUCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MXYMUCNO3',
    'C<sub>8</sub>H<sub>11</sub>NO<sub>7</sub>',
    '',
    '',
    'YZJRXCREGHPQLR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYMUCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYMUCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXYMUCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PXYMUCNO3',
    'C<sub>8</sub>H<sub>11</sub>NO<sub>7</sub>',
    '',
    '',
    'GICKPQRZPMBHKH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYMUCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYMUCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXYMUCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPBZMUCNO3',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>7</sub>',
    '',
    '',
    'UHFJHZLCDDVXBJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBZMUCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBZMUCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBZMUCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:METLMUCNO3',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>7</sub>',
    '',
    '',
    'WWNOXWKNSLKIMY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METLMUCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METLMUCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:METLMUCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PBZMUCNO3',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>7</sub>',
    '',
    '',
    'QLDJRFHCOXXYTH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBZMUCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBZMUCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBZMUCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PETLMUCNO3',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>7</sub>',
    '',
    '',
    'PIVPLJYVWKBKLM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PETLMUCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PETLMUCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PETLMUCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TM124MUNO3',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>7</sub>',
    '',
    '',
    'NIRISDMZVMYRLC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124MUNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124MUNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124MUNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TM135MUNO3',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>7</sub>',
    '',
    '',
    'WYJKGTDXAIWZNI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM135MUNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM135MUNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM135MUNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DMEBMUNO3',
    'C<sub>10</sub>H<sub>15</sub>NO<sub>7</sub>',
    '',
    '',
    'KKQBKVQGVIRRAG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMEBMUNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMEBMUNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMEBMUNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DETLMUNO3',
    'C<sub>11</sub>H<sub>17</sub>NO<sub>7</sub>',
    '',
    '',
    'YPPYKYPDSBIFHG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DETLMUNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DETLMUNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DETLMUNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DMCNO3',
    'C<sub>3</sub>H<sub>5</sub>NO<sub>6</sub>',
    '',
    '',
    'XNSIPMZBSRCICM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMCNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MMFNO3',
    'C<sub>3</sub>H<sub>5</sub>NO<sub>6</sub>',
    '',
    '',
    'KROMLYNKDFILIM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MMFNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MMFNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MMFNO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ISOP1N5OOH',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>6</sub>',
    '',
    '',
    'LLNBZHMZWYQLAS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>7</sup>',
    '14000',
    'Q',
    (SELECT id from species WHERE iupac='ISOP1N5OOH'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'C520ONO2',
    'C<sub>5</sub>H<sub>9</sub>NO<sub>8</sub>',
    '',
    '',
    'ZSADVAXZKGJKSG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>9</sup>',
    '21000',
    'Q',
    (SELECT id from species WHERE iupac='C520ONO2'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ROO6R6ONO2',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>6</sub>',
    '',
    '',
    'CRECMHNOVVIMCR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>5</sup>',
    '12000',
    'Q',
    (SELECT id from species WHERE iupac='ROO6R6ONO2'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'C624ONO2',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>7</sub>',
    '',
    '',
    'XYBUKFJLXVIRLY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>10</sup>',
    '19000',
    'Q',
    (SELECT id from species WHERE iupac='C624ONO2'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ROO6R5ONO2',
    'C<sub>7</sub>H<sub>11</sub>NO<sub>7</sub>',
    '',
    '',
    'LNWOWXJMUJHMJJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>5</sup>',
    '15000',
    'Q',
    (SELECT id from species WHERE iupac='ROO6R5ONO2'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ROO6R1ONO2',
    'C<sub>10</sub>H<sub>17</sub>NO<sub>6</sub>',
    '',
    '',
    'JOFCABYMPNXMIS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '15000',
    'Q',
    (SELECT id from species WHERE iupac='ROO6R1ONO2'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'LIMAB15ONO2OOH',
    'C<sub>10</sub>H<sub>19</sub>NO<sub>7</sub>',
    '',
    '',
    'JBKULLYZCMWERK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitrates (RONO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>9</sup>',
    '19000',
    'Q',
    (SELECT id from species WHERE iupac='LIMAB15ONO2OOH'),
    (SELECT id from literature WHERE bibtexkey='3765'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3765-GROMHE'));
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Nitriles with oxygen (C, H, O, N)',
    (SELECT id from categories WHERE catname='Organic species with nitrogen (N)'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'isocyanic acid',
    'HNCO',
    '',
    '75-13-8',
    'OWIKHYCFFJSOEH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitriles with oxygen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '4700',
    'M',
    (SELECT id from species WHERE iupac='isocyanic acid'),
    (SELECT id from literature WHERE bibtexkey='3525'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3525',
    '', 'The value at T<sup>&ominus;</sup> is the intrinsic Henry''s law constant, but the temperature dependence refers to the effective Henry''s law constant at pH = 3.0.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '4100',
    'M',
    (SELECT id from species WHERE iupac='isocyanic acid'),
    (SELECT id from literature WHERE bibtexkey='3411'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3411',
    '', 'The value at T<sup>&ominus;</sup> is the intrinsic Henry''s law constant, but the temperature dependence refers to the effective Henry''s law constant at pH = 3.08.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3411'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='isocyanic acid'),
    (SELECT id from literature WHERE bibtexkey='2805'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='isocyanic acid'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3500-75-13-8',
    '3500,3411', 'Burkholder et&nbsp;al. (2019) refer to Borduas et&nbsp;al. (2016), but the quoted temperature dependence cannot be found there.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3500-75-13-8'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl isocyanate',
    'CH<sub>3</sub>NCO',
    '',
    '624-83-9',
    'HAMGRBXTJNITHG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitriles with oxygen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methyl isocyanate'),
    (SELECT id from literature WHERE bibtexkey='3525'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hydroxyacetonitrile',
    'C<sub>2</sub>H<sub>3</sub>NO',
    'glycolonitrile',
    '107-16-4',
    'LTYRAPJYLUPLCI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitriles with oxygen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydroxyacetonitrile'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-hydroxypropanenitrile',
    'C<sub>3</sub>H<sub>5</sub>NO',
    '',
    '78-97-7',
    'WOFDVDFSGLBFAC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitriles with oxygen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxypropanenitrile'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-hydroxypropanenitrile',
    'C<sub>3</sub>H<sub>5</sub>NO',
    'ethylene cyanohydrin',
    '109-78-4',
    'WSGYTJNNHPZFKR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitriles with oxygen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-hydroxypropanenitrile'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-hydroxypropanenitrile'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hydroxypropanenitrile'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl cyanoacetate',
    'C<sub>4</sub>H<sub>5</sub>NO<sub>2</sub>',
    '',
    '105-34-0',
    'ANGDWNBGPBMQHW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitriles with oxygen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methyl cyanoacetate'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cyanoethanoic acid, ethyl ester',
    'C<sub>5</sub>H<sub>7</sub>NO<sub>2</sub>',
    'ethyl cyanoacetate',
    '105-56-6',
    'ZIUSEGSNTOUIPT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitriles with oxygen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cyanoethanoic acid, ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cyanoethanoic acid, ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyanoethanoic acid, ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyanoethanoic acid, ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyanoethanoic acid, ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyanoethanoic acid, ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cyanoethanoic acid, ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-hydroxybenzoic acid nitrile',
    'C<sub>7</sub>H<sub>5</sub>NO',
    '2-cyanophenol',
    '611-20-1',
    'CHZCERSEMVWNHL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitriles with oxygen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxybenzoic acid nitrile'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-hydroxybenzoic acid nitrile',
    'C<sub>7</sub>H<sub>5</sub>NO',
    '3-cyanophenol',
    '873-62-1',
    'SGHBRHKBCLLVCI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitriles with oxygen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hydroxybenzoic acid nitrile'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hydroxybenzoic acid nitrile'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hydroxybenzoic acid nitrile'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hydroxybenzoic acid nitrile'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-hydroxybenzoic acid nitrile'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-hydroxybenzoic acid nitrile',
    'C<sub>7</sub>H<sub>5</sub>NO',
    '4-cyanophenol',
    '767-00-0',
    'CVNOWLNNPYYEOH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitriles with oxygen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-hydroxybenzoic acid nitrile'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-hydroxybenzoic acid nitrile'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-hydroxybenzoic acid nitrile'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-hydroxybenzoic acid nitrile'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phenyl isocyanate',
    'C<sub>7</sub>H<sub>5</sub>NO',
    '',
    '103-71-9',
    'DGTNSSLYPYDJGL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitriles with oxygen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='phenyl isocyanate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenyl isocyanate'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='phenyl isocyanate'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1'',1"-nitrilotris-2-propanol',
    'C<sub>9</sub>H<sub>21</sub>NO<sub>3</sub>',
    'triisopropanolamine',
    '122-20-3',
    'SLINHMUFWFWBMU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitriles with oxygen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1'',1"-nitrilotris-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cyometrinil',
    'C<sub>10</sub>H<sub>7</sub>N<sub>3</sub>O',
    '',
    '78370-21-5',
    'PYKLUAIDKVVEOS-JLHYYAGUSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitriles with oxygen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cyometrinil'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fenpropathrin',
    'C<sub>22</sub>H<sub>23</sub>NO<sub>3</sub>',
    '',
    '39515-41-8',
    'XQUXKZZNEFRCAW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitriles with oxygen (C, H, O, N)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='fenpropathrin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='fenpropathrin'),
    (SELECT id from literature WHERE bibtexkey='2973'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Nitro compounds (RNO<sub>2</sub>)',
    (SELECT id from categories WHERE catname='Organic species with nitrogen (N)'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nitromethane',
    'CH<sub>3</sub>NO<sub>2</sub>',
    '',
    '75-52-5',
    'LYGJENNIWJXYER-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '4000',
    'L',
    (SELECT id from species WHERE iupac='nitromethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '4000',
    'L',
    (SELECT id from species WHERE iupac='nitromethane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;1</sup>',
    '3900',
    'L',
    (SELECT id from species WHERE iupac='nitromethane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '4000',
    'L',
    (SELECT id from species WHERE iupac='nitromethane'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '4000',
    'L',
    (SELECT id from species WHERE iupac='nitromethane'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '4000',
    'M',
    (SELECT id from species WHERE iupac='nitromethane'),
    (SELECT id from literature WHERE bibtexkey='1996'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='nitromethane'),
    (SELECT id from literature WHERE bibtexkey='2449'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='nitromethane'),
    (SELECT id from literature WHERE bibtexkey='792'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='nitromethane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='nitromethane'),
    (SELECT id from literature WHERE bibtexkey='gaffney84'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from715'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nitromethane'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nitromethane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nitromethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nitromethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nitromethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nitromethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nitromethane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nitromethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nitromethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3700',
    'Q',
    (SELECT id from species WHERE iupac='nitromethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nitromethane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nitromethane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nitromethane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nitromethane'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='nitromethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3500',
    '?',
    (SELECT id from species WHERE iupac='nitromethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='nitromethane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='nitromethane'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='nitromethane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='nitromethane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nitromethane-13C',
    'CH<sub>3</sub>NO<sub>2</sub>',
    '',
    '32480-00-5',
    'LYGJENNIWJXYER-OUBTZVSYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;1</sup>',
    '5000',
    'M',
    (SELECT id from species WHERE iupac='nitromethane-13C'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nitroethane',
    'C<sub>2</sub>H<sub>5</sub>NO<sub>2</sub>',
    '',
    '79-24-3',
    'MCSAJNNLRCFZED-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '4400',
    'L',
    (SELECT id from species WHERE iupac='nitroethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '4400',
    'L',
    (SELECT id from species WHERE iupac='nitroethane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '4700',
    'L',
    (SELECT id from species WHERE iupac='nitroethane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '4400',
    'L',
    (SELECT id from species WHERE iupac='nitroethane'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '4400',
    'L',
    (SELECT id from species WHERE iupac='nitroethane'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '4400',
    'M',
    (SELECT id from species WHERE iupac='nitroethane'),
    (SELECT id from literature WHERE bibtexkey='1996'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='nitroethane'),
    (SELECT id from literature WHERE bibtexkey='729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at303K'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '729-nitroethane',
    '729', 'The values for nitroethane in Tables&nbsp;VI and VIII of Friant and Suffet (1979) differ by a factor of 10. Apparently, the value in Table&nbsp;VIII is wrong.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='729-nitroethane'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='nitroethane'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='nitroethane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='nitroethane'),
    (SELECT id from literature WHERE bibtexkey='gaffney84'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from715'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nitroethane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nitroethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nitroethane'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nitroethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nitroethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nitroethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nitroethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nitroethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4100',
    'Q',
    (SELECT id from species WHERE iupac='nitroethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nitroethane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nitroethane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nitroethane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nitroethane'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nitroethane'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='nitroethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4200',
    '?',
    (SELECT id from species WHERE iupac='nitroethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='nitroethane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='nitroethane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-nitropropane',
    'C<sub>3</sub>H<sub>7</sub>NO<sub>2</sub>',
    '',
    '108-03-2',
    'JSZOAYXJRCEYSX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '4700',
    'L',
    (SELECT id from species WHERE iupac='1-nitropropane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '4700',
    'L',
    (SELECT id from species WHERE iupac='1-nitropropane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '5100',
    'L',
    (SELECT id from species WHERE iupac='1-nitropropane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '4700',
    'L',
    (SELECT id from species WHERE iupac='1-nitropropane'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '4700',
    'L',
    (SELECT id from species WHERE iupac='1-nitropropane'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '4700',
    'M',
    (SELECT id from species WHERE iupac='1-nitropropane'),
    (SELECT id from literature WHERE bibtexkey='1996'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-nitropropane'),
    (SELECT id from literature WHERE bibtexkey='3646'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-nitropropane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitropropane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitropropane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitropropane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitropropane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitropropane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitropropane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitropropane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4400',
    'Q',
    (SELECT id from species WHERE iupac='1-nitropropane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitropropane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitropropane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitropropane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitropropane'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitropropane'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-nitropropane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4400',
    '?',
    (SELECT id from species WHERE iupac='1-nitropropane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-nitropropane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-nitropropane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-nitropropane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-nitropropane',
    'CH<sub>3</sub>CH(NO<sub>2</sub>)CH<sub>3</sub>',
    '',
    '79-46-9',
    'FGLBSLMDCBOPQK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;2</sup>',
    '4500',
    'L',
    (SELECT id from species WHERE iupac='2-nitropropane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;2</sup>',
    '4500',
    'L',
    (SELECT id from species WHERE iupac='2-nitropropane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;2</sup>',
    '4800',
    'L',
    (SELECT id from species WHERE iupac='2-nitropropane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;2</sup>',
    '4500',
    'L',
    (SELECT id from species WHERE iupac='2-nitropropane'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;2</sup>',
    '4500',
    'L',
    (SELECT id from species WHERE iupac='2-nitropropane'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;2</sup>',
    '4500',
    'M',
    (SELECT id from species WHERE iupac='2-nitropropane'),
    (SELECT id from literature WHERE bibtexkey='1996'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-nitropropane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-nitropropane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-nitropropane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitropropane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitropropane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitropropane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitropropane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitropropane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitropropane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4400',
    'Q',
    (SELECT id from species WHERE iupac='2-nitropropane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitropropane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitropropane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-Test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitropropane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitropropane'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitropropane'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4400',
    '?',
    (SELECT id from species WHERE iupac='2-nitropropane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-nitropropane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-nitropropane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-nitropropane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-nitrobutane',
    'C<sub>4</sub>H<sub>9</sub>NO<sub>2</sub>',
    '',
    '627-05-4',
    'NALZTFARIYUCBY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-nitrobutane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-nitrobutane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitrobutane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitrobutane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitrobutane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitrobutane'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-nitrobutane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>tert</i>-butylnitrite',
    'C<sub>4</sub>H<sub>9</sub>ONO',
    '',
    '540-80-7',
    'IOGXOCVLYRDXLW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>tert</i>-butylnitrite'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-nitropentane',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>2</sub>',
    '',
    '628-05-7',
    'BVALZCVRLDMXOQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-nitropentane'),
    (SELECT id from literature WHERE bibtexkey='2388'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitropentane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitropentane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitropentane'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-nitropentane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tris(hydroxymethyl)ethane trinitrate',
    'C<sub>5</sub>H<sub>9</sub>N<sub>3</sub>O<sub>9</sub>',
    '',
    '3032-55-1',
    'IPPYBNCEPZCLNI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tris(hydroxymethyl)ethane trinitrate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tris(hydroxymethyl)ethane trinitrate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tris(hydroxymethyl)ethane trinitrate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tris(hydroxymethyl)ethane trinitrate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-nitrohexane',
    'C<sub>6</sub>H<sub>13</sub>NO<sub>2</sub>',
    '',
    '646-14-0',
    'FEYJIFXFOHFGCC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitrohexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nitrocyclohexane',
    'C<sub>6</sub>H<sub>11</sub>NO<sub>2</sub>',
    '',
    '1122-60-7',
    'NJNQUTDUIPVROZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nitrocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-nitroethanol',
    'C<sub>2</sub>H<sub>5</sub>NO<sub>3</sub>',
    '',
    '625-48-9',
    'KIPMDPDAFINLIV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitroethanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitroethanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitroethanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitroethanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-nitro-2-propanol',
    'C<sub>3</sub>H<sub>7</sub>NO<sub>3</sub>',
    '',
    '3156-73-8',
    'PFNCKQIYLAVYJF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitro-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitro-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitro-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitro-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-nitro-1-propanol',
    'C<sub>3</sub>H<sub>7</sub>NO<sub>3</sub>',
    '',
    '2902-96-7',
    'PCNWBUOSTLGPMI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitro-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitro-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitro-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitro-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-nitro-2-butanol',
    'C<sub>4</sub>H<sub>9</sub>NO<sub>3</sub>',
    '',
    '3156-74-9',
    'FMEFHKJRIGHSLB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitro-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-nitro-1-butanol',
    'C<sub>4</sub>H<sub>9</sub>NO<sub>3</sub>',
    '',
    '609-31-4',
    'MHIHRIPETCJEMQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitro-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitro-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitro-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitro-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-nitro-2-butanol',
    'C<sub>4</sub>H<sub>9</sub>NO<sub>3</sub>',
    '',
    '6270-16-2',
    'OJVOGABFNZDOOZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-nitro-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-nitro-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-nitro-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-nitro-2-butanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nitroguanidine',
    'CH<sub>4</sub>N<sub>4</sub>O<sub>2</sub>',
    '',
    '556-88-7',
    'IDCPFAYURAQKDZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>10</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='nitroguanidine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tetranitromethane',
    'CN<sub>4</sub>O<sub>8</sub>',
    '',
    '509-14-8',
    'NYTOUQBROMCLBJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tetranitromethane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-methyl-N''-nitro-N-nitrosoguanidine',
    'C<sub>2</sub>H<sub>5</sub>N<sub>5</sub>O<sub>3</sub>',
    '',
    '70-25-7',
    'VZUNGTLZRAYYDE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-methyl-N''-nitro-N-nitrosoguanidine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-(hydroxymethyl)-2-nitro-1,3-propanediol',
    'C<sub>4</sub>H<sub>9</sub>NO<sub>5</sub>',
    '',
    '126-11-4',
    'OLQJQHSAWMFDJE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(hydroxymethyl)-2-nitro-1,3-propanediol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NC4DCO2H',
    'C<sub>4</sub>H<sub>3</sub>NO<sub>5</sub>',
    '',
    '',
    'ODFCIXRXNCCVGH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC4DCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC4DCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC4DCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NC4MDCO2H',
    'C<sub>5</sub>H<sub>5</sub>NO<sub>5</sub>',
    '',
    '',
    'LXEJKNKBIPISQO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC4MDCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC4MDCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC4MDCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NC4EDCO2H',
    'C<sub>6</sub>H<sub>7</sub>NO<sub>5</sub>',
    '',
    '',
    'GVSLZEQKUBDLJE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC4EDCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC4EDCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC4EDCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DNPHENOOH',
    'C<sub>6</sub>H<sub>6</sub>N<sub>2</sub>O<sub>10</sub>',
    '',
    '',
    'AKJGOKAIBHUAAE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>16</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNPHENOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNPHENOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNPHENOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NCATECOOH',
    'C<sub>6</sub>H<sub>7</sub>NO<sub>9</sub>',
    '',
    '',
    'UERHMILVGXASDJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>17</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NCATECOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NCATECOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NCATECOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NC5MDCO2H',
    'C<sub>6</sub>H<sub>7</sub>NO<sub>5</sub>',
    '',
    '',
    'VRGZGZRSZACGSZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC5MDCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC5MDCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC5MDCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NC4IPDCO2H',
    'C<sub>7</sub>H<sub>9</sub>NO<sub>5</sub>',
    '',
    '',
    'VOBLVGUNJWYRHD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC4IPDCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC4IPDCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC4IPDCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NC4PDCO2H',
    'C<sub>7</sub>H<sub>9</sub>NO<sub>5</sub>',
    '',
    '',
    'MSTRQTMGALLSFO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC4PDCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC4PDCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NC4PDCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DNCRESOOH',
    'C<sub>7</sub>H<sub>8</sub>N<sub>2</sub>O<sub>10</sub>',
    '',
    '',
    'FHWDGQSKNURQKZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>16</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNCRESOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNCRESOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNCRESOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MNCATECOOH',
    'C<sub>7</sub>H<sub>9</sub>NO<sub>9</sub>',
    '',
    '',
    'OCHAAZKMUDWIOE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>17</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MNCATECOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MNCATECOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MNCATECOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TL4ONO2OOH',
    'C<sub>7</sub>H<sub>9</sub>NO<sub>8</sub>',
    '',
    '',
    'MEXRHSIIQRTIBR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>14</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TL4ONO2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TL4ONO2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TL4ONO2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DNEBNZLOOH',
    'C<sub>8</sub>H<sub>10</sub>N<sub>2</sub>O<sub>10</sub>',
    '',
    '',
    'FNCRENCSRXRIPJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>16</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNEBNZLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNEBNZLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNEBNZLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DNMXYOLOOH',
    'C<sub>8</sub>H<sub>10</sub>N<sub>2</sub>O<sub>10</sub>',
    '',
    '',
    'KSAVSEUSLRIGAB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>16</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNMXYOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNMXYOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNMXYOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DNOXYOLOOH',
    'C<sub>8</sub>H<sub>10</sub>N<sub>2</sub>O<sub>10</sub>',
    '',
    '',
    'PBZRLTNSSYSOGL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>16</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNOXYOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNOXYOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNOXYOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DNPXYOLOOH',
    'C<sub>8</sub>H<sub>10</sub>N<sub>2</sub>O<sub>10</sub>',
    '',
    '',
    'AYHFAKIJCOHXBG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>16</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNPXYOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNPXYOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNPXYOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ENCATECOOH',
    'C<sub>8</sub>H<sub>11</sub>NO<sub>9</sub>',
    '',
    '',
    'QJBJEZDKVLRDGQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>17</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ENCATECOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ENCATECOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ENCATECOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MXNCATCOOH',
    'C<sub>8</sub>H<sub>11</sub>NO<sub>9</sub>',
    '',
    '',
    'QYJOURKZCRGVGB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>17</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXNCATCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXNCATCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXNCATCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MXOHNO2OOH',
    'C<sub>8</sub>H<sub>11</sub>NO<sub>8</sub>',
    '',
    '',
    'RRWTXIWIABDEOZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>14</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXOHNO2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXOHNO2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXOHNO2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OXNCATCOOH',
    'C<sub>8</sub>H<sub>11</sub>NO<sub>9</sub>',
    '',
    '',
    'GWPIPVPJLOZVKC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>17</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXNCATCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXNCATCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXNCATCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PXNCATCOOH',
    'C<sub>8</sub>H<sub>11</sub>NO<sub>9</sub>',
    '',
    '',
    'RMUFWTRDQQMPCD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>17</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXNCATCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXNCATCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXNCATCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TM124NOOH',
    'C<sub>8</sub>H<sub>11</sub>NO<sub>8</sub>',
    '',
    '',
    'LGMZUZOZZXWRQX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>14</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124NOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124NOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124NOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DNIPBZLOOH',
    'C<sub>9</sub>H<sub>12</sub>N<sub>2</sub>O<sub>10</sub>',
    '',
    '',
    'YKBFACRSJWRBHR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>16</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNIPBZLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNIPBZLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNIPBZLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DNMETOLOOH',
    'C<sub>9</sub>H<sub>12</sub>N<sub>2</sub>O<sub>10</sub>',
    '',
    '',
    'LAMZNFDUTXWEFA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>16</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNMETOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNMETOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNMETOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DNOETOLOOH',
    'C<sub>9</sub>H<sub>12</sub>N<sub>2</sub>O<sub>10</sub>',
    '',
    '',
    'KMVIJWGCTFHDMC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>16</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNOETOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNOETOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNOETOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DNPBNZLOOH',
    'C<sub>9</sub>H<sub>12</sub>N<sub>2</sub>O<sub>10</sub>',
    '',
    '',
    'YOHJWFCUZUQBMA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>16</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNPBNZLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNPBNZLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNPBNZLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DNPETOLOOH',
    'C<sub>9</sub>H<sub>12</sub>N<sub>2</sub>O<sub>10</sub>',
    '',
    '',
    'IOZSITWJVFMIBH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>16</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNPETOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNPETOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNPETOLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DNT123LOOH',
    'C<sub>9</sub>H<sub>12</sub>N<sub>2</sub>O<sub>10</sub>',
    '',
    '',
    'GBPJMJLXQYJDMC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>16</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNT123LOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNT123LOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNT123LOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DNT124LOOH',
    'C<sub>9</sub>H<sub>12</sub>N<sub>2</sub>O<sub>10</sub>',
    '',
    '',
    'INCIWBVFUFSSNB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>16</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNT124LOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNT124LOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNT124LOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EMPONO2OOH',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>8</sub>',
    '',
    '',
    'FZXCIHOWKZKJRK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>14</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EMPONO2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EMPONO2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EMPONO2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPNCATCOOH',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>9</sub>',
    '',
    '',
    'NYRKVILWQFQUNU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>17</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPNCATCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPNCATCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPNCATCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MTNCATCOOH',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>9</sub>',
    '',
    '',
    'MCLPDHQAEZEULP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>17</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTNCATCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTNCATCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTNCATCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OTNCATCOOH',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>9</sub>',
    '',
    '',
    'MVMRAYXEOTUUSG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>17</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OTNCATCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OTNCATCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OTNCATCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PNCATECOOH',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>9</sub>',
    '',
    '',
    'AWPUGBPLGLTYEJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>17</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PNCATECOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PNCATECOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PNCATECOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PTNCATCOOH',
    'C<sub>9</sub>H<sub>13</sub>NO<sub>9</sub>',
    '',
    '',
    'IJEUJFHQTRRKRP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>17</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PTNCATCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PTNCATCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PTNCATCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nitrobenzene',
    'C<sub>6</sub>H<sub>5</sub>NO<sub>2</sub>',
    '',
    '98-95-3',
    'LQNUZADURLCDLV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '6100',
    'L',
    (SELECT id from species WHERE iupac='nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;1</sup>',
    '7500',
    'M',
    (SELECT id from species WHERE iupac='nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2921'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2921H1'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '11000',
    'M',
    (SELECT id from species WHERE iupac='nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='1107'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '1107-98-95-3-consicheck',
    '1107', 'The data listed in Tables&nbsp;2 and 3 of Dewulf et&nbsp;al. (1999) are inconsistent, with 27&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1107-98-95-3-consicheck'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'M',
    (SELECT id from species WHERE iupac='nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2448'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;1</sup>',
    '6400',
    'V',
    (SELECT id from species WHERE iupac='nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2123'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2971'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '4500',
    'X',
    (SELECT id from species WHERE iupac='nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2165'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3083'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4600',
    'Q',
    (SELECT id from species WHERE iupac='nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5600',
    '?',
    (SELECT id from species WHERE iupac='nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nitrobenzene-d5',
    'C<sub>6</sub>D<sub>5</sub>NO<sub>2</sub>',
    '',
    '4165-60-0',
    'LQNUZADURLCDLV-RALIUCGRSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;1</sup>',
    '7500',
    'M',
    (SELECT id from species WHERE iupac='nitrobenzene-d5'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-nitrotoluene',
    'C<sub>6</sub>H<sub>4</sub>(NO<sub>2</sub>)CH<sub>3</sub>',
    '',
    '88-72-2',
    'PLAZTCDQAHEYBI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '5800',
    'L',
    (SELECT id from species WHERE iupac='2-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='2165'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;2</sup>',
    '2900',
    'X',
    (SELECT id from species WHERE iupac='2-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4900',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5900',
    '?',
    (SELECT id from species WHERE iupac='2-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-nitrotoluene',
    'C<sub>6</sub>H<sub>4</sub>(NO<sub>2</sub>)CH<sub>3</sub>',
    '',
    '99-08-1',
    'QZYHIOPPLUPUJF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '7000',
    'L',
    (SELECT id from species WHERE iupac='3-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'M',
    (SELECT id from species WHERE iupac='3-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'M',
    (SELECT id from species WHERE iupac='3-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='2457'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '3200',
    'X',
    (SELECT id from species WHERE iupac='3-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4900',
    'Q',
    (SELECT id from species WHERE iupac='3-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4900',
    '?',
    (SELECT id from species WHERE iupac='3-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at303K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-nitrotoluene',
    'C<sub>6</sub>H<sub>4</sub>(NO<sub>2</sub>)CH<sub>3</sub>',
    '',
    '99-99-0',
    'ZPTVNYMJQHSSEA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;1</sup>',
    '7100',
    'L',
    (SELECT id from species WHERE iupac='4-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'M',
    (SELECT id from species WHERE iupac='4-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '3100',
    'X',
    (SELECT id from species WHERE iupac='4-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4900',
    'Q',
    (SELECT id from species WHERE iupac='4-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3800',
    '?',
    (SELECT id from species WHERE iupac='4-nitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-dinitrobenzene',
    'C<sub>6</sub>H<sub>4</sub>N<sub>2</sub>O<sub>4</sub>',
    '',
    '528-29-0',
    'IZUKQUVSCNEFMJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3-dinitrobenzene',
    'C<sub>6</sub>H<sub>4</sub>N<sub>2</sub>O<sub>4</sub>',
    '',
    '99-65-0',
    'WDCYWAQPCXBPJA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,3-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,3-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2614_pc_problem'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2236'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,3-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4-dinitrobenzene',
    'C<sub>6</sub>H<sub>4</sub>N<sub>2</sub>O<sub>4</sub>',
    '',
    '100-25-4',
    'FYFDQJRXFWGIBS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3,5-trinitrobenzene',
    'C<sub>6</sub>H<sub>3</sub>N<sub>3</sub>O<sub>6</sub>',
    '',
    '99-35-4',
    'UATJOMSPNYCXIX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3,5-trinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,3,5-trinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-trinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,6-trinitrophenol',
    'C<sub>6</sub>H<sub>3</sub>N<sub>3</sub>O<sub>7</sub>',
    'picric acid',
    '88-89-1',
    'OXNIZHLAWKMVMX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,4,6-trinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-nitrobenzenamine',
    'C<sub>6</sub>H<sub>6</sub>N<sub>2</sub>O<sub>2</sub>',
    '2-nitroaniline',
    '88-74-4',
    'DPJCXCZTLWNFOH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>1</sup>',
    '6800',
    'L',
    (SELECT id from species WHERE iupac='2-nitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-nitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='2-nitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-nitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-nitrobenzenamine',
    'C<sub>6</sub>H<sub>6</sub>N<sub>2</sub>O<sub>2</sub>',
    '3-nitroaniline',
    '99-09-2',
    'XJCVRTZCHMZPBD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-nitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='3-nitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-nitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-nitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-nitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-nitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-nitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-nitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-nitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-nitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-nitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-3072'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-nitrobenzenamine',
    'C<sub>6</sub>H<sub>6</sub>N<sub>2</sub>O<sub>2</sub>',
    '4-nitroaniline',
    '100-01-6',
    'TYMLOMAKGOJONV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>3</sup>',
    '8200',
    'L',
    (SELECT id from species WHERE iupac='4-nitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='4-nitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='4-nitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-nitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-nitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dinitrobenzenamine',
    'C<sub>6</sub>H<sub>5</sub>N<sub>3</sub>O<sub>4</sub>',
    '',
    '97-02-9',
    'LXQOQPGNCGEELI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dinitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-642'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-6-nitroaniline',
    'C<sub>7</sub>H<sub>8</sub>N<sub>2</sub>O<sub>2</sub>',
    '',
    '570-24-1',
    'FCMRHMPITHLLLA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-6-nitroaniline'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-2,3-dinitrobenzene',
    'C<sub>7</sub>H<sub>6</sub>N<sub>2</sub>O<sub>4</sub>',
    '2,3-dinitrotoluene; 2,3-DNT',
    '602-01-7',
    'DYSXLQBUUOPLBB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-2,3-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-2,3-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-2,3-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-2,3-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-2,3-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-2,3-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-2,3-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-2,3-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-2,3-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-2,4-dinitrobenzene',
    'C<sub>7</sub>H<sub>6</sub>N<sub>2</sub>O<sub>4</sub>',
    '2,4-dinitrotoluene; 2,4-DNT',
    '121-14-2',
    'RMBFBMJGBANMMK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>1</sup>',
    '7900',
    'L',
    (SELECT id from species WHERE iupac='1-methyl-2,4-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-methyl-2,4-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-methyl-2,4-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-methyl-2,4-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2165'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-methyl-2,4-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-methyl-2,4-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2236'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '2900',
    'X',
    (SELECT id from species WHERE iupac='1-methyl-2,4-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'C',
    (SELECT id from species WHERE iupac='1-methyl-2,4-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1-methyl-2,4-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-2,4-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-2,4-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-2,4-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-2,4-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-2,4-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-2,4-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-2,4-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-2,4-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-2,4-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-methyl-2,4-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-1,4-dinitrobenzene',
    'C<sub>7</sub>H<sub>6</sub>N<sub>2</sub>O<sub>4</sub>',
    '2,5-dinitrotoluene; 2,5-DNT',
    '619-15-8',
    'KZBOXYKTSUUBTO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-1,4-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1,4-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1,4-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1,4-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1,4-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-1,3-dinitrobenzene',
    'C<sub>7</sub>H<sub>6</sub>N<sub>2</sub>O<sub>4</sub>',
    '2,6-dinitrotoluene; 2,6-DNT',
    '606-20-2',
    'XTRDKALNCIHHNI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8',
    '7600',
    'L',
    (SELECT id from species WHERE iupac='2-methyl-1,3-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-1,3-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-1,3-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-1,3-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-1,3-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'C',
    (SELECT id from species WHERE iupac='2-methyl-1,3-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='2-methyl-1,3-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1,3-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1,3-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1,3-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1,3-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1,3-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1,3-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-1,2-dinitrobenzene',
    'C<sub>7</sub>H<sub>6</sub>N<sub>2</sub>O<sub>4</sub>',
    '3,4-dinitrotoluene; 3,4-DNT',
    '610-39-9',
    'INYDMNPNDHRJQJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>1</sup>',
    '9600',
    'L',
    (SELECT id from species WHERE iupac='4-methyl-1,2-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1,2-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1,2-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1,2-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1,2-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-1,2-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-2,4,6-trinitrobenzene',
    'C<sub>7</sub>H<sub>5</sub>N<sub>3</sub>O<sub>6</sub>',
    '2,4,6-trinitrotoluene; TNT',
    '118-96-7',
    'SPSSULHKWOKEEL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>2</sup>',
    '7700',
    'L',
    (SELECT id from species WHERE iupac='1-methyl-2,4,6-trinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-methyl-2,4,6-trinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-methyl-2,4,6-trinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2165'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6200',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-2,4,6-trinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6400',
    '?',
    (SELECT id from species WHERE iupac='1-methyl-2,4,6-trinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,6-trinitro-1,3-dimethyl-5-<i>tert</i>-butylbenzene',
    'C<sub>12</sub>H<sub>15</sub>N<sub>3</sub>O<sub>6</sub>',
    'musk xylene',
    '81-15-2',
    'XMWRWTSZNLOZFN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,4,6-trinitro-1,3-dimethyl-5-<i>tert</i>-butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3014'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4,6-trinitro-1,3-dimethyl-5-<i>tert</i>-butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2388'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trinitro-1,3-dimethyl-5-<i>tert</i>-butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trinitro-1,3-dimethyl-5-<i>tert</i>-butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trinitro-1,3-dimethyl-5-<i>tert</i>-butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trinitro-1,3-dimethyl-5-<i>tert</i>-butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trinitro-1,3-dimethyl-5-<i>tert</i>-butylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-nitrophenol',
    'HOC<sub>6</sub>H<sub>4</sub>(NO<sub>2</sub>)',
    '',
    '88-75-5',
    'IQUPABOKLQSFBK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '5700',
    'M',
    (SELECT id from species WHERE iupac='2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2183'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;1</sup>',
    '6300',
    'M',
    (SELECT id from species WHERE iupac='2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='1513'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;1</sup>',
    '6300',
    'M',
    (SELECT id from species WHERE iupac='2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='1514'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='1155'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2966'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='941'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='1068'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at281K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;1</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;1</sup>',
    '4600',
    'X',
    (SELECT id from species WHERE iupac='2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'C',
    (SELECT id from species WHERE iupac='2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4400',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6300',
    '?',
    (SELECT id from species WHERE iupac='2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-nitrophenol',
    'HOC<sub>6</sub>H<sub>4</sub>(NO<sub>2</sub>)',
    '',
    '554-84-7',
    'RTZZCYNQPHTPPL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2183'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at308K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='gaffney84'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from715'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-nitrophenol',
    'HOC<sub>6</sub>H<sub>4</sub>(NO<sub>2</sub>)',
    '',
    '100-02-7',
    'BTJIUGUIPKRLHP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='4-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='4-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2183'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at308K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='4-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='1155'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2966'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='941'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2971'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>4</sup>',
    '9100',
    'T',
    (SELECT id from species WHERE iupac='4-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='724'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='assumedMatm'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8',
    '6000',
    'X',
    (SELECT id from species WHERE iupac='4-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'C',
    (SELECT id from species WHERE iupac='4-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-nitroanisole',
    'C<sub>7</sub>H<sub>7</sub>NO<sub>3</sub>',
    '',
    '100-17-4',
    'BNUHAJGCKIQFGE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-nitroanisole'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-2-nitrophenol',
    'C<sub>7</sub>H<sub>7</sub>NO<sub>3</sub>',
    '',
    '4920-77-8',
    'QIORDSKCCHRSSD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2',
    '',
    'M',
    (SELECT id from species WHERE iupac='3-methyl-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='1155'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-methyl-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='941'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4700',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4200',
    '?',
    (SELECT id from species WHERE iupac='3-methyl-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-2-nitrophenol',
    'C<sub>7</sub>H<sub>7</sub>NO<sub>3</sub>',
    '',
    '119-33-5',
    'SYDNSSSQVSOXTN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='4-methyl-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='1155'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-methyl-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='941'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4700',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6800',
    '?',
    (SELECT id from species WHERE iupac='4-methyl-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-methyl-2-nitrophenol',
    'C<sub>7</sub>H<sub>7</sub>NO<sub>3</sub>',
    '',
    '700-38-9',
    'NQXUSSVLFOBRSE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='5-methyl-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='1155'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='5-methyl-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='941'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4700',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5600',
    '?',
    (SELECT id from species WHERE iupac='5-methyl-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '6-methyl-2-nitrophenol',
    'C<sub>7</sub>H<sub>7</sub>NO<sub>3</sub>',
    '',
    '13073-29-5',
    'AQDKZPFDOWHRDZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='6-methyl-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='1155'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-methyl-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-methyl-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-methyl-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-methyl-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-methyl-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-methyl-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4700',
    'Q',
    (SELECT id from species WHERE iupac='6-methyl-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5200',
    '?',
    (SELECT id from species WHERE iupac='6-methyl-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-4-nitrophenol',
    'C<sub>7</sub>H<sub>7</sub>NO<sub>3</sub>',
    '',
    '2581-34-2',
    'PIIZYNQECPTVEO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3-methyl-4-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='1155'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-4-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-4-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-4-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-4-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methoxy-2-nitrophenol',
    'C<sub>7</sub>H<sub>7</sub>NO<sub>4</sub>',
    '',
    '1568-70-3',
    'YBUGOACXDPDUIR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3',
    '',
    'M',
    (SELECT id from species WHERE iupac='4-methoxy-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='1155'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-methoxy-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='941'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methoxy-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methoxy-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methoxy-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methoxy-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4900',
    'Q',
    (SELECT id from species WHERE iupac='4-methoxy-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6600',
    '?',
    (SELECT id from species WHERE iupac='4-methoxy-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-amino-2,6-dinitrotoluene',
    'C<sub>7</sub>H<sub>7</sub>N<sub>3</sub>O<sub>4</sub>',
    '',
    '19406-51-0',
    'KQRJATLINVYHEZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-amino-2,6-dinitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-hydroxy-3-nitro-benzaldehyde',
    'C<sub>7</sub>H<sub>5</sub>NO<sub>4</sub>',
    '',
    '3011-34-5',
    'YTHJCZRFJGXPTL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-hydroxy-3-nitro-benzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='941'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-hydroxy-3-nitro-benzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-hydroxy-3-nitro-benzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-hydroxy-3-nitro-benzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dinitrophenol',
    'C<sub>6</sub>H<sub>4</sub>N<sub>2</sub>O<sub>5</sub>',
    '',
    '51-28-5',
    'UFBJCMHMOXMLKC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,4-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,4-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='1155'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='941'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>4</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='2,4-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5000',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3300',
    '?',
    (SELECT id from species WHERE iupac='2,4-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5-dinitrophenol',
    'C<sub>6</sub>H<sub>4</sub>N<sub>2</sub>O<sub>5</sub>',
    '',
    '329-71-5',
    'UWEZBKLLMKVIPI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,5-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='941'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'picramic acid',
    'C<sub>6</sub>H<sub>5</sub>N<sub>3</sub>O<sub>5</sub>',
    '4,6-dinitro-2-aminophenol',
    '96-91-3',
    'QXYMVUZOGFVPGH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='picramic acid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-amino-2-nitrophenol',
    'C<sub>6</sub>H<sub>6</sub>N<sub>2</sub>O<sub>3</sub>',
    '',
    '119-34-6',
    'WHODQVWERNSQEO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-amino-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-amino-5-nitrophenol',
    'C<sub>6</sub>H<sub>6</sub>N<sub>2</sub>O<sub>3</sub>',
    '',
    '121-88-0',
    'DOPJTDJKZNWLRB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-amino-5-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-amino-4-nitrophenol',
    'C<sub>6</sub>H<sub>6</sub>N<sub>2</sub>O<sub>3</sub>',
    '',
    '99-57-0',
    'VLZVIIYRNMWPSN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-amino-4-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-nitro-o-phenylenediamine',
    'C<sub>6</sub>H<sub>7</sub>N<sub>3</sub>O<sub>2</sub>',
    '4-nitro-1,2-diaminobenzene',
    '99-56-9',
    'RAUWPNXIALNKQM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nitro-o-phenylenediamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-nitrobenzene-1,3-diamine',
    'C<sub>6</sub>H<sub>7</sub>N<sub>3</sub>O<sub>2</sub>',
    '',
    '5131-58-8',
    'DPIZKMGPXNXSGL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nitrobenzene-1,3-diamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-nitro-1,4-benzenediamine',
    'C<sub>6</sub>H<sub>7</sub>N<sub>3</sub>O<sub>2</sub>',
    '',
    '5307-14-2',
    'HVHNMNGARPCGGD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitro-1,4-benzenediamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-2,6-dinitrophenol',
    'C<sub>7</sub>H<sub>6</sub>N<sub>2</sub>O<sub>5</sub>',
    '2,6-dinitro-p-cresol',
    '609-93-8',
    'HOYRZHJJAHRMLL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='4-methyl-2,6-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='1155'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2,6-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2,6-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2,6-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2,6-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2,6-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3000',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2,6-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3400',
    '?',
    (SELECT id from species WHERE iupac='4-methyl-2,6-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-4,6-dinitrophenol',
    'C<sub>7</sub>H<sub>6</sub>N<sub>2</sub>O<sub>5</sub>',
    '6-methyl-2,4-dinitrophenol; 4,6-dinitro-o-cresol; DNOC',
    '534-52-1',
    'ZXVONLUNISGICL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methyl-4,6-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='1155'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-methyl-4,6-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-4,6-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-4,6-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='941'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-4,6-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-4,6-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0',
    '',
    'C',
    (SELECT id from species WHERE iupac='2-methyl-4,6-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='3083'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-4,6-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-4,6-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-4,6-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-4,6-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-4,6-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-4,6-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-4,6-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-4,6-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-4,6-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-4,6-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-4,6-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5400',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-4,6-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methyl-4,6-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4200',
    '?',
    (SELECT id from species WHERE iupac='2-methyl-4,6-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-nitrobenzimidazole',
    'C<sub>7</sub>H<sub>5</sub>N<sub>3</sub>O<sub>2</sub>',
    '',
    '94-52-0',
    'XPAZGLFMMUODDK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-nitrobenzimidazole'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-nitrobenzoic acid',
    'C<sub>7</sub>H<sub>5</sub>NO<sub>4</sub>',
    '',
    '121-92-6',
    'AFPHTEQTJZKQAQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-nitrobenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-nitrobenzoic acid',
    'C<sub>7</sub>H<sub>5</sub>NO<sub>4</sub>',
    '',
    '62-23-7',
    'OTLNPYWUJOZPPA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nitrobenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nitrobenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,5-dinitrobenzoic acid',
    'C<sub>7</sub>H<sub>4</sub>N<sub>2</sub>O<sub>6</sub>',
    '',
    '99-34-3',
    'VYWYYJYRVSBHJQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dinitrobenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,6-trinitrobenzoic acid',
    'C<sub>7</sub>H<sub>3</sub>N<sub>3</sub>O<sub>8</sub>',
    '',
    '129-66-8',
    'KAQBNBSMMVTKRN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trinitrobenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dinitrotoluene',
    'C<sub>7</sub>H<sub>6</sub>N<sub>2</sub>O<sub>4</sub>',
    '',
    '25321-14-6',
    'MOSFIJXAXDLOML-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dinitrotoluene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-3,5-dinitrobenzene',
    'C<sub>7</sub>H<sub>6</sub>N<sub>2</sub>O<sub>4</sub>',
    '',
    '618-85-9',
    'RUIFULUFLANOCI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-3,5-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methoxy-2-nitrobenzene',
    'C<sub>7</sub>H<sub>7</sub>NO<sub>3</sub>',
    '',
    '91-23-6',
    'CFBYEGUGFPZCNF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-methoxy-2-nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-methoxy-2-nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methoxy-2-nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methoxy-2-nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methoxy-2-nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methoxy-2-nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methoxy-2-nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-5-nitrobenzenamine',
    'C<sub>7</sub>H<sub>8</sub>N<sub>2</sub>O<sub>2</sub>',
    '5-nitro-o-toluidine',
    '99-55-8',
    'DSBIJCMXAIKKKI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-5-nitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methoxy-5-nitrobenzenamine',
    'C<sub>7</sub>H<sub>8</sub>N<sub>2</sub>O<sub>3</sub>',
    '5-nitro-o-anisidine',
    '99-59-2',
    'NIPDVSLAMPAWTP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methoxy-5-nitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-642'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(2-nitroethenyl)benzene',
    'C<sub>8</sub>H<sub>7</sub>NO<sub>2</sub>',
    '',
    '102-96-5',
    'PIAOLBVUVDXHHL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2-nitroethenyl)benzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-dimethyl-3-nitrobenzene',
    'C<sub>8</sub>H<sub>9</sub>NO<sub>2</sub>',
    '',
    '83-41-0',
    'FVHAWXWFPBPFOS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethyl-3-nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethyl-3-nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethyl-3-nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethyl-3-nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethyl-3-nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-dimethyl-4-nitrobenzene',
    'C<sub>8</sub>H<sub>9</sub>NO<sub>2</sub>',
    '',
    '99-51-4',
    'HFZKOYWDLDYELC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethyl-4-nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethyl-4-nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethyl-4-nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dimethyl-4-nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4-dimethyl-2-nitrobenzene',
    'C<sub>8</sub>H<sub>9</sub>NO<sub>2</sub>',
    '',
    '89-58-7',
    'BSFHJMGROOFSRA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dimethyl-2-nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dimethyl-2-nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dimethyl-2-nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dimethyl-2-nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dimethyl-1-nitrobenzene',
    'C<sub>8</sub>H<sub>9</sub>NO<sub>2</sub>',
    '',
    '89-87-2',
    'BBUPBICWUURTNP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-1-nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-1-nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-1-nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethyl-1-nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-2-nitroanisole',
    'C<sub>8</sub>H<sub>9</sub>NO<sub>3</sub>',
    '',
    '119-10-8',
    'LGNMURXRPLMVJI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-nitroanisole'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-nitroanisole'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-nitroanisole'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-nitroanisole'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-3-nitrobenzoic acid',
    'C<sub>8</sub>H<sub>7</sub>NO<sub>4</sub>',
    '',
    '1975-50-4',
    'YPQAFWHSMWWPLX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-nitrobenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-4-nitrobenzoic acid',
    'C<sub>8</sub>H<sub>7</sub>NO<sub>4</sub>',
    '',
    '3113-71-1',
    'XDTTUTIFWDAMIX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-4-nitrobenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-3,5-dinitrobenzoic acid',
    'C<sub>8</sub>H<sub>6</sub>N<sub>2</sub>O<sub>6</sub>',
    '',
    '28169-46-2',
    'CDVNZMKTJIBBBV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3,5-dinitrobenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-(1-methylethyl)-4-nitrobenzene',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>2</sub>',
    '',
    '1817-47-6',
    'JXMYUMNAEKRMIP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-(1-methylethyl)-4-nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-(1-methylethyl)-4-nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-(1-methylethyl)-4-nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-(1-methylethyl)-4-nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-nitro-8-hydroxyquinoline',
    'C<sub>9</sub>H<sub>6</sub>N<sub>2</sub>O<sub>3</sub>',
    'nitroxoline',
    '4008-48-4',
    'RJIWZDNTCBHXAL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-nitro-8-hydroxyquinoline'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-(1-methylpropyl)-4,6-dinitrophenol',
    'C<sub>10</sub>H<sub>12</sub>N<sub>2</sub>O<sub>5</sub>',
    'dinoseb',
    '88-85-7',
    'OWZPCEFYPSAJFR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-(1-methylpropyl)-4,6-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='1155'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-(1-methylpropyl)-4,6-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-(1-methylpropyl)-4,6-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(1-methylpropyl)-4,6-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(1-methylpropyl)-4,6-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(1-methylpropyl)-4,6-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(1-methylpropyl)-4,6-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(1-methylpropyl)-4,6-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6400',
    'Q',
    (SELECT id from species WHERE iupac='2-(1-methylpropyl)-4,6-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-(1-methylpropyl)-4,6-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7200',
    '?',
    (SELECT id from species WHERE iupac='2-(1-methylpropyl)-4,6-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='2-(1-methylpropyl)-4,6-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2614_88-85-7',
    '2614', 'Mackay et&nbsp;al. (2006d) list two values for dinoseb which differ by a factor of 1000. It is unclear which number is correct (if any), and the data are not reproduced here.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2614_88-85-7'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-nitronaphthalene',
    'C<sub>10</sub>H<sub>7</sub>NO<sub>2</sub>',
    '',
    '86-57-7',
    'RJKGJBPXVHTNJL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-nitronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-nitronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-nitronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2614_pc_problem'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-nitronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-nitronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-nitronaphthalene',
    'C<sub>10</sub>H<sub>7</sub>NO<sub>2</sub>',
    '',
    '581-89-5',
    'ZJYJZEAJZXVAMF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3-dinitronaphthalene',
    'C<sub>10</sub>H<sub>6</sub>N<sub>2</sub>O<sub>4</sub>',
    '',
    '606-37-1',
    'ULALSFRIGPMWRS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dinitronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,5-dinitronaphthalene',
    'C<sub>10</sub>H<sub>6</sub>N<sub>2</sub>O<sub>4</sub>',
    '',
    '605-71-0',
    'ZUTCJXFCHHDFJS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,5-dinitronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,8-dinitronaphthalene',
    'C<sub>10</sub>H<sub>6</sub>N<sub>2</sub>O<sub>4</sub>',
    '',
    '602-38-0',
    'AVCSMMMOCOTIHF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,8-dinitronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dinoterb',
    'C<sub>10</sub>H<sub>12</sub>N<sub>2</sub>O<sub>5</sub>',
    '',
    '1420-07-1',
    'IIPZYDQGBIWLBU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'X',
    (SELECT id from species WHERE iupac='dinoterb'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dinoterb'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dinoterb'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-(1-methylpropyl)-2-nitrophenol',
    'C<sub>10</sub>H<sub>13</sub>NO<sub>3</sub>',
    '4-<i>sec</i>-butyl-2-nitrophenol',
    '3555-18-8',
    'GCDCKEORRIGZKI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='4-(1-methylpropyl)-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='1155'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-(1-methylpropyl)-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='941'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-(1-methylpropyl)-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-(1-methylpropyl)-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-(1-methylpropyl)-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5800',
    'Q',
    (SELECT id from species WHERE iupac='4-(1-methylpropyl)-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4300',
    '?',
    (SELECT id from species WHERE iupac='4-(1-methylpropyl)-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-4-nitronaphthalene',
    'C<sub>11</sub>H<sub>9</sub>NO<sub>2</sub>',
    '',
    '880-93-3',
    'FRLVKAJKOYFHKQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-4-nitronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-5-nitronaphthalene',
    'C<sub>11</sub>H<sub>9</sub>NO<sub>2</sub>',
    '',
    '91137-27-8',
    'AOSRALZFDNFXFZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-5-nitronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-methyl-6-nitronaphthalene',
    'C<sub>11</sub>H<sub>9</sub>NO<sub>2</sub>',
    '',
    '105752-67-8',
    'SOXBGESONWKYDX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-methyl-6-nitronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-1-nitronaphthalene',
    'C<sub>11</sub>H<sub>9</sub>NO<sub>2</sub>',
    '',
    '881-03-8',
    'IZNWACYOILBFEG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-nitronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-1-nitronaphthalene',
    'C<sub>11</sub>H<sub>9</sub>NO<sub>2</sub>',
    '',
    '13615-38-8',
    'HKMFJWNUOWBRGF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-nitronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-nitrodibenzofuran',
    'C<sub>12</sub>H<sub>7</sub>NO<sub>3</sub>',
    '',
    '5410-97-9',
    'UVFAHDAUVZRVCC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-nitrodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'musk ambrette (artificial)',
    'C<sub>12</sub>H<sub>16</sub>N<sub>2</sub>O<sub>5</sub>',
    '',
    '83-66-9',
    'SUAUILGSCPYJCS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='musk ambrette (artificial)'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='musk ambrette (artificial)'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='musk ambrette (artificial)'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='musk ambrette (artificial)'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='musk ambrette (artificial)'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bis(p-nitrophenyl) ether',
    'C<sub>12</sub>H<sub>8</sub>N<sub>2</sub>O<sub>5</sub>',
    '',
    '101-63-3',
    'MWAGUKZCDDRDCS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis(p-nitrophenyl) ether'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis(p-nitrophenyl) ether'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis(p-nitrophenyl) ether'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis(p-nitrophenyl) ether'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-nitroazobenzene',
    'C<sub>12</sub>H<sub>9</sub>N<sub>3</sub>O<sub>2</sub>',
    '',
    '2491-52-3',
    'TZTDJBMGPQLSLI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-nitroazobenzene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-nitro-N-phenylbenzenamine',
    'C<sub>12</sub>H<sub>10</sub>N<sub>2</sub>O<sub>2</sub>',
    '',
    '836-30-6',
    'XXYMSQQCBUKFHE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nitro-N-phenylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nitro-N-phenylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nitro-N-phenylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nitro-N-phenylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-cyclohexyl-4,6-dinitrophenol',
    'C<sub>12</sub>H<sub>14</sub>N<sub>2</sub>O<sub>5</sub>',
    '',
    '131-89-5',
    'QJYHUJAGJUHXJN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-cyclohexyl-4,6-dinitrophenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dinoseb acetate',
    'C<sub>12</sub>H<sub>14</sub>N<sub>2</sub>O<sub>6</sub>',
    '',
    '2813-95-8',
    'RDJTWDKSYLLHRW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dinoseb acetate'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dipicrylamine',
    'C<sub>12</sub>H<sub>5</sub>N<sub>7</sub>O<sub>12</sub>',
    '2,2'',4,4'',6,6''-hexanitrodiphenylamine',
    '131-73-7',
    'CBCIHIVRDWLAME-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dipicrylamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-dihydro-5-nitroacenaphthylene',
    'C<sub>12</sub>H<sub>9</sub>NO<sub>2</sub>',
    '5-nitroacenaphthene',
    '602-87-9',
    'CUARLQDWYSRQDF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dihydro-5-nitroacenaphthylene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dihydro-5-nitroacenaphthylene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-nitro-1,1''-biphenyl',
    'C<sub>12</sub>H<sub>9</sub>NO<sub>2</sub>',
    '',
    '86-00-0',
    'YOJKKXRJMXIKSR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitro-1,1''-biphenyl'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-nitro-1,1''-biphenyl',
    'C<sub>12</sub>H<sub>9</sub>NO<sub>2</sub>',
    '',
    '2113-58-8',
    'FYRPEHRWMVMHQM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-nitro-1,1''-biphenyl'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-nitro-1,1''-biphenyl',
    'C<sub>12</sub>H<sub>9</sub>NO<sub>2</sub>',
    '',
    '92-93-3',
    'BAJQRLZAPXASRD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nitro-1,1''-biphenyl'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nitro-1,1''-biphenyl'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-nitro-9H-fluorene',
    'C<sub>13</sub>H<sub>9</sub>NO<sub>2</sub>',
    '',
    '607-57-8',
    'XFOHWECQTFIEIX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitro-9H-fluorene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitro-9H-fluorene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-<i>tert</i>-butyl-4,6-dinitro-1,2,3-trimethylbenzene',
    'C<sub>13</sub>H<sub>18</sub>N<sub>2</sub>O<sub>4</sub>',
    '',
    '145-39-1',
    'MINYPECWDZURGR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-<i>tert</i>-butyl-4,6-dinitro-1,2,3-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-<i>tert</i>-butyl-4,6-dinitro-1,2,3-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-<i>tert</i>-butyl-4,6-dinitro-1,2,3-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-<i>tert</i>-butyl-4,6-dinitro-1,2,3-trimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'penoxaline',
    'C<sub>13</sub>H<sub>19</sub>N<sub>3</sub>O<sub>4</sub>',
    'pendimethalin',
    '40487-42-1',
    'CHIFOSRWCNZCFN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='penoxaline'),
    (SELECT id from literature WHERE bibtexkey='1144'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='penoxaline'),
    (SELECT id from literature WHERE bibtexkey='2452'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='penoxaline'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='penoxaline'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='penoxaline'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='penoxaline'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='penoxaline'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6-dinitro-4-octylphenol',
    'C<sub>14</sub>H<sub>20</sub>N<sub>2</sub>O<sub>5</sub>',
    '',
    '4097-33-0',
    'NYGISSDEOKKXOE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dinitro-4-octylphenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'musk ketone',
    'C<sub>14</sub>H<sub>18</sub>N<sub>2</sub>O<sub>5</sub>',
    '',
    '81-14-1',
    'WXCMHFPAUCOJIG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '',
    'M',
    (SELECT id from species WHERE iupac='musk ketone'),
    (SELECT id from literature WHERE bibtexkey='3014'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='musk ketone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='musk ketone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='musk ketone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='musk ketone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='musk ketone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'moskene',
    'C<sub>14</sub>H<sub>18</sub>N<sub>2</sub>O<sub>4</sub>',
    '',
    '116-66-5',
    'UHWURQRPEIFIAK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='moskene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='moskene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='moskene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='moskene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nitrothal-isopropyl',
    'C<sub>14</sub>H<sub>17</sub>NO<sub>6</sub>',
    '',
    '10552-74-6',
    'VJAWBEFMCIINFU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='nitrothal-isopropyl'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '9-ethyl-3-nitrocarbazole',
    'C<sub>14</sub>H<sub>12</sub>N<sub>2</sub>O<sub>2</sub>',
    '',
    '86-20-4',
    'WONHLSYSHMRRGO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='9-ethyl-3-nitrocarbazole'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='9-ethyl-3-nitrocarbazole'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='9-ethyl-3-nitrocarbazole'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='9-ethyl-3-nitrocarbazole'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-nitroanthracene',
    'C<sub>14</sub>H<sub>9</sub>NO<sub>2</sub>',
    '',
    '3586-69-4',
    'NZWGQBVOKHEKLD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitroanthracene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '9-nitroanthracene',
    'C<sub>14</sub>H<sub>9</sub>NO<sub>2</sub>',
    '',
    '602-60-8',
    'LSIKFJXEYJIZNB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='9-nitroanthracene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-nitrophenanthrene',
    'C<sub>14</sub>H<sub>9</sub>NO<sub>2</sub>',
    '',
    '17024-19-0',
    'CPRHWWUDRYJODK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-nitrophenanthrene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '9-nitrophenanthrene',
    'C<sub>14</sub>H<sub>9</sub>NO<sub>2</sub>',
    '',
    '954-46-1',
    'QTTCNQHPKFAYEZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='9-nitrophenanthrene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'binapacryl',
    'C<sub>15</sub>H<sub>18</sub>N<sub>2</sub>O<sub>6</sub>',
    '',
    '485-31-4',
    'ZRDUSMYWDRPZRM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='binapacryl'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-nitrofluoranthene',
    'C<sub>16</sub>H<sub>9</sub>NO<sub>2</sub>',
    '',
    '13177-29-2',
    'VBCBFNMZBHKVQN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrofluoranthene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-nitrofluoranthene',
    'C<sub>16</sub>H<sub>9</sub>NO<sub>2</sub>',
    '',
    '892-21-7',
    'PIHGQKMEAMSUNA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-nitrofluoranthene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-[(2,4-dinitrophenyl)azo]-2-naphthol',
    'C<sub>16</sub>H<sub>10</sub>N<sub>4</sub>O<sub>5</sub>',
    'C.I. pigment orange 5',
    '3468-63-1',
    'HBHZKFOUIUMKHV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-[(2,4-dinitrophenyl)azo]-2-naphthol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,7-dinitrofluoranthene',
    'C<sub>16</sub>H<sub>8</sub>N<sub>2</sub>O<sub>4</sub>',
    '',
    '105735-71-5',
    'WAAHHGKGQYVTNS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,7-dinitrofluoranthene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3-dinitropyrene',
    'C<sub>16</sub>H<sub>8</sub>N<sub>2</sub>O<sub>4</sub>',
    '',
    '75321-20-9',
    'UJIPQBOHUQDIAA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dinitropyrene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,6-dinitropyrene',
    'C<sub>16</sub>H<sub>8</sub>N<sub>2</sub>O<sub>4</sub>',
    '',
    '42397-64-8',
    'GUXACCKTQWVTLG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,6-dinitropyrene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,6-dinitropyrene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,8-dinitropyrene',
    'C<sub>16</sub>H<sub>8</sub>N<sub>2</sub>O<sub>4</sub>',
    '',
    '42397-65-9',
    'BLYXNIHKOMELAP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,8-dinitropyrene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,8-dinitropyrene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-nitropyrene',
    'C<sub>16</sub>H<sub>9</sub>NO<sub>2</sub>',
    '',
    '5522-43-0',
    'ALRLPDGCPYIVHP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitropyrene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitropyrene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-nitropyrene',
    'C<sub>16</sub>H<sub>9</sub>NO<sub>2</sub>',
    '',
    '789-07-1',
    'MAZCGYFIOOIVHE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitropyrene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-nitropyrene',
    'C<sub>16</sub>H<sub>9</sub>NO<sub>2</sub>',
    '',
    '57835-92-4',
    'UISKIUIWPSPSAV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nitropyrene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N,N-diethyl-4-[(4-nitrophenyl)azo]aniline',
    'C<sub>16</sub>H<sub>18</sub>N<sub>4</sub>O<sub>2</sub>',
    '',
    '3025-52-3',
    'LVQIWDUSUJTZJF-ISLYRVAYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7',
    '',
    'V',
    (SELECT id from species WHERE iupac='N,N-diethyl-4-[(4-nitrophenyl)azo]aniline'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N-diethyl-4-[(4-nitrophenyl)azo]aniline'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'disperse red 1',
    'C<sub>16</sub>H<sub>18</sub>N<sub>4</sub>O<sub>3</sub>',
    '',
    '2872-52-8',
    'FOQABOMYTOFLPZ-ZCXUNETKSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>8</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='disperse red 1'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='disperse red 1'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-[(4-methyl-2-nitrophenyl)azo]-2-naphthalenol',
    'C<sub>17</sub>H<sub>13</sub>N<sub>3</sub>O<sub>3</sub>',
    'C.I. Pigment Red 3',
    '2425-85-6',
    'ZLFVRXUOSPRRKQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-[(4-methyl-2-nitrophenyl)azo]-2-naphthalenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phenyl 1-hydroxy-4-nitro-2-naphthoate',
    'C<sub>17</sub>H<sub>11</sub>NO<sub>5</sub>',
    '',
    '65208-34-6',
    'DMPUGHYNLCGVPX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenyl 1-hydroxy-4-nitro-2-naphthoate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenyl 1-hydroxy-4-nitro-2-naphthoate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenyl 1-hydroxy-4-nitro-2-naphthoate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenyl 1-hydroxy-4-nitro-2-naphthoate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '7-nitrobenz[a]anthracene',
    'C<sub>18</sub>H<sub>11</sub>NO<sub>2</sub>',
    '',
    '20268-51-3',
    'KOPVBVBUIYTJBG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='7-nitrobenz[a]anthracene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '6-nitrochrysene',
    'C<sub>18</sub>H<sub>11</sub>NO<sub>2</sub>',
    '',
    '7496-02-8',
    'UAWLTQJFZUYROA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-nitrochrysene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'meptyldinocap',
    'C<sub>18</sub>H<sub>24</sub>N<sub>2</sub>O<sub>6</sub>',
    '',
    '131-72-6',
    'NIOPZPCMRQGZCE-WEVVVXLNSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='meptyldinocap'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-nitrobenzo[a]pyrene',
    'C<sub>20</sub>H<sub>11</sub>NO<sub>2</sub>',
    '',
    '70021-99-7',
    'ICKISBPYFVBVQG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitrobenzo[a]pyrene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-nitrobenzo[a]pyrene',
    'C<sub>20</sub>H<sub>11</sub>NO<sub>2</sub>',
    '',
    '70021-98-6',
    'CQIJHYPCKYZMIV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-nitrobenzo[a]pyrene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '6-nitrobenzo[a]pyrene',
    'C<sub>20</sub>H<sub>11</sub>NO<sub>2</sub>',
    '',
    '63041-90-7',
    'NMMAFYSZGOFZCM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-nitrobenzo[a]pyrene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-nitrobenzo[a]pyrene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NPHEN1OOH',
    'C<sub>6</sub>H<sub>5</sub>NO<sub>4</sub>',
    '',
    '',
    'QKMAXSKQIHICGE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPHEN1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPHEN1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPHEN1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NCATECHOL',
    'C<sub>6</sub>H<sub>5</sub>NO<sub>4</sub>',
    '',
    '',
    'XJNPNXSISMKQEX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NCATECHOL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NCATECHOL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NCATECHOL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NCRES1OOH',
    'C<sub>7</sub>H<sub>7</sub>NO<sub>4</sub>',
    '',
    '',
    'PUXUHFKGXFXGAC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NCRES1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NCRES1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NCRES1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MNCATECH',
    'C<sub>7</sub>H<sub>7</sub>NO<sub>4</sub>',
    '',
    '',
    'DPKDSDOOIONLAG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MNCATECH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MNCATECH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MNCATECH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NEBNZ1OOH',
    'C<sub>8</sub>H<sub>9</sub>NO<sub>4</sub>',
    '',
    '',
    'WELXCAQABDDCET-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NEBNZ1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NEBNZ1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NEBNZ1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NMXYOL1OOH',
    'C<sub>8</sub>H<sub>9</sub>NO<sub>4</sub>',
    '',
    '',
    'WHVCHTZZXIECJY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NMXYOL1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NMXYOL1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NMXYOL1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NOXYOL1OOH',
    'C<sub>8</sub>H<sub>9</sub>NO<sub>4</sub>',
    '',
    '',
    'WTJTXPQAQHBAPV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOXYOL1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOXYOL1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOXYOL1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NPXYOL1OOH',
    'C<sub>8</sub>H<sub>9</sub>NO<sub>4</sub>',
    '',
    '',
    'MKCNKDVBVLGUFV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPXYOL1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPXYOL1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPXYOL1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DM124OHNO2',
    'C<sub>8</sub>H<sub>9</sub>NO<sub>3</sub>',
    '',
    '',
    'KGDIYDUZVHFMHQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DM124OHNO2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DM124OHNO2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DM124OHNO2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DMPHOHNO2',
    'C<sub>8</sub>H<sub>9</sub>NO<sub>3</sub>',
    '',
    '',
    'YXNYMZXPUWOUJT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMPHOHNO2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMPHOHNO2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMPHOHNO2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DNEBNZOL',
    'C<sub>8</sub>H<sub>8</sub>N<sub>2</sub>O<sub>5</sub>',
    '',
    '',
    'SYWMIOFIFBKHTK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNEBNZOL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNEBNZOL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNEBNZOL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DNMXYOL',
    'C<sub>8</sub>H<sub>8</sub>N<sub>2</sub>O<sub>5</sub>',
    '',
    '',
    'MHXAYMPVZDCVJX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNMXYOL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNMXYOL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNMXYOL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DNOXYOL',
    'C<sub>8</sub>H<sub>8</sub>N<sub>2</sub>O<sub>5</sub>',
    '',
    '',
    'JCTQXQRGEDMCSI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNOXYOL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNOXYOL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNOXYOL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DNPXYOL',
    'C<sub>8</sub>H<sub>8</sub>N<sub>2</sub>O<sub>5</sub>',
    '',
    '',
    'RROXWBBJMPCPHD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNPXYOL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNPXYOL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNPXYOL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:EBNZOHNO2',
    'C<sub>8</sub>H<sub>9</sub>NO<sub>3</sub>',
    '',
    '',
    'RSETVJMGQZKFCF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBNZOHNO2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBNZOHNO2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:EBNZOHNO2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:ENCATECH',
    'C<sub>8</sub>H<sub>9</sub>NO<sub>4</sub>',
    '',
    '',
    'CGDBCFCRALNPBR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ENCATECH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ENCATECH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:ENCATECH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MXNCATECH',
    'C<sub>8</sub>H<sub>9</sub>NO<sub>4</sub>',
    '',
    '',
    'DNJZITGVNONOFW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXNCATECH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXNCATECH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXNCATECH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MXY1OHNO2',
    'C<sub>8</sub>H<sub>9</sub>NO<sub>3</sub>',
    '',
    '',
    'KJRCHILWKQLEBC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXY1OHNO2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXY1OHNO2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MXY1OHNO2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OXNCATECH',
    'C<sub>8</sub>H<sub>9</sub>NO<sub>4</sub>',
    '',
    '',
    'BBBHATWMUPCFKG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXNCATECH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXNCATECH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXNCATECH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OXY1OHNO2',
    'C<sub>8</sub>H<sub>9</sub>NO<sub>3</sub>',
    '',
    '',
    'KXWOAPZXQJGYPU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXY1OHNO2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXY1OHNO2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OXY1OHNO2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PXNCATECH',
    'C<sub>8</sub>H<sub>9</sub>NO<sub>4</sub>',
    '',
    '',
    'MAHUOFZDOBGDSU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXNCATECH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXNCATECH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXNCATECH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PXY1OHNO2',
    'C<sub>8</sub>H<sub>9</sub>NO<sub>3</sub>',
    '',
    '',
    'VIQHHRZADKSPIM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXY1OHNO2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXY1OHNO2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PXY1OHNO2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NIPBNZ1OOH',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>4</sub>',
    '',
    '',
    'IXEXRYHUTBEDFT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NIPBNZ1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NIPBNZ1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NIPBNZ1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NMETOL1OOH',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>4</sub>',
    '',
    '',
    'OTBVEKBEKVMFBF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NMETOL1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NMETOL1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NMETOL1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NOETOL1OOH',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>4</sub>',
    '',
    '',
    'ZYYASKSQLLYACE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOETOL1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOETOL1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NOETOL1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NPBNZ1OOH',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>4</sub>',
    '',
    '',
    'CVKCTJQZVRPANA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPBNZ1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPBNZ1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPBNZ1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NPETOL1OOH',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>4</sub>',
    '',
    '',
    'PGRGKKYGDUKVIK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPETOL1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPETOL1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NPETOL1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NT123L1OOH',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>4</sub>',
    '',
    '',
    'QUQYRHULCDEZAA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NT123L1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NT123L1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NT123L1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:NT124L1OOH',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>4</sub>',
    '',
    '',
    'DLQITMPSPXAOFG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NT124L1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NT124L1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:NT124L1OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DNIPBNZOL',
    'C<sub>9</sub>H<sub>10</sub>N<sub>2</sub>O<sub>5</sub>',
    '',
    '29385-11-3',
    'HBYHYLBZPLCIEE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNIPBNZOL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNIPBNZOL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNIPBNZOL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNIPBNZOL'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNIPBNZOL'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNIPBNZOL'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DNMETOL',
    'C<sub>9</sub>H<sub>10</sub>N<sub>2</sub>O<sub>5</sub>',
    '',
    '',
    'NLLBSWNZAUXBGJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNMETOL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNMETOL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNMETOL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DNOETOL',
    'C<sub>9</sub>H<sub>10</sub>N<sub>2</sub>O<sub>5</sub>',
    '',
    '',
    'AGMONASRVOHMRW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNOETOL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNOETOL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNOETOL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DNPBNZOL',
    'C<sub>9</sub>H<sub>10</sub>N<sub>2</sub>O<sub>5</sub>',
    '',
    '',
    'FCIYPWNHZQHVEQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNPBNZOL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNPBNZOL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNPBNZOL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DNPETOL',
    'C<sub>9</sub>H<sub>10</sub>N<sub>2</sub>O<sub>5</sub>',
    '',
    '',
    'DZWALJMRDDSGJQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNPETOL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNPETOL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNPETOL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DNT123BOL',
    'C<sub>9</sub>H<sub>10</sub>N<sub>2</sub>O<sub>5</sub>',
    '',
    '',
    'KTYJIHPJHVSEQH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNT123BOL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNT123BOL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNT123BOL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DNT124BOL',
    'C<sub>9</sub>H<sub>10</sub>N<sub>2</sub>O<sub>5</sub>',
    '',
    '',
    'HCZZKJMHIZGVJN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNT124BOL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNT124BOL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DNT124BOL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:HOEMPHNO2',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>3</sub>',
    '',
    '',
    'YSPMBFYZTNTHGD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOEMPHNO2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOEMPHNO2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:HOEMPHNO2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPBNZOHNO2',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>3</sub>',
    '',
    '',
    'RRFSVDKJKYCCEK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBNZOHNO2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBNZOHNO2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPBNZOHNO2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:IPNCATECH',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>4</sub>',
    '',
    '',
    'MCPZUPZVJHDAPC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPNCATECH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPNCATECH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:IPNCATECH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MET1OHNO2',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>3</sub>',
    '',
    '',
    'QDGFKFKXXCXYOS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MET1OHNO2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MET1OHNO2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MET1OHNO2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MTNCATECH',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>4</sub>',
    '',
    '',
    'CJFAOEWQLMJWBQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTNCATECH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTNCATECH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MTNCATECH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OET1OHNO2',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>3</sub>',
    '',
    '',
    'MEMHWZGPMLWUCR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OET1OHNO2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OET1OHNO2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OET1OHNO2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:OTNCATECH',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>4</sub>',
    '',
    '',
    'JWEUFFGZFSJOFB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OTNCATECH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OTNCATECH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:OTNCATECH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PBNZOHNO2',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>3</sub>',
    '',
    '',
    'SNIBPLNVBYUZKZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBNZOHNO2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBNZOHNO2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PBNZOHNO2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PET1OHNO2',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>3</sub>',
    '',
    '',
    'DXOFURYTWRHSOS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PET1OHNO2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PET1OHNO2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PET1OHNO2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PNCATECH',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>4</sub>',
    '',
    '',
    'UWDKGIAMIWLDOZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PNCATECH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PNCATECH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PNCATECH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:PTNCATECH',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>4</sub>',
    '',
    '',
    'POSTUROPYARVPT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PTNCATECH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PTNCATECH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:PTNCATECH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:T123NCATEC',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>4</sub>',
    '',
    '',
    'NRIGBHNXEXAXSY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:T123NCATEC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:T123NCATEC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:T123NCATEC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:T124NCATEC',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>4</sub>',
    '',
    '',
    'XNILZTOSMSXQOP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:T124NCATEC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:T124NCATEC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:T124NCATEC'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TM123OHNO2',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>3</sub>',
    '',
    '',
    'GRYTUHBAWMNFLK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM123OHNO2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM123OHNO2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM123OHNO2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TM124OHNO2',
    'C<sub>9</sub>H<sub>11</sub>NO<sub>3</sub>',
    '',
    '',
    'NKOCMNXLDSIDQC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Nitro compounds (RNO<sub>2</sub>)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124OHNO2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124OHNO2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TM124OHNO2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO categories (catname) VALUES (
    'Organic species with fluorine (F)');
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Organic fluorine',
    (SELECT id from categories WHERE catname='Organic species with fluorine (F)'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fluoromethane',
    'CH<sub>3</sub>F',
    '',
    '593-53-3',
    'NBVXSUQYWXRMNV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;4</sup>',
    '2100',
    'L',
    (SELECT id from species WHERE iupac='fluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;4</sup>',
    '2000',
    'L',
    (SELECT id from species WHERE iupac='fluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '2200',
    'L',
    (SELECT id from species WHERE iupac='fluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3518-593-53-3-consicheck',
    '3518', 'Values at 298&nbsp;K in Tables&nbsp;C2 and C5 of Brockbank (2013) are inconsistent, with 6&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3518-593-53-3-consicheck'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;4</sup>',
    '2000',
    'L',
    (SELECT id from species WHERE iupac='fluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;4</sup>',
    '2000',
    'L',
    (SELECT id from species WHERE iupac='fluoromethane'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;4</sup>',
    '2200',
    'L',
    (SELECT id from species WHERE iupac='fluoromethane'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;4</sup>',
    '2100',
    'M',
    (SELECT id from species WHERE iupac='fluoromethane'),
    (SELECT id from literature WHERE bibtexkey='1340'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;4</sup>',
    '2200',
    'M',
    (SELECT id from species WHERE iupac='fluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2222'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2222-593-53-3-ABC',
    '2222', 'The data from Glew and Moelwyn-Hughes (1953) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;135.82151 +7593.40134/T +18.05983&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2222-593-53-3-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='fluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='fluoromethane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='fluoromethane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='fluoromethane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2200',
    'Q',
    (SELECT id from species WHERE iupac='fluoromethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fluoromethane'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fluoromethane'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2200',
    '?',
    (SELECT id from species WHERE iupac='fluoromethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fluoromethane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'difluoromethane',
    'CH<sub>2</sub>F<sub>2</sub>',
    'R32',
    '75-10-5',
    'RWRIWBAIICGTTQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;4</sup>',
    '2100',
    'M',
    (SELECT id from species WHERE iupac='difluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3272'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;4</sup>',
    '2500',
    'M',
    (SELECT id from species WHERE iupac='difluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3262'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;4</sup>',
    '3500',
    'M',
    (SELECT id from species WHERE iupac='difluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3261'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;4</sup>',
    '2400',
    'M',
    (SELECT id from species WHERE iupac='difluoromethane'),
    (SELECT id from literature WHERE bibtexkey='923'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0923-75-10-5-ABC',
    '923', 'The data from Maaßen (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;163.70243 +8973.31702/T +22.17142&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0923-75-10-5-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;4</sup>',
    '2300',
    'M',
    (SELECT id from species WHERE iupac='difluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2013'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2013-75-10-5-ABC',
    '2013', 'The data from Reichl (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;142.70480 +8025.53525/T +19.04459&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2013-75-10-5-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='difluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='difluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='difluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2200',
    'Q',
    (SELECT id from species WHERE iupac='difluoromethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='difluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2400',
    '?',
    (SELECT id from species WHERE iupac='difluoromethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='difluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='difluoromethane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'trifluoromethane',
    'CHF<sub>3</sub>',
    'R23',
    '75-46-7',
    'XPDWGBQVDMORPB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '2500',
    'L',
    (SELECT id from species WHERE iupac='trifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '2200',
    'L',
    (SELECT id from species WHERE iupac='trifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '2500',
    'L',
    (SELECT id from species WHERE iupac='trifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '2200',
    'L',
    (SELECT id from species WHERE iupac='trifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '3300',
    'L',
    (SELECT id from species WHERE iupac='trifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '3200',
    'L',
    (SELECT id from species WHERE iupac='trifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;4</sup>',
    '2500',
    'M',
    (SELECT id from species WHERE iupac='trifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3261'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '2400',
    'M',
    (SELECT id from species WHERE iupac='trifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='921'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0921-75-46-7-ABC',
    '921', 'The data from Zheng et&nbsp;al. (1997) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;190.61883 +10088.26604/T +25.94088&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0921-75-46-7-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '2400',
    'M',
    (SELECT id from species WHERE iupac='trifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='923'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0923-75-46-7-ABC',
    '923', 'The data from Maaßen (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;177.44258 +9554.69077/T +23.94054&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0923-75-46-7-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='trifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='trifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;4</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='trifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '2700',
    'Q',
    (SELECT id from species WHERE iupac='trifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3570'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2200',
    'Q',
    (SELECT id from species WHERE iupac='trifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='trifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3000',
    '?',
    (SELECT id from species WHERE iupac='trifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='trifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='trifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tetrafluoromethane',
    'CF<sub>4</sub>',
    'carbontetrafluoride',
    '75-73-0',
    'TXEYQDLBPFQVAA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;6</sup>',
    '1800',
    'L',
    (SELECT id from species WHERE iupac='tetrafluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '2300',
    'L',
    (SELECT id from species WHERE iupac='tetrafluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;6</sup>',
    '1800',
    'L',
    (SELECT id from species WHERE iupac='tetrafluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;6</sup>',
    '2300',
    'L',
    (SELECT id from species WHERE iupac='tetrafluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;6</sup>',
    '2300',
    'L',
    (SELECT id from species WHERE iupac='tetrafluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2828'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;6</sup>',
    '1800',
    'L',
    (SELECT id from species WHERE iupac='tetrafluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;6</sup>',
    '1800',
    'L',
    (SELECT id from species WHERE iupac='tetrafluoromethane'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;6</sup>',
    '2000',
    'M',
    (SELECT id from species WHERE iupac='tetrafluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2013'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2013-75-73-0-ABC',
    '2013', 'The data from Reichl (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;350.64777 +16708.21486/T +49.40261&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2013-75-73-0-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;6</sup>',
    '1800',
    'M',
    (SELECT id from species WHERE iupac='tetrafluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3569'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3569-75-73-0-ABC',
    '3569', 'The data from Scharlin and Battino (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;552.21779 +25529.81258/T +79.59510&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3569-75-73-0-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;6</sup>',
    '1800',
    'M',
    (SELECT id from species WHERE iupac='tetrafluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2485'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2485-75-73-0-ABC',
    '2485', 'The data from Scharlin and Battino (1994) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;552.21779 +25529.81258/T +79.59510&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2485-75-73-0-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;6</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='tetrafluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2486'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;6</sup>',
    '1600',
    'M',
    (SELECT id from species WHERE iupac='tetrafluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3601'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;6</sup>',
    '1900',
    'M',
    (SELECT id from species WHERE iupac='tetrafluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2484'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2484-75-73-0-ABC',
    '2484', 'The data from Wen and Muccitelli (1979) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;356.93310 +16943.80173/T +50.37092&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2484-75-73-0-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;6</sup>',
    '1800',
    'M',
    (SELECT id from species WHERE iupac='tetrafluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2831'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2831-75-73-0-ABC',
    '2831', 'The data from Ashton et&nbsp;al. (1968) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;320.94892 +15261.58540/T +45.04995&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2831-75-73-0-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;6</sup>',
    '1500',
    'M',
    (SELECT id from species WHERE iupac='tetrafluoromethane'),
    (SELECT id from literature WHERE bibtexkey='764'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0764-75-73-0-ABC',
    '764', 'The data from Morrison and Johnstone (1954) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;174.44927 +8434.85415/T +23.34667&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0764-75-73-0-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tetrafluoromethane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;6</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='tetrafluoromethane'),
    (SELECT id from literature WHERE bibtexkey='766'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='tetrafluoromethane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;6</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='tetrafluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrafluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrafluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrafluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;6</sup>',
    '1800',
    'Q',
    (SELECT id from species WHERE iupac='tetrafluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3570'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrafluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrafluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrafluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrafluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2200',
    'Q',
    (SELECT id from species WHERE iupac='tetrafluoromethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrafluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3780'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrafluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '-840',
    'Q',
    (SELECT id from species WHERE iupac='tetrafluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2610'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrafluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrafluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrafluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tetrafluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '1900',
    '?',
    (SELECT id from species WHERE iupac='tetrafluoromethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tetrafluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;6</sup>',
    '1700',
    '?',
    (SELECT id from species WHERE iupac='tetrafluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3811'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tetrafluoromethane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fluoroethane',
    'C<sub>2</sub>H<sub>5</sub>F',
    '',
    '353-36-6',
    'UHCBBWUQDAVSMS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='fluoroethane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fluoroethane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1-difluoroethane',
    'C<sub>2</sub>H<sub>4</sub>F<sub>2</sub>',
    'R152a',
    '75-37-6',
    'NPNPZTNLOVBDOC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;4</sup>',
    '2600',
    'L',
    (SELECT id from species WHERE iupac='1,1-difluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3500-75-37-6-consicheck',
    '3500', 'The H298 and A, B data listed in Table&nbsp;5-7 of Burkholder et&nbsp;al. (2019) are inconsistent, with 8&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3500-75-37-6-consicheck'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;4</sup>',
    '2600',
    'L',
    (SELECT id from species WHERE iupac='1,1-difluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3245-75-37-6-consicheck',
    '3245', 'The H298 and A, B data listed in Table&nbsp;5-7 of Burkholder et&nbsp;al. (2015) are inconsistent, with 8&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3245-75-37-6-consicheck'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;4</sup>',
    '2800',
    'M',
    (SELECT id from species WHERE iupac='1,1-difluoroethane'),
    (SELECT id from literature WHERE bibtexkey='921'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0921-75-37-6-ABC',
    '921', 'The data from Zheng et&nbsp;al. (1997) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;203.78636 +11097.46295/T +27.89781&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0921-75-37-6-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;4</sup>',
    '2800',
    'M',
    (SELECT id from species WHERE iupac='1,1-difluoroethane'),
    (SELECT id from literature WHERE bibtexkey='923'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0923-75-37-6-ABC',
    '923', 'The data from Maaßen (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;184.82864 +10260.68840/T +25.06659&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0923-75-37-6-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;4</sup>',
    '2700',
    'M',
    (SELECT id from species WHERE iupac='1,1-difluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2013'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2013-75-37-6-ABC',
    '2013', 'The data from Reichl (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;175.64793 +9805.36391/T +23.71997&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2013-75-37-6-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;4</sup>',
    '2300',
    'V',
    (SELECT id from species WHERE iupac='1,1-difluoroethane'),
    (SELECT id from literature WHERE bibtexkey='1014'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1-difluoroethane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;4</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1,1-difluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at294K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-difluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-difluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-difluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-difluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-difluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-difluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-difluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-difluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-difluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2600',
    'Q',
    (SELECT id from species WHERE iupac='1,1-difluoroethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-difluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-difluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-difluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1-difluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2800',
    '?',
    (SELECT id from species WHERE iupac='1,1-difluoroethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1-difluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at301K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1-difluoroethane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at301K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-difluoroethane',
    'C<sub>2</sub>H<sub>4</sub>F<sub>2</sub>',
    '',
    '624-72-6',
    'AHFMSNDOYCFEPH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-difluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,1,2-tetrafluoroethane',
    'C<sub>2</sub>H<sub>2</sub>F<sub>4</sub>',
    'R134a',
    '811-97-2',
    'LVGUZGTVOIAKKC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '2700',
    'L',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '2700',
    'L',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;4</sup>',
    '3100',
    'M',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3564'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '2900',
    'M',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='921'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0921-811-97-2-ABC',
    '921', 'The data from Zheng et&nbsp;al. (1997) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;244.13803 +12963.44791/T +33.68869&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0921-811-97-2-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '3000',
    'M',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='923'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0923-811-97-2-ABC',
    '923', 'The data from Maaßen (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;225.56576 +12186.49271/T +30.88527&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0923-811-97-2-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '2900',
    'M',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2013'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2013-811-97-2-ABC',
    '2013', 'The data from Reichl (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;208.89051 +11387.65726/T +28.42219&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2013-811-97-2-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;4</sup>',
    '1400',
    'M',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2121'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2121-811-97-2-ABC',
    '2121', 'The data from Chang and Criddle (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;1003.84803 +45506.40253/T +147.89569&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2121-811-97-2-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;4</sup>',
    '2600',
    'V',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='1014'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;4</sup>',
    '3100',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3570'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,2,2-tetrafluoroethane',
    'C<sub>2</sub>H<sub>2</sub>F<sub>4</sub>',
    '',
    '359-35-3',
    'WXGNWUVNYMJENI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pentafluoroethane',
    'C<sub>2</sub>HF<sub>5</sub>',
    'R125',
    '354-33-6',
    'GTLACDSXYULKMZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;4</sup>',
    '3300',
    'M',
    (SELECT id from species WHERE iupac='pentafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3261'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;5</sup>',
    '3000',
    'M',
    (SELECT id from species WHERE iupac='pentafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2013'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2013-354-33-6-ABC',
    '2013', 'The data from Reichl (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;164.25882 +9381.26592/T +21.50848&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2013-354-33-6-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;5</sup>',
    '4800',
    'V',
    (SELECT id from species WHERE iupac='pentafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='1014'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;5</sup>',
    '3000',
    'Q',
    (SELECT id from species WHERE iupac='pentafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3570'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2600',
    'Q',
    (SELECT id from species WHERE iupac='pentafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2900',
    '?',
    (SELECT id from species WHERE iupac='pentafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hexafluoroethane',
    'C<sub>2</sub>F<sub>6</sub>',
    '',
    '76-16-4',
    'WMIYKQLTONQJES-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;7</sup>',
    '2100',
    'M',
    (SELECT id from species WHERE iupac='hexafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2610'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;7</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='hexafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2486'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;7</sup>',
    '2300',
    'M',
    (SELECT id from species WHERE iupac='hexafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2484'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2484-76-16-4-ABC',
    '2484', 'The data from Wen and Muccitelli (1979) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;499.57565 +23563.38593/T +71.28478&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2484-76-16-4-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='hexafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;7</sup>',
    '2600',
    'Q',
    (SELECT id from species WHERE iupac='hexafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3570'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2600',
    'Q',
    (SELECT id from species WHERE iupac='hexafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '1700',
    'Q',
    (SELECT id from species WHERE iupac='hexafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2610'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='hexafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2900',
    '?',
    (SELECT id from species WHERE iupac='hexafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='hexafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='hexafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-fluoropropane',
    'C<sub>3</sub>H<sub>7</sub>F',
    '',
    '460-13-9',
    'JRHNUZCXXOTJCA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-fluoropropane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'at287K',
    '', 'Value at T = 287&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at287K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-fluoropropane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-fluoropropane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-fluoropropane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-fluoropropane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at287K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-fluoropropane'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-fluoropropane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at287K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-fluoropropane',
    'C<sub>3</sub>H<sub>7</sub>F',
    '',
    '420-26-8',
    'PRNZBCYBKGCOFI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-fluoropropane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-fluoropropane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-fluoropropane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-fluoropropane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-fluoropropane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-fluoropropane'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-fluoropropane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,1,2,2-pentafluoropropane',
    'C<sub>3</sub>H<sub>3</sub>F<sub>5</sub>',
    '',
    '1814-88-6',
    'FDOPVENYMZRARC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2,2-pentafluoropropane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,1,3,3,3-hexafluoropropane',
    'C<sub>3</sub>H<sub>2</sub>F<sub>6</sub>',
    '',
    '690-39-1',
    'NSGXIBWMJZWTPY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,3,3,3-hexafluoropropane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,3,3,3-hexafluoropropane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,3,3,3-hexafluoropropane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,3,3,3-hexafluoropropane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,1,2,3,3,3-heptafluoropropane',
    'C<sub>3</sub>HF<sub>7</sub>',
    'R227',
    '431-89-0',
    'YFMFNYKEUDLDTL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '3300',
    'M',
    (SELECT id from species WHERE iupac='1,1,1,2,3,3,3-heptafluoropropane'),
    (SELECT id from literature WHERE bibtexkey='2013'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2013-431-89-0-ABC',
    '2013', 'The data from Reichl (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;78.74672 +5836.90728/T +8.41930&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2013-431-89-0-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2,3,3,3-heptafluoropropane'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2,3,3,3-heptafluoropropane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2900',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2,3,3,3-heptafluoropropane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3300',
    '?',
    (SELECT id from species WHERE iupac='1,1,1,2,3,3,3-heptafluoropropane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'octafluoropropane',
    'C<sub>3</sub>F<sub>8</sub>',
    'R218',
    '76-19-7',
    'QYSGYZVSCZSLHT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;7</sup>',
    '6900',
    'M',
    (SELECT id from species WHERE iupac='octafluoropropane'),
    (SELECT id from literature WHERE bibtexkey='2484'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;7</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='octafluoropropane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;7</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='octafluoropropane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='octafluoropropane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octafluoropropane'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octafluoropropane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octafluoropropane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octafluoropropane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octafluoropropane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octafluoropropane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octafluoropropane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octafluoropropane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octafluoropropane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='octafluoropropane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'decafluorobutane',
    'C<sub>4</sub>F<sub>10</sub>',
    '',
    '355-25-9',
    'KAVGMUDTWQVPDF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decafluorobutane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'octafluorocyclobutane',
    'C<sub>4</sub>F<sub>8</sub>',
    '',
    '115-25-3',
    'BCCOBQSFUDVTJQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '3000',
    'L',
    (SELECT id from species WHERE iupac='octafluorocyclobutane'),
    (SELECT id from literature WHERE bibtexkey='2447'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2447-115-25-3-ABC',
    '2447', 'The data from Clever et&nbsp;al. (2005) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;588.11467 +28143.61522/T +84.26598&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2447-115-25-3-ABC'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2447-115-25-3',
    '2447', 'In their Table&nbsp;13, Clever et&nbsp;al. (2005) list Ostwald coefficients that are probably incorrect by a factor of 100. Therefore, these values are not used. Instead, H<sub>s</sub> is calculated using the amount fraction x<sub>1</sub> from the same table.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2447-115-25-3'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '3300',
    'M',
    (SELECT id from species WHERE iupac='octafluorocyclobutane'),
    (SELECT id from literature WHERE bibtexkey='2485'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2485-115-25-3-ABC',
    '2485', 'The data from Scharlin and Battino (1994) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;630.69809 +30309.09484/T +90.46889&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2485-115-25-3-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='octafluorocyclobutane'),
    (SELECT id from literature WHERE bibtexkey='2486'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '3000',
    'M',
    (SELECT id from species WHERE iupac='octafluorocyclobutane'),
    (SELECT id from literature WHERE bibtexkey='2484'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2484-115-25-3-ABC',
    '2484', 'The data from Wen and Muccitelli (1979) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;673.45393 +31915.35190/T +97.01332&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2484-115-25-3-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='octafluorocyclobutane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='octafluorocyclobutane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at299K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octafluorocyclobutane'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octafluorocyclobutane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octafluorocyclobutane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octafluorocyclobutane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octafluorocyclobutane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octafluorocyclobutane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octafluorocyclobutane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octafluorocyclobutane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octafluorocyclobutane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4500',
    'Q',
    (SELECT id from species WHERE iupac='octafluorocyclobutane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3800',
    '?',
    (SELECT id from species WHERE iupac='octafluorocyclobutane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='octafluorocyclobutane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at299K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='octafluorocyclobutane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at299K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,1,2,2,3,4,5,5,5-decafluoropentane',
    'C<sub>5</sub>H<sub>2</sub>F<sub>10</sub>',
    '',
    '138495-42-8',
    'RIQRGMUSBYGDBL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2,2,3,4,5,5,5-decafluoropentane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2,2,3,4,5,5,5-decafluoropentane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2,2,3,4,5,5,5-decafluoropentane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2,2,3,4,5,5,5-decafluoropentane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dodecafluoropentane',
    'C<sub>5</sub>F<sub>12</sub>',
    '',
    '678-26-2',
    'NJCBUSHGCBERSK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;8</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='dodecafluoropentane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dodecafluoropentane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tetradecafluorohexane',
    'C<sub>6</sub>F<sub>14</sub>',
    'perflexane',
    '355-42-0',
    'ZJIJAJXFLBMLCK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;9</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='tetradecafluorohexane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetradecafluorohexane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fluorocyclohexane',
    'C<sub>6</sub>H<sub>11</sub>F',
    '',
    '372-46-3',
    'GOBGVVAHHOUMDK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fluorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-fluoroheptane',
    'C<sub>7</sub>H<sub>15</sub>F',
    '',
    '661-11-0',
    'BITLXSQYFZTQGC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-fluoroheptane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hexadecafluoroheptane',
    'C<sub>7</sub>F<sub>16</sub>',
    '',
    '335-57-9',
    'LGUZHRODIJCVOC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;9</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='hexadecafluoroheptane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexadecafluoroheptane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-fluorooctane',
    'C<sub>8</sub>H<sub>17</sub>F',
    '',
    '463-11-6',
    'DHIVLKMGKIZOHF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-fluorooctane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'perfluorooctane',
    'C<sub>8</sub>F<sub>18</sub>',
    '',
    '307-34-6',
    'YVBBRRALBYAZBM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;10</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='perfluorooctane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'eicosafluorononane',
    'C<sub>9</sub>F<sub>20</sub>',
    '',
    '375-96-2',
    'UVWPNDVAQBNQBG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='eicosafluorononane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'perfluoroundecane',
    'C<sub>11</sub>F<sub>24</sub>',
    '',
    '307-49-3',
    'VCIVYCHKSHULON-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;13</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='perfluoroundecane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='perfluoroundecane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='perfluoroundecane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;12</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='perfluoroundecane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,1,2,2,3,3,4,4,5,5,6,6,7,7,8,8,9,9,10,10-henicosafluorododecane',
    'C<sub>12</sub>H<sub>5</sub>F<sub>21</sub>',
    'perfluorodecyl ethane',
    '154478-87-2',
    'HUPGRQWHZOWFPQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2,2,3,3,4,4,5,5,6,6,7,7,8,8,9,9,10,10-henicosafluorododecane'),
    (SELECT id from literature WHERE bibtexkey='2994'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,1,2,2,3,3,4,4,5,5,6,6-tridecafluorotetradecane',
    'C<sub>14</sub>H<sub>17</sub>F<sub>13</sub>',
    '',
    '133331-77-8',
    'WRYIIOKOQSICTB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2,2,3,3,4,4,5,5,6,6-tridecafluorotetradecane'),
    (SELECT id from literature WHERE bibtexkey='2994'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,1,2,2,3,3,4,4,5,5,6,6-tridecafluoroicosane',
    'C<sub>20</sub>H<sub>29</sub>F<sub>13</sub>',
    '',
    '154628-00-9',
    'BREOHRVZEZMFOB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2,2,3,3,4,4,5,5,6,6-tridecafluoroicosane'),
    (SELECT id from literature WHERE bibtexkey='2994'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,1,2,2,3,3,4,4,5,5,6,6-tridecafluorodocosane',
    'C<sub>22</sub>H<sub>33</sub>F<sub>13</sub>',
    '',
    '133310-71-1',
    'ZKYMFADZZFTYJH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2,2,3,3,4,4,5,5,6,6-tridecafluorodocosane'),
    (SELECT id from literature WHERE bibtexkey='2994'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,1,2,2,3,3,4,4,5,5,6,6,7,7,8,8-heptadecafluorotetracosane',
    'C<sub>24</sub>H<sub>33</sub>F<sub>17</sub>',
    '',
    '117146-18-6',
    'FTECWCULPOFDJS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2,2,3,3,4,4,5,5,6,6,7,7,8,8-heptadecafluorotetracosane'),
    (SELECT id from literature WHERE bibtexkey='2994'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,1,2,2,3,3,4,4,5,5,6,6,7,7,8,8,9,9,10,10-henicosafluorohexacosane',
    'C<sub>26</sub>H<sub>33</sub>F<sub>21</sub>',
    '',
    '',
    'LZENXKBSJNMIKY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2,2,3,3,4,4,5,5,6,6,7,7,8,8,9,9,10,10-henicosafluorohexacosane'),
    (SELECT id from literature WHERE bibtexkey='2994'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,1,2,2,3,3,4,4,5,5,6,6,7,7,8,8,9,9,10,10,11,11,12,12-pentacosafluorohexacosane',
    'C<sub>26</sub>H<sub>29</sub>F<sub>25</sub>',
    '',
    '93454-73-0',
    'OUASUHCMZXPMCH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;13</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2,2,3,3,4,4,5,5,6,6,7,7,8,8,9,9,10,10,11,11,12,12-pentacosafluorohexacosane'),
    (SELECT id from literature WHERE bibtexkey='2994'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,1,2,2,3,3,4,4,5,5,6,6,7,7,8,8,9,9,10,10,11,11,12,12-pentacosafluorooctacosane',
    'C<sub>28</sub>H<sub>33</sub>F<sub>25</sub>',
    '',
    '93454-74-1',
    'CZCMNCOQMXNFTL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;14</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2,2,3,3,4,4,5,5,6,6,7,7,8,8,9,9,10,10,11,11,12,12-pentacosafluorooctacosane'),
    (SELECT id from literature WHERE bibtexkey='2994'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fluoroethene',
    'C<sub>2</sub>H<sub>3</sub>F',
    'vinyl fluoride',
    '75-02-5',
    'XUCNUKMRBVNAPB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fluoroethene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1-difluoroethene',
    'C<sub>2</sub>H<sub>2</sub>F<sub>2</sub>',
    '',
    '75-38-7',
    'BQCIDUSAKPWEOX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1-difluoroethene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,1-difluoroethene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-difluoroethene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-difluoroethene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-difluoroethene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-difluoroethene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-difluoroethene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1-difluoroethene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1-difluoroethene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'trifluoroethene',
    'C<sub>2</sub>HF<sub>3</sub>',
    '',
    '359-11-5',
    'MIZLGWKEZAPEFJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trifluoroethene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tetrafluoroethene',
    'C<sub>2</sub>F<sub>4</sub>',
    '',
    '116-14-3',
    'BFKJFAAPBSQJPD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '2100',
    'L',
    (SELECT id from species WHERE iupac='tetrafluoroethene'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tetrafluoroethene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='tetrafluoroethene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;6</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='tetrafluoroethene'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at303K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrafluoroethene'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrafluoroethene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrafluoroethene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrafluoroethene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2400',
    'Q',
    (SELECT id from species WHERE iupac='tetrafluoroethene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrafluoroethene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2100',
    '?',
    (SELECT id from species WHERE iupac='tetrafluoroethene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tetrafluoroethene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tetrafluoroethene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3,3-trifluoropropene',
    'C<sub>3</sub>H<sub>3</sub>F<sub>3</sub>',
    '',
    '677-21-4',
    'FDMFUZHCIRHGRG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,3-trifluoropropene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hexafluoropropene',
    'C<sub>3</sub>F<sub>6</sub>',
    '',
    '116-15-4',
    'HCDGVLDPFQMKDK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;6</sup>',
    '2400',
    'L',
    (SELECT id from species WHERE iupac='hexafluoropropene'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;6</sup>',
    '2600',
    'M',
    (SELECT id from species WHERE iupac='hexafluoropropene'),
    (SELECT id from literature WHERE bibtexkey='923'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0923-116-15-4-ABC',
    '923', 'The data from Maaßen (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;197.14327 +10473.25304/T +26.34780&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0923-116-15-4-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexafluoropropene'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexafluoropropene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexafluoropropene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2800',
    'Q',
    (SELECT id from species WHERE iupac='hexafluoropropene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2400',
    '?',
    (SELECT id from species WHERE iupac='hexafluoropropene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,3,3,3-pentafluoro-2-(trifluoromethyl)-1-propene',
    'C<sub>4</sub>F<sub>8</sub>',
    'perfluoroisobutylene',
    '382-21-8',
    'DAFIBNSJXIGBQB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,3,3,3-pentafluoro-2-(trifluoromethyl)-1-propene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(perfluorobutyl)ethene',
    'C<sub>6</sub>H<sub>3</sub>F<sub>9</sub>',
    '4:2 FTO',
    '19430-93-4',
    'GVEUEBXMTMZVSD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(perfluorobutyl)ethene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(perfluorobutyl)ethene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(perfluorobutyl)ethene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(perfluorobutyl)ethene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(perfluorobutyl)ethene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;6</sup>',
    '4100',
    'Q',
    (SELECT id from species WHERE iupac='(perfluorobutyl)ethene'),
    (SELECT id from literature WHERE bibtexkey='2993'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(E)-perfluoro(4-methyl-2-pentene)',
    'C<sub>6</sub>F<sub>12</sub>',
    '',
    '3709-71-5',
    'SAPOZTRFWJZUFT-OWOJBTEDSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;8</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(E)-perfluoro(4-methyl-2-pentene)'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(perfluorohexyl)ethene',
    'C<sub>8</sub>H<sub>3</sub>F<sub>13</sub>',
    '6:2 FTO',
    '25291-17-2',
    'FYQFWFHDPNXORA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '4900',
    'M',
    (SELECT id from species WHERE iupac='(perfluorohexyl)ethene'),
    (SELECT id from literature WHERE bibtexkey='3939'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;7</sup>',
    '4900',
    'Q',
    (SELECT id from species WHERE iupac='(perfluorohexyl)ethene'),
    (SELECT id from literature WHERE bibtexkey='2993'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(perfluorooctyl)ethene',
    'C<sub>10</sub>H<sub>3</sub>F<sub>17</sub>',
    '8:2 FTO',
    '21652-58-4',
    'NKAMGQZDVMQEJL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;7</sup>',
    '5700',
    'Q',
    (SELECT id from species WHERE iupac='(perfluorooctyl)ethene'),
    (SELECT id from literature WHERE bibtexkey='2993'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(perfluorodecyl)ethene',
    'C<sub>12</sub>H<sub>3</sub>F<sub>21</sub>',
    '10:2 FTO',
    '30389-25-4',
    'UCHSAVGOZUCXHC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;8</sup>',
    '6500',
    'Q',
    (SELECT id from species WHERE iupac='(perfluorodecyl)ethene'),
    (SELECT id from literature WHERE bibtexkey='2993'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,1,2,2,3,3,4,4,5,5,6,6,7,7,8,8,9,9,10,10,11,11,12,12-pentacosafluorooctacos-13-ene',
    'C<sub>28</sub>H<sub>31</sub>F<sub>25</sub>',
    '',
    '',
    'LBVDHZOJOFOXJM-FOCLMDBBSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2,2,3,3,4,4,5,5,6,6,7,7,8,8,9,9,10,10,11,11,12,12-pentacosafluorooctacos-13-ene'),
    (SELECT id from literature WHERE bibtexkey='2994'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fluorobenzene',
    'C<sub>6</sub>H<sub>5</sub>F',
    '',
    '462-06-6',
    'PYLWMHQQBFSUBP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '4100',
    'L',
    (SELECT id from species WHERE iupac='fluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='fluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '3900',
    'M',
    (SELECT id from species WHERE iupac='fluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '4300',
    'M',
    (SELECT id from species WHERE iupac='fluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1107'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='fluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2457'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '4400',
    'M',
    (SELECT id from species WHERE iupac='fluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='640'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='fluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2165'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='fluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='fluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='fluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3135'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3700',
    'Q',
    (SELECT id from species WHERE iupac='fluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3800',
    '?',
    (SELECT id from species WHERE iupac='fluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='637'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-difluorobenzene',
    'C<sub>6</sub>H<sub>4</sub>F<sub>2</sub>',
    'o-difluorobenzene',
    '367-11-3',
    'GOYDNIKZWGIXJT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '3700',
    'L',
    (SELECT id from species WHERE iupac='1,2-difluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '3500',
    'M',
    (SELECT id from species WHERE iupac='1,2-difluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2926'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,2-difluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-difluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-difluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-difluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-difluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-difluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-difluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-difluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3-difluorobenzene',
    'C<sub>6</sub>H<sub>4</sub>F<sub>2</sub>',
    'm-difluorobenzene',
    '372-18-9',
    'UEMGWPRHOOEKTA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-difluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-difluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-difluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,3-difluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,3-difluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4-difluorobenzene',
    'C<sub>6</sub>H<sub>4</sub>F<sub>2</sub>',
    'p-difluorobenzene',
    '540-36-3',
    'QUGUFLJIAFISSW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '3900',
    'M',
    (SELECT id from species WHERE iupac='1,4-difluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,4-difluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-difluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-difluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-difluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-difluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-difluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,4-difluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,4-difluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,5-tetrafluorobenzene',
    'C<sub>6</sub>H<sub>2</sub>F<sub>4</sub>',
    '',
    '2367-82-0',
    'UHHYOKRQTQBKSB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3,5-tetrafluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,5-tetrafluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,5-tetrafluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,5-tetrafluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4,5-tetrafluorobenzene',
    'C<sub>6</sub>H<sub>2</sub>F<sub>4</sub>',
    '',
    '327-54-8',
    'SDXUIOOHCIQXRP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,4,5-tetrafluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,5-tetrafluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,5-tetrafluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,5-tetrafluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pentafluorobenzene',
    'C<sub>6</sub>HF<sub>5</sub>',
    '',
    '363-72-4',
    'WACNXHCZHTVBJM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;4</sup>',
    '4800',
    'M',
    (SELECT id from species WHERE iupac='pentafluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hexafluorobenzene',
    'C<sub>6</sub>F<sub>6</sub>',
    '',
    '392-56-3',
    'ZQBFAOFFOQMSGJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;4</sup>',
    '5100',
    'L',
    (SELECT id from species WHERE iupac='hexafluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;4</sup>',
    '5200',
    'M',
    (SELECT id from species WHERE iupac='hexafluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='hexafluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3666'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexafluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3666'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3666-COSMO',
    '', 'Calculated using the COSMO-RS method.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3666-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(trifluoromethyl)-benzene',
    'C<sub>6</sub>H<sub>5</sub>CF<sub>3</sub>',
    '&#945;,&#945;,&#945;-trifluorotoluene; benzotrifluoride',
    '98-08-8',
    'GETTZEONDQJALK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(trifluoromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(trifluoromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(trifluoromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(trifluoromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='(trifluoromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(trifluoromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(trifluoromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(trifluoromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(trifluoromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(trifluoromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(trifluoromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(trifluoromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(trifluoromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(trifluoromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(trifluoromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(trifluoromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(trifluoromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(trifluoromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'decafluorobiphenyl',
    'C<sub>10</sub>F<sub>10</sub>',
    '',
    '434-90-2',
    'ONUFSRWQCKNVSL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;3</sup>',
    '3600',
    'M',
    (SELECT id from species WHERE iupac='decafluorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'carbonyl fluoride',
    'COF<sub>2</sub>',
    '',
    '353-50-4',
    'IYRWEQXVUNLMAY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='carbonyl fluoride'),
    (SELECT id from literature WHERE bibtexkey='671'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='carbonyl fluoride'),
    (SELECT id from literature WHERE bibtexkey='1125'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at278K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='carbonyl fluoride'),
    (SELECT id from literature WHERE bibtexkey='george93'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'from498',
    '498', 'Value given here as quoted by Kanakidou et&nbsp;al. (1995).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from498'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'formyl fluoride',
    'FCHO',
    '',
    '1493-02-3',
    'NHGVZTMBVDFPHJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='formyl fluoride'),
    (SELECT id from literature WHERE bibtexkey='498'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-fluoroethanol',
    'C<sub>2</sub>H<sub>5</sub>FO',
    '',
    '371-62-0',
    'GGDYAKVUZMZKRV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2-fluoroethanol'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2-fluoroethanol'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-fluoroethanol'),
    (SELECT id from literature WHERE bibtexkey='3526'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-fluoroethanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-fluoroethanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-fluoroethanol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-fluoroethanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-fluoroethanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-difluoroethanol',
    'C<sub>2</sub>H<sub>4</sub>F<sub>2</sub>O',
    '',
    '359-13-7',
    'VOGSDFLJZPNWHY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2,2-difluoroethanol'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2,2-difluoroethanol'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2-difluoroethanol'),
    (SELECT id from literature WHERE bibtexkey='3526'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,2-trifluoroethanol',
    'CF<sub>3</sub>CH<sub>2</sub>OH',
    '',
    '75-89-8',
    'RHQDFWAXVIIEBN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '6200',
    'L',
    (SELECT id from species WHERE iupac='2,2,2-trifluoroethanol'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '6200',
    'L',
    (SELECT id from species WHERE iupac='2,2,2-trifluoroethanol'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '6200',
    'L',
    (SELECT id from species WHERE iupac='2,2,2-trifluoroethanol'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '6200',
    'M',
    (SELECT id from species WHERE iupac='2,2,2-trifluoroethanol'),
    (SELECT id from literature WHERE bibtexkey='2808'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2,2-trifluoroethanol'),
    (SELECT id from literature WHERE bibtexkey='3402'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;1</sup>',
    '5900',
    'M',
    (SELECT id from species WHERE iupac='2,2,2-trifluoroethanol'),
    (SELECT id from literature WHERE bibtexkey='727'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,2-trifluoroethanol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,2-trifluoroethanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,2-trifluoroethanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,2-trifluoroethanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,2-trifluoroethanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,2-trifluoroethanol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,2-trifluoroethanol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,2-trifluoroethanol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,2-trifluoroethanol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,2-trifluoroethanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,2-trifluoroethanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6500',
    'Q',
    (SELECT id from species WHERE iupac='2,2,2-trifluoroethanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,2-trifluoroethanol'),
    (SELECT id from literature WHERE bibtexkey='3780'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3780_75-89-8',
    '1501,3780', 'Comparing with Abraham et&nbsp;al. (1994a), it seems that the compound called "trifluoroethanol" by Goss (2005) refers to 2,2,2-trifluoroethanol.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3780_75-89-8'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,2-trifluoroethanol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,2-trifluoroethanol'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,2-trifluoroethanol'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,2-trifluoroethanol'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2,2-trifluoroethanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5600',
    '?',
    (SELECT id from species WHERE iupac='2,2,2-trifluoroethanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2,2-trifluoroethanol'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,1-trifluoro-2-propanol',
    'CF<sub>3</sub>CHOHCH<sub>3</sub>',
    '',
    '374-01-6',
    'GILIYJDBJZWGBG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,1,1-trifluoro-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3402'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;1</sup>',
    '6300',
    'M',
    (SELECT id from species WHERE iupac='1,1,1-trifluoro-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='727'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1-trifluoro-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1-trifluoro-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1-trifluoro-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1-trifluoro-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1-trifluoro-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1-trifluoro-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1-trifluoro-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6900',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1-trifluoro-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1-trifluoro-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1,1-trifluoro-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6300',
    '?',
    (SELECT id from species WHERE iupac='1,1,1-trifluoro-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,3-tetrafluoro-1-propanol',
    'CHF<sub>2</sub>CF<sub>2</sub>CH<sub>2</sub>OH',
    '',
    '76-37-9',
    'NBUKAOOFKZFCGD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '7000',
    'L',
    (SELECT id from species WHERE iupac='2,2,3,3-tetrafluoro-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '7000',
    'L',
    (SELECT id from species WHERE iupac='2,2,3,3-tetrafluoro-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '7000',
    'L',
    (SELECT id from species WHERE iupac='2,2,3,3-tetrafluoro-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '7000',
    'M',
    (SELECT id from species WHERE iupac='2,2,3,3-tetrafluoro-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2808'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2,3,3-tetrafluoro-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3402'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '6700',
    'M',
    (SELECT id from species WHERE iupac='2,2,3,3-tetrafluoro-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='727'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3-tetrafluoro-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3-tetrafluoro-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3-tetrafluoro-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3-tetrafluoro-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3-tetrafluoro-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3-tetrafluoro-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3-tetrafluoro-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6900',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3-tetrafluoro-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3-tetrafluoro-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2,3,3-tetrafluoro-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6600',
    '?',
    (SELECT id from species WHERE iupac='2,2,3,3-tetrafluoro-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,3,3-pentafluoro-1-propanol',
    'CF<sub>3</sub>CF<sub>2</sub>CH<sub>2</sub>OH',
    '',
    '422-05-9',
    'PSQZJKGXDGNDFP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '4300',
    'L',
    (SELECT id from species WHERE iupac='2,2,3,3,3-pentafluoro-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '4300',
    'L',
    (SELECT id from species WHERE iupac='2,2,3,3,3-pentafluoro-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '4300',
    'L',
    (SELECT id from species WHERE iupac='2,2,3,3,3-pentafluoro-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '4300',
    'M',
    (SELECT id from species WHERE iupac='2,2,3,3,3-pentafluoro-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2808'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2,3,3,3-pentafluoro-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3402'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;1</sup>',
    '6000',
    'M',
    (SELECT id from species WHERE iupac='2,2,3,3,3-pentafluoro-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='727'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3,3-pentafluoro-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3,3-pentafluoro-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3,3-pentafluoro-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3,3-pentafluoro-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3,3-pentafluoro-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3,3-pentafluoro-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3,3-pentafluoro-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6800',
    'Q',
    (SELECT id from species WHERE iupac='2,2,3,3,3-pentafluoro-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2,3,3,3-pentafluoro-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6000',
    '?',
    (SELECT id from species WHERE iupac='2,2,3,3,3-pentafluoro-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,1,3,3,3-hexafluoro-2-propanol',
    'CF<sub>3</sub>CHOHCF<sub>3</sub>',
    '',
    '920-66-1',
    'BYEAHWXPCBROCE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,1,1,3,3,3-hexafluoro-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3402'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '6700',
    'M',
    (SELECT id from species WHERE iupac='1,1,1,3,3,3-hexafluoro-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='727'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,3,3,3-hexafluoro-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,3,3,3-hexafluoro-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,3,3,3-hexafluoro-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,3,3,3-hexafluoro-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,3,3,3-hexafluoro-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,3,3,3-hexafluoro-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,3,3,3-hexafluoro-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6800',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,3,3,3-hexafluoro-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,3,3,3-hexafluoro-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3780'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3780_920-66-1',
    '1501,3780', 'Comparing with Abraham et&nbsp;al. (1994a), it seems that the compound called "hexafluoropropanol" by Goss (2005) refers to 1,1,1,3,3,3-hexafluoro-2-propanol.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3780_920-66-1'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,3,3,3-hexafluoro-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1,1,3,3,3-hexafluoro-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6700',
    '?',
    (SELECT id from species WHERE iupac='1,1,1,3,3,3-hexafluoro-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1,1,3,3,3-hexafluoro-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'trifluoroacetylfluoride',
    'CF<sub>3</sub>COF',
    '',
    '354-34-7',
    'DCEPGADSNJKOJK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trifluoroacetylfluoride'),
    (SELECT id from literature WHERE bibtexkey='671'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trifluoroacetylfluoride'),
    (SELECT id from literature WHERE bibtexkey='1125'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at278K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trifluoroacetylfluoride'),
    (SELECT id from literature WHERE bibtexkey='1127'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'at284K',
    '', 'Value at T = 284&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at284K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trifluoroacetylfluoride'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trifluoroacetylfluoride'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='trifluoroacetylfluoride'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-fluoro-2-propanone',
    'CH<sub>2</sub>FCOCH<sub>3</sub>',
    'fluoroacetone',
    '430-51-3',
    'MSWVMWGCNZQPIA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-fluoro-2-propanone'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-fluoro-2-propanone'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-fluoro-2-propanone'),
    (SELECT id from literature WHERE bibtexkey='3526'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,1-trifluoro-2-propanone',
    'CF<sub>3</sub>COCH<sub>3</sub>',
    '1,1,1-trifluoroacetone',
    '421-50-1',
    'FHUDAMLDXFJHJE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '8900',
    'L',
    (SELECT id from species WHERE iupac='1,1,1-trifluoro-2-propanone'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '8900',
    'L',
    (SELECT id from species WHERE iupac='1,1,1-trifluoro-2-propanone'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '8900',
    'L',
    (SELECT id from species WHERE iupac='1,1,1-trifluoro-2-propanone'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '8900',
    'M',
    (SELECT id from species WHERE iupac='1,1,1-trifluoro-2-propanone'),
    (SELECT id from literature WHERE bibtexkey='495'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1-trifluoro-2-propanone'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1-trifluoro-2-propanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1-trifluoro-2-propanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1-trifluoro-2-propanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1-trifluoro-2-propanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1-trifluoro-2-propanone'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1,1-trifluoro-2-propanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1-difluoro-2-methoxyethane',
    'C<sub>3</sub>H<sub>6</sub>F<sub>2</sub>O',
    '',
    '461-57-4',
    'CRGZRXUKXVTRNO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1-difluoro-2-methoxyethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-difluoro-2-methoxyethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fluoroethanoic acid',
    'CH<sub>2</sub>FCOOH',
    'fluoroacetic acid',
    '144-49-0',
    'QEWYKACRFQMRMB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='fluoroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='fluoroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='fluoroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='fluoroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='896'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fluoroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fluoroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fluoroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fluoroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fluoroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fluoroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fluoroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'difluoroethanoic acid',
    'CHF<sub>2</sub>COOH',
    'difluoroacetic acid',
    '381-73-7',
    'PBWZKZYHONABLN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>2</sup>',
    '6900',
    'L',
    (SELECT id from species WHERE iupac='difluoroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>2</sup>',
    '6900',
    'L',
    (SELECT id from species WHERE iupac='difluoroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>2</sup>',
    '6900',
    'L',
    (SELECT id from species WHERE iupac='difluoroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>2</sup>',
    '6900',
    'M',
    (SELECT id from species WHERE iupac='difluoroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='896'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='difluoroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='difluoroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='difluoroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='difluoroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='difluoroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='difluoroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7700',
    'Q',
    (SELECT id from species WHERE iupac='difluoroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='difluoroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6900',
    '?',
    (SELECT id from species WHERE iupac='difluoroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'trifluoroethanoic acid',
    'CF<sub>3</sub>COOH',
    'trifluoroacetic acid',
    '76-05-1',
    'DTQVDTLACAAQTR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>1</sup>',
    '4100',
    'L',
    (SELECT id from species WHERE iupac='trifluoroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>1</sup>',
    '4100',
    'L',
    (SELECT id from species WHERE iupac='trifluoroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>1</sup>',
    '9300',
    'L',
    (SELECT id from species WHERE iupac='trifluoroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>1</sup>',
    '4100',
    'M',
    (SELECT id from species WHERE iupac='trifluoroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trifluoroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3940'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3940',
    '', 'Measured in aqueous hydrochloric acid and extrapolated to pure water as the solvent at 25&nbsp;<sup>&#176;</sup>C. Measurements were also made at other temperatures; however, those were not extrapolated to pure water as the solvent.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3940'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>1</sup>',
    '9300',
    'M',
    (SELECT id from species WHERE iupac='trifluoroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='619'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trifluoroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trifluoroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3939'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3939_EPI',
    '', 'Calculated using the EPI Suite Bond estimation method.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3939_EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trifluoroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trifluoroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trifluoroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trifluoroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trifluoroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trifluoroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trifluoroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trifluoroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trifluoroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trifluoroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7700',
    'Q',
    (SELECT id from species WHERE iupac='trifluoroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='trifluoroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '9400',
    '?',
    (SELECT id from species WHERE iupac='trifluoroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'perfluoropropanoic acid',
    'C<sub>3</sub>HF<sub>5</sub>O<sub>2</sub>',
    '',
    '422-64-0',
    'LRMSQVBRUNSOJL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8',
    '',
    'M',
    (SELECT id from species WHERE iupac='perfluoropropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3940'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3940'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='perfluoropropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3939'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3939_EPI'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'perfluorobutanoic acid',
    'C<sub>4</sub>HF<sub>7</sub>O<sub>2</sub>',
    '',
    '375-22-4',
    'YPJUNDFVDDCYIH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='perfluorobutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3940'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3940'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='perfluorobutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3939'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3939_EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='perfluorobutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='perfluorobutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='perfluorobutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='perfluorobutanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'perfluoropentanoic acid',
    'C<sub>5</sub>HF<sub>9</sub>O<sub>2</sub>',
    '',
    '2706-90-3',
    'CXZGQIAOTKWCDB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='perfluoropentanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3940'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3940'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='perfluoropentanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3939'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3939_EPI'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'perfluorohexanoic acid',
    'C<sub>6</sub>HF<sub>11</sub>O<sub>2</sub>',
    '',
    '307-24-4',
    'PXUULQAPEKKVAH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'M',
    (SELECT id from species WHERE iupac='perfluorohexanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3940'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3940'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='perfluorohexanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3939'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3939_EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='perfluorohexanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2992'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2992SPARC',
    '2992', 'Calculated using the new SPARC method; see Arp et&nbsp;al. (2006) for details.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2992SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='perfluorohexanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2992'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2992COSMO',
    '2992', 'Calculated using the COSMOtherm method; see Arp et&nbsp;al. (2006) for details.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2992COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'perfluoroheptanoic acid',
    'C<sub>7</sub>HF<sub>13</sub>O<sub>2</sub>',
    '',
    '375-85-9',
    'ZWBAMYVPMDSJGQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'M',
    (SELECT id from species WHERE iupac='perfluoroheptanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3940'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3940'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='perfluoroheptanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3939'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3939_EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='perfluoroheptanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='perfluoroheptanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='perfluoroheptanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='perfluoroheptanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='perfluoroheptanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2992'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2992SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='perfluoroheptanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2992'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2992COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pentadecafluorooctanoic acid',
    'C<sub>8</sub>HF<sub>15</sub>O<sub>2</sub>',
    'perfluorooctanoic acid; PFOA',
    '335-67-1',
    'SNGREZUHAYWORS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='pentadecafluorooctanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2816'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='pentadecafluorooctanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2566'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '',
    'M',
    (SELECT id from species WHERE iupac='pentadecafluorooctanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3940'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3940'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentadecafluorooctanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3939'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3939_EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentadecafluorooctanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentadecafluorooctanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentadecafluorooctanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentadecafluorooctanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentadecafluorooctanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentadecafluorooctanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentadecafluorooctanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentadecafluorooctanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentadecafluorooctanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2992'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2992SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentadecafluorooctanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2992'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2992COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'perfluorononanoic acid',
    'C<sub>9</sub>HF<sub>17</sub>O<sub>2</sub>',
    '',
    '375-95-1',
    'UZUFPBIDKMEQEQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='perfluorononanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2992'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2992SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='perfluorononanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2992'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2992COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2H,2H-perfluorodecanoic acid',
    'C<sub>10</sub>H<sub>3</sub>F<sub>17</sub>O<sub>2</sub>',
    '8:2 FTCA',
    '27854-31-5',
    'XTBXSCIWOVSSGB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2H,2H-perfluorodecanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3939'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'perfluorodecanoic acid',
    'C<sub>10</sub>HF<sub>19</sub>O<sub>2</sub>',
    '',
    '335-76-2',
    'PCIUEQPBYFRTEM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='perfluorodecanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2992'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2992SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='perfluorodecanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2992'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2992COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'perfluoroundecanoic acid',
    'C<sub>11</sub>HF<sub>21</sub>O<sub>2</sub>',
    '',
    '2058-94-8',
    'SIDINRCMMRKXGQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='perfluoroundecanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2992'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2992SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='perfluoroundecanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2992'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2992COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'perfluorododecanoic acid',
    'C<sub>12</sub>HF<sub>23</sub>O<sub>2</sub>',
    '',
    '307-55-1',
    'CXGONMQFMIYUJR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;3</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='perfluorododecanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2991'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'perfluorotetradecanoic acid',
    'C<sub>14</sub>HF<sub>27</sub>O<sub>2</sub>',
    '',
    '376-06-7',
    'RUDINRUXCKIXAJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='perfluorotetradecanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2991'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,1,3,3,3-hexafluoro-2-propanone',
    'C<sub>3</sub>F<sub>6</sub>O',
    '',
    '684-16-2',
    'VBZWSGALLODQNC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,3,3,3-hexafluoro-2-propanone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'desflurane',
    'C<sub>3</sub>H<sub>2</sub>F<sub>6</sub>O',
    '',
    '57041-67-5',
    'DPYMFVXJLLWWEU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='desflurane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='desflurane'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'sevoflurane',
    'C<sub>4</sub>H<sub>3</sub>F<sub>7</sub>O',
    '',
    '28523-86-6',
    'DFEYYRMXOJXZRJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='sevoflurane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='sevoflurane'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyl 2,2,2-trifluoroethyl ether',
    'C<sub>4</sub>H<sub>7</sub>F<sub>3</sub>O',
    '',
    '461-24-5',
    'ZKNHDJMXIUOHLX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl 2,2,2-trifluoroethyl ether'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'iso-indoklon',
    'C<sub>4</sub>H<sub>4</sub>F<sub>6</sub>O',
    '1,1,1,3,3,3-hexafluoro-2-methoxypropane',
    '13171-18-1',
    'VNXYDFNVQBICRO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='iso-indoklon'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'di(2,2,2-trifluoroethyl) ether',
    'C<sub>4</sub>H<sub>4</sub>F<sub>6</sub>O',
    'flurothyl',
    '333-36-8',
    'KGPPDNUWZNWPSI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;3</sup>',
    '-390',
    'V',
    (SELECT id from species WHERE iupac='di(2,2,2-trifluoroethyl) ether'),
    (SELECT id from literature WHERE bibtexkey='3693'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HTdep_r2_lessthan_0.9'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='di(2,2,2-trifluoroethyl) ether'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(2,2,2-trifluoroethoxy)-ethene',
    'CF<sub>3</sub>CH<sub>2</sub>OCHCH<sub>2</sub>',
    'fluoroxene; fluroxene',
    '406-90-6',
    'DLEGDLSLRSOURQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;4</sup>',
    '4000',
    'L',
    (SELECT id from species WHERE iupac='(2,2,2-trifluoroethoxy)-ethene'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='(2,2,2-trifluoroethoxy)-ethene'),
    (SELECT id from literature WHERE bibtexkey='2441'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;4</sup>',
    '4000',
    'L',
    (SELECT id from species WHERE iupac='(2,2,2-trifluoroethoxy)-ethene'),
    (SELECT id from literature WHERE bibtexkey='3696'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;4</sup>',
    '4300',
    'M',
    (SELECT id from species WHERE iupac='(2,2,2-trifluoroethoxy)-ethene'),
    (SELECT id from literature WHERE bibtexkey='2445'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='(2,2,2-trifluoroethoxy)-ethene'),
    (SELECT id from literature WHERE bibtexkey='2467'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='(2,2,2-trifluoroethoxy)-ethene'),
    (SELECT id from literature WHERE bibtexkey='2446'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2,2,2-trifluoroethoxy)-ethene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(2,2,2-trifluoroethoxy)-ethene'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(2,2,2-trifluoroethoxy)-ethene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,2-trifluoroethyl methanoate',
    'HCOOCH<sub>2</sub>CF<sub>3</sub>',
    '',
    '32042-38-9',
    'CAFROQYMUICGNO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;3</sup>',
    '4700',
    'L',
    (SELECT id from species WHERE iupac='2,2,2-trifluoroethyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;3</sup>',
    '4700',
    'L',
    (SELECT id from species WHERE iupac='2,2,2-trifluoroethyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;3</sup>',
    '4700',
    'L',
    (SELECT id from species WHERE iupac='2,2,2-trifluoroethyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;3</sup>',
    '4700',
    'M',
    (SELECT id from species WHERE iupac='2,2,2-trifluoroethyl methanoate'),
    (SELECT id from literature WHERE bibtexkey='2802'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,2-trifluoroethyl ethanoate',
    'CH<sub>3</sub>COOCH<sub>2</sub>CF<sub>3</sub>',
    '',
    '406-95-1',
    'ZOWSJJBOQDKOHI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;3</sup>',
    '5200',
    'L',
    (SELECT id from species WHERE iupac='2,2,2-trifluoroethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3500-406-95-1',
    '', 'A refit yields A = &#8722;18.99, B = 5493, and H(298&nbsp;K) = 0.57&nbsp;M&nbsp;atm<sup>&#8722;1</sup> (Robert E.&nbsp;Huie, personal communication, 2021).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3500-406-95-1'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;3</sup>',
    '5200',
    'L',
    (SELECT id from species WHERE iupac='2,2,2-trifluoroethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3245-406-95-1',
    '', 'A refit yields A = &#8722;18.99, B = 5493, and H(298&nbsp;K) = 0.57&nbsp;M&nbsp;atm<sup>&#8722;1</sup> (Robert E.&nbsp;Huie, personal communication, 2021).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3245-406-95-1'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;3</sup>',
    '5200',
    'L',
    (SELECT id from species WHERE iupac='2,2,2-trifluoroethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;3</sup>',
    '5300',
    'M',
    (SELECT id from species WHERE iupac='2,2,2-trifluoroethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='2803'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6400',
    'Q',
    (SELECT id from species WHERE iupac='2,2,2-trifluoroethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5500',
    '?',
    (SELECT id from species WHERE iupac='2,2,2-trifluoroethyl ethanoate'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'trifluoroethanoic acid, methyl ester',
    'CF<sub>3</sub>COOCH<sub>3</sub>',
    'methyl trifluoroacetate',
    '431-47-0',
    'VMVNZNXAVJHNDJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '5300',
    'L',
    (SELECT id from species WHERE iupac='trifluoroethanoic acid, methyl ester'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3500-431-47-0',
    '', 'A refit yields A = &#8722;21.67, B = 5776, and H(298&nbsp;K) = 0.10&nbsp;M&nbsp;atm<sup>&#8722;1</sup> (Robert E.&nbsp;Huie, personal communication, 2021).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3500-431-47-0'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3500-431-47-0-consicheck',
    '3500', 'The H298 and A, B data listed in Table&nbsp;5-4 of Burkholder et&nbsp;al. (2019) are inconsistent, with 29&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3500-431-47-0-consicheck'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '5300',
    'L',
    (SELECT id from species WHERE iupac='trifluoroethanoic acid, methyl ester'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3245-431-47-0',
    '', 'A refit yields A = &#8722;21.67, B = 5776, and H(298&nbsp;K) = 0.10&nbsp;M&nbsp;atm<sup>&#8722;1</sup> (Robert E.&nbsp;Huie, personal communication, 2021).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3245-431-47-0'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3245-431-47-0-consicheck',
    '3245', 'The H298 and A, B data listed in Table&nbsp;5-4 of Burkholder et&nbsp;al. (2015) are inconsistent, with 29&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3245-431-47-0-consicheck'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '5300',
    'L',
    (SELECT id from species WHERE iupac='trifluoroethanoic acid, methyl ester'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2626-431-47-0-consicheck',
    '2626', 'The H298 and A, B data listed in Table&nbsp;5.4 of Sander et&nbsp;al. (2011) are inconsistent, with 29&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2626-431-47-0-consicheck'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '4900',
    'M',
    (SELECT id from species WHERE iupac='trifluoroethanoic acid, methyl ester'),
    (SELECT id from literature WHERE bibtexkey='2803'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6100',
    'Q',
    (SELECT id from species WHERE iupac='trifluoroethanoic acid, methyl ester'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5800',
    '?',
    (SELECT id from species WHERE iupac='trifluoroethanoic acid, methyl ester'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'trifluoroethanoic acid, ethyl ester',
    'CF<sub>3</sub>COOC<sub>2</sub>H<sub>5</sub>',
    'ethyl trifluoroacetate',
    '383-63-1',
    'STSCVKRWJPWALQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;4</sup>',
    '4900',
    'L',
    (SELECT id from species WHERE iupac='trifluoroethanoic acid, ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;4</sup>',
    '4900',
    'L',
    (SELECT id from species WHERE iupac='trifluoroethanoic acid, ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;4</sup>',
    '4900',
    'L',
    (SELECT id from species WHERE iupac='trifluoroethanoic acid, ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;4</sup>',
    '4900',
    'M',
    (SELECT id from species WHERE iupac='trifluoroethanoic acid, ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3507'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;4</sup>',
    '4900',
    'M',
    (SELECT id from species WHERE iupac='trifluoroethanoic acid, ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2802'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'trifluoro(trifluoromethyl)-oxirane',
    'C<sub>3</sub>F<sub>6</sub>O',
    '',
    '428-59-1',
    'PGFXOWRDDHCDTE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;6</sup>',
    '2400',
    'C',
    (SELECT id from species WHERE iupac='trifluoro(trifluoromethyl)-oxirane'),
    (SELECT id from literature WHERE bibtexkey='2447'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2447-428-59-1-ABC',
    '2447', 'The data from Clever et&nbsp;al. (2005) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( 289.52696 &#8722;11352.27202/T &#8722;46.16631&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2447-428-59-1-ABC'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2447-428-59-1',
    '2447', 'The Ostwald coefficient given by Clever et&nbsp;al. (2005) at 313.2&nbsp;K is probably incorrect. Therefore, the Ostwald coefficients are not used. Instead, H<sub>s</sub> is calculated using the amount fraction x<sub>1</sub> from the same table.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2447-428-59-1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3,4,4,4-pentafluorobutan-1-ol',
    'C<sub>4</sub>H<sub>5</sub>OF<sub>5</sub>',
    '',
    '54949-74-5',
    'JPMHUDBOKDBBLG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4,4-pentafluorobutan-1-ol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4,4-pentafluorobutan-1-ol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4,4-pentafluorobutan-1-ol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4,4-pentafluorobutan-1-ol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,1,3,3,3-hexafluoro-2-methyl-2-propanol',
    'C<sub>4</sub>H<sub>4</sub>F<sub>6</sub>O',
    '',
    '1515-14-6',
    'FQDXJYBXPOMIBX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,1,1,3,3,3-hexafluoro-2-methyl-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3402'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,4,4,4-hexafluoro-1-butanol',
    'C<sub>4</sub>H<sub>4</sub>F<sub>6</sub>O',
    '',
    '382-31-0',
    'LVFXLZRISXUAIL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2,3,4,4,4-hexafluoro-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3402'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,3,4,4,4-heptafluoro-1-butanol',
    'C<sub>4</sub>H<sub>3</sub>F<sub>7</sub>O',
    '',
    '375-01-9',
    'WXJFKAZDSQLPBX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2,3,3,4,4,4-heptafluoro-1-butanol'),
    (SELECT id from literature WHERE bibtexkey='3402'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3,4,4,5,5,5-heptafluoro-2-pentanol',
    'C<sub>5</sub>H<sub>5</sub>F<sub>7</sub>O',
    '',
    '375-14-4',
    'RBPHBIMHZSTIDT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3,3,4,4,5,5,5-heptafluoro-2-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3402'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,3,4,4,5,5-octafluoro-1-pentanol',
    'C<sub>5</sub>H<sub>4</sub>F<sub>8</sub>O',
    '',
    '355-80-6',
    'JUGSKHLZINSXPQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2,3,3,4,4,5,5-octafluoro-1-pentanol'),
    (SELECT id from literature WHERE bibtexkey='3402'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,1,2,2,3,3,4,4-nonafluoro-4-methoxybutane',
    'C<sub>5</sub>H<sub>3</sub>F<sub>9</sub>O',
    '',
    '163702-07-6',
    'OKIYQFLILPKULA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2,2,3,3,4,4-nonafluoro-4-methoxybutane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2,2,3,3,4,4-nonafluoro-4-methoxybutane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2,2,3,3,4,4-nonafluoro-4-methoxybutane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2,2,3,3,4,4-nonafluoro-4-methoxybutane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-ethoxy-1,1,2,3,3,3-hexafluoro-2-(trifluoromethyl)propane',
    'C<sub>6</sub>H<sub>5</sub>F<sub>9</sub>O',
    '',
    '163702-06-5',
    'SQEGLLMNIBLLNQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethoxy-1,1,2,3,3,3-hexafluoro-2-(trifluoromethyl)propane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethoxy-1,1,2,3,3,3-hexafluoro-2-(trifluoromethyl)propane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethoxy-1,1,2,3,3,3-hexafluoro-2-(trifluoromethyl)propane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethoxy-1,1,2,3,3,3-hexafluoro-2-(trifluoromethyl)propane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1H,1H,2H,2H-perfluorohexan-1-ol',
    'C<sub>6</sub>H<sub>5</sub>F<sub>9</sub>O',
    '4:2 FTOH',
    '2043-47-2',
    'JCMNMOBHVPONLD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1H,1H,2H,2H-perfluorohexan-1-ol'),
    (SELECT id from literature WHERE bibtexkey='3939'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;3</sup>',
    '4500',
    'M',
    (SELECT id from species WHERE iupac='1H,1H,2H,2H-perfluorohexan-1-ol'),
    (SELECT id from literature WHERE bibtexkey='3013'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1H,1H,2H,2H-perfluorohexan-1-ol'),
    (SELECT id from literature WHERE bibtexkey='2993'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;5</sup>',
    '5400',
    'M',
    (SELECT id from species WHERE iupac='1H,1H,2H,2H-perfluorohexan-1-ol'),
    (SELECT id from literature WHERE bibtexkey='2996'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2996'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1H,1H,2H,2H-perfluorohexan-1-ol'),
    (SELECT id from literature WHERE bibtexkey='3013'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1H,1H,2H,2H-perfluorohexan-1-ol'),
    (SELECT id from literature WHERE bibtexkey='3939'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3939_EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1H,1H,2H,2H-perfluorohexan-1-ol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1H,1H,2H,2H-perfluorohexan-1-ol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1H,1H,2H,2H-perfluorohexan-1-ol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1H,1H,2H,2H-perfluorohexan-1-ol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1H,1H,2H,2H-perfluorohexan-1-ol'),
    (SELECT id from literature WHERE bibtexkey='2992'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2992SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1H,1H,2H,2H-perfluorohexan-1-ol'),
    (SELECT id from literature WHERE bibtexkey='2992'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2992COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;3</sup>',
    '7200',
    'Q',
    (SELECT id from species WHERE iupac='1H,1H,2H,2H-perfluorohexan-1-ol'),
    (SELECT id from literature WHERE bibtexkey='2993'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,3,4,4,5,5,6,6,6-undecafluoro-1-hexanol',
    'C<sub>6</sub>H<sub>3</sub>F<sub>11</sub>O',
    '',
    '423-46-1',
    'QZFZPVVDBGXQTB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2,3,3,4,4,5,5,6,6,6-undecafluoro-1-hexanol'),
    (SELECT id from literature WHERE bibtexkey='3402'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-ethoxy-1,1,2,2,3,3,4,4,4-nonafluorobutane',
    'C<sub>6</sub>H<sub>5</sub>F<sub>9</sub>O',
    '',
    '163702-05-4',
    'DFUYAWQUODQGFF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethoxy-1,1,2,2,3,3,4,4,4-nonafluorobutane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethoxy-1,1,2,2,3,3,4,4,4-nonafluorobutane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethoxy-1,1,2,2,3,3,4,4,4-nonafluorobutane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-ethoxy-1,1,2,2,3,3,4,4,4-nonafluorobutane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,3,4,4,5,5,6,6,7,7-dodecafluoro-1-heptanol',
    'C<sub>7</sub>H<sub>4</sub>F<sub>12</sub>O',
    '',
    '335-99-9',
    'BYKNGMLDSIEFFG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2,3,3,4,4,5,5,6,6,7,7-dodecafluoro-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3402'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,3,4,4,5,5,6,6,7,7,7-tridecafluoro-1-heptanol',
    'C<sub>7</sub>H<sub>3</sub>F<sub>13</sub>O',
    '',
    '375-82-6',
    'STLNAVFVCIRZLL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2,3,3,4,4,5,5,6,6,7,7,7-tridecafluoro-1-heptanol'),
    (SELECT id from literature WHERE bibtexkey='3402'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1H,1H,2H,2H-perfluoro-1-octanol',
    'C<sub>8</sub>H<sub>5</sub>F<sub>13</sub>O',
    '6:2 FTOH',
    '647-42-7',
    'GRJRKPMIRMSBNK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;4</sup>',
    '4700',
    'M',
    (SELECT id from species WHERE iupac='1H,1H,2H,2H-perfluoro-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='3939'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;4</sup>',
    '2600',
    'M',
    (SELECT id from species WHERE iupac='1H,1H,2H,2H-perfluoro-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='3013'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1H,1H,2H,2H-perfluoro-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='2993'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;5</sup>',
    '7000',
    'M',
    (SELECT id from species WHERE iupac='1H,1H,2H,2H-perfluoro-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='2996'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2996'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1H,1H,2H,2H-perfluoro-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='3402'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1H,1H,2H,2H-perfluoro-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='3013'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1H,1H,2H,2H-perfluoro-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='3939'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3939_EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1H,1H,2H,2H-perfluoro-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1H,1H,2H,2H-perfluoro-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1H,1H,2H,2H-perfluoro-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1H,1H,2H,2H-perfluoro-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1H,1H,2H,2H-perfluoro-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='2992'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2992SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1H,1H,2H,2H-perfluoro-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='2992'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2992COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '8000',
    'Q',
    (SELECT id from species WHERE iupac='1H,1H,2H,2H-perfluoro-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='2993'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,3,3,4,4,5,5,6,6,7,7,8,8,8-pentadecafluoro-1-octanol',
    'C<sub>8</sub>H<sub>3</sub>F<sub>15</sub>O',
    '',
    '307-30-2',
    'PJDOLCGOTSNFJM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2,3,3,4,4,5,5,6,6,7,7,8,8,8-pentadecafluoro-1-octanol'),
    (SELECT id from literature WHERE bibtexkey='3402'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethoxyperfluoro(2-methylhexane)',
    'C<sub>9</sub>H<sub>5</sub>F<sub>15</sub>O',
    '',
    '297730-93-9',
    'HHBBIOLEJRWIGU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;8</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-ethoxyperfluoro(2-methylhexane)'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl perfluoro(8-(fluoroformyl)-5-methyl-4,7-dioxanonanoate)',
    'C<sub>10</sub>H<sub>3</sub>F<sub>15</sub>O<sub>5</sub>',
    '',
    '69116-73-0',
    'JOMJXRTUQWIHQD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl perfluoro(8-(fluoroformyl)-5-methyl-4,7-dioxanonanoate)'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl perfluoro(8-(fluoroformyl)-5-methyl-4,7-dioxanonanoate)'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl perfluoro(8-(fluoroformyl)-5-methyl-4,7-dioxanonanoate)'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl perfluoro(8-(fluoroformyl)-5-methyl-4,7-dioxanonanoate)'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3,4,4,5,5,6,6,6-nonafluorohexyl methacrylate',
    'C<sub>10</sub>H<sub>9</sub>F<sub>9</sub>O<sub>2</sub>',
    '',
    '1799-84-4',
    'TYNRPOFACABVSI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4,5,5,6,6,6-nonafluorohexyl methacrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4,5,5,6,6,6-nonafluorohexyl methacrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4,5,5,6,6,6-nonafluorohexyl methacrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4,5,5,6,6,6-nonafluorohexyl methacrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1H,1H,2H,2H-perfluorodecan-1-ol',
    'C<sub>10</sub>H<sub>5</sub>F<sub>17</sub>O',
    '8:2 FTOH',
    '678-39-7',
    'JJUBFBTUBACDHW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1H,1H,2H,2H-perfluorodecan-1-ol'),
    (SELECT id from literature WHERE bibtexkey='3939'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;4</sup>',
    '3100',
    'M',
    (SELECT id from species WHERE iupac='1H,1H,2H,2H-perfluorodecan-1-ol'),
    (SELECT id from literature WHERE bibtexkey='3013'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;4</sup>',
    '8800',
    'M',
    (SELECT id from species WHERE iupac='1H,1H,2H,2H-perfluorodecan-1-ol'),
    (SELECT id from literature WHERE bibtexkey='2996'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2996'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1H,1H,2H,2H-perfluorodecan-1-ol'),
    (SELECT id from literature WHERE bibtexkey='3013'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1H,1H,2H,2H-perfluorodecan-1-ol'),
    (SELECT id from literature WHERE bibtexkey='2993'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1H,1H,2H,2H-perfluorodecan-1-ol'),
    (SELECT id from literature WHERE bibtexkey='3939'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3939_EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1H,1H,2H,2H-perfluorodecan-1-ol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1H,1H,2H,2H-perfluorodecan-1-ol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1H,1H,2H,2H-perfluorodecan-1-ol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1H,1H,2H,2H-perfluorodecan-1-ol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1H,1H,2H,2H-perfluorodecan-1-ol'),
    (SELECT id from literature WHERE bibtexkey='2992'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2992SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1H,1H,2H,2H-perfluorodecan-1-ol'),
    (SELECT id from literature WHERE bibtexkey='2992'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2992COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;4</sup>',
    '8600',
    'Q',
    (SELECT id from species WHERE iupac='1H,1H,2H,2H-perfluorodecan-1-ol'),
    (SELECT id from literature WHERE bibtexkey='2993'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methoxyperfluoro(2,5-di(propan-2-yl)oxolane)',
    'C<sub>11</sub>H<sub>3</sub>F<sub>19</sub>O<sub>2</sub>',
    '',
    '957209-18-6',
    'YRGYOFYTTFLPQM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;8</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methoxyperfluoro(2,5-di(propan-2-yl)oxolane)'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3,4,4,5,5,6,6,7,7,8,8,8-tridecafluorooctyl acrylate',
    'C<sub>11</sub>H<sub>7</sub>F<sub>13</sub>O<sub>2</sub>',
    '',
    '17527-29-6',
    'VPKQPPJQTZJZDB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4,5,5,6,6,7,7,8,8,8-tridecafluorooctyl acrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4,5,5,6,6,7,7,8,8,8-tridecafluorooctyl acrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4,5,5,6,6,7,7,8,8,8-tridecafluorooctyl acrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4,5,5,6,6,7,7,8,8,8-tridecafluorooctyl acrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-(perfluorohexyl)ethyl methacrylate',
    'C<sub>12</sub>H<sub>9</sub>F<sub>13</sub>O<sub>2</sub>',
    '',
    '2144-53-8',
    'CDXFIRXEAJABAZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(perfluorohexyl)ethyl methacrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(perfluorohexyl)ethyl methacrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(perfluorohexyl)ethyl methacrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(perfluorohexyl)ethyl methacrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,2,2-tetrahydroperfluoro dodecanol',
    'C<sub>12</sub>H<sub>5</sub>F<sub>21</sub>O',
    '10:2 FTOH',
    '865-86-1',
    'FLXYIZWPNQYPIT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrahydroperfluoro dodecanol'),
    (SELECT id from literature WHERE bibtexkey='3939'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '2700',
    'M',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrahydroperfluoro dodecanol'),
    (SELECT id from literature WHERE bibtexkey='3013'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrahydroperfluoro dodecanol'),
    (SELECT id from literature WHERE bibtexkey='3013'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrahydroperfluoro dodecanol'),
    (SELECT id from literature WHERE bibtexkey='3939'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3939_EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrahydroperfluoro dodecanol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrahydroperfluoro dodecanol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrahydroperfluoro dodecanol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrahydroperfluoro dodecanol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrahydroperfluoro dodecanol'),
    (SELECT id from literature WHERE bibtexkey='2992'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2992SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrahydroperfluoro dodecanol'),
    (SELECT id from literature WHERE bibtexkey='2992'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2992COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;4</sup>',
    '9600',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrahydroperfluoro dodecanol'),
    (SELECT id from literature WHERE bibtexkey='2993'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;5</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrahydroperfluoro dodecanol'),
    (SELECT id from literature WHERE bibtexkey='2992'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2992',
    '', 'Extrapolated based on number of carbons.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2992'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3,4,4,5,5,6,6,7,7,8,8,9,9,10,10,10-heptadecafluorodecyl acrylate',
    'C<sub>13</sub>H<sub>7</sub>F<sub>17</sub>O<sub>2</sub>',
    '',
    '27905-45-9',
    'QUKRIOLKOHUUBM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3,3,4,4,5,5,6,6,7,7,8,8,9,9,10,10,10-heptadecafluorodecyl acrylate'),
    (SELECT id from literature WHERE bibtexkey='3939'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4,5,5,6,6,7,7,8,8,9,9,10,10,10-heptadecafluorodecyl acrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4,5,5,6,6,7,7,8,8,9,9,10,10,10-heptadecafluorodecyl acrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4,5,5,6,6,7,7,8,8,9,9,10,10,10-heptadecafluorodecyl acrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4,5,5,6,6,7,7,8,8,9,9,10,10,10-heptadecafluorodecyl acrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3,4,4,5,5,6,6,7,7,8,8,9,9,10,10,10-heptadecafluorodecyl methacrylate',
    'C<sub>14</sub>H<sub>9</sub>F<sub>17</sub>O<sub>2</sub>',
    '',
    '1996-88-9',
    'HBZFBSFGXQBQTB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4,5,5,6,6,7,7,8,8,9,9,10,10,10-heptadecafluorodecyl methacrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4,5,5,6,6,7,7,8,8,9,9,10,10,10-heptadecafluorodecyl methacrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4,5,5,6,6,7,7,8,8,9,9,10,10,10-heptadecafluorodecyl methacrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4,5,5,6,6,7,7,8,8,9,9,10,10,10-heptadecafluorodecyl methacrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3,4,4,5,5,6,6,7,7,8,8,9,9,10,10,11,11,12,12,13,13,14,14,14-pentacosafluorotetradecan-1-ol',
    'C<sub>14</sub>H<sub>5</sub>F<sub>25</sub>O',
    '',
    '39239-77-5',
    'QBBJBWKVSJWYQK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4,5,5,6,6,7,7,8,8,9,9,10,10,11,11,12,12,13,13,14,14,14-pentacosafluorotetradecan-1-ol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4,5,5,6,6,7,7,8,8,9,9,10,10,11,11,12,12,13,13,14,14,14-pentacosafluorotetradecan-1-ol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4,5,5,6,6,7,7,8,8,9,9,10,10,11,11,12,12,13,13,14,14,14-pentacosafluorotetradecan-1-ol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4,5,5,6,6,7,7,8,8,9,9,10,10,11,11,12,12,13,13,14,14,14-pentacosafluorotetradecan-1-ol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-(perfluorodecyl)ethyl acrylate',
    'C<sub>15</sub>H<sub>7</sub>F<sub>21</sub>O<sub>2</sub>',
    '',
    '17741-60-5',
    'FIAHOPQKBBASOY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(perfluorodecyl)ethyl acrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(perfluorodecyl)ethyl acrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(perfluorodecyl)ethyl acrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(perfluorodecyl)ethyl acrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,2,2-tetrahydroperfluoro-1-hexadecanol',
    'C<sub>16</sub>H<sub>5</sub>OF<sub>29</sub>',
    '',
    '60699-51-6',
    'ZDUOTHMDVYXZBS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrahydroperfluoro-1-hexadecanol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrahydroperfluoro-1-hexadecanol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrahydroperfluoro-1-hexadecanol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrahydroperfluoro-1-hexadecanol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-(perfluorodecyl)ethyl methacrylate',
    'C<sub>16</sub>H<sub>9</sub>F<sub>21</sub>O<sub>2</sub>',
    '',
    '2144-54-9',
    'FQHLOOOXLDQLPF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(perfluorodecyl)ethyl methacrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(perfluorodecyl)ethyl methacrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(perfluorodecyl)ethyl methacrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(perfluorodecyl)ethyl methacrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3,4,4,5,5,6,6,7,7,8,8,9,9,10,10,11,11,12,12,13,13,14,14,14-pentacosafluorotetradecyl prop-2-enoate',
    'C<sub>17</sub>H<sub>7</sub>F<sub>25</sub>O<sub>2</sub>',
    '',
    '34395-24-9',
    'SWTZSHBOMGAQKX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4,5,5,6,6,7,7,8,8,9,9,10,10,11,11,12,12,13,13,14,14,14-pentacosafluorotetradecyl prop-2-enoate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4,5,5,6,6,7,7,8,8,9,9,10,10,11,11,12,12,13,13,14,14,14-pentacosafluorotetradecyl prop-2-enoate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4,5,5,6,6,7,7,8,8,9,9,10,10,11,11,12,12,13,13,14,14,14-pentacosafluorotetradecyl prop-2-enoate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4,5,5,6,6,7,7,8,8,9,9,10,10,11,11,12,12,13,13,14,14,14-pentacosafluorotetradecyl prop-2-enoate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'profluthrin',
    'C<sub>17</sub>H<sub>18</sub>F<sub>4</sub>O<sub>2</sub>',
    '',
    '223419-20-3',
    'AGMMRUPNXPWLGF-AATRIKPKSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='profluthrin'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-perfluorododecylethyl methacrylate',
    'C<sub>18</sub>H<sub>9</sub>F<sub>25</sub>O<sub>2</sub>',
    '',
    '6014-75-1',
    'LFEGLDRNIDJMKB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-perfluorododecylethyl methacrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-perfluorododecylethyl methacrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-perfluorododecylethyl methacrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-perfluorododecylethyl methacrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,2,2-tetrahydroperfluoro-1-octadecanol',
    'C<sub>18</sub>H<sub>5</sub>OF<sub>33</sub>',
    '',
    '65104-67-8',
    'UYSGWTCETIRUHO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;12</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrahydroperfluoro-1-octadecanol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;15</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrahydroperfluoro-1-octadecanol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrahydroperfluoro-1-octadecanol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;12</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrahydroperfluoro-1-octadecanol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'metofluthrin',
    'C<sub>18</sub>H<sub>20</sub>F<sub>4</sub>O<sub>3</sub>',
    '',
    '240494-70-6',
    'KVIZNNVXXNFLMU-AATRIKPKSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'V',
    (SELECT id from species WHERE iupac='metofluthrin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,2,2-tetrahydroperfluorohexadecyl acrylate',
    'C<sub>19</sub>H<sub>7</sub>F29O<sub>2</sub>',
    '',
    '34362-49-7',
    'KLOHTAIHCCMZIL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;12</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrahydroperfluorohexadecyl acrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrahydroperfluorohexadecyl acrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrahydroperfluorohexadecyl acrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;12</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrahydroperfluorohexadecyl acrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fluoxymesterone',
    'C<sub>20</sub>H<sub>29</sub>FO<sub>3</sub>',
    '',
    '76-43-7',
    'YLRFCQOZQXIBAB-YXVJBPKESA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fluoxymesterone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dexamethasone',
    'C<sub>22</sub>H<sub>29</sub>FO<sub>5</sub>',
    '',
    '50-02-2',
    'UREBDLICKHMUKA-GCMAGEFQSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dexamethasone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,2,2-tetrahydroperfluoroeicosyl alcohol',
    'C<sub>20</sub>H<sub>5</sub>OF<sub>37</sub>',
    '',
    '65104-65-6',
    'FDCQNVKWWMNRQN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;13</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrahydroperfluoroeicosyl alcohol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;18</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrahydroperfluoroeicosyl alcohol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrahydroperfluoroeicosyl alcohol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;14</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrahydroperfluoroeicosyl alcohol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-hydroxyfluorobenzene',
    'C<sub>6</sub>H<sub>5</sub>FO',
    'o-fluorophenol',
    '367-12-4',
    'HFHFGHLXUCOHLN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '',
    'R',
    (SELECT id from species WHERE iupac='2-hydroxyfluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxyfluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxyfluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxyfluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxyfluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxyfluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxyfluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-hydroxyfluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-hydroxyfluorobenzene',
    'C<sub>6</sub>H<sub>5</sub>FO',
    'p-fluorophenol',
    '371-41-5',
    'RHMPLDJJXGPMEX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='4-hydroxyfluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-hydroxyfluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-hydroxyfluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-hydroxyfluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-hydroxyfluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-hydroxyfluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-hydroxyfluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-hydroxyfluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-hydroxyfluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-fluorophenol',
    'C<sub>6</sub>H<sub>5</sub>FO',
    '',
    '372-20-3',
    'SJTBRFHBXDZMPS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-fluorophenol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6-difluorophenol',
    'C<sub>6</sub>H<sub>4</sub>F<sub>2</sub>O',
    '',
    '28177-48-2',
    'CKKOVFGIBXCEIJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-difluorophenol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,4''-(hexafluoroisopropylidene)diphenol',
    'C<sub>15</sub>H<sub>10</sub>F<sub>6</sub>O<sub>2</sub>',
    '',
    '1478-61-1',
    'ZFVMWEVVKGLCIJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4''-(hexafluoroisopropylidene)diphenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4''-(hexafluoroisopropylidene)diphenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4''-(hexafluoroisopropylidene)diphenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4''-(hexafluoroisopropylidene)diphenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4''-(hexafluoroisopropylidene)diphenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'flocoumafen',
    'C<sub>33</sub>H<sub>25</sub>F<sub>3</sub>O<sub>4</sub>',
    '',
    '90035-08-8',
    'KKBGNYHHEIAGOH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='flocoumafen'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3,3-tetrafluoro-2-(trifluoromethyl)propanenitrile',
    'C<sub>4</sub>F<sub>7</sub>N',
    '',
    '42532-60-5',
    'AASDJASZOZGYMM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;8</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3,3,3-tetrafluoro-2-(trifluoromethyl)propanenitrile'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-fluoroaniline',
    'C<sub>6</sub>H<sub>6</sub>FN',
    '',
    '348-54-9',
    'FTZQXOJYPFINKJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-fluoroaniline'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-fluoroaniline',
    'C<sub>6</sub>H<sub>6</sub>FN',
    '',
    '371-40-4',
    'KRZCOLNOCZKSDF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-fluoroaniline'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-(trifluoromethyl)aniline',
    'C<sub>7</sub>H<sub>6</sub>F<sub>3</sub>N',
    '',
    '98-16-8',
    'VIUDTWATMPPKEL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-(trifluoromethyl)aniline'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'perfluorotributylamine',
    'C<sub>12</sub>F<sub>27</sub>N',
    '',
    '311-89-7',
    'RVZRBWKZFJCCIB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='perfluorotributylamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='perfluorotributylamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='perfluorotributylamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='perfluorotributylamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='perfluorotributylamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-ethyl-1-[3-(trifluoromethyl)phenyl]-2-propanamine',
    'C<sub>12</sub>H<sub>16</sub>F<sub>3</sub>N',
    'fenfluramine',
    '458-24-2',
    'DBGIVFWFUFKIQN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-ethyl-1-[3-(trifluoromethyl)phenyl]-2-propanamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tris(undecafluoropentyl)amine',
    'C<sub>15</sub>F<sub>33</sub>N',
    '',
    '338-84-1',
    'AQZYBQIAUSKCCS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;12</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tris(undecafluoropentyl)amine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;12</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tris(undecafluoropentyl)amine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tris(undecafluoropentyl)amine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;12</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tris(undecafluoropentyl)amine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'indaziflam A',
    'C<sub>16</sub>H<sub>20</sub>FN<sub>5</sub>',
    '',
    '730979-19-8',
    'YFONKFDEZLYQDH-OPQQBVKSSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='indaziflam A'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'indaziflam B',
    'C<sub>16</sub>H<sub>20</sub>FN<sub>5</sub>',
    '',
    '730979-32-5',
    'YFONKFDEZLYQDH-OUJBWJOFSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='indaziflam B'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cinacalcet',
    'C<sub>22</sub>H<sub>22</sub>F<sub>3</sub>N',
    '',
    '226256-56-0',
    'VDHAWDNDOKGFTD-MRXNPFEDSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cinacalcet'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hydramethylnon',
    'C<sub>25</sub>H<sub>24</sub>F<sub>6</sub>N<sub>4</sub>',
    '',
    '67485-29-4',
    'IQVNEKKDSLOHHK-FNCQTZNRSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='hydramethylnon'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='hydramethylnon'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydramethylnon'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-fluoroacetamide',
    'C<sub>2</sub>H<sub>4</sub>FNO',
    '',
    '640-19-7',
    'FVTWJXMFYOXOKK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-fluoroacetamide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-fluorouracil',
    'C<sub>4</sub>H<sub>3</sub>FN<sub>2</sub>O<sub>2</sub>',
    '',
    '51-21-8',
    'GHASVSINZRGABV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-fluorouracil'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'perfluoro-N-methylmorpholine',
    'C<sub>5</sub>F<sub>11</sub>NO',
    '',
    '382-28-5',
    'PQMAKJUXOOVROI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;8</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='perfluoro-N-methylmorpholine'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-fluoro-2,4-dinitrobenzene',
    'C<sub>6</sub>H<sub>3</sub>FN<sub>2</sub>O<sub>4</sub>',
    '',
    '70-34-8',
    'LOTKRQAVGJMPNV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-fluoro-2,4-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-fluoro-2-nitrophenol',
    'C<sub>6</sub>H<sub>4</sub>FNO<sub>3</sub>',
    '',
    '446-36-6',
    'QQURWFRNETXFTN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='5-fluoro-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='1155'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8',
    '',
    'V',
    (SELECT id from species WHERE iupac='5-fluoro-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='941'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4100',
    'Q',
    (SELECT id from species WHERE iupac='5-fluoro-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6200',
    '?',
    (SELECT id from species WHERE iupac='5-fluoro-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-nitro-3-(trifluoromethyl)phenol',
    'C<sub>7</sub>H<sub>4</sub>F<sub>3</sub>NO<sub>3</sub>',
    '',
    '88-30-2',
    'ZEFMBAFMCSYJOO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nitro-3-(trifluoromethyl)phenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nitro-3-(trifluoromethyl)phenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nitro-3-(trifluoromethyl)phenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nitro-3-(trifluoromethyl)phenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nitro-3-(trifluoromethyl)phenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-nitro-3-(trifluoromethyl)benzene',
    'C<sub>7</sub>H<sub>4</sub>F<sub>3</sub>NO<sub>2</sub>',
    '',
    '98-46-4',
    'WHNAMGUAXHGCHH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitro-3-(trifluoromethyl)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitro-3-(trifluoromethyl)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitro-3-(trifluoromethyl)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nitro-3-(trifluoromethyl)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-isocyanato-3-(trifluoromethyl)-benzene',
    'C<sub>8</sub>H<sub>4</sub>F<sub>3</sub>NO',
    '',
    '329-01-1',
    'SXJYSIBLFGQAND-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-isocyanato-3-(trifluoromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-isocyanato-3-(trifluoromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-isocyanato-3-(trifluoromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-isocyanato-3-(trifluoromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'flonicamid',
    'C<sub>9</sub>H<sub>6</sub>F<sub>3</sub>N<sub>3</sub>O',
    '',
    '158062-67-0',
    'RLQJEEJISHYWON-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>7</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='flonicamid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='flonicamid'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'trifluridine',
    'C<sub>10</sub>H<sub>11</sub>F<sub>3</sub>N<sub>2</sub>O<sub>5</sub>',
    '',
    '70-00-8',
    'VSQQQLOSPVPRAZ-RRKCRQDMSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trifluridine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-(4-amino-2-hydroxyphenyl)-2,2,3,3,4,4,4-heptafluorobutanamide',
    'C<sub>10</sub>H<sub>7</sub>F<sub>7</sub>N<sub>2</sub>O<sub>2</sub>',
    '',
    '847-51-8',
    'STPOJASQXPXVMS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-(4-amino-2-hydroxyphenyl)-2,2,3,3,4,4,4-heptafluorobutanamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-(4-amino-2-hydroxyphenyl)-2,2,3,3,4,4,4-heptafluorobutanamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-(4-amino-2-hydroxyphenyl)-2,2,3,3,4,4,4-heptafluorobutanamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-(4-amino-2-hydroxyphenyl)-2,2,3,3,4,4,4-heptafluorobutanamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fluometuron',
    'C<sub>10</sub>H<sub>11</sub>F<sub>3</sub>N<sub>2</sub>O',
    '',
    '2164-17-2',
    'RZILCCPWPBTYDO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='fluometuron'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='fluometuron'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dinitramine',
    'C<sub>11</sub>H<sub>13</sub>F<sub>3</sub>N<sub>4</sub>O<sub>4</sub>',
    '',
    '29091-05-2',
    'OFDYMSKSGFSLLM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='dinitramine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='dinitramine'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2',
    '',
    'V',
    (SELECT id from species WHERE iupac='dinitramine'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-methyl-N-[4-(trifluoromethyl)phenyl]-4-isoxazolecarboxamide',
    'C<sub>12</sub>H<sub>9</sub>F<sub>3</sub>N<sub>2</sub>O<sub>2</sub>',
    'leflunomide',
    '75706-12-6',
    'VHOGYURTWQBHIL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-N-[4-(trifluoromethyl)phenyl]-4-isoxazolecarboxamide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fludioxonil',
    'C<sub>12</sub>H<sub>6</sub>F<sub>2</sub>N<sub>2</sub>O<sub>2</sub>',
    '',
    '131341-86-1',
    'MUJOIMFVNIBMKC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='fludioxonil'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fludioxonil'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fludioxonil'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fluconazole',
    'C<sub>13</sub>H<sub>12</sub>F<sub>2</sub>N<sub>6</sub>O',
    '',
    '86386-73-4',
    'RFHAOTPXVQNOHP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fluconazole'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethalfluralin',
    'C<sub>13</sub>H<sub>14</sub>F<sub>3</sub>N<sub>3</sub>O<sub>4</sub>',
    '',
    '55283-68-6',
    'PTFJIKYUEPWBMS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethalfluralin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benfluralin',
    'C<sub>13</sub>H<sub>16</sub>F<sub>3</sub>N<sub>3</sub>O<sub>4</sub>',
    'benefin',
    '1861-40-1',
    'SMDHCQAYESWHAE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benfluralin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='benfluralin'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2614_pc_problem'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benfluralin'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='benfluralin'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'trifluralin',
    'C<sub>13</sub>H<sub>16</sub>F<sub>3</sub>N<sub>3</sub>O<sub>4</sub>',
    '',
    '1582-09-8',
    'ZSDSQXJSNMTJDA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trifluralin'),
    (SELECT id from literature WHERE bibtexkey='893'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trifluralin'),
    (SELECT id from literature WHERE bibtexkey='2538'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trifluralin'),
    (SELECT id from literature WHERE bibtexkey='901'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at296K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trifluralin'),
    (SELECT id from literature WHERE bibtexkey='901'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '901wwc',
    '', 'Measured with the wetted-wall column at room temperature.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='901wwc'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='trifluralin'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2614_pc_problem'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='trifluralin'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8',
    '',
    'V',
    (SELECT id from species WHERE iupac='trifluralin'),
    (SELECT id from literature WHERE bibtexkey='2455'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='trifluralin'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='trifluralin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trifluralin'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trifluralin'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trifluralin'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5000',
    'Q',
    (SELECT id from species WHERE iupac='trifluralin'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2100',
    '?',
    (SELECT id from species WHERE iupac='trifluralin'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'prodiamine',
    'C<sub>13</sub>H<sub>17</sub>F<sub>3</sub>N<sub>4</sub>O<sub>4</sub>',
    '',
    '29091-21-2',
    'RSVPPPHXAASNOL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    '?',
    (SELECT id from species WHERE iupac='prodiamine'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fluorodifen',
    'C<sub>13</sub>H<sub>7</sub>F<sub>3</sub>N<sub>2</sub>O<sub>5</sub>',
    '',
    '15457-05-3',
    'HHMCAJWVGYGUEF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='fluorodifen'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2614_pc_problem'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fluorodifen'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'profluralin',
    'C<sub>14</sub>H<sub>16</sub>F<sub>3</sub>N<sub>3</sub>O<sub>4</sub>',
    '',
    '26399-36-0',
    'ITVQAKZNYJEWKS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='profluralin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='profluralin'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='profluralin'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='profluralin'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'flumequine',
    'C<sub>14</sub>H<sub>12</sub>FNO<sub>3</sub>',
    '',
    '42835-25-6',
    'DPSPPJIUMHPXMA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='flumequine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fluazifop',
    'C<sub>15</sub>H<sub>12</sub>F<sub>3</sub>NO<sub>4</sub>',
    '',
    '69335-91-7',
    'YUVKUEAFAVKILW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fluazifop'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fluazifop-p',
    'C<sub>15</sub>H<sub>12</sub>F<sub>3</sub>NO<sub>4</sub>',
    '',
    '83066-88-0',
    'YUVKUEAFAVKILW-SECBINFHSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fluazifop-p'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'prosulfuron',
    'C<sub>15</sub>H<sub>16</sub>F<sub>3</sub>N<sub>5</sub>O<sub>4</sub>S',
    '',
    '94125-34-5',
    'LTUNNEGNEKBSEH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 3.3&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='prosulfuron'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'flurprimidol',
    'C<sub>15</sub>H<sub>15</sub>N<sub>2</sub>O<sub>2</sub>F<sub>3</sub>',
    '',
    '56425-91-3',
    'VEVZCONIUDBCDC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='flurprimidol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='flurprimidol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'flutriafol',
    'C<sub>16</sub>H<sub>13</sub>F<sub>2</sub>N<sub>3</sub>O',
    '',
    '76674-21-0',
    'JWUCHKBSVLQQCO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>7</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='flutriafol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='flutriafol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='flutriafol'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'flunitrazepam',
    'C<sub>16</sub>H<sub>12</sub>FN<sub>3</sub>O<sub>3</sub>',
    '',
    '1622-62-4',
    'PPTYJKAXVCCBDU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='flunitrazepam'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cyhalofop',
    'C<sub>16</sub>H<sub>12</sub>FNO<sub>4</sub>',
    '',
    '122008-78-0',
    'ROBSGBGTWRRYSK-SNVBAGLBSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cyhalofop'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benzpyrimoxan',
    'C<sub>16</sub>H<sub>15</sub>F<sub>3</sub>N<sub>2</sub>O<sub>3</sub>',
    '',
    '1449021-97-9',
    'ZYXYTGQFPZEUFX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='benzpyrimoxan'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tolprocarb',
    'C<sub>16</sub>H<sub>21</sub>F<sub>3</sub>N<sub>2</sub>O<sub>3</sub>',
    '',
    '911499-62-2',
    'RSOBJVBYZCMJOS-CYBMUJFWSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tolprocarb'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'flutolanil',
    'C<sub>17</sub>H<sub>16</sub>F<sub>3</sub>NO<sub>2</sub>',
    '',
    '66332-96-5',
    'PTCGDEVVHUXTMP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='flutolanil'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='flutolanil'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='flutolanil'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'beflubutamid',
    'C<sub>18</sub>H<sub>17</sub>F<sub>4</sub>NO<sub>2</sub>',
    '',
    '113614-08-7',
    'FFQPZWRNXKPNPX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='beflubutamid'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fluxapyroxad',
    'C<sub>18</sub>H<sub>12</sub>F<sub>5</sub>N<sub>3</sub>O',
    '',
    '907204-31-3',
    'SXSGXWCSHSVPGB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fluxapyroxad'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'flurtamone',
    'C<sub>18</sub>H<sub>14</sub>F<sub>3</sub>NO<sub>2</sub>',
    '',
    '96525-23-4',
    'NYRMIJKDBAQCHC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>8</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='flurtamone'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'picoxystrobin',
    'C<sub>18</sub>H<sub>16</sub>F<sub>3</sub>NO<sub>4</sub>',
    '',
    '117428-22-5',
    'IBSNKSODLGJUMQ-SDNWHVSQSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='picoxystrobin'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'sedaxane',
    'C<sub>18</sub>H<sub>19</sub>F<sub>2</sub>N<sub>3</sub>O',
    '',
    '874967-67-6',
    'XQJQCBDIXRIYRP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='sedaxane'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'penflufen',
    'C<sub>18</sub>H<sub>24</sub>FN<sub>3</sub>O',
    '',
    '494793-67-8',
    'GOFJDXZZHFNFLV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='penflufen'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fluazifop-p-butyl',
    'C<sub>19</sub>H<sub>20</sub>F<sub>3</sub>NO<sub>4</sub>',
    '',
    '79241-46-6',
    'VAIZTNZGPYBOGF-CYBMUJFWSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fluazifop-p-butyl'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'picolinafen',
    'C<sub>19</sub>H<sub>12</sub>F<sub>4</sub>N<sub>2</sub>O<sub>2</sub>',
    '',
    '137641-05-5',
    'CWKFPEBMTGKLKX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='picolinafen'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diflufenican',
    'C<sub>19</sub>H<sub>11</sub>F<sub>5</sub>N<sub>2</sub>O<sub>2</sub>',
    '',
    '83164-33-4',
    'WYEHFWKAOXOVJD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diflufenican'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diflufenican'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='diflufenican'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&lt; 8.5&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='diflufenican'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fluazifop-butyl',
    'C<sub>19</sub>H<sub>20</sub>F<sub>3</sub>NO<sub>4</sub>',
    '',
    '69806-50-4',
    'VAIZTNZGPYBOGF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='fluazifop-butyl'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'flumioxazin',
    'C<sub>19</sub>H<sub>15</sub>FN<sub>2</sub>O<sub>4</sub>',
    '',
    '103361-09-7',
    'FOUWCSDKDDHKQP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='flumioxazin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='flumioxazin'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fluridone',
    'C<sub>19</sub>H<sub>14</sub>F<sub>3</sub>NO',
    '',
    '59756-60-4',
    'YWBVHLJPRPCRSD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='fluridone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='fluridone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='fluridone'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2614_pc_problem'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fluridone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cyhalofop-butyl',
    'C<sub>20</sub>H<sub>20</sub>FNO<sub>4</sub>',
    '',
    '122008-85-9',
    'TYIYMOAHACZAMQ-CQSZACIVSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='cyhalofop-butyl'),
    (SELECT id from literature WHERE bibtexkey='macbean2012'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cyhalofop-butyl'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'raltegravir',
    'C<sub>20</sub>H<sub>21</sub>FN<sub>6</sub>O<sub>5</sub>',
    '',
    '518048-05-0',
    'CZFFBEXEKNGXKS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>17</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='raltegravir'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fluacrypyrim',
    'C<sub>20</sub>H<sub>21</sub>N<sub>2</sub>O<sub>5</sub>F<sub>3</sub>',
    '',
    '229977-93-9',
    'MXWAGQASUDSFBG-RVDMUPIBSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fluacrypyrim'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'trifloxystrobin',
    'C<sub>20</sub>H<sub>19</sub>F<sub>3</sub>N<sub>2</sub>O<sub>4</sub>',
    '',
    '141517-21-7',
    'ONCZDRURRATYFI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='trifloxystrobin'),
    (SELECT id from literature WHERE bibtexkey='macbean2012'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='trifloxystrobin'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'isopyrazam',
    'C<sub>20</sub>H<sub>23</sub>F<sub>2</sub>N<sub>3</sub>O',
    '',
    '881685-58-1',
    'XTDZGXBTXBEZDN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='isopyrazam'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='isopyrazam'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'syn-isopyrazam',
    'C<sub>20</sub>H<sub>23</sub>F<sub>2</sub>N<sub>3</sub>O',
    '',
    '683777-13-1',
    'XTDZGXBTXBEZDN-HEHGZKQESA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='syn-isopyrazam'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'anti-isopyrazam',
    'C<sub>20</sub>H<sub>23</sub>F<sub>2</sub>N<sub>3</sub>O',
    '',
    '683777-14-2',
    'XTDZGXBTXBEZDN-XEZPLFJOSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='anti-isopyrazam'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'etoxazole',
    'C<sub>21</sub>H<sub>23</sub>F<sub>2</sub>NO<sub>2</sub>',
    '',
    '153233-91-1',
    'IXSZQYVWNJNRAL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='etoxazole'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='etoxazole'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='etoxazole'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='etoxazole'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'droperidol',
    'C<sub>22</sub>H<sub>22</sub>FN<sub>3</sub>O<sub>2</sub>',
    '',
    '548-73-2',
    'RMEDXOLNCUSCGS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='droperidol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'paliperidone',
    'C<sub>23</sub>H<sub>27</sub>FN<sub>4</sub>O<sub>3</sub>',
    '',
    '144598-75-4',
    'PMXMIIMHBWHSKN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>15</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='paliperidone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'risperidone',
    'C<sub>23</sub>H<sub>27</sub>FN<sub>4</sub>O<sub>2</sub>',
    '',
    '106266-06-2',
    'RAPZEAPATHNIPO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='risperidone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ezetimibe',
    'C<sub>24</sub>H<sub>21</sub>F<sub>2</sub>NO<sub>3</sub>',
    '',
    '163222-33-1',
    'OLNTVTPDXPETLC-XPWALMASSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>12</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ezetimibe'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cyflumetofen',
    'C<sub>24</sub>H<sub>24</sub>F<sub>3</sub>NO<sub>4</sub>',
    '',
    '400882-07-7',
    'AWSZRJQNBMEZOI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 1.1&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cyflumetofen'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'acrinathrin',
    'C<sub>26</sub>H<sub>21</sub>F<sub>6</sub>NO<sub>5</sub>',
    '',
    '101007-06-1',
    'YLFSVIMMRPNPFK-WEQBUNFVSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='acrinathrin'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cerivastatin',
    'C<sub>26</sub>H<sub>34</sub>FNO<sub>5</sub>',
    '',
    '145599-86-6',
    'SEERZIQQUAZTOL-ANMDKAQQSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>13</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cerivastatin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'flucythrinate, isomer 1',
    'C<sub>26</sub>H<sub>23</sub>F<sub>2</sub>NO<sub>4</sub>',
    '',
    '70124-77-5',
    'GBIHOLCMZGAKNG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='flucythrinate, isomer 1'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='flucythrinate, isomer 1'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'PFBHA-methanal',
    'H<sub>2</sub>C=NOCH<sub>2</sub>C<sub>6</sub>F<sub>5</sub>',
    '',
    '86356-73-2',
    'SRTQFRQWTUMMTC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '7200',
    'M',
    (SELECT id from species WHERE iupac='PFBHA-methanal'),
    (SELECT id from literature WHERE bibtexkey='2497'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'PFBHA-ethanal',
    'CH<sub>3</sub>CH=NOCH<sub>2</sub>C<sub>6</sub>F<sub>5</sub>',
    '',
    '114611-59-5',
    'AKDRYEADQPNLOH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '5400',
    'M',
    (SELECT id from species WHERE iupac='PFBHA-ethanal'),
    (SELECT id from literature WHERE bibtexkey='2497'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'PFBHA-propanone',
    '(CH<sub>3</sub>)<sub>2</sub>C=NOCH<sub>2</sub>C<sub>6</sub>F<sub>5</sub>',
    '',
    '899828-53-6',
    'DLIFNTQMBOCKTL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '3800',
    'M',
    (SELECT id from species WHERE iupac='PFBHA-propanone'),
    (SELECT id from literature WHERE bibtexkey='2497'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'PFBHA-butanone',
    '(C<sub>2</sub>H<sub>5</sub>)(CH<sub>3</sub>)C=NOCH<sub>2</sub>C<sub>6</sub>F<sub>5</sub>',
    '',
    '',
    'LNDQFOSWZJYEIC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;3</sup>',
    '6000',
    'M',
    (SELECT id from species WHERE iupac='PFBHA-butanone'),
    (SELECT id from literature WHERE bibtexkey='2497'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'PFBHA-2-pentanone',
    '(C<sub>3</sub>H<sub>7</sub>)(CH<sub>3</sub>)C=NOCH<sub>2</sub>C<sub>6</sub>F<sub>5</sub>',
    '',
    '',
    'YKQOTQPNOJSJFA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;3</sup>',
    '2200',
    'M',
    (SELECT id from species WHERE iupac='PFBHA-2-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2497'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'PFBHA-hexanal',
    'C<sub>5</sub>H<sub>11</sub>CH=NOCH<sub>2</sub>C<sub>6</sub>F<sub>5</sub>',
    '',
    '',
    'GPAVMFOMYSGJDM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='PFBHA-hexanal'),
    (SELECT id from literature WHERE bibtexkey='2497'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'PFBHA-octanal',
    'C<sub>7</sub>H<sub>15</sub>CH=NOCH<sub>2</sub>C<sub>6</sub>F<sub>5</sub>',
    '',
    '',
    'RLSQIXNUITTXKZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='PFBHA-octanal'),
    (SELECT id from literature WHERE bibtexkey='2497'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'PFBHA-decanal',
    'C<sub>9</sub>H<sub>19</sub>CH=NOCH<sub>2</sub>C<sub>6</sub>F<sub>5</sub>',
    '',
    '',
    'NUGDFCWVLOJWOP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='PFBHA-decanal'),
    (SELECT id from literature WHERE bibtexkey='2497'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'PFBHA-propenal',
    'CH<sub>2</sub>CHCH=NOCH<sub>2</sub>C<sub>6</sub>F<sub>5</sub>',
    '',
    '',
    'ICDUEGOPUWNJNF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;3</sup>',
    '5400',
    'M',
    (SELECT id from species WHERE iupac='PFBHA-propenal'),
    (SELECT id from literature WHERE bibtexkey='2497'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(E)-PFBHA-propenal',
    'C<sub>10</sub>H<sub>6</sub>F<sub>5</sub>NO',
    '',
    '932710-55-9',
    'ICDUEGOPUWNJNF-HQYXKAPLSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(E)-PFBHA-propenal'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_O1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'PFBHA-crotonaldehyde',
    'CH<sub>3</sub>CHCHCH=NOCH<sub>2</sub>C<sub>6</sub>F<sub>5</sub>',
    '',
    '932710-52-6',
    'QNPFFCQTVXPCLD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;3</sup>',
    '3400',
    'M',
    (SELECT id from species WHERE iupac='PFBHA-crotonaldehyde'),
    (SELECT id from literature WHERE bibtexkey='2497'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'PFBHA-benzaldehyde',
    'C<sub>6</sub>H<sub>5</sub>CH=NOCH<sub>2</sub>C<sub>6</sub>F<sub>5</sub>',
    '',
    '',
    'UKSAZCDAGVHMRF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;3</sup>',
    '2000',
    'M',
    (SELECT id from species WHERE iupac='PFBHA-benzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='2497'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'PFBHA-4-methyl-benzaldehyde',
    'C<sub>8</sub>H<sub>8</sub>=NOCH<sub>2</sub>C<sub>6</sub>F<sub>5</sub>',
    '',
    '',
    'UCASBURGYXMQLW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='PFBHA-4-methyl-benzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='2497'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'PFBHA-9-fluorenone',
    'C<sub>13</sub>H<sub>8</sub>=NOCH<sub>2</sub>C<sub>6</sub>F<sub>5</sub>',
    '',
    '',
    'UABDVZDYKDIZFO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='PFBHA-9-fluorenone'),
    (SELECT id from literature WHERE bibtexkey='2497'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'PFBHA-ethanedial',
    '(HC=NOCH<sub>2</sub>C<sub>6</sub>F<sub>5</sub>)<sub>2</sub>',
    '',
    '618858-54-1',
    'VNVBOBJSRGZDCW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='PFBHA-ethanedial'),
    (SELECT id from literature WHERE bibtexkey='2497'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'PFBHA-1-hydroxypropanone',
    '(CH<sub>2</sub>OH)(CH<sub>3</sub>)C=NOCH<sub>2</sub>C<sub>6</sub>F<sub>5</sub>',
    '',
    '',
    'BCTASVPUYLXFBW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='PFBHA-1-hydroxypropanone'),
    (SELECT id from literature WHERE bibtexkey='2497'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'PFBHA-3-hydroxy-3-methyl-2-butanone',
    '(HOC<sub>3</sub>H<sub>6</sub>)(CH<sub>3</sub>)C=NOCH<sub>2</sub>C<sub>6</sub>F<sub>5</sub>',
    '',
    '',
    'VNWPJWLGZUDTBZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Organic fluorine'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='PFBHA-3-hydroxy-3-methyl-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='2497'));
INSERT INTO categories (catname) VALUES (
    'Organic species with chlorine (Cl)');
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Chlorocarbons (C, H, Cl)',
    (SELECT id from categories WHERE catname='Organic species with chlorine (Cl)'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chloromethane',
    'CH<sub>3</sub>Cl',
    'methyl chloride',
    '74-87-3',
    'NEHMKBQYUWJMIP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '2900',
    'L',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='3681'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '2900',
    'L',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;4</sup>',
    '3400',
    'L',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '3300',
    'L',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;4</sup>',
    '3400',
    'L',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '2800',
    'L',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '3300',
    'L',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2626-74-87-3-consicheck',
    '2626', 'The H298 and A, B data listed in Table&nbsp;5.4 of Sander et&nbsp;al. (2011) are inconsistent, with 9&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2626-74-87-3-consicheck'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '3300',
    'L',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='1855'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '3300',
    'L',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '1945-74-87-3-consicheck',
    '1945', 'The H298 and A, B data listed in Table&nbsp;5.4 of Sander et&nbsp;al. (2006) are inconsistent, with 9&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1945-74-87-3-consicheck'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '3300',
    'L',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '2800',
    'L',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;4</sup>',
    '2400',
    'M',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;4</sup>',
    '2000',
    'M',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='2824'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;4</sup>',
    '3200',
    'M',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='1026'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;4</sup>',
    '3300',
    'M',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='583'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;4</sup>',
    '2800',
    'M',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='2013'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2013-74-87-3-ABC',
    '2013', 'The data from Reichl (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;251.05500 +13259.10200/T +35.01685&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2013-74-87-3-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '3000',
    'M',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='1342'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '4200',
    'M',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='532'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='544'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '544',
    '543', 'The same data were also published in McConnell et&nbsp;al. (1975).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='544'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '2600',
    'M',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='1340'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;4</sup>',
    '2500',
    'M',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='2552'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '2900',
    'M',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='2222'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2222-74-87-3-ABC',
    '2222', 'The data from Glew and Moelwyn-Hughes (1953) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;171.13914 +9743.00524/T +23.09616&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2222-74-87-3-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='545'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '545noTdep',
    '', 'Values at different temperatures are from different sources. Thus a temperature dependence was not calculated.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='545noTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='545'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;4</sup>',
    '-630',
    'X',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2600',
    'Q',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2700',
    '?',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chloromethane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dichloromethane',
    'CH<sub>2</sub>Cl<sub>2</sub>',
    'methylene chloride',
    '75-09-2',
    'YMWUJEATGCHHMB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '3500',
    'L',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3681'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '3700',
    'L',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '3900',
    'L',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '3700',
    'L',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '3900',
    'L',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;3</sup>',
    '3300',
    'L',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '4100',
    'L',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '3700',
    'L',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='1855'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '4100',
    'L',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '4100',
    'L',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '4100',
    'L',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;3</sup>',
    '3900',
    'M',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '2300',
    'M',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2824'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '3700',
    'M',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3564'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2955'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;3</sup>',
    '3500',
    'M',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3690'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;3</sup>',
    '4200',
    'M',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='1026'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='1573'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at296K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3672'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2935'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='1113'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '1113',
    '1113', 'Chiang et&nbsp;al. (1998) show vinyl chloride in their Table&nbsp;2 but most probably they meant to refer to dichloromethane instead.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1113'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7',
    '',
    'M',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3646'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2450'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;3</sup>',
    '3200',
    'M',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2904'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;3</sup>',
    '3500',
    'M',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2905'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='637'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2493'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '3400',
    'M',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='855'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0855-75-09-2-ABC',
    '855', 'The data from Wright et&nbsp;al. (1992) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;444.17924 +22456.73010/T +63.76504&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0855-75-09-2-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '3500',
    'M',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='856'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3675'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2924'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '4200',
    'M',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='1156'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1156'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;3</sup>',
    '3800',
    'M',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='532'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2448'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2479'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '4500',
    'M',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2269'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '4200',
    'M',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='601'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '3600',
    'M',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='1150'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2918'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='544'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='544'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '4400',
    'M',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='640'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '4000',
    'M',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='863'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '4100',
    'V',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2905'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='545'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='545noTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='545'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at275K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='1916'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '3600',
    'X',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='1912'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='1912'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3083'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='545'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='1916'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3000',
    'Q',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3900',
    '?',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dichloromethane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dichloromethane-d2',
    'CD<sub>2</sub>Cl<sub>2</sub>',
    'methylene chloride-d2',
    '1665-00-5',
    'YMWUJEATGCHHMB-DICFDUPASA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '4600',
    'M',
    (SELECT id from species WHERE iupac='dichloromethane-d2'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'trichloromethane',
    'CHCl<sub>3</sub>',
    'chloroform',
    '67-66-3',
    'HEDRZPFGACZZDS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '4200',
    'L',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3681'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '4300',
    'L',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '4400',
    'L',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '4300',
    'L',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '4400',
    'L',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '4200',
    'L',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3518-67-66-3-consicheck',
    '3518', 'Values at 298&nbsp;K in Tables&nbsp;C2 and C5 of Brockbank (2013) are inconsistent, with 7&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3518-67-66-3-consicheck'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '4500',
    'L',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '4300',
    'L',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='1855'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '4500',
    'L',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '4500',
    'L',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '4500',
    'L',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2441'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '3900',
    'L',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3696'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '4500',
    'M',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '3900',
    'M',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2824'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3572'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '4500',
    'M',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3690'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2940'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '4200',
    'M',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2953'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2953-67-66-3-ABC',
    '2953', 'The data from Görgényi et&nbsp;al. (2002) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;378.59438 +20174.67146/T +53.50889&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2953-67-66-3-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '4600',
    'M',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='1026'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='1573'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at296K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2935'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2938'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='1113'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3646'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2450'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '3400',
    'M',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2904'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '3400',
    'M',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2905'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '4700',
    'M',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2463'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '4200',
    'M',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='583'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0583-67-66-3-ABC',
    '583', 'The data from Moore et&nbsp;al. (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( 32.52949 +1878.33965/T &#8722;7.88669&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0583-67-66-3-ABC'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '4400',
    'M',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='584'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='637'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2493'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '4000',
    'M',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='855'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0855-67-66-3-ABC',
    '855', 'The data from Wright et&nbsp;al. (1992) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;109.09283 +8000.75665/T +13.39152&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0855-67-66-3-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;3</sup>',
    '7300',
    'M',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='598'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '2000',
    'M',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2901'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2901'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2924'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '5000',
    'M',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='1156'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1156'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '4600',
    'M',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='532'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '4300',
    'M',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2243'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2448'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2903'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '4300',
    'M',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2269'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '5200',
    'M',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='531'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '4200',
    'M',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='601'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '3900',
    'M',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='608'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '608',
    '2952', 'Probably an interpolation of the data from Balls (1980).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='608'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '4000',
    'M',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='1150'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '5600',
    'M',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2271'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '7200',
    'M',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2952'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2918'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='544'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='544'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '5100',
    'M',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='640'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3697'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '4600',
    'M',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='863'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '4400',
    'V',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2905'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2975'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at283K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3945'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='545'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='545noTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='545'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at275K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='1916'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '4700',
    'V',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='862'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '4100',
    'X',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='1147'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '4400',
    'X',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='1912'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='1912'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='531'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='531'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3083'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='545'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='1916'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3300',
    'Q',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-Test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2481'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4300',
    '?',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='trichloromethane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tetrachloromethane',
    'CCl<sub>4</sub>',
    'carbontetrachloride',
    '56-23-5',
    'VZGDMQKNWNREIO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '4200',
    'L',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='3681'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;4</sup>',
    '4300',
    'L',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;4</sup>',
    '4200',
    'L',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;4</sup>',
    '4300',
    'L',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;4</sup>',
    '4200',
    'L',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;4</sup>',
    '4200',
    'L',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3518-56-23-5-consicheck',
    '3518', 'Values at 298&nbsp;K in Tables&nbsp;C2 and C5 of Brockbank (2013) are inconsistent, with 5&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3518-56-23-5-consicheck'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '4200',
    'L',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;4</sup>',
    '4300',
    'L',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='1855'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '4200',
    'L',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '4200',
    'L',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '4200',
    'L',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;4</sup>',
    '4500',
    'M',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;4</sup>',
    '4400',
    'M',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='2824'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '3800',
    'M',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='3690'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='2935'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='1113'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;4</sup>',
    '3700',
    'M',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='3571'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3571-56-23-5-ABC',
    '3571', 'The data from Bullister and Wisegarver (1998) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;704.15798 +34144.64622/T +102.06046&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3571-56-23-5-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;4</sup>',
    '1900',
    'M',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='2904'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '2600',
    'M',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='2905'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;4</sup>',
    '4400',
    'M',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='584'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='637'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;4</sup>',
    '3600',
    'M',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='903'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='903'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='2457'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;4</sup>',
    '4500',
    'M',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='855'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0855-56-23-5-ABC',
    '855', 'The data from Wright et&nbsp;al. (1992) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;426.63883 +22457.44484/T +60.22986&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0855-56-23-5-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;4</sup>',
    '3600',
    'M',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='856'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '4100',
    'M',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='598'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;4</sup>',
    '5600',
    'M',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='2270'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;4</sup>',
    '4000',
    'M',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='1156'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1156'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;4</sup>',
    '4400',
    'M',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='532'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;4</sup>',
    '4300',
    'M',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='2243'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='2448'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='2479'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='2903'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;4</sup>',
    '3200',
    'M',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='608'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='608'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;4</sup>',
    '4400',
    'M',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='1150'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;4</sup>',
    '3300',
    'M',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='2952'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;5</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='2918'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='544'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='544'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;4</sup>',
    '5200',
    'M',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='640'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;4</sup>',
    '4400',
    'M',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='863'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;4</sup>',
    '4200',
    'V',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='2905'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='2974'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='3945'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='545'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;4</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='766'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;4</sup>',
    '1100',
    'X',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;4</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='1912'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;4</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='1912'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;4</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;4</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='3083'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;4</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='545'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;4</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3700',
    'Q',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='2481'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4300',
    '?',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='2233'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tetrachloromethane'),
    (SELECT id from literature WHERE bibtexkey='2979'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at297K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chloroethane',
    'C<sub>2</sub>H<sub>5</sub>Cl',
    '',
    '75-00-3',
    'HRYZWHHZPQKTII-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;4</sup>',
    '3000',
    'L',
    (SELECT id from species WHERE iupac='chloroethane'),
    (SELECT id from literature WHERE bibtexkey='3681'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;4</sup>',
    '2900',
    'L',
    (SELECT id from species WHERE iupac='chloroethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;4</sup>',
    '2800',
    'L',
    (SELECT id from species WHERE iupac='chloroethane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;4</sup>',
    '2900',
    'L',
    (SELECT id from species WHERE iupac='chloroethane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;4</sup>',
    '2800',
    'L',
    (SELECT id from species WHERE iupac='chloroethane'),
    (SELECT id from literature WHERE bibtexkey='1855'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;4</sup>',
    '2900',
    'L',
    (SELECT id from species WHERE iupac='chloroethane'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;4</sup>',
    '2900',
    'L',
    (SELECT id from species WHERE iupac='chloroethane'),
    (SELECT id from literature WHERE bibtexkey='747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='chloroethane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='chloroethane'),
    (SELECT id from literature WHERE bibtexkey='2441'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;4</sup>',
    '3500',
    'L',
    (SELECT id from species WHERE iupac='chloroethane'),
    (SELECT id from literature WHERE bibtexkey='3696'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;4</sup>',
    '3200',
    'M',
    (SELECT id from species WHERE iupac='chloroethane'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;4</sup>',
    '3100',
    'M',
    (SELECT id from species WHERE iupac='chloroethane'),
    (SELECT id from literature WHERE bibtexkey='2824'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;4</sup>',
    '3200',
    'M',
    (SELECT id from species WHERE iupac='chloroethane'),
    (SELECT id from literature WHERE bibtexkey='923'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0923-75-00-3-ABC',
    '923', 'The data from Maaßen (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;221.58683 +12291.19608/T +30.42274&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0923-75-00-3-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;4</sup>',
    '3300',
    'M',
    (SELECT id from species WHERE iupac='chloroethane'),
    (SELECT id from literature WHERE bibtexkey='2013'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2013-75-00-3-ABC',
    '2013', 'The data from Reichl (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;233.85465 +12927.81251/T +32.20905&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2013-75-00-3-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;4</sup>',
    '2600',
    'M',
    (SELECT id from species WHERE iupac='chloroethane'),
    (SELECT id from literature WHERE bibtexkey='1156'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1156'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;4</sup>',
    '3100',
    'M',
    (SELECT id from species WHERE iupac='chloroethane'),
    (SELECT id from literature WHERE bibtexkey='532'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chloroethane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chloroethane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chloroethane'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chloroethane'),
    (SELECT id from literature WHERE bibtexkey='545'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chloroethane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='chloroethane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;4</sup>',
    '750',
    'X',
    (SELECT id from species WHERE iupac='chloroethane'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;4</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='chloroethane'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;4</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='chloroethane'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroethane'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroethane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroethane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroethane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroethane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroethane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3000',
    'Q',
    (SELECT id from species WHERE iupac='chloroethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroethane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroethane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroethane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroethane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroethane'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroethane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroethane'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chloroethane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2900',
    '?',
    (SELECT id from species WHERE iupac='chloroethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chloroethane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chloroethane'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chloroethane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chloroethane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chloroethane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1-dichloroethane',
    'CHCl<sub>2</sub>CH<sub>3</sub>',
    '',
    '75-34-3',
    'SCYULBFZEHDVBN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '3900',
    'L',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3681'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '4000',
    'L',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '3900',
    'L',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '4100',
    'L',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '3900',
    'L',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '4000',
    'L',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '4100',
    'L',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='1855'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '4100',
    'L',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '3700',
    'L',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '3600',
    'L',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '3900',
    'M',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '3300',
    'M',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2824'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2899'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '3900',
    'M',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2953'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2953-75-34-3-ABC',
    '2953', 'The data from Görgényi et&nbsp;al. (2002) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;372.18420 +19566.35271/T +52.67600&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2953-75-34-3-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2450'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '2600',
    'M',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2904'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '4300',
    'M',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='584'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '4900',
    'M',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='855'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0855-75-34-3-ABC',
    '855', 'The data from Wright et&nbsp;al. (1992) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;1295.59488 +61538.96732/T +190.02999&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0855-75-34-3-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '3700',
    'M',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='856'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '2100',
    'M',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2901'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2901'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '3100',
    'M',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='1156'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1156'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '4100',
    'M',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='532'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '4900',
    'M',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2271'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2918'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '4400',
    'M',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='863'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3945'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='545'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '3800',
    'X',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='1147'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '1700',
    'X',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3083'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3300',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-Test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3900',
    '?',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-dichloroethane',
    'CH<sub>2</sub>ClCH<sub>2</sub>Cl',
    '',
    '107-06-2',
    'WSLDOOZREJYCGB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;3</sup>',
    '4400',
    'L',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3681'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;3</sup>',
    '4300',
    'L',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;3</sup>',
    '3700',
    'L',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;3</sup>',
    '4300',
    'L',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;3</sup>',
    '3700',
    'L',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;3</sup>',
    '4200',
    'L',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;3</sup>',
    '4300',
    'L',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='1855'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;3</sup>',
    '4300',
    'L',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;3</sup>',
    '4200',
    'L',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;3</sup>',
    '4200',
    'L',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;3</sup>',
    '4400',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;3</sup>',
    '6100',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2824'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2969'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2969epics'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2969'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2969linear'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2969'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2969direct'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2969'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2969nonlin'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3646'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2450'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '3700',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2904'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;3</sup>',
    '4600',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='584'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='637'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2493'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;3</sup>',
    '4300',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='855'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0855-107-06-2-ABC',
    '855', 'The data from Wright et&nbsp;al. (1992) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;309.75754 +17275.24359/T +43.35857&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0855-107-06-2-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;3</sup>',
    '3600',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='856'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;3</sup>',
    '4500',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2270'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;3</sup>',
    '3000',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2901'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2901'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2924'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;3</sup>',
    '1500',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='1156'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HTdep_r2_lessthan_0.9'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1156'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;3</sup>',
    '3500',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='1150'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2918'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='544'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='544'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;3</sup>',
    '4400',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='640'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2491'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at303K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;3</sup>',
    '4400',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='863'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='545'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;3</sup>',
    '3700',
    'X',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='1147'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;3</sup>',
    '2400',
    'X',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='1912'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='1912'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3083'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='545'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3300',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3600',
    '?',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2979'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at297K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-dichloroethane-d4',
    'CD<sub>2</sub>ClCD<sub>2</sub>Cl',
    '',
    '17060-07-0',
    'WSLDOOZREJYCGB-LNLMKGTHSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;3</sup>',
    '4300',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichloroethane-d4'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,1-trichloroethane',
    'CH<sub>3</sub>CCl<sub>3</sub>',
    'methylchloroform; MCF',
    '71-55-6',
    'UOCLXMDMGBRAIB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;4</sup>',
    '3800',
    'L',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3681'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;4</sup>',
    '3700',
    'L',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;4</sup>',
    '4200',
    'L',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;4</sup>',
    '3700',
    'L',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;4</sup>',
    '4200',
    'L',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;4</sup>',
    '4100',
    'L',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;4</sup>',
    '3700',
    'L',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='1855'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '3900',
    'L',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;4</sup>',
    '4000',
    'L',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;4</sup>',
    '3900',
    'L',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;4</sup>',
    '4000',
    'M',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;4</sup>',
    '4100',
    'M',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2824'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '3500',
    'M',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2896'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='1113'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2450'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;4</sup>',
    '1900',
    'M',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2904'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2463'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;4</sup>',
    '4100',
    'M',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='584'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;4</sup>',
    '2500',
    'M',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='599'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0599-71-55-6-ABC',
    '599', 'The data from Robbins et&nbsp;al. (1993) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( 313.50875 &#8722;12121.71831/T &#8722;49.20602&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0599-71-55-6-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='637'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;4</sup>',
    '3100',
    'M',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='903'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='903'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2493'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;4</sup>',
    '3300',
    'M',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='855'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0855-71-55-6-ABC',
    '855', 'The data from Wright et&nbsp;al. (1992) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( 255.46482 &#8722;8896.18926/T &#8722;40.90189&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0855-71-55-6-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;4</sup>',
    '3700',
    'M',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='856'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;4</sup>',
    '1300',
    'M',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='857'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='857'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;4</sup>',
    '5200',
    'M',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2270'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2924'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;4</sup>',
    '3400',
    'M',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='1156'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1156'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;4</sup>',
    '4100',
    'M',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='532'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;4</sup>',
    '4100',
    'M',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2243'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2479'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;4</sup>',
    '4200',
    'M',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2269'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;4</sup>',
    '4300',
    'M',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='601'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;4</sup>',
    '3200',
    'M',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='608'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='608'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;4</sup>',
    '4400',
    'M',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='1150'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;4</sup>',
    '7000',
    'M',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2271'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2918'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='544'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='544'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;4</sup>',
    '4700',
    'V',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='1014'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='545'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='545noTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='545'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='545'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at275K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='1916'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;4</sup>',
    '4000',
    'X',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='1147'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '1700',
    'X',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;4</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3083'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3700',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2481'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3700',
    '?',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1,1-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2979'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at297K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,2-trichloroethane',
    'CHCl<sub>2</sub>CH<sub>2</sub>Cl',
    '',
    '79-00-5',
    'UBOXGVDOUJQMTN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '4400',
    'L',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3681'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '4100',
    'L',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '4100',
    'L',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '4400',
    'L',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3518-79-00-5-consicheck',
    '3518', 'Values at 298&nbsp;K in Tables&nbsp;C2 and C5 of Brockbank (2013) are inconsistent, with 5&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3518-79-00-5-consicheck'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '4100',
    'L',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='1855'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '4200',
    'L',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '4900',
    'L',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '4900',
    'L',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;3</sup>',
    '2400',
    'M',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3681'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3681-79-00-5-ABC',
    '3681', 'The data from Schwardt et&nbsp;al. (2021) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( 200.57633 &#8722;7128.32092/T &#8722;31.87111&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3681-79-00-5-ABC'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '5400',
    'M',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2899'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '4700',
    'M',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='1107'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2938'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2450'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '5100',
    'M',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2904'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '5900',
    'M',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='903'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='903'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '4300',
    'M',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='855'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0855-79-00-5-ABC',
    '855', 'The data from Wright et&nbsp;al. (1992) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;304.31063 +17046.46392/T +42.59182&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0855-79-00-5-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '4100',
    'M',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='856'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '4800',
    'M',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='1156'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1156'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '3700',
    'M',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='1150'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2918'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='545'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '4300',
    'X',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='1147'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '2700',
    'X',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3700',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2481'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4200',
    '?',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,2-trichloroethane-d3',
    'CDCl<sub>2</sub>CD<sub>2</sub>Cl',
    '',
    '171086-93-4',
    'UBOXGVDOUJQMTN-FUDHJZNOSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '5100',
    'M',
    (SELECT id from species WHERE iupac='1,1,2-trichloroethane-d3'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,1,2-tetrachloroethane',
    'CCl<sub>3</sub>CH<sub>2</sub>Cl',
    '',
    '630-20-6',
    'QVLAWKAXOMEXPM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;3</sup>',
    '6700',
    'L',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='3681'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '4600',
    'L',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '4600',
    'L',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '4900',
    'L',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '4600',
    'L',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='1855'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '3200',
    'L',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;3</sup>',
    '11000',
    'M',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='3681'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3681-630-20-6-ABC',
    '3681', 'The data from Schwardt et&nbsp;al. (2021) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;1784.40256 +88283.19114/T +260.26556&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3681-630-20-6-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;3</sup>',
    '4800',
    'M',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;3</sup>',
    '4100',
    'M',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='2904'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;3</sup>',
    '4400',
    'M',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='855'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0855-630-20-6-ABC',
    '855', 'The data from Wright et&nbsp;al. (1992) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( 608.52671 &#8722;23622.70039/T &#8722;93.86675&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0855-630-20-6-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;3</sup>',
    '4600',
    'M',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='856'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='2918'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '5000',
    'V',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='545'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4100',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4600',
    '?',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,2,2-tetrachloroethane',
    'CHCl<sub>2</sub>CHCl<sub>2</sub>',
    '',
    '79-34-5',
    'QPFMBZIOSGYJDE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '3700',
    'L',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='3681'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '4800',
    'L',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '4800',
    'L',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '5000',
    'L',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '4800',
    'L',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='1855'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '3200',
    'L',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '7200',
    'M',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='2450'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '6800',
    'M',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='2904'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2904',
    '2904', 'The value for A in the table of Kondoh and Nakajima (1997) is incorrect. Recalculating the regression, it can be seen that it should be 13.95 and not 1.395.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2904'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='2457'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '3100',
    'M',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='855'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0855-79-34-5-ABC',
    '855', 'The data from Wright et&nbsp;al. (1992) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( 2638.58362 &#8722;114985.14319/T &#8722;396.08684&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0855-79-34-5-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '4800',
    'M',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='856'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '2900',
    'M',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='1156'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HTdep_r2_lessthan_0.5'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1156'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '3500',
    'M',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='1150'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='2918'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='545'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '4200',
    'X',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='1147'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '3000',
    'X',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4100',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4500',
    '?',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachloroethane'),
    (SELECT id from literature WHERE bibtexkey='2979'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at297K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pentachloroethane',
    'CHCl<sub>2</sub>CCl<sub>3</sub>',
    '',
    '76-01-7',
    'BNIXVQGCZULYKV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '7700',
    'L',
    (SELECT id from species WHERE iupac='pentachloroethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3500-76-01-7-consicheck',
    '3500', 'The H298 and A, B data listed in Table&nbsp;5-4 of Burkholder et&nbsp;al. (2019) are inconsistent, with 9&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3500-76-01-7-consicheck'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '7700',
    'L',
    (SELECT id from species WHERE iupac='pentachloroethane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='pentachloroethane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;3</sup>',
    '5400',
    'M',
    (SELECT id from species WHERE iupac='pentachloroethane'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pentachloroethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pentachloroethane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pentachloroethane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pentachloroethane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pentachloroethane'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pentachloroethane'),
    (SELECT id from literature WHERE bibtexkey='545'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pentachloroethane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentachloroethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentachloroethane'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentachloroethane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentachloroethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentachloroethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentachloroethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentachloroethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentachloroethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentachloroethane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentachloroethane'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentachloroethane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pentachloroethane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pentachloroethane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pentachloroethane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hexachloroethane',
    'C<sub>2</sub>Cl<sub>6</sub>',
    '',
    '67-72-1',
    'VHHHONWQHHHLTI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '5700',
    'L',
    (SELECT id from species WHERE iupac='hexachloroethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '5600',
    'L',
    (SELECT id from species WHERE iupac='hexachloroethane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '6100',
    'L',
    (SELECT id from species WHERE iupac='hexachloroethane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '5600',
    'L',
    (SELECT id from species WHERE iupac='hexachloroethane'),
    (SELECT id from literature WHERE bibtexkey='747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '2600',
    'M',
    (SELECT id from species WHERE iupac='hexachloroethane'),
    (SELECT id from literature WHERE bibtexkey='1156'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HTdep_r2_lessthan_0.9'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1156'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '5600',
    'M',
    (SELECT id from species WHERE iupac='hexachloroethane'),
    (SELECT id from literature WHERE bibtexkey='2243'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='hexachloroethane'),
    (SELECT id from literature WHERE bibtexkey='2903'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='hexachloroethane'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexachloroethane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexachloroethane'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexachloroethane'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexachloroethane'),
    (SELECT id from literature WHERE bibtexkey='2974'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexachloroethane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexachloroethane'),
    (SELECT id from literature WHERE bibtexkey='545'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexachloroethane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='hexachloroethane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '2100',
    'X',
    (SELECT id from species WHERE iupac='hexachloroethane'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;4</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='hexachloroethane'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='hexachloroethane'),
    (SELECT id from literature WHERE bibtexkey='3083'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexachloroethane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexachloroethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexachloroethane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexachloroethane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexachloroethane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexachloroethane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexachloroethane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexachloroethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexachloroethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexachloroethane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexachloroethane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexachloroethane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='hexachloroethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='hexachloroethane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='hexachloroethane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='hexachloroethane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='hexachloroethane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-chloropropane',
    'C<sub>3</sub>H<sub>7</sub>Cl',
    '',
    '540-54-5',
    'SNMVRZFUUCLYTO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;4</sup>',
    '4500',
    'L',
    (SELECT id from species WHERE iupac='1-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='2493'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='2918'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;4</sup>',
    '4400',
    'M',
    (SELECT id from species WHERE iupac='1-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='863'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3300',
    'Q',
    (SELECT id from species WHERE iupac='1-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535dupl'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3500',
    '?',
    (SELECT id from species WHERE iupac='1-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-chloropropane',
    'C<sub>3</sub>H<sub>7</sub>Cl',
    '',
    '75-29-6',
    'ULYZAYCEDJDHCC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;4</sup>',
    '4400',
    'L',
    (SELECT id from species WHERE iupac='2-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='2493'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;4</sup>',
    '4300',
    'M',
    (SELECT id from species WHERE iupac='2-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='863'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1-dichloropropane',
    'C<sub>3</sub>H<sub>6</sub>Cl<sub>2</sub>',
    '',
    '78-99-9',
    'WIHMGGWNMISDNJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-dichloropropane',
    'C<sub>3</sub>H<sub>6</sub>Cl<sub>2</sub>',
    '',
    '78-87-5',
    'KNKRKFALVUDBJE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;3</sup>',
    '4100',
    'L',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='3681'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '4300',
    'L',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '4300',
    'L',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '4000',
    'L',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '4300',
    'L',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '4300',
    'L',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;3</sup>',
    '4400',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='2899'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '4300',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='1107'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='2938'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='3646'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='2450'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;3</sup>',
    '3700',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='2904'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '4200',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='855'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0855-78-87-5-ABC',
    '855', 'The data from Wright et&nbsp;al. (1992) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;573.71583 +28877.33987/T +82.70652&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0855-78-87-5-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '3800',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='856'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '3800',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='2270'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '4700',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='1156'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HTdep_r2_lessthan_0.9'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1156'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='3946'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '4300',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='1150'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='2918'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '2100',
    'X',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='3653'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='3083'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3700',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4000',
    '?',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='2233'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='2979'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at297K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-dichloropropane-d6',
    'C<sub>3</sub>D<sub>6</sub>Cl<sub>2</sub>',
    '',
    '93952-08-0',
    'KNKRKFALVUDBJE-LIDOUZCJSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '4600',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichloropropane-d6'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3-dichloropropane',
    'C<sub>3</sub>H<sub>6</sub>Cl<sub>2</sub>',
    '',
    '142-28-9',
    'YHRUOJUYPBUZOS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '3900',
    'L',
    (SELECT id from species WHERE iupac='1,3-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '3900',
    'L',
    (SELECT id from species WHERE iupac='1,3-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '3100',
    'L',
    (SELECT id from species WHERE iupac='1,3-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '5300',
    'M',
    (SELECT id from species WHERE iupac='1,3-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '5000',
    'M',
    (SELECT id from species WHERE iupac='1,3-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='2904'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,3-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='3946'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '3900',
    'M',
    (SELECT id from species WHERE iupac='1,3-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='1150'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3700',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,3-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3900',
    '?',
    (SELECT id from species WHERE iupac='1,3-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,3-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,3-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,3-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dichloropropane',
    'C<sub>3</sub>H<sub>6</sub>Cl<sub>2</sub>',
    '',
    '594-20-7',
    'ZEOVXNVKXIPWMS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;4</sup>',
    '7400',
    'M',
    (SELECT id from species WHERE iupac='2,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;4</sup>',
    '3900',
    'M',
    (SELECT id from species WHERE iupac='2,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='2923'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;4</sup>',
    '630',
    'M',
    (SELECT id from species WHERE iupac='2,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='2904'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3700',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3900',
    '?',
    (SELECT id from species WHERE iupac='2,2-dichloropropane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,1-trichloropropane',
    'C<sub>3</sub>H<sub>5</sub>Cl<sub>3</sub>',
    '',
    '7789-89-1',
    'AVGQTJUPLKNPQP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1,1-trichloropropane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,1,1-trichloropropane'),
    (SELECT id from literature WHERE bibtexkey='yaws2005'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1-trichloropropane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1-trichloropropane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1-trichloropropane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1-trichloropropane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,2-trichloropropane',
    'C<sub>3</sub>H<sub>5</sub>Cl<sub>3</sub>',
    '',
    '598-77-6',
    'GRSQYISVQKPZCW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1,2-trichloropropane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,1,2-trichloropropane'),
    (SELECT id from literature WHERE bibtexkey='yaws2005'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2-trichloropropane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2-trichloropropane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2-trichloropropane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2-trichloropropane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3-trichloropropane',
    'C<sub>3</sub>H<sub>5</sub>Cl<sub>3</sub>',
    '',
    '96-18-4',
    'CFXQEHVMCRXUSD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '3700',
    'L',
    (SELECT id from species WHERE iupac='1,2,3-trichloropropane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '3700',
    'L',
    (SELECT id from species WHERE iupac='1,2,3-trichloropropane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '1900',
    'L',
    (SELECT id from species WHERE iupac='1,2,3-trichloropropane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '3700',
    'L',
    (SELECT id from species WHERE iupac='1,2,3-trichloropropane'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '3700',
    'L',
    (SELECT id from species WHERE iupac='1,2,3-trichloropropane'),
    (SELECT id from literature WHERE bibtexkey='747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '7200',
    'M',
    (SELECT id from species WHERE iupac='1,2,3-trichloropropane'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '5300',
    'M',
    (SELECT id from species WHERE iupac='1,2,3-trichloropropane'),
    (SELECT id from literature WHERE bibtexkey='2904'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '4000',
    'M',
    (SELECT id from species WHERE iupac='1,2,3-trichloropropane'),
    (SELECT id from literature WHERE bibtexkey='598'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2,3-trichloropropane'),
    (SELECT id from literature WHERE bibtexkey='3946'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '3500',
    'M',
    (SELECT id from species WHERE iupac='1,2,3-trichloropropane'),
    (SELECT id from literature WHERE bibtexkey='1150'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3-trichloropropane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3-trichloropropane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3-trichloropropane'),
    (SELECT id from literature WHERE bibtexkey='545'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,2,3-trichloropropane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,2,3-trichloropropane'),
    (SELECT id from literature WHERE bibtexkey='yaws2005'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-trichloropropane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-trichloropropane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-trichloropropane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-trichloropropane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-trichloropropane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-trichloropropane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-trichloropropane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-trichloropropane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4000',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-trichloropropane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-trichloropropane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-trichloropropane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2,3-trichloropropane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4100',
    '?',
    (SELECT id from species WHERE iupac='1,2,3-trichloropropane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2,3-trichloropropane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2,3-trichloropropane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,2,2,3-pentachloropropane',
    'C<sub>3</sub>H<sub>3</sub>Cl<sub>5</sub>',
    '',
    '16714-68-4',
    'IYFMQUDCYNWFTL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2,3-pentachloropropane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2,3-pentachloropropane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2,3-pentachloropropane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2,3-pentachloropropane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-chloro-2-methylpropane',
    'C<sub>4</sub>H<sub>9</sub>Cl',
    '',
    '513-36-0',
    'QTBFPMKWQKYFLR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-chloro-2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-chloro-2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-chloro-2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-chloro-2-methylpropane',
    'C<sub>4</sub>H<sub>9</sub>Cl',
    '<i>tert</i>-butyl chloride',
    '507-20-0',
    'NBRKLOOSMBRFMH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '5600',
    'M',
    (SELECT id from species WHERE iupac='2-chloro-2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='3658'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-chloro-2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-chloro-2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-chloro-2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-chloro-2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-chlorobutane',
    'C<sub>4</sub>H<sub>9</sub>Cl',
    'butyl chloride',
    '109-69-3',
    'VFWCMGCRMGJXDK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;4</sup>',
    '4500',
    'L',
    (SELECT id from species WHERE iupac='1-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='2938'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='2493'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;4</sup>',
    '3500',
    'M',
    (SELECT id from species WHERE iupac='1-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='1150'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='2918'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3700',
    'Q',
    (SELECT id from species WHERE iupac='1-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3700',
    '?',
    (SELECT id from species WHERE iupac='1-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='637'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-chlorobutane',
    'C<sub>4</sub>H<sub>9</sub>Cl',
    '<i>sec</i>-butyl chloride',
    '78-86-4',
    'BSPCSKHALVHRSR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;4</sup>',
    '4500',
    'L',
    (SELECT id from species WHERE iupac='2-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;4</sup>',
    '4500',
    'M',
    (SELECT id from species WHERE iupac='2-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='1150'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3700',
    'Q',
    (SELECT id from species WHERE iupac='2-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-Test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4500',
    '?',
    (SELECT id from species WHERE iupac='2-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-chlorobutane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1-dichlorobutane',
    'C<sub>4</sub>H<sub>8</sub>Cl<sub>2</sub>',
    '',
    '541-33-3',
    'SEQRDAAUNCRFIT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1-dichlorobutane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1-dichlorobutane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichlorobutane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichlorobutane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichlorobutane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichlorobutane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichlorobutane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichlorobutane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichlorobutane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4-dichlorobutane',
    'C<sub>4</sub>H<sub>8</sub>Cl<sub>2</sub>',
    '',
    '110-56-5',
    'KJDRSWPQXHESDQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '3600',
    'L',
    (SELECT id from species WHERE iupac='1,4-dichlorobutane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,4-dichlorobutane'),
    (SELECT id from literature WHERE bibtexkey='3946'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '3100',
    'M',
    (SELECT id from species WHERE iupac='1,4-dichlorobutane'),
    (SELECT id from literature WHERE bibtexkey='1150'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dichlorobutane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dichlorobutane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dichlorobutane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dichlorobutane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4000',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dichlorobutane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dichlorobutane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dichlorobutane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dichlorobutane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dichlorobutane'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,4-dichlorobutane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3700',
    '?',
    (SELECT id from species WHERE iupac='1,4-dichlorobutane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,4-dichlorobutane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dichlorobutane',
    'C<sub>4</sub>H<sub>8</sub>Cl<sub>2</sub>',
    '',
    '7581-97-7',
    'RMISVOPUIFJTEO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3-dichlorobutane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3-dichlorobutane'),
    (SELECT id from literature WHERE bibtexkey='yaws2005'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dichlorobutane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dichlorobutane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dichlorobutane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dichlorobutane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dichlorobutane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-chloropentane',
    'C<sub>5</sub>H<sub>11</sub>Cl',
    '',
    '543-59-9',
    'SQCZQTSHSZLZIQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;4</sup>',
    '4000',
    'L',
    (SELECT id from species WHERE iupac='1-chloropentane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-chloropentane'),
    (SELECT id from literature WHERE bibtexkey='2493'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;4</sup>',
    '4700',
    'M',
    (SELECT id from species WHERE iupac='1-chloropentane'),
    (SELECT id from literature WHERE bibtexkey='1150'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-chloropentane'),
    (SELECT id from literature WHERE bibtexkey='2918'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-chloropentane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-chloropentane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-chloropentane'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-chloropentane'),
    (SELECT id from literature WHERE bibtexkey='2388'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-chloropentane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-chloropentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloropentane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloropentane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloropentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloropentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloropentane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloropentane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4000',
    'Q',
    (SELECT id from species WHERE iupac='1-chloropentane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloropentane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloropentane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloropentane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloropentane'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloropentane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-chloropentane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-chloropentane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4400',
    '?',
    (SELECT id from species WHERE iupac='1-chloropentane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-chloropentane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-chloropentane'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-chloropentane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-chloropentane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-chloropentane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-chloropentane',
    'C<sub>5</sub>H<sub>11</sub>Cl',
    '',
    '625-29-6',
    'NFRKUDYZEVQXTE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-chloropentane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-chloropentane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloropentane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloropentane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloropentane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloropentane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloropentane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-Test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloropentane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloropentane'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloropentane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-chloropentane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-chloropentane',
    'C<sub>5</sub>H<sub>11</sub>Cl',
    '',
    '616-20-6',
    'CXQSCYIVCSCSES-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-chloropentane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-chloropentane'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-chloropentane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-chloropentane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-chloropentane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-chloropentane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-chloropentane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-chloropentane'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-chloropentane'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-chloropentane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-chloropentane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-dichloropentane',
    'C<sub>5</sub>H<sub>10</sub>Cl<sub>2</sub>',
    '',
    '1674-33-5',
    'PPLBPDUKNRCHGG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,2-dichloropentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2005'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloropentane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,5-dichloropentane',
    'C<sub>5</sub>H<sub>10</sub>Cl<sub>2</sub>',
    '',
    '628-76-2',
    'LBKDGROORAKTLC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '4000',
    'L',
    (SELECT id from species WHERE iupac='1,5-dichloropentane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '1600',
    'M',
    (SELECT id from species WHERE iupac='1,5-dichloropentane'),
    (SELECT id from literature WHERE bibtexkey='1150'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,5-dichloropentane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,5-dichloropentane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,5-dichloropentane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,5-dichloropentane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4400',
    'Q',
    (SELECT id from species WHERE iupac='1,5-dichloropentane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,5-dichloropentane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,5-dichloropentane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,5-dichloropentane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4100',
    '?',
    (SELECT id from species WHERE iupac='1,5-dichloropentane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dichloropentane',
    'C<sub>5</sub>H<sub>10</sub>Cl<sub>2</sub>',
    '',
    '600-11-3',
    'HVFJQRZGBBKTPL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3-dichloropentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2005'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dichloropentane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-chloro-2-methylbutane',
    'C<sub>5</sub>H<sub>11</sub>Cl',
    '',
    '594-36-5',
    'CRNIHJHMEQZAAS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-chloro-2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-chloro-2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-chlorohexane',
    'C<sub>6</sub>H<sub>13</sub>Cl',
    '',
    '544-10-5',
    'MLRVZFYXUZQSRU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-chlorohexane'),
    (SELECT id from literature WHERE bibtexkey='2493'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;4</sup>',
    '4500',
    'M',
    (SELECT id from species WHERE iupac='1-chlorohexane'),
    (SELECT id from literature WHERE bibtexkey='1150'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chlorohexane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chlorohexane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chlorohexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chlorohexane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4300',
    'Q',
    (SELECT id from species WHERE iupac='1-chlorohexane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chlorohexane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chlorohexane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chlorohexane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chlorohexane'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-chlorohexane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4400',
    '?',
    (SELECT id from species WHERE iupac='1-chlorohexane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-chlorohexane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-chlorohexane',
    'C<sub>6</sub>H<sub>13</sub>Cl',
    '',
    '638-28-8',
    'GLCIPJOIEVLTPR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-chlorohexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2005'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chlorohexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-chlorohexane',
    'C<sub>6</sub>H<sub>13</sub>Cl',
    '',
    '2346-81-8',
    'BXSMMAVTEURRGG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-chlorohexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2005'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-chlorohexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-chloroheptane',
    'C<sub>7</sub>H<sub>15</sub>Cl',
    '',
    '629-06-1',
    'DZMDPHNGKBEVRE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-chloroheptane'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloroheptane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloroheptane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloroheptane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloroheptane'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-chloroheptane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-chloroheptane',
    'C<sub>7</sub>H<sub>15</sub>Cl',
    '',
    '1001-89-4',
    'PTSLUOSUHFGQHV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-chloroheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2005'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloroheptane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-chloroheptane',
    'C<sub>7</sub>H<sub>15</sub>Cl',
    '',
    '999-52-0',
    'DMKNOEJJJSHSML-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-chloroheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2005'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-chloroheptane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-chloroheptane',
    'C<sub>7</sub>H<sub>15</sub>Cl',
    '',
    '998-95-8',
    'MGSGWAXIEMEWCQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-chloroheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2005'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chloroheptane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-chlorooctane',
    'C<sub>8</sub>H<sub>17</sub>Cl',
    '',
    '111-85-3',
    'CNDHHGUSRIZDSL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-chlorooctane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;4</sup>',
    '6100',
    'V',
    (SELECT id from species WHERE iupac='1-chlorooctane'),
    (SELECT id from literature WHERE bibtexkey='2554'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-chlorooctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2005'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chlorooctane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chlorooctane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chlorooctane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chlorooctane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chlorooctane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-chlorooctane',
    'C<sub>8</sub>H<sub>17</sub>Cl',
    '',
    '628-61-5',
    'HKDCIIMOALDWHF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-chlorooctane'),
    (SELECT id from literature WHERE bibtexkey='yaws2005'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chlorooctane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-(chloromethyl)-heptane',
    'C<sub>8</sub>H<sub>17</sub>Cl',
    '',
    '123-04-6',
    'WLVCBAMXYMWGLJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-(chloromethyl)-heptane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-(chloromethyl)-heptane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,8-dichlorooctane',
    'C<sub>8</sub>H<sub>16</sub>Cl<sub>2</sub>',
    '',
    '2162-99-4',
    'WXYMNDFVLNUAIA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;3</sup>',
    '7100',
    'M',
    (SELECT id from species WHERE iupac='1,8-dichlorooctane'),
    (SELECT id from literature WHERE bibtexkey='2122'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2122-2162-99-4-ABC',
    '2122', 'The data from Sarraute et&nbsp;al. (2006) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;503.53929 +28223.72051/T +70.89539&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2122-2162-99-4-ABC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-chlorononane',
    'C<sub>9</sub>H<sub>19</sub>Cl',
    '',
    '2473-01-0',
    'RKAMCQVGHFRILV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-chlorononane'),
    (SELECT id from literature WHERE bibtexkey='yaws2005'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chlorononane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-chlorononane',
    'C<sub>9</sub>H<sub>19</sub>Cl',
    '',
    '2216-36-6',
    'DTWJISBCMBWFNY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-chlorononane'),
    (SELECT id from literature WHERE bibtexkey='yaws2005'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chlorononane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-chlorononane',
    'C<sub>9</sub>H<sub>19</sub>Cl',
    '',
    '28123-70-8',
    'GHLDSOWZIOPMTC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='5-chlorononane'),
    (SELECT id from literature WHERE bibtexkey='yaws2005'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-chlorononane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-chlorodecane',
    'C<sub>10</sub>H<sub>21</sub>Cl',
    '',
    '1002-69-3',
    'ZTEHOZMYMCEYRM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-chlorodecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2005'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chlorodecane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,10-dichlorodecane',
    'C<sub>10</sub>H<sub>20</sub>Cl<sub>2</sub>',
    '',
    '2162-98-3',
    'RBBNTRDPSVZESY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,10-dichlorodecane'),
    (SELECT id from literature WHERE bibtexkey='982'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,10-dichlorodecane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,9,10-tetrachlorodecane',
    'C<sub>10</sub>H<sub>18</sub>Cl<sub>4</sub>',
    '',
    '205646-11-3',
    'VXBHNYIEBLRXAW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2,9,10-tetrachlorodecane'),
    (SELECT id from literature WHERE bibtexkey='982'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,9,10-tetrachlorodecane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,9,10-tetrachlorodecane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,9,10-tetrachlorodecane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,9,10-tetrachlorodecane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pentachlorodecane isomers',
    'C<sub>10</sub>H<sub>17</sub>Cl<sub>5</sub>',
    '',
    '175801-37-3',
    'AMKBEJYNNQNKGD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='pentachlorodecane isomers'),
    (SELECT id from literature WHERE bibtexkey='982'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='pentachlorodecane isomers'),
    (SELECT id from literature WHERE bibtexkey='982'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-chloroundecane',
    'C<sub>11</sub>H<sub>23</sub>Cl',
    '',
    '2473-03-2',
    'ZHKKNUKCXPWZOP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-chloroundecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2005'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloroundecane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,10,11-tetrachloroundecane',
    'C<sub>11</sub>H<sub>20</sub>Cl<sub>4</sub>',
    '',
    '210049-49-3',
    'VVAAXDBMZVCVPA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2,10,11-tetrachloroundecane'),
    (SELECT id from literature WHERE bibtexkey='982'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,10,11-tetrachloroundecane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,10,11-tetrachloroundecane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,10,11-tetrachloroundecane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,10,11-tetrachloroundecane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pentachloroundecane isomers',
    'C<sub>11</sub>H<sub>19</sub>Cl<sub>5</sub>',
    '',
    '210175-48-7',
    'BBCUCNDIXLWBNQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='pentachloroundecane isomers'),
    (SELECT id from literature WHERE bibtexkey='982'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'M',
    (SELECT id from species WHERE iupac='pentachloroundecane isomers'),
    (SELECT id from literature WHERE bibtexkey='982'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-chlorododecane',
    'C<sub>12</sub>H<sub>25</sub>Cl',
    '',
    '112-52-7',
    'YAYNEUUHHLGGAH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-chlorododecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2005'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chlorododecane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,12-dichlorododecane',
    'C<sub>12</sub>H<sub>24</sub>Cl<sub>2</sub>',
    '',
    '3922-28-9',
    'RNXPZVYZVHJVHM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,12-dichlorododecane'),
    (SELECT id from literature WHERE bibtexkey='982'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,12-dichlorododecane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-chlorotridecane',
    'C<sub>13</sub>H<sub>27</sub>Cl',
    '',
    '822-13-9',
    'ASZMYJSJEOGSBR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-chlorotridecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2005'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chlorotridecane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-chlorotetradecane',
    'C<sub>14</sub>H<sub>29</sub>Cl',
    '',
    '2425-54-9',
    'RNHWYOLIEJIAMV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-chlorotetradecane'),
    (SELECT id from literature WHERE bibtexkey='yaws2005'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chlorotetradecane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tetrachlorocyclopentane',
    'C<sub>5</sub>H<sub>6</sub>Cl<sub>4</sub>',
    '',
    '59808-78-5',
    'ZFMWDTNZPKDVBU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrachlorocyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrachlorocyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrachlorocyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrachlorocyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,2,3,3,4-hexachlorocyclopentane',
    'C<sub>5</sub>H<sub>4</sub>Cl<sub>6</sub>',
    '',
    '68258-91-3',
    'RPUFWOAXMFQSDJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,3,3,4-hexachlorocyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,3,3,4-hexachlorocyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,3,3,4-hexachlorocyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,3,3,4-hexachlorocyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,2,3,3,4,5-heptachlorocyclopentane',
    'C<sub>5</sub>H<sub>3</sub>Cl<sub>7</sub>',
    '',
    '68258-90-2',
    'XCEUTYGYMGYCBG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,3,3,4,5-heptachlorocyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,3,3,4,5-heptachlorocyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,3,3,4,5-heptachlorocyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,3,3,4,5-heptachlorocyclopentane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,3,4,5-hexachlorocyclopentene',
    'C<sub>5</sub>H<sub>2</sub>Cl<sub>6</sub>',
    '',
    '',
    'OSRFTCIVMWPVNP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,3,4,5-hexachlorocyclopentene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,3,4,5-hexachlorocyclopentene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,3,4,5-hexachlorocyclopentene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,3,4,5-hexachlorocyclopentene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'heptachlorocyclopentene',
    'C<sub>5</sub>HCl<sub>7</sub>',
    '',
    '62111-47-1',
    'AJUXFTIOMRYFRL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptachlorocyclopentene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptachlorocyclopentene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptachlorocyclopentene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptachlorocyclopentene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chlorocyclohexane',
    'C<sub>6</sub>H<sub>11</sub>Cl',
    '',
    '542-18-7',
    'UNFUYWDGSFDHCW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '3300',
    'M',
    (SELECT id from species WHERE iupac='chlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2923'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4200',
    'Q',
    (SELECT id from species WHERE iupac='chlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3200',
    '?',
    (SELECT id from species WHERE iupac='chlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '&#945;-1,2,3,4,5,6-hexachlorocyclohexane',
    'C<sub>6</sub>H<sub>6</sub>Cl<sub>6</sub>',
    '&#945;-lindane; &#945;-HCH',
    '319-84-6',
    'JLYXXMFPNIAWKQ-SHFUYGGZSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'L',
    (SELECT id from species WHERE iupac='&#945;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2978'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='LDV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'L',
    (SELECT id from species WHERE iupac='&#945;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2978'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '5500',
    'M',
    (SELECT id from species WHERE iupac='&#945;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2814'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '7500',
    'M',
    (SELECT id from species WHERE iupac='&#945;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2216'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='&#945;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '6500',
    'M',
    (SELECT id from species WHERE iupac='&#945;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='1152'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='&#945;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='1926'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '1926',
    '1927', 'As explained by Miller and Stuart (2003), the measurements were performed at 296&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1926'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='&#945;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='&#945;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2974'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'V',
    (SELECT id from species WHERE iupac='&#945;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2977'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='&#945;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;3</sup>',
    '3900',
    'T',
    (SELECT id from species WHERE iupac='&#945;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'C',
    (SELECT id from species WHERE iupac='&#945;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '1157-22-25',
    '', 'Value for T&nbsp;= 295... 298&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1157-22-25'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#945;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#945;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#945;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#945;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#945;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7100',
    'Q',
    (SELECT id from species WHERE iupac='&#945;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7100',
    '?',
    (SELECT id from species WHERE iupac='&#945;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '&#946;-1,2,3,4,5,6-hexachlorocyclohexane',
    'C<sub>6</sub>H<sub>6</sub>Cl<sub>6</sub>',
    '&#946;-lindane; &#946;-HCH',
    '319-85-7',
    'JLYXXMFPNIAWKQ-CDRYSYESSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='&#946;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2978'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='LDV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='&#946;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2978'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>1</sup>',
    '7800',
    'M',
    (SELECT id from species WHERE iupac='&#946;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2216'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='&#946;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6',
    '',
    'V',
    (SELECT id from species WHERE iupac='&#946;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='&#946;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2974'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3',
    '',
    'V',
    (SELECT id from species WHERE iupac='&#946;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='&#946;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '1157-20-25',
    '', 'Value for T&nbsp;= 293... 298&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1157-20-25'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='&#946;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#946;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#946;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#946;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7100',
    'Q',
    (SELECT id from species WHERE iupac='&#946;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='&#946;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7800',
    '?',
    (SELECT id from species WHERE iupac='&#946;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '&#947;-1,2,3,4,5,6-hexachlorocyclohexane',
    'C<sub>6</sub>H<sub>6</sub>Cl<sub>6</sub>',
    '&#947;-lindane; lindane; &#947;-HCH',
    '58-89-9',
    'JLYXXMFPNIAWKQ-GNIYUCBRSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7',
    '',
    'L',
    (SELECT id from species WHERE iupac='&#947;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2978'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='LDV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3',
    '',
    'L',
    (SELECT id from species WHERE iupac='&#947;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2978'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '',
    'L',
    (SELECT id from species WHERE iupac='&#947;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '',
    'M',
    (SELECT id from species WHERE iupac='&#947;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9',
    '3300',
    'M',
    (SELECT id from species WHERE iupac='&#947;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2814'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0',
    '6200',
    'M',
    (SELECT id from species WHERE iupac='&#947;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='1942'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3',
    '7500',
    'M',
    (SELECT id from species WHERE iupac='&#947;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2216'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    'M',
    (SELECT id from species WHERE iupac='&#947;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '5500',
    'M',
    (SELECT id from species WHERE iupac='&#947;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='1152'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    'M',
    (SELECT id from species WHERE iupac='&#947;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='901'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at296K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0',
    '',
    'M',
    (SELECT id from species WHERE iupac='&#947;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='900'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at296K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7',
    '',
    'V',
    (SELECT id from species WHERE iupac='&#947;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3',
    '',
    'V',
    (SELECT id from species WHERE iupac='&#947;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2967'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='&#947;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2974'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9',
    '',
    'V',
    (SELECT id from species WHERE iupac='&#947;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2977'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7',
    '',
    'V',
    (SELECT id from species WHERE iupac='&#947;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2975'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at283K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7',
    '',
    'V',
    (SELECT id from species WHERE iupac='&#947;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='&#947;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2976'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9',
    '',
    'V',
    (SELECT id from species WHERE iupac='&#947;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2968'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='&#947;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2979'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='&#947;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2471'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '7100',
    'T',
    (SELECT id from species WHERE iupac='&#947;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='&#947;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='mccarty80'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from2556'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='&#947;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0',
    '',
    'C',
    (SELECT id from species WHERE iupac='&#947;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1157-20-25'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'C',
    (SELECT id from species WHERE iupac='&#947;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#947;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#947;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#947;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#947;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#947;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#947;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#947;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#947;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7100',
    'Q',
    (SELECT id from species WHERE iupac='&#947;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    '?',
    (SELECT id from species WHERE iupac='&#947;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6200',
    '?',
    (SELECT id from species WHERE iupac='&#947;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='&#947;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='695'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '&#948;-1,2,3,4,5,6-hexachlorocyclohexane',
    'C<sub>6</sub>H<sub>6</sub>Cl<sub>6</sub>',
    '&#948;-lindane; &#948;-HCH',
    '319-86-8',
    'JLYXXMFPNIAWKQ-GPIVLXJGSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='&#948;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='&#948;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='&#948;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='&#948;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='&#948;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1157-20-25'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#948;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#948;-1,2,3,4,5,6-hexachlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,5,6,7,8,8-hexachloro-3a,4,7,7a-tetrahydro-4,7-methano-1H-indene',
    'C<sub>10</sub>H<sub>6</sub>Cl<sub>6</sub>',
    '',
    '3734-48-3',
    'XCJXQCUJXDUNDN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,5,6,7,8,8-hexachloro-3a,4,7,7a-tetrahydro-4,7-methano-1H-indene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,5,6,7,8,8-hexachloro-3a,4,7,7a-tetrahydro-4,7-methano-1H-indene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,5,6,7,8,8-hexachloro-3a,4,7,7a-tetrahydro-4,7-methano-1H-indene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,5,6,7,8,8-hexachloro-3a,4,7,7a-tetrahydro-4,7-methano-1H-indene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,5,6,7,8,8-hexachloro-3a,4,7,7a-tetrahydro-4,7-methano-1H-indene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dienochlor',
    'C<sub>10</sub>Cl<sub>10</sub>',
    '',
    '2227-17-0',
    'LWLJUMBEZJHXHV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dienochlor'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dienochlor'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'mirex',
    'C<sub>10</sub>Cl<sub>12</sub>',
    'dodecachloropentacyclodecane',
    '2385-85-5',
    'GVYLCNUFSHDAAW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '11000',
    'M',
    (SELECT id from species WHERE iupac='mirex'),
    (SELECT id from literature WHERE bibtexkey='852'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='mirex'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='mirex'),
    (SELECT id from literature WHERE bibtexkey='2975'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at283K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='mirex'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='mirex'),
    (SELECT id from literature WHERE bibtexkey='3945'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;4</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='mirex'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='mirex'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='mirex'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='mirex'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '10000',
    'Q',
    (SELECT id from species WHERE iupac='mirex'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='mirex'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '11000',
    '?',
    (SELECT id from species WHERE iupac='mirex'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dechlorane plus',
    'C<sub>18</sub>H<sub>12</sub>Cl<sub>12</sub>',
    '',
    '13560-89-9',
    'UGQQAJOWXNCOPY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dechlorane plus'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dechlorane plus'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dechlorane plus'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dechlorane plus'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dechlorane plus'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chloroethene',
    'CH<sub>2</sub>CHCl',
    'vinyl chloride',
    '75-01-4',
    'BZHJMEDXRYGGRV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;4</sup>',
    '2500',
    'L',
    (SELECT id from species WHERE iupac='chloroethene'),
    (SELECT id from literature WHERE bibtexkey='3681'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;4</sup>',
    '3100',
    'L',
    (SELECT id from species WHERE iupac='chloroethene'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;4</sup>',
    '3100',
    'L',
    (SELECT id from species WHERE iupac='chloroethene'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;4</sup>',
    '3000',
    'L',
    (SELECT id from species WHERE iupac='chloroethene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;4</sup>',
    '3100',
    'L',
    (SELECT id from species WHERE iupac='chloroethene'),
    (SELECT id from literature WHERE bibtexkey='1855'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '3100',
    'L',
    (SELECT id from species WHERE iupac='chloroethene'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '3100',
    'L',
    (SELECT id from species WHERE iupac='chloroethene'),
    (SELECT id from literature WHERE bibtexkey='747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;4</sup>',
    '3000',
    'L',
    (SELECT id from species WHERE iupac='chloroethene'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '2400',
    'M',
    (SELECT id from species WHERE iupac='chloroethene'),
    (SELECT id from literature WHERE bibtexkey='3681'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3681-75-01-4-ABC',
    '3681', 'The data from Schwardt et&nbsp;al. (2021) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;20.66741 +2604.13624/T +0.71646&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3681-75-01-4-ABC'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '3200',
    'M',
    (SELECT id from species WHERE iupac='chloroethene'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;4</sup>',
    '2300',
    'M',
    (SELECT id from species WHERE iupac='chloroethene'),
    (SELECT id from literature WHERE bibtexkey='2824'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'M',
    (SELECT id from species WHERE iupac='chloroethene'),
    (SELECT id from literature WHERE bibtexkey='1113'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1113'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;4</sup>',
    '2900',
    'M',
    (SELECT id from species WHERE iupac='chloroethene'),
    (SELECT id from literature WHERE bibtexkey='1156'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1156'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;4</sup>',
    '3300',
    'M',
    (SELECT id from species WHERE iupac='chloroethene'),
    (SELECT id from literature WHERE bibtexkey='532'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;6</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='chloroethene'),
    (SELECT id from literature WHERE bibtexkey='544'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='544'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at283K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='chloroethene'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2612_pc_problem',
    '2612', 'Mackay et&nbsp;al. (2006b) list a vapor pressure p, a solubility c, and a Henry''s law constant calculated as p/c. However, the data are internally inconsistent and deviate by more than 10&nbsp;%.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2612_pc_problem'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chloroethene'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chloroethene'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chloroethene'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chloroethene'),
    (SELECT id from literature WHERE bibtexkey='3945'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chloroethene'),
    (SELECT id from literature WHERE bibtexkey='545'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chloroethene'),
    (SELECT id from literature WHERE bibtexkey='545'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chloroethene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='chloroethene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;4</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='chloroethene'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroethene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroethene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroethene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroethene'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroethene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroethene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroethene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroethene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroethene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroethene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroethene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroethene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroethene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroethene'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroethene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroethene'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chloroethene'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chloroethene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '2700',
    '?',
    (SELECT id from species WHERE iupac='chloroethene'),
    (SELECT id from literature WHERE bibtexkey='3811'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chloroethene'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chloroethene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chloroethene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chloroethene-d3',
    'CD<sub>2</sub>CDCl',
    'vinyl chloride-d3',
    '6745-35-3',
    'BZHJMEDXRYGGRV-FUDHJZNOSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;4</sup>',
    '3100',
    'M',
    (SELECT id from species WHERE iupac='chloroethene-d3'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1-dichloroethene',
    'CH<sub>2</sub>CCl<sub>2</sub>',
    '',
    '75-35-4',
    'LGXVIGDEPROXKC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;4</sup>',
    '3500',
    'L',
    (SELECT id from species WHERE iupac='1,1-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3681'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;4</sup>',
    '3400',
    'L',
    (SELECT id from species WHERE iupac='1,1-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;4</sup>',
    '3400',
    'L',
    (SELECT id from species WHERE iupac='1,1-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;4</sup>',
    '3900',
    'L',
    (SELECT id from species WHERE iupac='1,1-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3518-75-35-4-consicheck',
    '3518', 'Values at 298&nbsp;K in Tables&nbsp;C2 and C5 of Brockbank (2013) are inconsistent, with 6&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3518-75-35-4-consicheck'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;4</sup>',
    '3400',
    'L',
    (SELECT id from species WHERE iupac='1,1-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='1855'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;4</sup>',
    '3800',
    'L',
    (SELECT id from species WHERE iupac='1,1-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '4000',
    'L',
    (SELECT id from species WHERE iupac='1,1-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '3900',
    'L',
    (SELECT id from species WHERE iupac='1,1-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;4</sup>',
    '3400',
    'M',
    (SELECT id from species WHERE iupac='1,1-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3681'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3681-75-35-4-ABC',
    '3681', 'The data from Schwardt et&nbsp;al. (2021) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;214.72727 +12076.60512/T +29.20360&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3681-75-35-4-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;4</sup>',
    '4600',
    'M',
    (SELECT id from species WHERE iupac='1,1-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;4</sup>',
    '4200',
    'M',
    (SELECT id from species WHERE iupac='1,1-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='1107'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,1-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='1113'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;4</sup>',
    '1600',
    'M',
    (SELECT id from species WHERE iupac='1,1-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2904'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;4</sup>',
    '3300',
    'M',
    (SELECT id from species WHERE iupac='1,1-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='856'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '4500',
    'M',
    (SELECT id from species WHERE iupac='1,1-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2270'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;4</sup>',
    '2900',
    'M',
    (SELECT id from species WHERE iupac='1,1-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='1156'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1156'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '1156-typo',
    '1156,2894', 'A typo in Ashworth et&nbsp;al. (1988) has been corrected by Howe et&nbsp;al. (1987).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1156-typo'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;4</sup>',
    '3700',
    'M',
    (SELECT id from species WHERE iupac='1,1-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='532'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,1-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2479'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;4</sup>',
    '4600',
    'M',
    (SELECT id from species WHERE iupac='1,1-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='1150'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;4</sup>',
    '6600',
    'M',
    (SELECT id from species WHERE iupac='1,1-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2271'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,1-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;5</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,1-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='544'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='544'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='545'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='545noTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='545'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,1-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;4</sup>',
    '1200',
    'X',
    (SELECT id from species WHERE iupac='1,1-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1,1-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;4</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1,1-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3083'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3300',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3700',
    '?',
    (SELECT id from species WHERE iupac='1,1-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-dichloroethene',
    'C<sub>2</sub>H<sub>2</sub>Cl<sub>2</sub>',
    '',
    '540-59-0',
    'KFUSEUYYWQURPO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(Z)-1,2-dichloroethene',
    'CHClCHCl',
    '<i>cis</i>-1,2-dichloroethene',
    '156-59-2',
    'KFUSEUYYWQURPO-UPHRSURJSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '3400',
    'L',
    (SELECT id from species WHERE iupac='(Z)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3681'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '3700',
    'L',
    (SELECT id from species WHERE iupac='(Z)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '3700',
    'L',
    (SELECT id from species WHERE iupac='(Z)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '4000',
    'L',
    (SELECT id from species WHERE iupac='(Z)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '3700',
    'L',
    (SELECT id from species WHERE iupac='(Z)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='1855'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '4000',
    'L',
    (SELECT id from species WHERE iupac='(Z)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '3900',
    'L',
    (SELECT id from species WHERE iupac='(Z)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '3900',
    'L',
    (SELECT id from species WHERE iupac='(Z)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '3800',
    'M',
    (SELECT id from species WHERE iupac='(Z)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '3900',
    'M',
    (SELECT id from species WHERE iupac='(Z)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2824'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '3100',
    'M',
    (SELECT id from species WHERE iupac='(Z)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2897'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='(Z)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2935'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='(Z)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2450'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '3000',
    'M',
    (SELECT id from species WHERE iupac='(Z)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2904'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '3100',
    'M',
    (SELECT id from species WHERE iupac='(Z)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2905'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '4000',
    'M',
    (SELECT id from species WHERE iupac='(Z)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='855'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0855-156-59-2-ABC',
    '855', 'The data from Wright et&nbsp;al. (1992) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;332.68901 +17925.88529/T +46.77838&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0855-156-59-2-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '3800',
    'M',
    (SELECT id from species WHERE iupac='(Z)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='856'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '4200',
    'M',
    (SELECT id from species WHERE iupac='(Z)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2270'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '3200',
    'M',
    (SELECT id from species WHERE iupac='(Z)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='1156'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1156'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '4200',
    'M',
    (SELECT id from species WHERE iupac='(Z)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='532'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='(Z)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2479'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '4100',
    'M',
    (SELECT id from species WHERE iupac='(Z)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2271'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='(Z)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2918'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(Z)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(Z)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2905'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(Z)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(Z)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(Z)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='545'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(Z)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='(Z)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(Z)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-cis-trans'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(Z)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-cis-trans'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(Z)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-cis-trans'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(Z)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(Z)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(Z)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3300',
    'Q',
    (SELECT id from species WHERE iupac='(Z)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(Z)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(Z)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(Z)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(Z)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4200',
    '?',
    (SELECT id from species WHERE iupac='(Z)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(Z)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(Z)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(Z)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(Z)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(Z)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(E)-1,2-dichloroethene',
    'CHClCHCl',
    '<i>trans</i>-1,2-dichloroethene',
    '156-60-5',
    'KFUSEUYYWQURPO-OWOJBTEDSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;4</sup>',
    '3600',
    'L',
    (SELECT id from species WHERE iupac='(E)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3681'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '3600',
    'L',
    (SELECT id from species WHERE iupac='(E)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '3600',
    'L',
    (SELECT id from species WHERE iupac='(E)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '3900',
    'L',
    (SELECT id from species WHERE iupac='(E)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '3500',
    'L',
    (SELECT id from species WHERE iupac='(E)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='1855'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '4200',
    'L',
    (SELECT id from species WHERE iupac='(E)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;4</sup>',
    '4100',
    'L',
    (SELECT id from species WHERE iupac='(E)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;4</sup>',
    '4100',
    'L',
    (SELECT id from species WHERE iupac='(E)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;4</sup>',
    '2600',
    'M',
    (SELECT id from species WHERE iupac='(E)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3681'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3681-156-60-5-ABC',
    '3681', 'The data from Schwardt et&nbsp;al. (2021) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;6.68864 +2211.35284/T &#8722;1.35565&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3681-156-60-5-ABC'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '4000',
    'M',
    (SELECT id from species WHERE iupac='(E)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '3500',
    'M',
    (SELECT id from species WHERE iupac='(E)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2897'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='(E)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2935'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='(E)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2450'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '2200',
    'M',
    (SELECT id from species WHERE iupac='(E)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2904'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '6200',
    'M',
    (SELECT id from species WHERE iupac='(E)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2905'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;4</sup>',
    '4900',
    'M',
    (SELECT id from species WHERE iupac='(E)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2931'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2931-156-60-5-ABC',
    '2931', 'The data from Khalfaoui and Newsham (1994b) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;593.56757 +30300.79738/T +85.11672&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2931-156-60-5-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;4</sup>',
    '3400',
    'M',
    (SELECT id from species WHERE iupac='(E)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='903'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='903'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '4200',
    'M',
    (SELECT id from species WHERE iupac='(E)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='855'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0855-156-60-5-ABC',
    '855', 'The data from Wright et&nbsp;al. (1992) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;294.54970 +16409.35487/T +40.82700&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0855-156-60-5-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '3700',
    'M',
    (SELECT id from species WHERE iupac='(E)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='856'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;4</sup>',
    '5000',
    'M',
    (SELECT id from species WHERE iupac='(E)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='1148'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref1148-156-60-5-ABC',
    '1148', 'The data from Cooling et&nbsp;al. (1992) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;511.78322 +26710.11950/T +72.88403&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref1148-156-60-5-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;4</sup>',
    '4800',
    'M',
    (SELECT id from species WHERE iupac='(E)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2270'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;4</sup>',
    '3000',
    'M',
    (SELECT id from species WHERE iupac='(E)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='1156'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1156'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1156-typo'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '4200',
    'M',
    (SELECT id from species WHERE iupac='(E)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='532'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='(E)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2479'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;4</sup>',
    '5400',
    'M',
    (SELECT id from species WHERE iupac='(E)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2271'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='(E)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='(E)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2918'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(E)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(E)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2905'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(E)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(E)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(E)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(E)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(E)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='545'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(E)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='(E)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '1700',
    'X',
    (SELECT id from species WHERE iupac='(E)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='(E)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='(E)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3083'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(E)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-cis-trans'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(E)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-cis-trans'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(E)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-cis-trans'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(E)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(E)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(E)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3300',
    'Q',
    (SELECT id from species WHERE iupac='(E)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(E)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(E)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(E)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4300',
    '?',
    (SELECT id from species WHERE iupac='(E)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(E)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(E)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(E)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(E)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(E)-1,2-dichloroethene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'trichloroethene',
    'C<sub>2</sub>HCl<sub>3</sub>',
    'trichloroethylene',
    '79-01-6',
    'XSTXAVWGXDQKEL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '4100',
    'L',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3681'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '4300',
    'L',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;4</sup>',
    '4200',
    'L',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '4300',
    'L',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;4</sup>',
    '4200',
    'L',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '4200',
    'L',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '4300',
    'L',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='1855'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '4300',
    'L',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '4600',
    'L',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;4</sup>',
    '4600',
    'L',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2441'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '4100',
    'L',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3696'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '4200',
    'M',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3681'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3681-79-01-6-ABC',
    '3681', 'The data from Schwardt et&nbsp;al. (2021) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;265.05147 +15058.79780/T +36.44507&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3681-79-01-6-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '4700',
    'M',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '2800',
    'M',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2921'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2921H0'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2921'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2921H1'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '3900',
    'M',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2824'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2955'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '3900',
    'M',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2897'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;4</sup>',
    '4300',
    'M',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2953'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2953-79-01-6-ABC',
    '2953', 'The data from Görgényi et&nbsp;al. (2002) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;480.92432 +24776.46284/T +68.60174&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2953-79-01-6-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '3600',
    'M',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2522'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;4</sup>',
    '4900',
    'M',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='1026'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='1573'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at296K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '3900',
    'M',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2896'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '4800',
    'M',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3692'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3692-79-01-6-ABC',
    '3692', 'The data from Knauss et&nbsp;al. (2000) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;389.28726 +21123.08804/T +54.69871&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3692-79-01-6-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;4</sup>',
    '4900',
    'M',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='1107'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2935'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;4</sup>',
    '3700',
    'M',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='1046'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='1113'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='1114'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;4</sup>',
    '4000',
    'M',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='1114'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '3800',
    'M',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='837'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2450'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '2200',
    'M',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2904'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;4</sup>',
    '3600',
    'M',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2905'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2463'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2930'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '3900',
    'M',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='584'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='622'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;4</sup>',
    '5000',
    'M',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2931'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2931-79-01-6-ABC',
    '2931', 'The data from Khalfaoui and Newsham (1994b) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;511.93773 +26713.30359/T +72.90551&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2931-79-01-6-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;4</sup>',
    '3100',
    'M',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='599'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0599-79-01-6-ABC',
    '599', 'The data from Robbins et&nbsp;al. (1993) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( 176.56015 &#8722;5511.47473/T &#8722;28.96682&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0599-79-01-6-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='637'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2493'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '3700',
    'M',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='855'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0855-79-01-6-ABC',
    '855', 'The data from Wright et&nbsp;al. (1992) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( 681.41357 &#8722;27448.54898/T &#8722;104.63745&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0855-79-01-6-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '4200',
    'M',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='856'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;4</sup>',
    '4900',
    'M',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='1148'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref1148-79-01-6-ABC',
    '1148', 'The data from Cooling et&nbsp;al. (1992) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;574.03630 +29404.80442/T +82.22224&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref1148-79-01-6-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '5200',
    'M',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='598'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '5200',
    'M',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2270'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;4</sup>',
    '2000',
    'M',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2901'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2901'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2924'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;4</sup>',
    '3700',
    'M',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='1156'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1156'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '4800',
    'M',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='532'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;4</sup>',
    '4700',
    'M',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2243'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2448'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2479'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;4</sup>',
    '5400',
    'M',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='1331'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '4300',
    'M',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2269'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2902'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;4</sup>',
    '4900',
    'M',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='601'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '4600',
    'M',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='1150'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;4</sup>',
    '4800',
    'M',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2271'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2918'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='544'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='544'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2905'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='545'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='545noTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='545'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='545'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at275K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='1916'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;4</sup>',
    '1600',
    'X',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;4</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3083'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3600',
    'Q',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-Test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4200',
    '?',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='trichloroethene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tetrachloroethene',
    'C<sub>2</sub>Cl<sub>4</sub>',
    'tetrachloroethylene',
    '127-18-4',
    'CYTYCFOTNPOANT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;4</sup>',
    '4700',
    'L',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='3681'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;4</sup>',
    '4500',
    'L',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;4</sup>',
    '4400',
    'L',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;4</sup>',
    '4500',
    'L',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;4</sup>',
    '4400',
    'L',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;4</sup>',
    '4700',
    'L',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '4500',
    'L',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='1855'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;4</sup>',
    '4200',
    'L',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;4</sup>',
    '4800',
    'L',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;4</sup>',
    '4800',
    'L',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;4</sup>',
    '4500',
    'M',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='3681'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3681-127-18-4-ABC',
    '3681', 'The data from Schwardt et&nbsp;al. (2021) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;330.94781 +18207.73829/T +46.05991&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3681-127-18-4-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;4</sup>',
    '4600',
    'M',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '4200',
    'M',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='2824'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;4</sup>',
    '4200',
    'M',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='2897'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;4</sup>',
    '5300',
    'M',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='1026'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;4</sup>',
    '4100',
    'M',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='2896'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;4</sup>',
    '4400',
    'M',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='3692'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3692-127-18-4-ABC',
    '3692', 'The data from Knauss et&nbsp;al. (2000) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;281.09217 +15955.08953/T +38.60107&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3692-127-18-4-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='2935'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='2938'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='1113'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='1114'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;4</sup>',
    '4100',
    'M',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='1114'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;4</sup>',
    '4200',
    'M',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='837'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='2450'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;4</sup>',
    '2200',
    'M',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='2904'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;4</sup>',
    '4200',
    'M',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='2905'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;4</sup>',
    '4800',
    'M',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='584'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;4</sup>',
    '5200',
    'M',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='599'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0599-127-18-4-ABC',
    '599', 'The data from Robbins et&nbsp;al. (1993) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;1145.60543 +55089.35358/T +167.32916&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0599-127-18-4-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='637'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='2493'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;4</sup>',
    '2100',
    'M',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='857'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HTdep_r2_lessthan_0.9'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='857'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;4</sup>',
    '5500',
    'M',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='598'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '5300',
    'M',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='2270'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;4</sup>',
    '4400',
    'M',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='1156'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1156'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;4</sup>',
    '4900',
    'M',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='532'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;4</sup>',
    '4400',
    'M',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='2243'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='2448'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='2479'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;4</sup>',
    '4600',
    'M',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='2269'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;4</sup>',
    '5100',
    'M',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='601'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;4</sup>',
    '4700',
    'M',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='1150'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;4</sup>',
    '5200',
    'M',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='2271'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '4300',
    'M',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='2951'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='2918'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='544'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='544'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='2905'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='3587'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='545'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='545noTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='545'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='545'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at275K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='1916'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;4</sup>',
    '1500',
    'X',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;4</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='3083'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;4</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='545'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;4</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='1916'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3900',
    'Q',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5100',
    '?',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tetrachloroethene'),
    (SELECT id from literature WHERE bibtexkey='2979'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at297K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dichloroethyne',
    'C<sub>2</sub>Cl<sub>2</sub>',
    '',
    '7572-29-4',
    'ZMJOVJSTYLQINE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichloroethyne'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-chloro-1-propene',
    'C<sub>3</sub>H<sub>5</sub>Cl',
    '',
    '590-21-6',
    'OWXJKYNZGFSVRC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-1-propene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-chloro-1-propene',
    'C<sub>3</sub>H<sub>5</sub>Cl',
    '',
    '557-98-2',
    'PNLQPWWBHXMFCA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-1-propene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-chloro-1-propene',
    'C<sub>3</sub>H<sub>5</sub>Cl',
    'allyl chloride',
    '107-05-1',
    'OSDWBNJEKMUWAV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='3-chloro-1-propene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '4500',
    'M',
    (SELECT id from species WHERE iupac='3-chloro-1-propene'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3-chloro-1-propene'),
    (SELECT id from literature WHERE bibtexkey='3646'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-chloro-1-propene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-chloro-1-propene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-chloro-1-propene'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-chloro-1-propene'),
    (SELECT id from literature WHERE bibtexkey='545'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-chloro-1-propene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-chloro-1-propene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-chloro-1-propene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-chloro-1-propene'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-chloro-1-propene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-chloro-1-propene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-chloro-1-propene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-chloro-1-propene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-chloro-1-propene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-chloro-1-propene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-chloro-1-propene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-chloro-1-propene'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-chloro-1-propene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-chloro-1-propene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-chloro-1-propene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-chloro-1-propene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1-dichloropropene',
    'C<sub>3</sub>H<sub>4</sub>Cl<sub>2</sub>',
    '',
    '563-58-6',
    'ZAIDIVBQUMFXEC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;4</sup>',
    '4200',
    'M',
    (SELECT id from species WHERE iupac='1,1-dichloropropene'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;4</sup>',
    '1900',
    'M',
    (SELECT id from species WHERE iupac='1,1-dichloropropene'),
    (SELECT id from literature WHERE bibtexkey='2904'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-dichloropropene',
    'C<sub>3</sub>H<sub>4</sub>Cl<sub>2</sub>',
    '',
    '563-54-2',
    'PPKPKFIWDXDAGC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dichloropropene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloropropene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloropropene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3-dichloropropene',
    'C<sub>3</sub>H<sub>4</sub>Cl<sub>2</sub>',
    '',
    '542-75-6',
    'UOORRWUZONOOLO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;3</sup>',
    '4300',
    'M',
    (SELECT id from species WHERE iupac='1,3-dichloropropene'),
    (SELECT id from literature WHERE bibtexkey='855'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0855-542-75-6-ABC',
    '855', 'The data from Wright et&nbsp;al. (1992) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;224.85290 +13463.70772/T +30.65123&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0855-542-75-6-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,3-dichloropropene'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3-dichloropropene'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,3-dichloropropene'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '1500',
    'X',
    (SELECT id from species WHERE iupac='1,3-dichloropropene'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1,3-dichloropropene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1,3-dichloropropene'),
    (SELECT id from literature WHERE bibtexkey='3653'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1,3-dichloropropene'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1,3-dichloropropene'),
    (SELECT id from literature WHERE bibtexkey='3083'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichloropropene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichloropropene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichloropropene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichloropropene'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichloropropene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichloropropene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>cis</i>-1,3-dichloropropene',
    'C<sub>3</sub>H<sub>4</sub>Cl<sub>2</sub>',
    '',
    '10061-01-5',
    'UOORRWUZONOOLO-UPHRSURJSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,3-dichloropropene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;3</sup>',
    '5500',
    'M',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,3-dichloropropene'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,3-dichloropropene'),
    (SELECT id from literature WHERE bibtexkey='3948'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at290K'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3948_exptl',
    '', 'Henry''s law constants were evaluated using data from Florida sandy field soil.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3948_exptl'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;3</sup>',
    '4300',
    'M',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,3-dichloropropene'),
    (SELECT id from literature WHERE bibtexkey='2904'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,3-dichloropropene'),
    (SELECT id from literature WHERE bibtexkey='3946'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;3</sup>',
    '5800',
    'M',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,3-dichloropropene'),
    (SELECT id from literature WHERE bibtexkey='3086'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,3-dichloropropene'),
    (SELECT id from literature WHERE bibtexkey='545'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,3-dichloropropene'),
    (SELECT id from literature WHERE bibtexkey='3948'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at290K'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3948_theor',
    '3948', 'According to Thomas et&nbsp;al. (2006), theoretical Henry''s law constants were calculated using the "normal boiling point, the critical temperature, and the enthalpy of volatilization at the normal boiling point".');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3948_theor'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='<i>cis</i>-1,3-dichloropropene'),
    (SELECT id from literature WHERE bibtexkey='1330'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>trans</i>-1,3-dichloropropene',
    'C<sub>3</sub>H<sub>4</sub>Cl<sub>2</sub>',
    '',
    '10061-02-6',
    'UOORRWUZONOOLO-OWOJBTEDSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,3-dichloropropene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;3</sup>',
    '4800',
    'M',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,3-dichloropropene'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,3-dichloropropene'),
    (SELECT id from literature WHERE bibtexkey='3948'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at290K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3948_exptl'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '5000',
    'M',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,3-dichloropropene'),
    (SELECT id from literature WHERE bibtexkey='2904'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,3-dichloropropene'),
    (SELECT id from literature WHERE bibtexkey='3946'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;3</sup>',
    '5700',
    'M',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,3-dichloropropene'),
    (SELECT id from literature WHERE bibtexkey='3086'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,3-dichloropropene'),
    (SELECT id from literature WHERE bibtexkey='545'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,3-dichloropropene'),
    (SELECT id from literature WHERE bibtexkey='3948'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at290K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3948_theor'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='<i>trans</i>-1,3-dichloropropene'),
    (SELECT id from literature WHERE bibtexkey='1330'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dichloropropene',
    'C<sub>3</sub>H<sub>4</sub>Cl<sub>2</sub>',
    '',
    '78-88-6',
    'FALCMQXTWHPRIH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2,3-dichloropropene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3-dichloropropene'),
    (SELECT id from literature WHERE bibtexkey='3946'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3-dichloropropene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3-dichloropropene'),
    (SELECT id from literature WHERE bibtexkey='545'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3-dichloropropene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dichloropropene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dichloropropene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dichloropropene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dichloropropene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dichloropropene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dichloropropene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dichloropropene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dichloropropene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dichloropropene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dichloropropene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dichloropropene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3-dichloropropene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3-trichloro-1-propene',
    'C<sub>3</sub>H<sub>3</sub>Cl<sub>3</sub>',
    '',
    '96-19-5',
    'HIILBTHBHCLUER-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-trichloro-1-propene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,2,3,3,3-hexachloro-1-propene',
    'C<sub>3</sub>Cl<sub>6</sub>',
    '',
    '1888-71-7',
    'VFDYKPARTDCDCU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1,2,3,3,3-hexachloro-1-propene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,3,3,3-hexachloro-1-propene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,3,3,3-hexachloro-1-propene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,3,3,3-hexachloro-1-propene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,3,3,3-hexachloro-1-propene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,3,3,3-hexachloro-1-propene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-chloro-1-butene',
    'C<sub>4</sub>H<sub>7</sub>Cl',
    '',
    '563-52-0',
    'VZGLVCFVUREVDP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-chloro-1-butene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-chloro-2-methyl-1-propene',
    'C<sub>4</sub>H<sub>7</sub>Cl',
    '',
    '563-47-3',
    'OHXAOPZTJOUYKM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-chloro-2-methyl-1-propene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-chloro-2-methyl-1-propene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-chloro-2-methyl-1-propene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-chloro-2-butene',
    'C<sub>4</sub>H<sub>7</sub>Cl',
    'crotyl chloride',
    '591-97-9',
    'YTKRILODNOEEPX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-chloro-2-butene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(Z)-1-chloro-2-butene',
    'C<sub>4</sub>H<sub>7</sub>Cl',
    '<i>cis</i>-1-chloro-2-butene',
    '4628-21-1',
    'YTKRILODNOEEPX-IHWYPQMZSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '2800',
    'M',
    (SELECT id from species WHERE iupac='(Z)-1-chloro-2-butene'),
    (SELECT id from literature WHERE bibtexkey='2923'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3800',
    'Q',
    (SELECT id from species WHERE iupac='(Z)-1-chloro-2-butene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2800',
    '?',
    (SELECT id from species WHERE iupac='(Z)-1-chloro-2-butene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(E)-1-chloro-2-butene',
    'C<sub>4</sub>H<sub>7</sub>Cl',
    '<i>trans</i>-1-chloro-2-butene',
    '4894-61-5',
    'YTKRILODNOEEPX-NSCUHMNNSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '3000',
    'M',
    (SELECT id from species WHERE iupac='(E)-1-chloro-2-butene'),
    (SELECT id from literature WHERE bibtexkey='2923'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3800',
    'Q',
    (SELECT id from species WHERE iupac='(E)-1-chloro-2-butene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3000',
    '?',
    (SELECT id from species WHERE iupac='(E)-1-chloro-2-butene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3-dichloro-2-butene',
    'C<sub>4</sub>H<sub>6</sub>Cl<sub>2</sub>',
    '',
    '926-57-8',
    'WLIADPFXSACYLS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichloro-2-butene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4-dichloro-2-butene',
    'C<sub>4</sub>H<sub>6</sub>Cl<sub>2</sub>',
    '',
    '764-41-0',
    'FQDIANVAWVHZIR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-dichloro-2-butene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-dichloro-2-butene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dichloro-2-butene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dichloro-2-butene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(Z)-1,4-dichloro-2-butene',
    'C<sub>4</sub>H<sub>6</sub>Cl<sub>2</sub>',
    '',
    '1476-11-5',
    'FQDIANVAWVHZIR-UPHRSURJSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '9400',
    'M',
    (SELECT id from species WHERE iupac='(Z)-1,4-dichloro-2-butene'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='(Z)-1,4-dichloro-2-butene'),
    (SELECT id from literature WHERE bibtexkey='3946'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(Z)-1,4-dichloro-2-butene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(Z)-1,4-dichloro-2-butene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(Z)-1,4-dichloro-2-butene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(E)-1,4-dichloro-2-butene',
    'C<sub>4</sub>H<sub>6</sub>Cl<sub>2</sub>',
    '',
    '110-57-6',
    'FQDIANVAWVHZIR-OWOJBTEDSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '6600',
    'M',
    (SELECT id from species WHERE iupac='(E)-1,4-dichloro-2-butene'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='(E)-1,4-dichloro-2-butene'),
    (SELECT id from literature WHERE bibtexkey='3946'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(E)-1,4-dichloro-2-butene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(E)-1,4-dichloro-2-butene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(E)-1,4-dichloro-2-butene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(E)-1,4-dichloro-2-butene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(E)-1,4-dichloro-2-butene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4-dichloro-1-butene',
    'C<sub>4</sub>H<sub>6</sub>Cl<sub>2</sub>',
    '',
    '760-23-6',
    'XVEASTGLHPVZNA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,4-dichloro-1-butene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,4-dichloro-1-butene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dichloro-1-butene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-chloro-2-methylpropene',
    'C<sub>4</sub>H<sub>7</sub>Cl',
    'dimethylvinyl chloride',
    '513-37-1',
    'KWISWUFGPUHDRY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-chloro-2-methylpropene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='1-chloro-2-methylpropene'),
    (SELECT id from literature WHERE bibtexkey='3034'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'CRCwrong1',
    '3034,479', 'Haynes (2014) refers to Mackay and Shiu (1981), but that article lists this value for 1-chloro-2-methylpropane (the saturated compound), not for 1-chloro-2-methylpropene.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='CRCwrong1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-chloro-1,3-butadiene',
    'C<sub>4</sub>H<sub>5</sub>Cl',
    '',
    '126-99-8',
    'YACLQRRMGMJLJV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-chloro-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-1,3-butadiene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hexachlorobutadiene',
    'CCl<sub>2</sub>CClCClCCl<sub>2</sub>',
    '',
    '87-68-3',
    'RWNKSTSCBHKHTB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;4</sup>',
    '5500',
    'L',
    (SELECT id from species WHERE iupac='hexachlorobutadiene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;4</sup>',
    '3100',
    'L',
    (SELECT id from species WHERE iupac='hexachlorobutadiene'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '6200',
    'M',
    (SELECT id from species WHERE iupac='hexachlorobutadiene'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '4900',
    'M',
    (SELECT id from species WHERE iupac='hexachlorobutadiene'),
    (SELECT id from literature WHERE bibtexkey='1107'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;4</sup>',
    '2500',
    'M',
    (SELECT id from species WHERE iupac='hexachlorobutadiene'),
    (SELECT id from literature WHERE bibtexkey='2904'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='hexachlorobutadiene'),
    (SELECT id from literature WHERE bibtexkey='1139'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='hexachlorobutadiene'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='hexachlorobutadiene'),
    (SELECT id from literature WHERE bibtexkey='544'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='544'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexachlorobutadiene'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexachlorobutadiene'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexachlorobutadiene'),
    (SELECT id from literature WHERE bibtexkey='2974'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexachlorobutadiene'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='hexachlorobutadiene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;4</sup>',
    '4600',
    'X',
    (SELECT id from species WHERE iupac='hexachlorobutadiene'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;4</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='hexachlorobutadiene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;4</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='hexachlorobutadiene'),
    (SELECT id from literature WHERE bibtexkey='3653'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;4</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='hexachlorobutadiene'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;4</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='hexachlorobutadiene'),
    (SELECT id from literature WHERE bibtexkey='3083'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexachlorobutadiene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexachlorobutadiene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexachlorobutadiene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexachlorobutadiene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexachlorobutadiene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexachlorobutadiene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexachlorobutadiene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5300',
    'Q',
    (SELECT id from species WHERE iupac='hexachlorobutadiene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexachlorobutadiene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3500',
    '?',
    (SELECT id from species WHERE iupac='hexachlorobutadiene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='hexachlorobutadiene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hexachlorocyclopentadiene',
    'C<sub>5</sub>Cl<sub>6</sub>',
    '',
    '77-47-4',
    'VUNCWTMEJYMOOR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='hexachlorocyclopentadiene'),
    (SELECT id from literature WHERE bibtexkey='2529'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='hexachlorocyclopentadiene'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexachlorocyclopentadiene'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexachlorocyclopentadiene'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexachlorocyclopentadiene'),
    (SELECT id from literature WHERE bibtexkey='2529'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexachlorocyclopentadiene'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;4</sup>',
    '1500',
    'X',
    (SELECT id from species WHERE iupac='hexachlorocyclopentadiene'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;4</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='hexachlorocyclopentadiene'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;4</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='hexachlorocyclopentadiene'),
    (SELECT id from literature WHERE bibtexkey='3083'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexachlorocyclopentadiene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexachlorocyclopentadiene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexachlorocyclopentadiene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexachlorocyclopentadiene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexachlorocyclopentadiene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexachlorocyclopentadiene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexachlorocyclopentadiene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexachlorocyclopentadiene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chlordane',
    'C<sub>10</sub>H<sub>6</sub>Cl<sub>8</sub>',
    '',
    '57-74-9',
    'BIWJNBZANLAXMG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='chlordane'),
    (SELECT id from literature WHERE bibtexkey='901'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at296K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='chlordane'),
    (SELECT id from literature WHERE bibtexkey='901'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='901wwc'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='chlordane'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chlordane'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='chlordane'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='chlordane'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='chlordane'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='chlordane'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='chlordane'),
    (SELECT id from literature WHERE bibtexkey='3083'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlordane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlordane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlordane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlordane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlordane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlordane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlordane'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlordane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chlordane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>cis</i>-chlordane',
    'C<sub>10</sub>H<sub>6</sub>Cl<sub>8</sub>',
    '&#945;-chlordane',
    '5103-71-9',
    'BIWJNBZANLAXMG-KMMBHOGFSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='<i>cis</i>-chlordane'),
    (SELECT id from literature WHERE bibtexkey='2948'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='LDV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='<i>cis</i>-chlordane'),
    (SELECT id from literature WHERE bibtexkey='2948'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '4100',
    'M',
    (SELECT id from species WHERE iupac='<i>cis</i>-chlordane'),
    (SELECT id from literature WHERE bibtexkey='2492'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '6100',
    'M',
    (SELECT id from species WHERE iupac='<i>cis</i>-chlordane'),
    (SELECT id from literature WHERE bibtexkey='2814'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='<i>cis</i>-chlordane'),
    (SELECT id from literature WHERE bibtexkey='1926'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1926'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='<i>cis</i>-chlordane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='<i>cis</i>-chlordane'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2614_pc_problem'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;3</sup>',
    '7300',
    'T',
    (SELECT id from species WHERE iupac='<i>cis</i>-chlordane'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>cis</i>-chlordane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>trans</i>-chlordane',
    'C<sub>10</sub>H<sub>6</sub>Cl<sub>8</sub>',
    '&#946;-chlordane',
    '5103-74-2',
    'BIWJNBZANLAXMG-OESJLNMISA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='<i>trans</i>-chlordane'),
    (SELECT id from literature WHERE bibtexkey='2948'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='LDV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='<i>trans</i>-chlordane'),
    (SELECT id from literature WHERE bibtexkey='2948'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '3500',
    'M',
    (SELECT id from species WHERE iupac='<i>trans</i>-chlordane'),
    (SELECT id from literature WHERE bibtexkey='2492'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;2</sup>',
    '7600',
    'M',
    (SELECT id from species WHERE iupac='<i>trans</i>-chlordane'),
    (SELECT id from literature WHERE bibtexkey='2814'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='<i>trans</i>-chlordane'),
    (SELECT id from literature WHERE bibtexkey='1926'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1926'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='<i>trans</i>-chlordane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='<i>trans</i>-chlordane'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2614_pc_problem'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '7100',
    'T',
    (SELECT id from species WHERE iupac='<i>trans</i>-chlordane'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-chlordane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>trans</i>-chlordane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '&#947;-chlordane',
    'C<sub>10</sub>H<sub>6</sub>Cl<sub>8</sub>',
    '',
    '5566-34-7',
    'JBZJEPYXXVKOKF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='&#947;-chlordane'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_O1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>cis</i>-nonachlor',
    'C<sub>10</sub>H<sub>5</sub>Cl<sub>9</sub>',
    '',
    '5103-73-1',
    'OCHOKXCPKDPNQU-BBXWSCHTSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '5100',
    'M',
    (SELECT id from species WHERE iupac='<i>cis</i>-nonachlor'),
    (SELECT id from literature WHERE bibtexkey='2814'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>trans</i>-nonachlor',
    'C<sub>10</sub>H<sub>5</sub>Cl<sub>9</sub>',
    '',
    '39765-80-5',
    'OCHOKXCPKDPNQU-FLVMBEMLSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '4800',
    'M',
    (SELECT id from species WHERE iupac='<i>trans</i>-nonachlor'),
    (SELECT id from literature WHERE bibtexkey='2492'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;2</sup>',
    '8000',
    'M',
    (SELECT id from species WHERE iupac='<i>trans</i>-nonachlor'),
    (SELECT id from literature WHERE bibtexkey='2814'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;4</sup>',
    '7600',
    'T',
    (SELECT id from species WHERE iupac='<i>trans</i>-nonachlor'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chlorobenzene',
    'C<sub>6</sub>H<sub>5</sub>Cl',
    '',
    '108-90-7',
    'MVPPADPHJFYWMZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '3700',
    'L',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3681'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3681chlorobenzene',
    '3681,3722', 'The regression parameters for chlorobenzene in Table&nbsp;1 of Schwardt et&nbsp;al. (2021) are wrong. Corrected values from Schwardt et&nbsp;al. (2022) are used here.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3681chlorobenzene'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '3600',
    'L',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '3800',
    'L',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '3800',
    'L',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '3800',
    'M',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3681'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3681-108-90-7-ABC',
    '3681', 'The data from Schwardt et&nbsp;al. (2021) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;266.69788 +14811.78372/T +37.00246&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3681-108-90-7-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;3</sup>',
    '4400',
    'M',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '1300',
    'M',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2982'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HTdep_r2_lessthan_0.9'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2970'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '2300',
    'M',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2996'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2996'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '4300',
    'M',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1107'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2935'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2938'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2950'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3646'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2339'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2450'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '3600',
    'M',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2904'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '1700',
    'M',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2905'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2930'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '2900',
    'M',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2931'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2931-108-90-7-ABC',
    '2931', 'The data from Khalfaoui and Newsham (1994b) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;757.46460 +35956.18738/T +110.75693&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2931-108-90-7-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='637'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '2900',
    'M',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='858'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2457'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '3100',
    'M',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1148'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref1148-108-90-7-ABC',
    '1148', 'The data from Cooling et&nbsp;al. (1992) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;820.00716 +38880.20610/T +120.01460&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref1148-108-90-7-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '4700',
    'M',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2270'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '2700',
    'M',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1156'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1156'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2448'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2479'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '3500',
    'M',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1150'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '4200',
    'M',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2271'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='490'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2918'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '4900',
    'M',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='640'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '2400',
    'V',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2339'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2905'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3110'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2971'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1910'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='490'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '2100',
    'X',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2165'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3083'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4000',
    'Q',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1935'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2542'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2481'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4000',
    '?',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2233'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chlorobenzene-d5',
    'C<sub>6</sub>D<sub>5</sub>Cl',
    '',
    '3114-55-4',
    'MVPPADPHJFYWMZ-RALIUCGRSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '4500',
    'M',
    (SELECT id from species WHERE iupac='chlorobenzene-d5'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-dichlorobenzene',
    'C<sub>6</sub>H<sub>4</sub>Cl<sub>2</sub>',
    'o-dichlorobenzene',
    '95-50-1',
    'RFFLAFLAYFXFSW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;3</sup>',
    '3700',
    'L',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3681'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;3</sup>',
    '5200',
    'L',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3518-95-50-1-consicheck',
    '3518', 'Values at 298&nbsp;K in Tables&nbsp;C2 and C5 of Brockbank (2013) are inconsistent, with 8&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3518-95-50-1-consicheck'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;3</sup>',
    '5300',
    'L',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '1943-95-50-1-erratum',
    '1943', 'Erratum for page 344 of Fogg and Sangster (2003): their reference [89] does not contain 1,2-dichlorobenzene.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1943-95-50-1-erratum'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;3</sup>',
    '5900',
    'L',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;3</sup>',
    '5900',
    'L',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;3</sup>',
    '4200',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2970'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2935'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2339'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2450'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '5000',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2904'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;3</sup>',
    '4400',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2905'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2457'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3675'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;3</sup>',
    '5100',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2270'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;3</sup>',
    '1400',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1156'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HTdep_r2_lessthan_0.5'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1156'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1139'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;3</sup>',
    '6700',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2269'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2918'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2339'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2905'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3110'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;3</sup>',
    '2800',
    'X',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2165'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3083'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4400',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1935'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2542'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4800',
    '?',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2979'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at297K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-dichlorobenzene-d4',
    'C<sub>6</sub>D<sub>4</sub>Cl<sub>2</sub>',
    'o-dichlorobenzene-d4',
    '2199-69-1',
    'RFFLAFLAYFXFSW-RHQRLBAQSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;3</sup>',
    '4200',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichlorobenzene-d4'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3-dichlorobenzene',
    'C<sub>6</sub>H<sub>4</sub>Cl<sub>2</sub>',
    'm-dichlorobenzene',
    '541-73-1',
    'ZPQOPVIELGIULI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '3700',
    'L',
    (SELECT id from species WHERE iupac='1,3-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3681'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '4400',
    'L',
    (SELECT id from species WHERE iupac='1,3-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '4300',
    'L',
    (SELECT id from species WHERE iupac='1,3-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,3-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;3</sup>',
    '4800',
    'M',
    (SELECT id from species WHERE iupac='1,3-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,3-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2970'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,3-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2950'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,3-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2450'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '4400',
    'M',
    (SELECT id from species WHERE iupac='1,3-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2904'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,3-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='637'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '2600',
    'M',
    (SELECT id from species WHERE iupac='1,3-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1156'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HTdep_r2_lessthan_0.9'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1156'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,3-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1139'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,3-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,3-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2918'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2339'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3110'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,3-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '2400',
    'X',
    (SELECT id from species WHERE iupac='1,3-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1,3-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1,3-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3083'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4100',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1935'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-Test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2542'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,3-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4500',
    '?',
    (SELECT id from species WHERE iupac='1,3-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,3-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,3-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,3-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,3-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4-dichlorobenzene',
    'C<sub>6</sub>H<sub>4</sub>Cl<sub>2</sub>',
    'p-dichlorobenzene',
    '106-46-7',
    'OCJBOOLMMGQPQU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;3</sup>',
    '3800',
    'L',
    (SELECT id from species WHERE iupac='1,4-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3681'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '6000',
    'L',
    (SELECT id from species WHERE iupac='1,4-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;3</sup>',
    '4400',
    'L',
    (SELECT id from species WHERE iupac='1,4-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,4-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;3</sup>',
    '4600',
    'M',
    (SELECT id from species WHERE iupac='1,4-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,4-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2970'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,4-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1113'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,4-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2339'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,4-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2450'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;3</sup>',
    '4800',
    'M',
    (SELECT id from species WHERE iupac='1,4-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2904'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '2700',
    'M',
    (SELECT id from species WHERE iupac='1,4-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1156'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1156'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,4-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2479'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,4-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1139'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,4-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,4-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2339'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3110'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,4-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;3</sup>',
    '2700',
    'X',
    (SELECT id from species WHERE iupac='1,4-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1,4-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2165'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1,4-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1,4-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3083'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4100',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1935'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2542'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2481'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,4-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3700',
    '?',
    (SELECT id from species WHERE iupac='1,4-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,4-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,4-dichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3-trichlorobenzene',
    'C<sub>6</sub>H<sub>3</sub>Cl<sub>3</sub>',
    '',
    '87-61-6',
    'RELMFMZEBKVZJC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '4600',
    'L',
    (SELECT id from species WHERE iupac='1,2,3-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '4800',
    'M',
    (SELECT id from species WHERE iupac='1,2,3-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;3</sup>',
    '4600',
    'M',
    (SELECT id from species WHERE iupac='1,2,3-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2926'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2,3-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3014'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '4200',
    'M',
    (SELECT id from species WHERE iupac='1,2,3-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1107'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2,3-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2339'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '7300',
    'M',
    (SELECT id from species WHERE iupac='1,2,3-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2904'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2,3-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1146'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2,3-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1139'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2,3-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2339'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3110'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4800',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1935'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2542'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2,3-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4200',
    '?',
    (SELECT id from species WHERE iupac='1,2,3-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3-trichlorobenzene-d3',
    'C<sub>6</sub>D<sub>3</sub>Cl<sub>3</sub>',
    '',
    '3907-98-0',
    'SMNOERSLNYGGOU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '4600',
    'M',
    (SELECT id from species WHERE iupac='1,2,3-trichlorobenzene-d3'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4-trichlorobenzene',
    'C<sub>6</sub>H<sub>3</sub>Cl<sub>3</sub>',
    '',
    '120-82-1',
    'PBKONEOXTCPAFI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '3100',
    'L',
    (SELECT id from species WHERE iupac='1,2,4-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3681'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '6400',
    'L',
    (SELECT id from species WHERE iupac='1,2,4-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '5100',
    'M',
    (SELECT id from species WHERE iupac='1,2,4-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2,4-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3014'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '3500',
    'M',
    (SELECT id from species WHERE iupac='1,2,4-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1107'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '1107-120-82-1-consicheck',
    '1107', 'The data listed in Tables&nbsp;2 and 3 of Dewulf et&nbsp;al. (1999) are inconsistent, with 7&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1107-120-82-1-consicheck'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2,4-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2935'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;3</sup>',
    '5500',
    'M',
    (SELECT id from species WHERE iupac='1,2,4-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2904'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2,4-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1146'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;3</sup>',
    '3900',
    'M',
    (SELECT id from species WHERE iupac='1,2,4-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1156'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HTdep_r2_lessthan_0.9'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1156'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2,4-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1139'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2,4-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,4-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2612_pc_problem'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,4-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,4-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,4-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2339'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,4-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,4-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,4-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2975'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at283K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,4-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3110'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,4-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2971'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,4-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,4-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,2,4-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,2,4-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;3</sup>',
    '2500',
    'X',
    (SELECT id from species WHERE iupac='1,2,4-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1,2,4-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;4</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1,2,4-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1,2,4-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3083'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4500',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1935'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2542'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2,4-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3200',
    '?',
    (SELECT id from species WHERE iupac='1,2,4-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2,4-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4-trichlorobenzene-d3',
    'C<sub>6</sub>D<sub>3</sub>Cl<sub>3</sub>',
    '',
    '2199-72-6',
    'PBKONEOXTCPAFI-CBYSEHNBSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;3</sup>',
    '4600',
    'M',
    (SELECT id from species WHERE iupac='1,2,4-trichlorobenzene-d3'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3,5-trichlorobenzene',
    'C<sub>6</sub>H<sub>3</sub>Cl<sub>3</sub>',
    '',
    '108-70-3',
    'XKEFYDZQGKAQCN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '4100',
    'M',
    (SELECT id from species WHERE iupac='1,3,5-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1107'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '1107-108-70-3-consicheck',
    '1107', 'The data listed in Tables&nbsp;2 and 3 of Dewulf et&nbsp;al. (1999) are inconsistent, with 7&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1107-108-70-3-consicheck'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,3,5-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1146'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,3,5-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2448'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,3,5-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1139'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3,5-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2612_pc_problem'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3,5-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3,5-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3,5-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2339'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3,5-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3,5-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3,5-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3,5-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3110'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3,5-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4200',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1935'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2542'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,3,5-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3539'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3539-108-70-3',
    '3539,1139', 'Rumble (2021) refers to Oliver (1985) as the source, but this value cannot be found there.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3539-108-70-3'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,3,5-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4400',
    '?',
    (SELECT id from species WHERE iupac='1,3,5-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,4-tetrachlorobenzene',
    'C<sub>6</sub>H<sub>2</sub>Cl<sub>4</sub>',
    '',
    '634-66-2',
    'GBDZXPJXOMHESU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2935'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '4800',
    'M',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1146'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2448'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1139'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2339'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2975'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at283K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3110'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5200',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1935'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2542'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4500',
    '?',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,5-tetrachlorobenzene',
    'C<sub>6</sub>H<sub>2</sub>Cl<sub>4</sub>',
    '',
    '634-90-2',
    'QZYNWJQFTJXIRN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2,3,5-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2339'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2,3,5-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1146'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2,3,5-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3,5-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3,5-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3,5-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3,5-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2339'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3,5-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3,5-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3110'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3,5-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1,2,3,5-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,5-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,5-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,5-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,5-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,5-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,5-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,5-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,5-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,5-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1935'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,5-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-Test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,5-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,5-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2542'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,5-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,5-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2,3,5-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4,5-tetrachlorobenzene',
    'C<sub>6</sub>H<sub>2</sub>Cl<sub>4</sub>',
    '',
    '95-94-3',
    'JHBKHLUZVFWLAG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2,4,5-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3009'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2,4,5-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3014'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2,4,5-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1139'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,4,5-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,4,5-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,4,5-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,4,5-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2339'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,4,5-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,4,5-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3110'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,4,5-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,5-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,5-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,5-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,5-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,5-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,5-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,5-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,5-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,5-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,5-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1935'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,5-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,5-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,5-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2542'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,5-tetrachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pentachlorobenzene',
    'C<sub>6</sub>HCl<sub>5</sub>',
    '',
    '608-93-5',
    'CEOCDNVZRAIOQZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '5400',
    'L',
    (SELECT id from species WHERE iupac='pentachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3681'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '5200',
    'L',
    (SELECT id from species WHERE iupac='pentachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2948'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='LDV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '5600',
    'L',
    (SELECT id from species WHERE iupac='pentachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2948'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='pentachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3009'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='pentachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3014'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '5200',
    'M',
    (SELECT id from species WHERE iupac='pentachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1146'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='pentachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2448'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='pentachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1139'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pentachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pentachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pentachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pentachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2339'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pentachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pentachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3110'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pentachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5700',
    'Q',
    (SELECT id from species WHERE iupac='pentachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1935'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2542'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pentachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5100',
    '?',
    (SELECT id from species WHERE iupac='pentachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hexachlorobenzene',
    'C<sub>6</sub>Cl<sub>6</sub>',
    '',
    '118-74-1',
    'CKAPSXZOOQJIBF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;3</sup>',
    '6600',
    'L',
    (SELECT id from species WHERE iupac='hexachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '6000',
    'L',
    (SELECT id from species WHERE iupac='hexachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2948'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='LDV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '6400',
    'L',
    (SELECT id from species WHERE iupac='hexachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2948'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='hexachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3009'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='hexachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3014'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '6900',
    'M',
    (SELECT id from species WHERE iupac='hexachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2492'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='hexachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;5</sup>',
    '570',
    'M',
    (SELECT id from species WHERE iupac='hexachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='903'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='903'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '5700',
    'M',
    (SELECT id from species WHERE iupac='hexachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1146'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6',
    '',
    'M',
    (SELECT id from species WHERE iupac='hexachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2448'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='hexachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1139'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='hexachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2533'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at296K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='hexachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1926'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1926'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='hexachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2339'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2974'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2977'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2966'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2975'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at283K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3110'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2971'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '3700',
    'T',
    (SELECT id from species WHERE iupac='hexachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='hexachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;3</sup>',
    '1600',
    'X',
    (SELECT id from species WHERE iupac='hexachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='hexachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='hexachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='hexachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='hexachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3083'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6400',
    'Q',
    (SELECT id from species WHERE iupac='hexachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1935'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2542'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='hexachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7200',
    '?',
    (SELECT id from species WHERE iupac='hexachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='hexachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(chloromethyl)-benzene',
    'C<sub>6</sub>H<sub>5</sub>CH<sub>2</sub>Cl',
    'benzylchloride',
    '100-44-7',
    'KCXMKQUNVWSEMD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '4400',
    'L',
    (SELECT id from species WHERE iupac='(chloromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '7200',
    'M',
    (SELECT id from species WHERE iupac='(chloromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='(chloromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2450'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='(chloromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2457'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(chloromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(chloromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(chloromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(chloromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(chloromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(chloromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(chloromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(chloromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(chloromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(chloromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(chloromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(chloromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(chloromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-chloro-2-methylbenzene',
    'C<sub>7</sub>H<sub>7</sub>Cl',
    'o-chlorotoluene',
    '95-49-8',
    'IBSQPLPBRSHTTG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '4500',
    'L',
    (SELECT id from species WHERE iupac='1-chloro-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;3</sup>',
    '4100',
    'M',
    (SELECT id from species WHERE iupac='1-chloro-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '3400',
    'M',
    (SELECT id from species WHERE iupac='1-chloro-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2904'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '3500',
    'M',
    (SELECT id from species WHERE iupac='1-chloro-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1150'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '3000',
    'X',
    (SELECT id from species WHERE iupac='1-chloro-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1-chloro-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2165'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4400',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-chloro-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4900',
    '?',
    (SELECT id from species WHERE iupac='1-chloro-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-chloro-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-chloro-3-methylbenzene',
    'C<sub>7</sub>H<sub>7</sub>Cl',
    'm-chlorotoluene',
    '108-41-8',
    'OSOUNOBYRMOXQQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-chloro-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-chloro-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2165'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4400',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4800',
    '?',
    (SELECT id from species WHERE iupac='1-chloro-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-chloro-4-methylbenzene',
    'C<sub>7</sub>H<sub>7</sub>Cl',
    'p-chlorotoluene',
    '106-43-4',
    'NPDACUSDTOMAMK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '4900',
    'L',
    (SELECT id from species WHERE iupac='1-chloro-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '4200',
    'M',
    (SELECT id from species WHERE iupac='1-chloro-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '3900',
    'M',
    (SELECT id from species WHERE iupac='1-chloro-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2904'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-chloro-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-chloro-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-chloro-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4400',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4300',
    '?',
    (SELECT id from species WHERE iupac='1-chloro-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-chloro-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(dichloromethyl)-benzene',
    'C<sub>7</sub>H<sub>6</sub>Cl<sub>2</sub>',
    '',
    '98-87-3',
    'CAHQGWAXKLQREW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(dichloromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(dichloromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(dichloromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(dichloromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(dichloromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(dichloromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(dichloromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(dichloromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-dichloro-4-methylbenzene',
    'C<sub>7</sub>H<sub>6</sub>Cl<sub>2</sub>',
    '3,4-dichlorotoluene',
    '95-75-0',
    'WYUIWKFIFOJVKW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dichloro-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloro-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloro-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloro-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloro-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloro-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3-dichloro-2-methylbenzene',
    'C<sub>7</sub>H<sub>6</sub>Cl<sub>2</sub>',
    '2,6-dichlorotoluene',
    '118-69-4',
    'DMEDNTFWIHCBRK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichloro-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichloro-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichloro-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichloro-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichloro-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dichloro-1-methylbenzene',
    'C<sub>7</sub>H<sub>6</sub>Cl<sub>2</sub>',
    '2,4-dichlorotoluene',
    '95-73-8',
    'FUNUTBJJKQIVSY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '5000',
    'L',
    (SELECT id from species WHERE iupac='2,4-dichloro-1-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3681'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '5000',
    'L',
    (SELECT id from species WHERE iupac='2,4-dichloro-1-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '4900',
    'M',
    (SELECT id from species WHERE iupac='2,4-dichloro-1-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2926'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dichloro-1-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dichloro-1-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dichloro-1-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dichloro-1-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dichloro-1-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4400',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dichloro-1-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5500',
    '?',
    (SELECT id from species WHERE iupac='2,4-dichloro-1-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,6-trichloromethylbenzene',
    'C<sub>7</sub>H<sub>5</sub>Cl<sub>3</sub>',
    '2,3,6-trichlorotoluene',
    '2077-46-5',
    'UZYYBZNZSSNYSA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3,6-trichloromethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1139'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,6-trichloromethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,6-trichloromethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,6-trichloromethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,5-trichloromethylbenzene',
    'C<sub>7</sub>H<sub>5</sub>Cl<sub>3</sub>',
    '2,4,5-trichlorotoluene',
    '6639-30-1',
    'ZCXHZKNWIYVQNC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,4,5-trichloromethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1139'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5-trichloromethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5-trichloromethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5-trichloromethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,6-trichloromethylbenzene',
    'C<sub>7</sub>H<sub>5</sub>Cl<sub>3</sub>',
    '2,4,6-trichlorotoluene',
    '23749-65-7',
    'RCTKUIOMKBEGTG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,4,6-trichloromethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pentachloromethylbenzene',
    'C<sub>7</sub>H<sub>3</sub>Cl<sub>5</sub>',
    '2,3,4,5,6-pentachlorotoluene',
    '877-11-2',
    'AVSIMRGRHWKCAY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='pentachloromethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1139'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentachloromethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentachloromethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentachloromethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-chloro-2-(chloromethyl)benzene',
    'C<sub>7</sub>H<sub>6</sub>Cl<sub>2</sub>',
    '',
    '611-19-8',
    'BASMANVIUSSIIM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-2-(chloromethyl)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-2-(chloromethyl)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-2-(chloromethyl)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-2-(chloromethyl)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-chloro-4-(chloromethyl)benzene',
    'C<sub>7</sub>H<sub>6</sub>Cl<sub>2</sub>',
    '',
    '104-83-6',
    'JQZAEUFPPSRDOP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-4-(chloromethyl)benzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-4-(chloromethyl)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-4-(chloromethyl)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-4-(chloromethyl)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-4-(chloromethyl)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chloro(dichloromethyl)benzene',
    'C<sub>7</sub>H<sub>5</sub>Cl<sub>3</sub>',
    '',
    '88-66-4',
    'BXSVYGKOUULJCL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloro(dichloromethyl)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloro(dichloromethyl)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloro(dichloromethyl)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloro(dichloromethyl)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(trichloromethyl)-benzene',
    'C<sub>7</sub>H<sub>5</sub>Cl<sub>3</sub>',
    '',
    '98-07-7',
    'XEMRAKSQROQPBR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(trichloromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(trichloromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(trichloromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(trichloromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(trichloromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-chloro-4-(trichloromethyl)benzene',
    'C<sub>7</sub>H<sub>4</sub>Cl<sub>4</sub>',
    '',
    '5216-25-1',
    'LVZPKYYPPLUECL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-4-(trichloromethyl)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-4-(trichloromethyl)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-4-(trichloromethyl)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-4-(trichloromethyl)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-chloro-3-ethenylbenzene',
    'C<sub>8</sub>H<sub>7</sub>Cl',
    '',
    '2039-85-2',
    'BOVQCIDBZXNFEJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-3-ethenylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-chloro-4-ethenylbenzene',
    'C<sub>8</sub>H<sub>7</sub>Cl',
    '',
    '1073-67-2',
    'KTZVZZJJVJQZHV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-4-ethenylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4-dichloro-2,5-dimethylbenzene',
    'C<sub>8</sub>H<sub>8</sub>Cl<sub>2</sub>',
    '',
    '1124-05-6',
    'UTGSRNVBAFCOEU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dichloro-2,5-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dichloro-2,5-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dichloro-2,5-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dichloro-2,5-dimethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4-bis(trichloromethyl)benzene',
    'C<sub>8</sub>H<sub>4</sub>Cl<sub>6</sub>',
    '',
    '68-36-0',
    'OTEKOJQFKOIXMU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-bis(trichloromethyl)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-bis(trichloromethyl)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-bis(trichloromethyl)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-bis(trichloromethyl)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '&#945;,&#945;-dichloro-o-xylene',
    'C<sub>8</sub>H<sub>8</sub>Cl<sub>2</sub>',
    '',
    '612-12-4',
    'FMGGHNGKHRCJLL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '11000',
    'M',
    (SELECT id from species WHERE iupac='&#945;,&#945;-dichloro-o-xylene'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-chlorostyrene',
    'C<sub>8</sub>H<sub>7</sub>Cl',
    '',
    '2039-87-4',
    'ISRGONDNXBCDBM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chlorostyrene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chlorostyrene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'octachlorostyrene',
    'C<sub>8</sub>Cl<sub>8</sub>',
    '',
    '29082-74-4',
    'RUYUCCQRWINUHE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='octachlorostyrene'),
    (SELECT id from literature WHERE bibtexkey='1139'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octachlorostyrene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octachlorostyrene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octachlorostyrene'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'heptachlor',
    'C<sub>10</sub>H<sub>5</sub>Cl<sub>7</sub>',
    '',
    '76-44-8',
    'FRCCEHPWNOQAEU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='heptachlor'),
    (SELECT id from literature WHERE bibtexkey='2948'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='LDV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='heptachlor'),
    (SELECT id from literature WHERE bibtexkey='2948'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '4300',
    'M',
    (SELECT id from species WHERE iupac='heptachlor'),
    (SELECT id from literature WHERE bibtexkey='2814'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='heptachlor'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='heptachlor'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='heptachlor'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='heptachlor'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='heptachlor'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='heptachlor'),
    (SELECT id from literature WHERE bibtexkey='mccarty80'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from2556'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='heptachlor'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='heptachlor'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='heptachlor'),
    (SELECT id from literature WHERE bibtexkey='3083'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptachlor'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptachlor'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptachlor'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptachlor'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptachlor'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptachlor'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='heptachlor'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='heptachlor'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-chloro-2-methyl-2-phenylpropane',
    'C<sub>10</sub>H<sub>13</sub>Cl',
    '',
    '515-40-2',
    'DNXXUUPUQXSUFH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-2-methyl-2-phenylpropane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-2-methyl-2-phenylpropane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-2-methyl-2-phenylpropane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-2-methyl-2-phenylpropane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3-dichloro-5-[(2S)-2,4,4,4-tetrachlorobutan-2-yl]benzene',
    'C<sub>10</sub>H<sub>8</sub>Cl<sub>6</sub>',
    '',
    '73588-42-8',
    'DELZPCKTBPIBEE-VIFPVBQESA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichloro-5-[(2S)-2,4,4,4-tetrachlorobutan-2-yl]benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichloro-5-[(2S)-2,4,4,4-tetrachlorobutan-2-yl]benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichloro-5-[(2S)-2,4,4,4-tetrachlorobutan-2-yl]benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichloro-5-[(2S)-2,4,4,4-tetrachlorobutan-2-yl]benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,4,5,6,7,8,8-nonachloro-2,3,3a,4,7,7a-hexahydro-4,7-methano-1H-indene',
    'C<sub>10</sub>H<sub>5</sub>Cl<sub>9</sub>',
    'nonachlor',
    '3734-49-4',
    'OCHOKXCPKDPNQU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4,5,6,7,8,8-nonachloro-2,3,3a,4,7,7a-hexahydro-4,7-methano-1H-indene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1-dichloro-2,2-bis-(4-chlorophenyl)-ethane',
    'C<sub>14</sub>H<sub>10</sub>Cl<sub>4</sub>',
    'p,p''-DDD',
    '72-54-8',
    'AHJKRLASYNVKDZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,1-dichloro-2,2-bis-(4-chlorophenyl)-ethane'),
    (SELECT id from literature WHERE bibtexkey='2948'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='LDV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,1-dichloro-2,2-bis-(4-chlorophenyl)-ethane'),
    (SELECT id from literature WHERE bibtexkey='2948'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,1-dichloro-2,2-bis-(4-chlorophenyl)-ethane'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;1</sup>',
    '5100',
    'M',
    (SELECT id from species WHERE iupac='1,1-dichloro-2,2-bis-(4-chlorophenyl)-ethane'),
    (SELECT id from literature WHERE bibtexkey='2814'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,1-dichloro-2,2-bis-(4-chlorophenyl)-ethane'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1-dichloro-2,2-bis-(4-chlorophenyl)-ethane'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2614_pc_problem'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1-dichloro-2,2-bis-(4-chlorophenyl)-ethane'),
    (SELECT id from literature WHERE bibtexkey='2974'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1-dichloro-2,2-bis-(4-chlorophenyl)-ethane'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1-dichloro-2,2-bis-(4-chlorophenyl)-ethane'),
    (SELECT id from literature WHERE bibtexkey='2971'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '7300',
    'T',
    (SELECT id from species WHERE iupac='1,1-dichloro-2,2-bis-(4-chlorophenyl)-ethane'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;4</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1,1-dichloro-2,2-bis-(4-chlorophenyl)-ethane'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichloro-2,2-bis-(4-chlorophenyl)-ethane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichloro-2,2-bis-(4-chlorophenyl)-ethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichloro-2,2-bis-(4-chlorophenyl)-ethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichloro-2,2-bis-(4-chlorophenyl)-ethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1-dichloro-2,2-bis-(4-chlorophenyl)-ethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'mitotane',
    'C<sub>14</sub>H<sub>10</sub>Cl<sub>4</sub>',
    'o,p''-DDD',
    '53-19-0',
    'JWBOIMRXGHLCPP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'V',
    (SELECT id from species WHERE iupac='mitotane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'V',
    (SELECT id from species WHERE iupac='mitotane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'V',
    (SELECT id from species WHERE iupac='mitotane'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='mitotane'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '1157-25-30',
    '', 'Value for T&nbsp;= 298... 303&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1157-25-30'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='mitotane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='mitotane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='mitotane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='mitotane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='mitotane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1-dichloro-2,2-bis-(4-chlorophenyl)-ethene',
    'C<sub>14</sub>H<sub>8</sub>Cl<sub>4</sub>',
    'p,p''-DDE',
    '72-55-9',
    'UCNVFOCBFJOQAL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,1-dichloro-2,2-bis-(4-chlorophenyl)-ethene'),
    (SELECT id from literature WHERE bibtexkey='2948'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='LDV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,1-dichloro-2,2-bis-(4-chlorophenyl)-ethene'),
    (SELECT id from literature WHERE bibtexkey='2948'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '4700',
    'M',
    (SELECT id from species WHERE iupac='1,1-dichloro-2,2-bis-(4-chlorophenyl)-ethene'),
    (SELECT id from literature WHERE bibtexkey='2492'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '7700',
    'M',
    (SELECT id from species WHERE iupac='1,1-dichloro-2,2-bis-(4-chlorophenyl)-ethene'),
    (SELECT id from literature WHERE bibtexkey='2814'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,1-dichloro-2,2-bis-(4-chlorophenyl)-ethene'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,1-dichloro-2,2-bis-(4-chlorophenyl)-ethene'),
    (SELECT id from literature WHERE bibtexkey='1926'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1926'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1-dichloro-2,2-bis-(4-chlorophenyl)-ethene'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2614_pc_problem'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1-dichloro-2,2-bis-(4-chlorophenyl)-ethene'),
    (SELECT id from literature WHERE bibtexkey='2974'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1-dichloro-2,2-bis-(4-chlorophenyl)-ethene'),
    (SELECT id from literature WHERE bibtexkey='2977'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1-dichloro-2,2-bis-(4-chlorophenyl)-ethene'),
    (SELECT id from literature WHERE bibtexkey='2975'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at283K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1-dichloro-2,2-bis-(4-chlorophenyl)-ethene'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1-dichloro-2,2-bis-(4-chlorophenyl)-ethene'),
    (SELECT id from literature WHERE bibtexkey='2971'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1-dichloro-2,2-bis-(4-chlorophenyl)-ethene'),
    (SELECT id from literature WHERE bibtexkey='3587'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '7600',
    'T',
    (SELECT id from species WHERE iupac='1,1-dichloro-2,2-bis-(4-chlorophenyl)-ethene'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1,1-dichloro-2,2-bis-(4-chlorophenyl)-ethene'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1157-20-25'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1,1-dichloro-2,2-bis-(4-chlorophenyl)-ethene'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichloro-2,2-bis-(4-chlorophenyl)-ethene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichloro-2,2-bis-(4-chlorophenyl)-ethene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichloro-2,2-bis-(4-chlorophenyl)-ethene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichloro-2,2-bis-(4-chlorophenyl)-ethene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1-dichloro-2,2-bis-(4-chlorophenyl)-ethene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'o,p''-DDE',
    'C<sub>14</sub>H<sub>8</sub>Cl<sub>4</sub>',
    '',
    '3424-82-6',
    'ZDYJWDIWLRZXDB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='o,p''-DDE'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='o,p''-DDE'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='o,p''-DDE'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='o,p''-DDE'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='o,p''-DDE'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,1-trichloro-2-(2-chlorophenyl)-2-(4-chlorophenyl)ethane',
    'C<sub>14</sub>H<sub>9</sub>Cl<sub>5</sub>',
    'o,p''-DDT',
    '789-02-6',
    'CVUGPAFCQJIYDT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1,1-trichloro-2-(2-chlorophenyl)-2-(4-chlorophenyl)ethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1,1-trichloro-2-(2-chlorophenyl)-2-(4-chlorophenyl)ethane'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1,1-trichloro-2-(2-chlorophenyl)-2-(4-chlorophenyl)ethane'),
    (SELECT id from literature WHERE bibtexkey='2977'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1-trichloro-2-(2-chlorophenyl)-2-(4-chlorophenyl)ethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,1-trichloro-2,2-bis-(4-chlorophenyl)-ethane',
    'C<sub>14</sub>H<sub>9</sub>Cl<sub>5</sub>',
    'DDT; p,p''-DDT',
    '50-29-3',
    'YVGGHNCTFXOJCH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,1,1-trichloro-2,2-bis-(4-chlorophenyl)-ethane'),
    (SELECT id from literature WHERE bibtexkey='2948'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='LDV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,1,1-trichloro-2,2-bis-(4-chlorophenyl)-ethane'),
    (SELECT id from literature WHERE bibtexkey='2948'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,1,1-trichloro-2,2-bis-(4-chlorophenyl)-ethane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;1</sup>',
    '7500',
    'M',
    (SELECT id from species WHERE iupac='1,1,1-trichloro-2,2-bis-(4-chlorophenyl)-ethane'),
    (SELECT id from literature WHERE bibtexkey='2814'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,1,1-trichloro-2,2-bis-(4-chlorophenyl)-ethane'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,1,1-trichloro-2,2-bis-(4-chlorophenyl)-ethane'),
    (SELECT id from literature WHERE bibtexkey='901'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at296K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,1,1-trichloro-2,2-bis-(4-chlorophenyl)-ethane'),
    (SELECT id from literature WHERE bibtexkey='901'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='901wwc'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1,1-trichloro-2,2-bis-(4-chlorophenyl)-ethane'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2614_pc_problem'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1,1-trichloro-2,2-bis-(4-chlorophenyl)-ethane'),
    (SELECT id from literature WHERE bibtexkey='2974'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1,1-trichloro-2,2-bis-(4-chlorophenyl)-ethane'),
    (SELECT id from literature WHERE bibtexkey='2977'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1,1-trichloro-2,2-bis-(4-chlorophenyl)-ethane'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1,1-trichloro-2,2-bis-(4-chlorophenyl)-ethane'),
    (SELECT id from literature WHERE bibtexkey='2976'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1,1-trichloro-2,2-bis-(4-chlorophenyl)-ethane'),
    (SELECT id from literature WHERE bibtexkey='2971'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1,1-trichloro-2,2-bis-(4-chlorophenyl)-ethane'),
    (SELECT id from literature WHERE bibtexkey='2968'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1,1-trichloro-2,2-bis-(4-chlorophenyl)-ethane'),
    (SELECT id from literature WHERE bibtexkey='2471'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '7800',
    'T',
    (SELECT id from species WHERE iupac='1,1,1-trichloro-2,2-bis-(4-chlorophenyl)-ethane'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,1,1-trichloro-2,2-bis-(4-chlorophenyl)-ethane'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1,1,1-trichloro-2,2-bis-(4-chlorophenyl)-ethane'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1157-20-25'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1,1,1-trichloro-2,2-bis-(4-chlorophenyl)-ethane'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1-trichloro-2,2-bis-(4-chlorophenyl)-ethane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1-trichloro-2,2-bis-(4-chlorophenyl)-ethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1-trichloro-2,2-bis-(4-chlorophenyl)-ethane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1-trichloro-2,2-bis-(4-chlorophenyl)-ethane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1-trichloro-2,2-bis-(4-chlorophenyl)-ethane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1-trichloro-2,2-bis-(4-chlorophenyl)-ethane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1-trichloro-2,2-bis-(4-chlorophenyl)-ethane'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1-trichloro-2,2-bis-(4-chlorophenyl)-ethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1-trichloro-2,2-bis-(4-chlorophenyl)-ethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1,1-trichloro-2,2-bis-(4-chlorophenyl)-ethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1,1-trichloro-2,2-bis-(4-chlorophenyl)-ethane'),
    (SELECT id from literature WHERE bibtexkey='695'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'aldrin',
    'C<sub>12</sub>H<sub>8</sub>Cl<sub>6</sub>',
    '',
    '309-00-2',
    'QBYJBZPUGVGKQQ-SJJAEHHWSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='aldrin'),
    (SELECT id from literature WHERE bibtexkey='2948'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='LDV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='aldrin'),
    (SELECT id from literature WHERE bibtexkey='2948'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='aldrin'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='aldrin'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '3900',
    'M',
    (SELECT id from species WHERE iupac='aldrin'),
    (SELECT id from literature WHERE bibtexkey='2814'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='aldrin'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='aldrin'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='aldrin'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='aldrin'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='aldrin'),
    (SELECT id from literature WHERE bibtexkey='2471'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='aldrin'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='aldrin'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='aldrin'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='aldrin'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='aldrin'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='aldrin'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1157-20-25'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='aldrin'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='aldrin'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='aldrin'),
    (SELECT id from literature WHERE bibtexkey='3083'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='aldrin'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='aldrin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='aldrin'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='aldrin'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='aldrin'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='aldrin'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='aldrin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='aldrin'),
    (SELECT id from literature WHERE bibtexkey='695'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'isodrin',
    'C<sub>12</sub>H<sub>8</sub>Cl<sub>6</sub>',
    '',
    '465-73-6',
    'QBYJBZPUGVGKQQ-DIFDVCDBSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isodrin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1''-(2,2-dichloroethylidene)bis[4-ethylbenzene',
    'C<sub>18</sub>H<sub>20</sub>Cl<sub>2</sub>',
    'perthane',
    '72-56-0',
    'QFMDFTQOJHFVNR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons (C, H, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1''-(2,2-dichloroethylidene)bis[4-ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Polychlorinated naphthalenes (PCNs)',
    (SELECT id from categories WHERE catname='Organic species with chlorine (Cl)'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-chloronaphthalene',
    'C<sub>10</sub>H<sub>7</sub>Cl',
    'PCN-1',
    '90-13-1',
    'JTPNRXUCIXHOKM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated naphthalenes (PCNs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-chloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2339'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-chloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-chloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-chloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='yaws2005'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-chloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-chloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-chloronaphthalene',
    'C<sub>10</sub>H<sub>7</sub>Cl',
    'PCN-2',
    '91-58-7',
    'CGYGETOMCSJHJU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated naphthalenes (PCNs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-chloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2339'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-chloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-chloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '3800',
    'X',
    (SELECT id from species WHERE iupac='2-chloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='2-chloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-chloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-dichloronaphthalene',
    'C<sub>10</sub>H<sub>6</sub>Cl<sub>2</sub>',
    'PCN-3',
    '2050-69-3',
    'MOXLHAPKZWTHEX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated naphthalenes (PCNs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-dichloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3766_M4',
    '3766', 'Ebert et&nbsp;al. (2023) present "curated experimental" Henry''s law constants from the literature but do not provide any references. It is only mentioned that the value is from multiple sources and obtained from the experimental octanol-water partition coefficient and the octanol-air partition coefficient.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M4'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3-dichloronaphthalene',
    'C<sub>10</sub>H<sub>6</sub>Cl<sub>2</sub>',
    'PCN-4',
    '2198-75-6',
    'AMCBMCWLCDERHY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated naphthalenes (PCNs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4-dichloronaphthalene',
    'C<sub>10</sub>H<sub>6</sub>Cl<sub>2</sub>',
    'PCN-5',
    '1825-31-6',
    'JDPKCYMVSKDOGS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated naphthalenes (PCNs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-dichloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dichloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,5-dichloronaphthalene',
    'C<sub>10</sub>H<sub>6</sub>Cl<sub>2</sub>',
    'PCN-6',
    '1825-30-5',
    'ZBQZXTBAGBTUAD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated naphthalenes (PCNs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,5-dichloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M4'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,7-dichloronaphthalene',
    'C<sub>10</sub>H<sub>6</sub>Cl<sub>2</sub>',
    'PCN-12',
    '2198-77-8',
    'DWBQZSYTSNYEEJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated naphthalenes (PCNs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,7-dichloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3766_D4',
    '3766', 'Ebert et&nbsp;al. (2023) present "curated experimental" Henry''s law constants from the literature but do not provide any references. It is only mentioned that the value is from a single database or data collection and obtained from the experimental octanol-water partition coefficient and the octanol-air partition coefficient.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D4'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4-trichloronaphthalene',
    'C<sub>10</sub>H<sub>5</sub>Cl<sub>3</sub>',
    'PCN-14',
    '50402-51-2',
    'MRJBOPVWPORBKZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated naphthalenes (PCNs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2,4-trichloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,5-trichloronaphthalene',
    'C<sub>10</sub>H<sub>5</sub>Cl<sub>3</sub>',
    'PCN-15',
    '55720-33-7',
    'MMHZKSMAFILONG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated naphthalenes (PCNs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '5300',
    'M',
    (SELECT id from species WHERE iupac='1,2,5-trichloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3732'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3732_inconsistent',
    '3732', 'Odabasi and Adali (2016) provide the parameters A and B for an equation to calculate temperature-dependent Henry''s law constants. Values calculated with this equation at 298&nbsp;K are slightly different than those measured at 298&nbsp;K and given as H in their Table&nbsp;1. Here, the values H and B are used.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3732_inconsistent'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,6-trichloronaphthalene',
    'C<sub>10</sub>H<sub>5</sub>Cl<sub>3</sub>',
    'PCN-16',
    '51570-44-6',
    'AAUJSCRITBXDJH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated naphthalenes (PCNs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '6500',
    'M',
    (SELECT id from species WHERE iupac='1,2,6-trichloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3732'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3732_inconsistent'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,7-trichloronaphthalene',
    'C<sub>10</sub>H<sub>5</sub>Cl<sub>3</sub>',
    'PCN-17',
    '55720-34-8',
    'QYYUVUXSJZJCLQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated naphthalenes (PCNs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2,7-trichloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3,5-trichloronaphthalene',
    'C<sub>10</sub>H<sub>5</sub>Cl<sub>3</sub>',
    'PCN-19',
    '51570-43-5',
    'DZHZYPCCEISGSQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated naphthalenes (PCNs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;2</sup>',
    '5500',
    'M',
    (SELECT id from species WHERE iupac='1,3,5-trichloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3732'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3732_inconsistent'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4,5-trichloronaphthalene',
    'C<sub>10</sub>H<sub>5</sub>Cl<sub>3</sub>',
    'PCN-23',
    '2437-55-0',
    'VQSNXLCFFHGXTI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated naphthalenes (PCNs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '5400',
    'M',
    (SELECT id from species WHERE iupac='1,4,5-trichloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3732'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3732_inconsistent'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4,6-trichloronaphthalene',
    'C<sub>10</sub>H<sub>5</sub>Cl<sub>3</sub>',
    'PCN-24',
    '2437-54-9',
    'RLTTZFDRZKJVKJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated naphthalenes (PCNs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,4,6-trichloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,6,7-trichloronaphthalene',
    'C<sub>10</sub>H<sub>5</sub>Cl<sub>3</sub>',
    'PCN-25',
    '55720-39-3',
    'FUEZTEBYLIMNHN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated naphthalenes (PCNs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,6,7-trichloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,4-tetrachloronaphthalene',
    'C<sub>10</sub>H<sub>4</sub>Cl<sub>4</sub>',
    'PCN-27',
    '20020-02-4',
    'NAQWICRLNQSPPW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated naphthalenes (PCNs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrachloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrachloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrachloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,5-tetrachloronaphthalene',
    'C<sub>10</sub>H<sub>4</sub>Cl<sub>4</sub>',
    'PCN-28',
    '53555-63-8',
    'HJJKSUVYCQAMBG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated naphthalenes (PCNs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2,3,5-tetrachloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M4'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4,5-tetrachloronaphthalene',
    'C<sub>10</sub>H<sub>4</sub>Cl<sub>4</sub>',
    'PCN-32',
    '6733-54-6',
    'BIVDISPRSYAHQQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated naphthalenes (PCNs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '5900',
    'M',
    (SELECT id from species WHERE iupac='1,2,4,5-tetrachloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3732'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3732_inconsistent'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4,6-tetrachloronaphthalene',
    'C<sub>10</sub>H<sub>4</sub>Cl<sub>4</sub>',
    'PCN-33',
    '51570-45-7',
    'GLVVZPZGCNEVEM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated naphthalenes (PCNs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2,4,6-tetrachloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4,7-tetrachloronaphthalene',
    'C<sub>10</sub>H<sub>4</sub>Cl<sub>4</sub>',
    'PCN-34',
    '67922-21-8',
    'PWXOBMRJWBBEED-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated naphthalenes (PCNs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2,4,7-tetrachloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4,8-tetrachloronaphthalene',
    'C<sub>10</sub>H<sub>4</sub>Cl<sub>4</sub>',
    'PCN-35',
    '6529-87-9',
    'WCMSFBRREKZZFL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated naphthalenes (PCNs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '6000',
    'M',
    (SELECT id from species WHERE iupac='1,2,4,8-tetrachloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3732'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3732_inconsistent'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,5,6-tetrachloronaphthalene',
    'C<sub>10</sub>H<sub>4</sub>Cl<sub>4</sub>',
    'PCN-36',
    '67922-22-9',
    'ZPUUGNBIWHBXBM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated naphthalenes (PCNs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2,5,6-tetrachloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,5,7-tetrachloronaphthalene',
    'C<sub>10</sub>H<sub>4</sub>Cl<sub>4</sub>',
    'PCN-37',
    '67922-23-0',
    'KQZUIOXHRIVQGR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated naphthalenes (PCNs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2,5,7-tetrachloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,5,8-tetrachloronaphthalene',
    'C<sub>10</sub>H<sub>4</sub>Cl<sub>4</sub>',
    'PCN-38',
    '149864-80-2',
    'DLTBLLHAQLBHDR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated naphthalenes (PCNs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2,5,8-tetrachloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,6,8-tetrachloronaphthalene',
    'C<sub>10</sub>H<sub>4</sub>Cl<sub>4</sub>',
    'PCN-40',
    '67922-24-1',
    'OVAYDYKVLHHIDQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated naphthalenes (PCNs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2,6,8-tetrachloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3,5,7-tetrachloronaphthalene',
    'C<sub>10</sub>H<sub>4</sub>Cl<sub>4</sub>',
    'PCN-42',
    '53555-64-9',
    'OTTCXKPQKOLSJN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated naphthalenes (PCNs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;2</sup>',
    '5600',
    'M',
    (SELECT id from species WHERE iupac='1,3,5,7-tetrachloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3732'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3732_inconsistent'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3,5,8-tetrachloronaphthalene',
    'C<sub>10</sub>H<sub>4</sub>Cl<sub>4</sub>',
    'PCN-43',
    '31604-28-1',
    'VFTLNRFRXWCJJK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated naphthalenes (PCNs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,3,5,8-tetrachloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D4'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3,6,8-tetrachloronaphthalene',
    'C<sub>10</sub>H<sub>4</sub>Cl<sub>4</sub>',
    'PCN-45',
    '150224-15-0',
    'XXWQPOHDPJIYIN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated naphthalenes (PCNs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,3,6,8-tetrachloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4,5,8-tetrachloronaphthalene',
    'C<sub>10</sub>H<sub>4</sub>Cl<sub>4</sub>',
    'PCN-46',
    '3432-57-3',
    'LITCKAVLJAKHOE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated naphthalenes (PCNs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '5700',
    'M',
    (SELECT id from species WHERE iupac='1,4,5,8-tetrachloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3732'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3732_inconsistent'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4,6,7-tetrachloronaphthalene',
    'C<sub>10</sub>H<sub>4</sub>Cl<sub>4</sub>',
    'PCN-47',
    '55720-43-9',
    'VJZRCIYSYVGDMU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated naphthalenes (PCNs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;2</sup>',
    '5800',
    'M',
    (SELECT id from species WHERE iupac='1,4,6,7-tetrachloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3732'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3732_inconsistent'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,4,6-pentachloronaphthalene',
    'C<sub>10</sub>H<sub>3</sub>Cl<sub>5</sub>',
    'PCN-50',
    '67922-26-3',
    'BAOLNVSMVTYGDA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated naphthalenes (PCNs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;2</sup>',
    '9000',
    'M',
    (SELECT id from species WHERE iupac='1,2,3,4,6-pentachloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3732'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3732_inconsistent'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,5,7-pentachloronaphthalene',
    'C<sub>10</sub>H<sub>3</sub>Cl<sub>5</sub>',
    'PCN-52',
    '53555-65-0',
    'OVSKLQPHXHPXDR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated naphthalenes (PCNs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2,3,5,7-pentachloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,5,8-pentachloronaphthalene',
    'C<sub>10</sub>H<sub>3</sub>Cl<sub>5</sub>',
    'PCN-53',
    '150224-24-1',
    'HVYRFNJXZVEGFK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated naphthalenes (PCNs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '9700',
    'M',
    (SELECT id from species WHERE iupac='1,2,3,5,8-pentachloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3732'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3732_inconsistent'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4,5,6-pentachloronaphthalene',
    'C<sub>10</sub>H<sub>3</sub>Cl<sub>5</sub>',
    'PCN-57',
    '150224-20-7',
    'KPOZENRUJCHWOA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated naphthalenes (PCNs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '9500',
    'M',
    (SELECT id from species WHERE iupac='1,2,4,5,6-pentachloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3732'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3732_inconsistent'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4,5,7-pentachloronaphthalene',
    'C<sub>10</sub>H<sub>3</sub>Cl<sub>5</sub>',
    'PCN-58',
    '150224-19-4',
    'WYLDWCYZCFRVRH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated naphthalenes (PCNs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;2</sup>',
    '8700',
    'M',
    (SELECT id from species WHERE iupac='1,2,4,5,7-pentachloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3732'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3732_inconsistent'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4,5,8-pentachloronaphthalene',
    'C<sub>10</sub>H<sub>3</sub>Cl<sub>5</sub>',
    'PCN-59',
    '150224-25-2',
    'FEIKEVSWLMYFFF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated naphthalenes (PCNs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '9100',
    'M',
    (SELECT id from species WHERE iupac='1,2,4,5,8-pentachloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3732'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3732_inconsistent'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4,6,7-pentachloronaphthalene',
    'C<sub>10</sub>H<sub>3</sub>Cl<sub>5</sub>',
    'PCN-60',
    '150224-17-2',
    'GXQUDLBNLKOIQB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated naphthalenes (PCNs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2,4,6,7-pentachloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4,6,8-pentachloronaphthalene',
    'C<sub>10</sub>H<sub>3</sub>Cl<sub>5</sub>',
    'PCN-61',
    '150224-22-9',
    'HGSDQSUMXKHGTH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated naphthalenes (PCNs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '8800',
    'M',
    (SELECT id from species WHERE iupac='1,2,4,6,8-pentachloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3732'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3732_inconsistent'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4,7,8-pentachloronaphthalene',
    'C<sub>10</sub>H<sub>3</sub>Cl<sub>5</sub>',
    'PCN-62',
    '150224-21-8',
    'LBCOXKFWBDTJTF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated naphthalenes (PCNs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '9200',
    'M',
    (SELECT id from species WHERE iupac='1,2,4,7,8-pentachloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3732'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3732_inconsistent'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,4,5,6-hexachloronaphthalene',
    'C<sub>10</sub>H<sub>2</sub>Cl<sub>6</sub>',
    'PCN-63',
    '58877-88-6',
    'CTLMCQOGOWNFHA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated naphthalenes (PCNs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;1</sup>',
    '12000',
    'M',
    (SELECT id from species WHERE iupac='1,2,3,4,5,6-hexachloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3732'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3732_inconsistent'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,4,5,7-hexachloronaphthalene',
    'C<sub>10</sub>H<sub>2</sub>Cl<sub>6</sub>',
    'PCN-64',
    '67922-27-4',
    'SWRNUKWDDYPZGV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated naphthalenes (PCNs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2,3,4,5,7-hexachloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,4,5,8-hexachloronaphthalene',
    'C<sub>10</sub>H<sub>2</sub>Cl<sub>6</sub>',
    'PCN-65',
    '103426-93-3',
    'PGCDNPCENWGYMA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated naphthalenes (PCNs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;1</sup>',
    '10000',
    'M',
    (SELECT id from species WHERE iupac='1,2,3,4,5,8-hexachloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3732'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3732_inconsistent'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,4,6,7-hexachloronaphthalene',
    'C<sub>10</sub>H<sub>2</sub>Cl<sub>6</sub>',
    'PCN-66',
    '103426-96-6',
    'ZRNSVEOEIWQEMU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated naphthalenes (PCNs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2,3,4,6,7-hexachloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M4'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,5,6,7-hexachloronaphthalene',
    'C<sub>10</sub>H<sub>2</sub>Cl<sub>6</sub>',
    'PCN-67',
    '103426-97-7',
    'XZLJCGGEQLNWDT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated naphthalenes (PCNs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2,3,5,6,7-hexachloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,5,6,8-hexachloronaphthalene',
    'C<sub>10</sub>H<sub>2</sub>Cl<sub>6</sub>',
    'PCN-68',
    '103426-95-5',
    'FQELOCOACCYGLL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated naphthalenes (PCNs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2,3,5,6,8-hexachloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,5,7,8-hexachloronaphthalene',
    'C<sub>10</sub>H<sub>2</sub>Cl<sub>6</sub>',
    'PCN-69',
    '103426-94-4',
    'JPQLLIUTUFJWMH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated naphthalenes (PCNs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;1</sup>',
    '12000',
    'M',
    (SELECT id from species WHERE iupac='1,2,3,5,7,8-hexachloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3732'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3732_inconsistent'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4,5,6,8-hexachloronaphthalene',
    'C<sub>10</sub>H<sub>2</sub>Cl<sub>6</sub>',
    'PCN-71',
    '90948-28-0',
    'JHKLUUFTHIWTKX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated naphthalenes (PCNs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2,4,5,6,8-hexachloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4,5,7,8-hexachloronaphthalene',
    'C<sub>10</sub>H<sub>2</sub>Cl<sub>6</sub>',
    'PCN-72',
    '103426-92-2',
    'SFZREMCYQNYZMZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated naphthalenes (PCNs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2,4,5,7,8-hexachloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,4,5,6,7-heptachloronaphthalene',
    'C<sub>10</sub>HCl<sub>7</sub>',
    'PCN-73',
    '58863-14-2',
    'NDZIBNJHNBUHKW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated naphthalenes (PCNs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6',
    '10000',
    'M',
    (SELECT id from species WHERE iupac='1,2,3,4,5,6,7-heptachloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3732'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3732_inconsistent'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,4,5,6,8-heptachloronaphthalene',
    'C<sub>10</sub>HCl<sub>7</sub>',
    'PCN-74',
    '58863-15-3',
    'QYEGXUUXWMKHHS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated naphthalenes (PCNs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '10000',
    'M',
    (SELECT id from species WHERE iupac='1,2,3,4,5,6,8-heptachloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3732'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3732_inconsistent'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'octachloronaphthalene',
    'C<sub>10</sub>Cl<sub>8</sub>',
    'PCN-75',
    '2234-13-1',
    'RTNLUFLDZOAXIC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated naphthalenes (PCNs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '7800',
    'M',
    (SELECT id from species WHERE iupac='octachloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3732'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3732_inconsistent'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='octachloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='octachloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octachloronaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Polychlorinated biphenyls (PCBs)',
    (SELECT id from categories WHERE catname='Organic species with chlorine (Cl)'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-chlorobiphenyl',
    'C<sub>12</sub>H<sub>9</sub>Cl',
    'PCB-1',
    '2051-60-7',
    'LAXBNTIAOJWAOP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-chlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2564'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2564mgsm',
    '2564', 'Modified gas-stripping method (MGSM); see Lau et&nbsp;al. (2006) for details.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2564mgsm'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-chlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2564'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2564igsm',
    '2564', 'Integrated gas-stripping method (IGSM); see Lau et&nbsp;al. (2006) for details.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2564igsm'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '5300',
    'M',
    (SELECT id from species WHERE iupac='2-chlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2496'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '5100',
    'M',
    (SELECT id from species WHERE iupac='2-chlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2340'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '5300',
    'V',
    (SELECT id from species WHERE iupac='2-chlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-chlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-chlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-chlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-chlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2302'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-chlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2932PCR',
    '2932', 'Calculated with the principal component regression (PCR) method; see Lee (2007) for details.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2932PLSR',
    '2932', 'Calculated with the partial least-square regression (PLSR) method; see Lee (2007) for details.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4600',
    'Q',
    (SELECT id from species WHERE iupac='2-chlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-chlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5400',
    '?',
    (SELECT id from species WHERE iupac='2-chlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-chlorobiphenyl',
    'C<sub>12</sub>H<sub>9</sub>Cl',
    'PCB-2',
    '2051-61-8',
    'NMWSKOLWZZWHPL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '5400',
    'V',
    (SELECT id from species WHERE iupac='3-chlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-chlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-chlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-chlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2302'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-chlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-chlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-chlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-chlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-chlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-chlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-chlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-chlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-chlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-chlorobiphenyl',
    'C<sub>12</sub>H<sub>9</sub>Cl',
    'PCB-3',
    '2051-62-9',
    'FPWNLURCHDRMHC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '5700',
    'L',
    (SELECT id from species WHERE iupac='4-chlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2540'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='LDV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '6100',
    'L',
    (SELECT id from species WHERE iupac='4-chlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2540'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='4-chlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2564'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2564mgsm'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='4-chlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2564'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2564igsm'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '6700',
    'M',
    (SELECT id from species WHERE iupac='4-chlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2496'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;2</sup>',
    '6700',
    'M',
    (SELECT id from species WHERE iupac='4-chlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '5100',
    'V',
    (SELECT id from species WHERE iupac='4-chlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-chlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-chlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-chlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2302'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-chlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-chlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2''-dichlorobiphenyl',
    'C<sub>12</sub>H<sub>8</sub>Cl<sub>2</sub>',
    'PCB-4',
    '13029-08-8',
    'JAYCNKDKIKZTAF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;2</sup>',
    '6000',
    'M',
    (SELECT id from species WHERE iupac='2,2''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1144'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='643'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1140'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '1140',
    '643', 'The same data were also published in Dunnivant et&nbsp;al. (1988).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1140'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3797'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;3</sup>',
    '5500',
    'V',
    (SELECT id from species WHERE iupac='2,2''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2302'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2979'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='murphy83'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'from643',
    '643', 'Value given here as quoted by Dunnivant et&nbsp;al. (1988).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from643'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dichlorobiphenyl',
    'C<sub>12</sub>H<sub>8</sub>Cl<sub>2</sub>',
    'PCB-5',
    '16605-91-7',
    'XOMKZKJEJBZBJJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '5800',
    'M',
    (SELECT id from species WHERE iupac='2,3-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '5500',
    'V',
    (SELECT id from species WHERE iupac='2,3-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5000',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5800',
    '?',
    (SELECT id from species WHERE iupac='2,3-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3''-dichlorobiphenyl',
    'C<sub>12</sub>H<sub>8</sub>Cl<sub>2</sub>',
    'PCB-6',
    '25569-80-6',
    'ZHBBDTRJIVXKEX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '5700',
    'M',
    (SELECT id from species WHERE iupac='2,3''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1194'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3797'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '5900',
    'V',
    (SELECT id from species WHERE iupac='2,3''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2302'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dichlorobiphenyl',
    'C<sub>12</sub>H<sub>8</sub>Cl<sub>2</sub>',
    'PCB-7',
    '33284-50-3',
    'WEJZHZJJXPXXMU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '5200',
    'M',
    (SELECT id from species WHERE iupac='2,4-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,4-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1140'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,4-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '5700',
    'V',
    (SELECT id from species WHERE iupac='2,4-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2302'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4700',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,4-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5500',
    '?',
    (SELECT id from species WHERE iupac='2,4-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4''-dichlorobiphenyl',
    'C<sub>12</sub>H<sub>8</sub>Cl<sub>2</sub>',
    'PCB-8',
    '34883-43-7',
    'UFNIBRDIUNVOMX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '6000',
    'L',
    (SELECT id from species WHERE iupac='2,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2540'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='LDV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '6300',
    'L',
    (SELECT id from species WHERE iupac='2,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2540'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2564'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2564mgsm'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2564'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2564igsm'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '5300',
    'M',
    (SELECT id from species WHERE iupac='2,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2496'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '5300',
    'M',
    (SELECT id from species WHERE iupac='2,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2340'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3793'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at294K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3797'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1926'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1926'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '5600',
    'V',
    (SELECT id from species WHERE iupac='2,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2302'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4700',
    'Q',
    (SELECT id from species WHERE iupac='2,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5600',
    '?',
    (SELECT id from species WHERE iupac='2,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5-dichlorobiphenyl',
    'C<sub>12</sub>H<sub>8</sub>Cl<sub>2</sub>',
    'PCB-9',
    '34883-39-1',
    'KKQWHYGECTYFIA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '5700',
    'M',
    (SELECT id from species WHERE iupac='2,5-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1146'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,5-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='643'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,5-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1140'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1140'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '5600',
    'V',
    (SELECT id from species WHERE iupac='2,5-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,5-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,5-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,5-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2302'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,5-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4700',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,5-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5800',
    '?',
    (SELECT id from species WHERE iupac='2,5-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6-dichlorobiphenyl',
    'C<sub>12</sub>H<sub>8</sub>Cl<sub>2</sub>',
    'PCB-10',
    '33146-45-1',
    'IYZWUWBAFUBNCH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '5700',
    'V',
    (SELECT id from species WHERE iupac='2,6-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,6-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,6-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3''-dichlorobiphenyl',
    'C<sub>12</sub>H<sub>8</sub>Cl<sub>2</sub>',
    'PCB-11',
    '2050-67-1',
    'KTXUOWUHFLBZPW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3,3''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='643'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3,3''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1140'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1140'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '5700',
    'V',
    (SELECT id from species WHERE iupac='3,3''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,3''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,3''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,3''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,3''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4-dichlorobiphenyl',
    'C<sub>12</sub>H<sub>8</sub>Cl<sub>2</sub>',
    'PCB-12',
    '2974-92-7',
    'ZGHQUYZPMWMLBM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3,4-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1194'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3,4-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='643'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3,4-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1140'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1140'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '5300',
    'V',
    (SELECT id from species WHERE iupac='3,4-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,4-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,4-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4''-dichlorobiphenyl',
    'C<sub>12</sub>H<sub>8</sub>Cl<sub>2</sub>',
    'PCB-13',
    '2974-90-5',
    'CJDNEKOMKXLSBN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '6100',
    'M',
    (SELECT id from species WHERE iupac='3,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;2</sup>',
    '5900',
    'V',
    (SELECT id from species WHERE iupac='3,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,5-dichlorobiphenyl',
    'C<sub>12</sub>H<sub>8</sub>Cl<sub>2</sub>',
    'PCB-14',
    '34883-41-5',
    'QHZSDTDMQZPUKC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '5500',
    'V',
    (SELECT id from species WHERE iupac='3,5-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,5-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,4''-dichlorobiphenyl',
    'C<sub>12</sub>H<sub>8</sub>Cl<sub>2</sub>',
    'PCB-15',
    '2050-68-2',
    'YTBRNEUEFCNVHC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;2</sup>',
    '6000',
    'L',
    (SELECT id from species WHERE iupac='4,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2540'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='LDV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;2</sup>',
    '6700',
    'L',
    (SELECT id from species WHERE iupac='4,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2540'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='4,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2564'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2564mgsm'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='4,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2564'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2564igsm'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '5300',
    'M',
    (SELECT id from species WHERE iupac='4,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2496'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HTdep_r2_lessthan_0.9'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='4,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1144'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='4,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='643'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='4,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1140'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1140'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;3</sup>',
    '4900',
    'V',
    (SELECT id from species WHERE iupac='4,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2302'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2979'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='murphy83'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from643'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='4,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='643'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4,4''-dichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3-trichlorobiphenyl',
    'C<sub>12</sub>H<sub>7</sub>Cl<sub>3</sub>',
    'PCB-16',
    '38444-78-9',
    'XVIZMMSINIOIQP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '5700',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1926'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1926'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '5800',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2302'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4500',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2'',3-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4700',
    '?',
    (SELECT id from species WHERE iupac='2,2'',3-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',4-trichlorobiphenyl',
    'C<sub>12</sub>H<sub>7</sub>Cl<sub>3</sub>',
    'PCB-17',
    '37680-66-3',
    'YKKYCYQDUUXNLN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '4700',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '6200',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',5-trichlorobiphenyl',
    'C<sub>12</sub>H<sub>7</sub>Cl<sub>3</sub>',
    'PCB-18',
    '37680-65-2',
    'DCMURXAZTZQAFB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3424'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3424-EPICS',
    '', 'Calculated using the EPICS method.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3424-EPICS'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3424'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3424-direct',
    '', 'Calculated using the "Direct" method.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3424-direct'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '4200',
    'M',
    (SELECT id from species WHERE iupac='2,2'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2340'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1194'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1140'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1139'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3797'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1926'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1926'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;3</sup>',
    '5800',
    'V',
    (SELECT id from species WHERE iupac='2,2'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2302'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4200',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-Test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4500',
    '?',
    (SELECT id from species WHERE iupac='2,2'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',6-trichlorobiphenyl',
    'C<sub>12</sub>H<sub>7</sub>Cl<sub>3</sub>',
    'PCB-19',
    '38444-73-4',
    'MVXIJRBBCDLNLX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '4700',
    'M',
    (SELECT id from species WHERE iupac='2,2'',6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1194'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3797'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '5400',
    'V',
    (SELECT id from species WHERE iupac='2,2'',6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3600',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2'',6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3100',
    '?',
    (SELECT id from species WHERE iupac='2,2'',6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3''-trichlorobiphenyl',
    'C<sub>12</sub>H<sub>7</sub>Cl<sub>3</sub>',
    'PCB-20',
    '38444-84-7',
    'SXHLTVKPNQVZGL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3,3''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1926'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1926'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '5800',
    'V',
    (SELECT id from species WHERE iupac='2,3,3''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,3''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2302'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,3''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3,3''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4-trichlorobiphenyl',
    'C<sub>12</sub>H<sub>7</sub>Cl<sub>3</sub>',
    'PCB-21',
    '55702-46-0',
    'IUYHQGMDSZOPDZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;3</sup>',
    '5200',
    'V',
    (SELECT id from species WHERE iupac='2,3,4-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,4-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4''-trichlorobiphenyl',
    'C<sub>12</sub>H<sub>7</sub>Cl<sub>3</sub>',
    'PCB-22',
    '38444-85-8',
    'ZMHWQAHZKUPENF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '4800',
    'M',
    (SELECT id from species WHERE iupac='2,3,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3797'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '5600',
    'V',
    (SELECT id from species WHERE iupac='2,3,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,5-trichlorobiphenyl',
    'C<sub>12</sub>H<sub>7</sub>Cl<sub>3</sub>',
    'PCB-23',
    '55720-44-0',
    'GBUCDGDROYMOAN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '5700',
    'V',
    (SELECT id from species WHERE iupac='2,3,5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,6-trichlorobiphenyl',
    'C<sub>12</sub>H<sub>7</sub>Cl<sub>3</sub>',
    'PCB-24',
    '55702-45-9',
    'LVROLHVSYNLFBE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '4700',
    'M',
    (SELECT id from species WHERE iupac='2,3,6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3,6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1194'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3,6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;3</sup>',
    '5600',
    'V',
    (SELECT id from species WHERE iupac='2,3,6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4500',
    'Q',
    (SELECT id from species WHERE iupac='2,3,6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3,6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2800',
    '?',
    (SELECT id from species WHERE iupac='2,3,6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',4-trichlorobiphenyl',
    'C<sub>12</sub>H<sub>7</sub>Cl<sub>3</sub>',
    'PCB-25',
    '55712-37-3',
    'XBBZAULFUPBZSP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '4700',
    'M',
    (SELECT id from species WHERE iupac='2,3'',4-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3'',4-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3'',4-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3797'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '5900',
    'V',
    (SELECT id from species WHERE iupac='2,3'',4-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3'',4-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4800',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5700',
    '?',
    (SELECT id from species WHERE iupac='2,3'',4-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',5-trichlorobiphenyl',
    'C<sub>12</sub>H<sub>7</sub>Cl<sub>3</sub>',
    'PCB-26',
    '38444-81-4',
    'ONNCPBRWFSKDMQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '4900',
    'M',
    (SELECT id from species WHERE iupac='2,3'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='643'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1140'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1140'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '5900',
    'V',
    (SELECT id from species WHERE iupac='2,3'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',6-trichlorobiphenyl',
    'C<sub>12</sub>H<sub>7</sub>Cl<sub>3</sub>',
    'PCB-27',
    '38444-76-7',
    'VQOFJPFYTCHPTR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3'',6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '6100',
    'V',
    (SELECT id from species WHERE iupac='2,3'',6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3'',6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,4''-trichlorobiphenyl',
    'C<sub>12</sub>H<sub>7</sub>Cl<sub>3</sub>',
    'PCB-28',
    '7012-37-5',
    'BZTYNSQSZHARAZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '6300',
    'L',
    (SELECT id from species WHERE iupac='2,4,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2540'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='LDV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '6600',
    'L',
    (SELECT id from species WHERE iupac='2,4,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2540'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,4,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3424'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3424-EPICS'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,4,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3424'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3424-direct'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,4,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2564'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2564mgsm'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,4,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2564'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2564igsm'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '2300',
    'M',
    (SELECT id from species WHERE iupac='2,4,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2496'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HTdep_r2_lessthan_0.9'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '3900',
    'M',
    (SELECT id from species WHERE iupac='2,4,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2340'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '6100',
    'M',
    (SELECT id from species WHERE iupac='2,4,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1146'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,4,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1194'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,4,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1140'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,4,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,4,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3793'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at294K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '5900',
    'V',
    (SELECT id from species WHERE iupac='2,4,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '7100',
    'T',
    (SELECT id from species WHERE iupac='2,4,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4800',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,4,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4800',
    '?',
    (SELECT id from species WHERE iupac='2,4,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,5-trichlorobiphenyl',
    'C<sub>12</sub>H<sub>7</sub>Cl<sub>3</sub>',
    'PCB-29',
    '15862-07-4',
    'VGVIKVCCUATMNG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '6500',
    'L',
    (SELECT id from species WHERE iupac='2,4,5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3681'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '6300',
    'L',
    (SELECT id from species WHERE iupac='2,4,5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2540'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='LDV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '6700',
    'L',
    (SELECT id from species WHERE iupac='2,4,5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2540'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '4200',
    'M',
    (SELECT id from species WHERE iupac='2,4,5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2340'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,4,5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1194'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;3</sup>',
    '5500',
    'V',
    (SELECT id from species WHERE iupac='2,4,5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4,5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4,5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4,5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2302'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4,5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3424'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5100',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,4,5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4500',
    '?',
    (SELECT id from species WHERE iupac='2,4,5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,6-trichlorobiphenyl',
    'C<sub>12</sub>H<sub>7</sub>Cl<sub>3</sub>',
    'PCB-30',
    '35693-92-6',
    'MTLMVEWEYZFYTH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,4,6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='643'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,4,6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1140'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1140'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4,6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;3</sup>',
    '5600',
    'V',
    (SELECT id from species WHERE iupac='2,4,6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4,6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4,6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4,6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2302'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4,6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4'',5-trichlorobiphenyl',
    'C<sub>12</sub>H<sub>7</sub>Cl<sub>3</sub>',
    'PCB-31',
    '16606-02-3',
    'VAHKBZSAUKPEOV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '6100',
    'L',
    (SELECT id from species WHERE iupac='2,4'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2540'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='LDV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '6600',
    'L',
    (SELECT id from species WHERE iupac='2,4'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2540'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '4900',
    'M',
    (SELECT id from species WHERE iupac='2,4'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,4'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1194'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,4'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,4'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3797'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,4'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1926'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1926'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '5700',
    'V',
    (SELECT id from species WHERE iupac='2,4'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2302'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,4'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4'',6-trichlorobiphenyl',
    'C<sub>12</sub>H<sub>7</sub>Cl<sub>3</sub>',
    'PCB-32',
    '38444-77-8',
    'IHIDFKLAWYPTKB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '5700',
    'V',
    (SELECT id from species WHERE iupac='2,4'',6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4'',6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4'',6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4'',6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4'',6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4'',6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4'',6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4'',6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4'',6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4'',6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,4'',6-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',4''-trichlorobiphenyl',
    'C<sub>12</sub>H<sub>7</sub>Cl<sub>3</sub>',
    'PCB-33',
    '38444-86-9',
    'RIMXLXBUOQMDHV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '5100',
    'M',
    (SELECT id from species WHERE iupac='2,3'',4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3'',4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3'',4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3797'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3'',4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='849'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '5600',
    'V',
    (SELECT id from species WHERE iupac='2,3'',4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3'',4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2612_pc_problem'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3'',4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3'',4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2302'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3'',4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3'',4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',5''-trichlorobiphenyl',
    'C<sub>12</sub>H<sub>7</sub>Cl<sub>3</sub>',
    'PCB-34',
    '37680-68-5',
    'GXVMAQACUOSFJF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '5800',
    'V',
    (SELECT id from species WHERE iupac='2,3'',5''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3'',5''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',5''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',5''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',5''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',5''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',5''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',5''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',5''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',5''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3'',5''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3'',4-trichlorobiphenyl',
    'C<sub>12</sub>H<sub>7</sub>Cl<sub>3</sub>',
    'PCB-35',
    '37680-69-6',
    'JHBVPKZLIBDTJR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '5600',
    'V',
    (SELECT id from species WHERE iupac='3,3'',4-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,3'',4-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',4-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',4-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',4-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',4-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3'',5-trichlorobiphenyl',
    'C<sub>12</sub>H<sub>7</sub>Cl<sub>3</sub>',
    'PCB-36',
    '38444-87-0',
    'RIBGNAJQTOXRDK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3,3'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1194'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '5600',
    'V',
    (SELECT id from species WHERE iupac='3,3'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,3'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,3'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4,4''-trichlorobiphenyl',
    'C<sub>12</sub>H<sub>7</sub>Cl<sub>3</sub>',
    'PCB-37',
    '38444-90-5',
    'YZANRISAORXTHU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3,4,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1194'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3,4,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3,4,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1926'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1926'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '5400',
    'V',
    (SELECT id from species WHERE iupac='3,4,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,4,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2302'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,4,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,4,4''-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4,5-trichlorobiphenyl',
    'C<sub>12</sub>H<sub>7</sub>Cl<sub>3</sub>',
    'PCB-38',
    '53555-66-1',
    'BSFZSQRJGZHMMV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '5400',
    'V',
    (SELECT id from species WHERE iupac='3,4,5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,4,5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4'',5-trichlorobiphenyl',
    'C<sub>12</sub>H<sub>7</sub>Cl<sub>3</sub>',
    'PCB-39',
    '38444-88-1',
    'SYSBNFJJSJLZMM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '5600',
    'V',
    (SELECT id from species WHERE iupac='3,4'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,4'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4'',5-trichlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3''-tetrachlorobiphenyl',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>',
    'PCB-40',
    '38444-93-8',
    'VTLYHLREPCPDKX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '3600',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1194'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='643'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1140'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1140'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1139'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '5300',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2302'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2'',3,3''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4-tetrachlorobiphenyl',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>',
    'PCB-41',
    '52663-59-9',
    'SEWHDNLIHDBVDZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,4-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '6200',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2'',3,4-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4''-tetrachlorobiphenyl',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>',
    'PCB-42',
    '36559-22-5',
    'ALFHIHDQSYXSGP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '3100',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;3</sup>',
    '5900',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2'',3,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,5-tetrachlorobiphenyl',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>',
    'PCB-43',
    '70362-46-8',
    'NRBNBYFPJCCKTO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '6300',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,5''-tetrachlorobiphenyl',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>',
    'PCB-44',
    '41464-39-5',
    'ALDJIKXAHSDLLB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3424'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3424-EPICS'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3424'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3424-direct'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '3100',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2340'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3797'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1926'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1926'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '6000',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2302'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4600',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2'',3,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3400',
    '?',
    (SELECT id from species WHERE iupac='2,2'',3,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,6-tetrachlorobiphenyl',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>',
    'PCB-45',
    '70362-45-7',
    'VHGHHZZTMJLTJX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '2900',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '6000',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,6''-tetrachlorobiphenyl',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>',
    'PCB-46',
    '41464-47-5',
    'CUGLICQCTXWQNF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '3400',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,6''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,6''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;4</sup>',
    '5300',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,6''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,6''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,6''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,6''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,6''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,6''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',4,4''-tetrachlorobiphenyl',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>',
    'PCB-47',
    '2437-79-8',
    'QORAVNMWUNPXAO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2564'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2564mgsm'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2564'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2564igsm'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '-6000',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2496'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1194'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '6200',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2302'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',4,5-tetrachlorobiphenyl',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>',
    'PCB-48',
    '70362-47-9',
    'XBTHILIDLBPRPM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '3000',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;3</sup>',
    '6100',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',4,5''-tetrachlorobiphenyl',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>',
    'PCB-49',
    '41464-40-8',
    'ZWPVHELAQPIZHO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '3000',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3797'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;3</sup>',
    '5900',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2302'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2'',4,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',4,6-tetrachlorobiphenyl',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>',
    'PCB-50',
    '62796-65-0',
    'VLLVVZDKBSYMCG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '2900',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2340'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1926'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1926'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;3</sup>',
    '6300',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2302'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3424'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3600',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3100',
    '?',
    (SELECT id from species WHERE iupac='2,2'',4,6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',4,6''-tetrachlorobiphenyl',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>',
    'PCB-51',
    '68194-04-7',
    'WVHNUGRFECMVLQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '6300',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,6''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,6''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,6''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,6''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,6''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,6''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,6''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,6''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,6''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,6''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2'',4,6''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',5,5''-tetrachlorobiphenyl',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>',
    'PCB-52',
    '35693-99-3',
    'HCWZEPKLWVAEOV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '6600',
    'L',
    (SELECT id from species WHERE iupac='2,2'',5,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2540'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='LDV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '6800',
    'L',
    (SELECT id from species WHERE iupac='2,2'',5,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2540'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',5,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3424'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3424-EPICS'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',5,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3424'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3424-direct'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '3700',
    'M',
    (SELECT id from species WHERE iupac='2,2'',5,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2340'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '6200',
    'M',
    (SELECT id from species WHERE iupac='2,2'',5,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1146'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',5,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1194'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',5,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='643'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',5,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1140'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1140'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',5,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',5,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1139'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',5,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3797'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',5,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1926'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1926'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',5,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='849'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '849-35693-99-3-range',
    '849', 'Westcott et&nbsp;al. (1981) give a range of 1.9&times;10<sup>&#8722;2</sup>&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>  &lt;  H<sub>s</sub><sup>cp</sup> &lt;  3.2&times;10<sup>&#8722;2</sup>&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='849-35693-99-3-range'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;3</sup>',
    '5700',
    'V',
    (SELECT id from species WHERE iupac='2,2'',5,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',5,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',5,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',5,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2975'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at283K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',5,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2302'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',5,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '7700',
    'T',
    (SELECT id from species WHERE iupac='2,2'',5,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2'',5,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='murphy83'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from643'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',5,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',5,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',5,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',5,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',5,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',5,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4200',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',5,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',5,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2'',5,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4900',
    '?',
    (SELECT id from species WHERE iupac='2,2'',5,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',5,6''-tetrachlorobiphenyl',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>',
    'PCB-53',
    '41464-41-9',
    'SFTUSTXGTCCSHX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',5,6''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='643'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',5,6''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1140'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1140'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',5,6''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',5,6''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3797'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',5,6''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '5500',
    'V',
    (SELECT id from species WHERE iupac='2,2'',5,6''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',5,6''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2302'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',5,6''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',5,6''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',5,6''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',5,6''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',5,6''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',5,6''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',5,6''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',6,6''-tetrachlorobiphenyl',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>',
    'PCB-54',
    '15968-05-5',
    'PXAGFNRKXSYIHU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',6,6''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1194'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',6,6''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='643'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',6,6''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1140'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1140'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;4</sup>',
    '4800',
    'V',
    (SELECT id from species WHERE iupac='2,2'',6,6''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',6,6''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='2,2'',6,6''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='643'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',6,6''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',6,6''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',6,6''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',6,6''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',6,6''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',6,6''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',6,6''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',6,6''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2'',6,6''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4-tetrachlorobiphenyl',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>',
    'PCB-55',
    '74338-24-2',
    'ZKGSEEWIVLAUNH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;3</sup>',
    '5900',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4''-tetrachlorobiphenyl',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>',
    'PCB-56',
    '41464-43-1',
    'UNCGJRRROFURDV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '3800',
    'M',
    (SELECT id from species WHERE iupac='2,3,3'',4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3,3'',4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;3</sup>',
    '5400',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',5-tetrachlorobiphenyl',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>',
    'PCB-57',
    '70424-67-8',
    'DHDBTLFALXRTLB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;3</sup>',
    '6100',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',5''-tetrachlorobiphenyl',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>',
    'PCB-58',
    '41464-49-7',
    'IOPBNBSKOPJKEG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '5400',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',6-tetrachlorobiphenyl',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>',
    'PCB-59',
    '74472-33-6',
    'WZNAMGYIQPAXDH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '6600',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,4''-tetrachlorobiphenyl',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>',
    'PCB-60',
    '33025-41-1',
    'XLDBTRJKXLKYTC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3,4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3,4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1926'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1926'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '5500',
    'V',
    (SELECT id from species WHERE iupac='2,3,4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,5-tetrachlorobiphenyl',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>',
    'PCB-61',
    '33284-53-6',
    'HLQDGCWIOSOMDP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '6600',
    'L',
    (SELECT id from species WHERE iupac='2,3,4,5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2540'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='LDV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '7200',
    'L',
    (SELECT id from species WHERE iupac='2,3,4,5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2540'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,4,5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;3</sup>',
    '5600',
    'V',
    (SELECT id from species WHERE iupac='2,3,4,5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,4,5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,6-tetrachlorobiphenyl',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>',
    'PCB-62',
    '54230-22-7',
    'HOBRTVXSIVSXIA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3,4,6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1194'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;3</sup>',
    '6000',
    'V',
    (SELECT id from species WHERE iupac='2,3,4,6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,4,6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3,4,6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4'',5-tetrachlorobiphenyl',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>',
    'PCB-63',
    '74472-34-7',
    'CITMYAMXIZQCJD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '3000',
    'M',
    (SELECT id from species WHERE iupac='2,3,4'',5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3,4'',5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;3</sup>',
    '6100',
    'V',
    (SELECT id from species WHERE iupac='2,3,4'',5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,4'',5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4'',5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4'',5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4'',5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4'',5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4'',6-tetrachlorobiphenyl',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>',
    'PCB-64',
    '52663-58-8',
    'FXRXQYZZALWWGA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '2900',
    'M',
    (SELECT id from species WHERE iupac='2,3,4'',6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3,4'',6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;3</sup>',
    '6000',
    'V',
    (SELECT id from species WHERE iupac='2,3,4'',6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,4'',6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4'',6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4'',6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4'',6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4'',6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4'',6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4'',6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4'',6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4'',6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3,4'',6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,5,6-tetrachlorobiphenyl',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>',
    'PCB-65',
    '33284-54-7',
    'BLAYIQLVUNIICD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;3</sup>',
    '5800',
    'V',
    (SELECT id from species WHERE iupac='2,3,5,6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,5,6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5,6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5,6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5,6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5,6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5,6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5,6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',4,4''-tetrachlorobiphenyl',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>',
    'PCB-66',
    '32598-10-0',
    'RKLLTEAEZIJBAU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '3500',
    'M',
    (SELECT id from species WHERE iupac='2,3'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2340'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '5300',
    'V',
    (SELECT id from species WHERE iupac='2,3'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2302'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3424'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5200',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3800',
    '?',
    (SELECT id from species WHERE iupac='2,3'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',4,5-tetrachlorobiphenyl',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>',
    'PCB-67',
    '73575-53-8',
    'LQEGJNOKOZHBBZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3'',4,5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1194'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '6200',
    'V',
    (SELECT id from species WHERE iupac='2,3'',4,5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3'',4,5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3'',4,5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',4,5''-tetrachlorobiphenyl',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>',
    'PCB-68',
    '73575-52-7',
    'KTTXLLZIBIDUCR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;3</sup>',
    '5800',
    'V',
    (SELECT id from species WHERE iupac='2,3'',4,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3'',4,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',4,6-tetrachlorobiphenyl',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>',
    'PCB-69',
    '60233-24-1',
    'CKUBKYSLNCKBOI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '6500',
    'V',
    (SELECT id from species WHERE iupac='2,3'',4,6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3'',4,6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3'',4,6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',4'',5-tetrachlorobiphenyl',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>',
    'PCB-70',
    '32598-11-1',
    'KENZYIHFBRWMOD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '3500',
    'M',
    (SELECT id from species WHERE iupac='2,3'',4'',5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3'',4'',5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1194'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3'',4'',5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3'',4'',5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3793'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at294K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3'',4'',5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3797'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;3</sup>',
    '5400',
    'V',
    (SELECT id from species WHERE iupac='2,3'',4'',5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3'',4'',5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2302'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3'',4'',5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4'',5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4'',5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4'',5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4'',5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4'',5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4'',5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4'',5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4'',5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3'',4'',5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',4'',6-tetrachlorobiphenyl',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>',
    'PCB-71',
    '41464-46-4',
    'WYVBETQIUHPLFO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '6000',
    'V',
    (SELECT id from species WHERE iupac='2,3'',4'',6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3'',4'',6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4'',6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4'',6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4'',6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4'',6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',5,5''-tetrachlorobiphenyl',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>',
    'PCB-72',
    '41464-42-0',
    'WBTMFEPLVQOWFI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;3</sup>',
    '5700',
    'V',
    (SELECT id from species WHERE iupac='2,3'',5,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3'',5,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',5,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',5,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',5,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',5,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',5'',6-tetrachlorobiphenyl',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>',
    'PCB-73',
    '74338-23-1',
    'HDULUCZRGGWTMZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;3</sup>',
    '5900',
    'V',
    (SELECT id from species WHERE iupac='2,3'',5'',6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3'',5'',6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',5'',6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',5'',6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',5'',6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',5'',6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,4'',5-tetrachlorobiphenyl',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>',
    'PCB-74',
    '32690-93-0',
    'TULCXSBAPHCWCF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '3000',
    'M',
    (SELECT id from species WHERE iupac='2,4,4'',5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,4,4'',5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1194'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,4,4'',5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;3</sup>',
    '5800',
    'V',
    (SELECT id from species WHERE iupac='2,4,4'',5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4,4'',5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4'',5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4'',5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4'',5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4'',5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4'',5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4'',5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4'',5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4'',5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,4,4'',5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,4'',6-tetrachlorobiphenyl',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>',
    'PCB-75',
    '32598-12-2',
    'RZFZBHKDGHISSH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '6400',
    'V',
    (SELECT id from species WHERE iupac='2,4,4'',6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4,4'',6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4'',6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4'',6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4'',6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4'',6-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',4'',5''-tetrachlorobiphenyl',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>',
    'PCB-76',
    '70362-48-0',
    'QILUYCYPNYWMIL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3'',4'',5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '5500',
    'V',
    (SELECT id from species WHERE iupac='2,3'',4'',5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3'',4'',5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4'',5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4'',5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4'',5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4'',5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3'',4,4''-tetrachlorobiphenyl',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>',
    'PCB-77',
    '32598-13-3',
    'UQMGJOKDKOLIDP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3,3'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3424'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3424-EPICS'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3,3'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3424'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3424-direct'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3,3'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2564'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2564mgsm'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3,3'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2564'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2564igsm'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3,3'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2565'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '13000',
    'M',
    (SELECT id from species WHERE iupac='3,3'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2496'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HTdep_r2_lessthan_0.9'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '4800',
    'M',
    (SELECT id from species WHERE iupac='3,3'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2340'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3,3'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='643'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3,3'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1140'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1140'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;4</sup>',
    '4600',
    'V',
    (SELECT id from species WHERE iupac='3,3'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,3'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,3'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,3'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2302'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,3'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;3</sup>',
    '7400',
    'T',
    (SELECT id from species WHERE iupac='3,3'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6100',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,3'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5600',
    '?',
    (SELECT id from species WHERE iupac='3,3'',4,4''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3'',4,5-tetrachlorobiphenyl',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>',
    'PCB-78',
    '70362-49-1',
    'SXFLURRQRFKBNN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;3</sup>',
    '5600',
    'V',
    (SELECT id from species WHERE iupac='3,3'',4,5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,3'',4,5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',4,5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',4,5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',4,5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',4,5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3'',4,5''-tetrachlorobiphenyl',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>',
    'PCB-79',
    '41464-48-6',
    'QLCTXEMDCZGPCG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '5400',
    'V',
    (SELECT id from species WHERE iupac='3,3'',4,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,3'',4,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',4,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',4,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',4,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',4,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',4,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',4,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',4,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',4,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,3'',4,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3'',5,5''-tetrachlorobiphenyl',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>',
    'PCB-80',
    '33284-52-5',
    'UTMWFJSRHLYRPY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;4</sup>',
    '5100',
    'V',
    (SELECT id from species WHERE iupac='3,3'',5,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,3'',5,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',5,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',5,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',5,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',5,5''-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4,4'',5-tetrachlorobiphenyl',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>',
    'PCB-81',
    '70362-50-4',
    'BHWVLZJTVIYLIV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3,4,4'',5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2565'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '4000',
    'M',
    (SELECT id from species WHERE iupac='3,4,4'',5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '5300',
    'V',
    (SELECT id from species WHERE iupac='3,4,4'',5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,4,4'',5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,4'',5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,4'',5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,4'',5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,4'',5-tetrachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4-pentachlorobiphenyl',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>',
    'PCB-82',
    '52663-62-4',
    'AUGNBQPSMWGAJE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '5100',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3797'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;3</sup>',
    '5800',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2302'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',5-pentachlorobiphenyl',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>',
    'PCB-83',
    '60145-20-2',
    'SUBRHHYLRGOTHL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '3600',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;3</sup>',
    '6300',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',6-pentachlorobiphenyl',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>',
    'PCB-84',
    '52663-60-2',
    'QVWUJLANSDKRAH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '6000',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,4''-pentachlorobiphenyl',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>',
    'PCB-85',
    '65510-45-4',
    'LACXVZHAJMVESG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '3100',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,4,4''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,4,4''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1194'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,4,4''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '6600',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,4''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,4''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2'',3,4,4''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,5-pentachlorobiphenyl',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>',
    'PCB-86',
    '55312-69-1',
    'AIURIRUDHVDRFQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;3</sup>',
    '6500',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2302'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,5''-pentachlorobiphenyl',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>',
    'PCB-87',
    '38380-02-8',
    'OPKYDBFRKPQCBS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '3900',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,4,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2340'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,4,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,4,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3793'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at294K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,4,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3797'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '6000',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2302'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3424'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5000',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2'',3,4,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4200',
    '?',
    (SELECT id from species WHERE iupac='2,2'',3,4,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,6-pentachlorobiphenyl',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>',
    'PCB-88',
    '55215-17-3',
    'QGDKRLQRLFUJPP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;3</sup>',
    '6800',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,6''-pentachlorobiphenyl',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>',
    'PCB-89',
    '73575-57-2',
    'GLOOIONSKMZYQZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '2500',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,4,6''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;3</sup>',
    '6100',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,6''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,6''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,6''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,6''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,6''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,6''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4'',5-pentachlorobiphenyl',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>',
    'PCB-90',
    '68194-07-0',
    'SUOAMBOBSWRMNQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '6600',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4'',6-pentachlorobiphenyl',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>',
    'PCB-91',
    '68194-05-8',
    'CXKIGWXPPVZSQK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '1200',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,4'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,4'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '6500',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,5,5''-pentachlorobiphenyl',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>',
    'PCB-92',
    '52663-61-3',
    'CRCBRZBVCDKPGA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '2900',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '6500',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,5,6-pentachlorobiphenyl',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>',
    'PCB-93',
    '73575-56-1',
    'BMXRLHMJGHJGLR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '6500',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,5,6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,5,6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,5,6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,5,6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,5,6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,5,6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,5,6''-pentachlorobiphenyl',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>',
    'PCB-94',
    '73575-55-0',
    'FJUVPPYNSDTRQV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;3</sup>',
    '6300',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,5,6''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,5,6''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,5,6''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,5,6''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,5,6''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,5,6''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,5'',6-pentachlorobiphenyl',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>',
    'PCB-95',
    '38379-99-6',
    'GXNNLIMMEXHBKV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '2500',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,5'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,5'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;3</sup>',
    '6200',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,5'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,5'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,5'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,5'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,5'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,5'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,5'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,5'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2'',3,5'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,6,6''-pentachlorobiphenyl',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>',
    'PCB-96',
    '73575-54-9',
    'QQFGAXUIQVKBKU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;4</sup>',
    '5800',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,6,6''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,6,6''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,6,6''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,6,6''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,6,6''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,6,6''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4'',5''-pentachlorobiphenyl',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>',
    'PCB-97',
    '41464-51-1',
    'JTUSORDQZVOEAZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '3600',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1194'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;3</sup>',
    '6300',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4'',6''-pentachlorobiphenyl',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>',
    'PCB-98',
    '60233-25-2',
    'GOFFZTAPOOICFT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;3</sup>',
    '6300',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4'',6''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4'',6''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',6''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',6''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',6''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',6''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',4,4'',5-pentachlorobiphenyl',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>',
    'PCB-99',
    '38380-01-7',
    'LMQJBFRGXHMNOX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2564'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2564mgsm'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2564'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2564igsm'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;3</sup>',
    '8700',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2496'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HTdep_r2_lessthan_0.9'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '1900',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1194'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '6600',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',4,4'',6-pentachlorobiphenyl',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>',
    'PCB-100',
    '39485-83-1',
    'RKUAZJIXKHPFRK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;3</sup>',
    '6600',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,4'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,4'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,4'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,4'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,4'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,4'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',4,5,5''-pentachlorobiphenyl',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>',
    'PCB-101',
    '37680-73-2',
    'LAHWLEDBADHJGA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '6800',
    'L',
    (SELECT id from species WHERE iupac='2,2'',4,5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2540'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='LDV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '7500',
    'L',
    (SELECT id from species WHERE iupac='2,2'',4,5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2540'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3424'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3424-EPICS'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3424'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3424-direct'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '3600',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2340'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='643'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1140'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1140'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1139'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='849'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '849-37680-73-2-range',
    '849', 'Westcott et&nbsp;al. (1981) give a range of 2.8&times;10<sup>&#8722;2</sup>&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>  &lt;  H<sub>s</sub><sup>cp</sup> &lt;  9.0&times;10<sup>&#8722;2</sup>&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='849-37680-73-2-range'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;3</sup>',
    '6400',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2302'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '8100',
    'T',
    (SELECT id from species WHERE iupac='2,2'',4,5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4600',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2'',4,5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3900',
    '?',
    (SELECT id from species WHERE iupac='2,2'',4,5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',4,5,6''-pentachlorobiphenyl',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>',
    'PCB-102',
    '68194-06-9',
    'BWWVXHRLMPBDCK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,5,6''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1194'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;3</sup>',
    '6300',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,5,6''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,5,6''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,5,6''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,5,6''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,5,6''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,5,6''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,5,6''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,5,6''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,5,6''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,5,6''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2'',4,5,6''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',4,5'',6-pentachlorobiphenyl',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>',
    'PCB-103',
    '60145-21-3',
    'PQHZWWBJPCNNGI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;3</sup>',
    '6600',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,5'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,5'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,5'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,5'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,5'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,5'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',4,6,6''-pentachlorobiphenyl',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>',
    'PCB-104',
    '56558-16-8',
    'MTCPZNVSDFCBBE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '1700',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,6,6''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2340'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,6,6''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='643'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,6,6''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1140'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1140'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '6300',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,6,6''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,6,6''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,6,6''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,6,6''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,6,6''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3424'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,6,6''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,6,6''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3100',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,6,6''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,6,6''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2000',
    '?',
    (SELECT id from species WHERE iupac='2,2'',4,6,6''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4,4''-pentachlorobiphenyl',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>',
    'PCB-105',
    '32598-14-4',
    'WIDHRBRBACOVOY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '6800',
    'L',
    (SELECT id from species WHERE iupac='2,3,3'',4,4''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2540'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='LDV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;2</sup>',
    '7500',
    'L',
    (SELECT id from species WHERE iupac='2,3,3'',4,4''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2540'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3,3'',4,4''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2565'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '9100',
    'M',
    (SELECT id from species WHERE iupac='2,3,3'',4,4''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2340'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4,4''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;3</sup>',
    '5700',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4,4''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4,4''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '8300',
    'T',
    (SELECT id from species WHERE iupac='2,3,3'',4,4''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,4''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,4''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3424'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,4''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,4''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,4''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,4''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4,5-pentachlorobiphenyl',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>',
    'PCB-106',
    '70424-69-0',
    'BQENMISTWGTJIJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '6500',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4,5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4,5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4'',5-pentachlorobiphenyl',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>',
    'PCB-107',
    '70424-68-9',
    'PVYBHVJTMRRXLG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '2200',
    'M',
    (SELECT id from species WHERE iupac='2,3,3'',4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3,3'',4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;3</sup>',
    '6200',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4,5''-pentachlorobiphenyl',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>',
    'PCB-108',
    '70362-41-3',
    'MPCDNZSLJWJDNW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '5800',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4,6-pentachlorobiphenyl',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>',
    'PCB-109',
    '74472-35-8',
    'XGQBSVVYMVILEL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '6600',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4,6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4,6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4'',6-pentachlorobiphenyl',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>',
    'PCB-110',
    '38380-03-9',
    'ARXHIJMGSIYYRZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '5200',
    'M',
    (SELECT id from species WHERE iupac='2,3,3'',4'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3,3'',4'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3,3'',4'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3797'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '6400',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5000',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4300',
    '?',
    (SELECT id from species WHERE iupac='2,3,3'',4'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',5,5''-pentachlorobiphenyl',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>',
    'PCB-111',
    '39635-32-0',
    'QMUDLTGWHILKHH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;3</sup>',
    '6200',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',5,6-pentachlorobiphenyl',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>',
    'PCB-112',
    '74472-36-9',
    'NTKSJAPQYKCFPP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;3</sup>',
    '6600',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',5,6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',5,6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',5,6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',5,6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',5,6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',5,6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',5'',6-pentachlorobiphenyl',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>',
    'PCB-113',
    '68194-10-5',
    'YDGFMDPEJCJZEV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '6500',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',5'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',5'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',5'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',5'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',5'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',5'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,4'',5-pentachlorobiphenyl',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>',
    'PCB-114',
    '74472-37-0',
    'SXZSFWHOSHAKMN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3,4,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2565'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3,4,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '6400',
    'V',
    (SELECT id from species WHERE iupac='2,3,4,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,4,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,4'',6-pentachlorobiphenyl',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>',
    'PCB-115',
    '74472-38-1',
    'IOVARPVVZDOPGQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '6900',
    'V',
    (SELECT id from species WHERE iupac='2,3,4,4'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,4,4'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,4'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,4'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,4'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,4'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,5,6-pentachlorobiphenyl',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>',
    'PCB-116',
    '18259-05-7',
    'GGMPTLAAIUQMIE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;3</sup>',
    '6500',
    'V',
    (SELECT id from species WHERE iupac='2,3,4,5,6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,4,5,6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,5,6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,5,6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,5,6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,5,6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4'',5,6-pentachlorobiphenyl',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>',
    'PCB-117',
    '68194-11-6',
    'ZDDZPDTVCZLFFC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '5900',
    'V',
    (SELECT id from species WHERE iupac='2,3,4'',5,6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,4'',5,6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4'',5,6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4'',5,6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4'',5,6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4'',5,6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',4,4'',5-pentachlorobiphenyl',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>',
    'PCB-118',
    '31508-00-6',
    'IUTPYMGCWINGEY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '6800',
    'L',
    (SELECT id from species WHERE iupac='2,3'',4,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2540'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='LDV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;2</sup>',
    '7600',
    'L',
    (SELECT id from species WHERE iupac='2,3'',4,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2540'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3'',4,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3424'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3424-EPICS'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3'',4,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3424'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3424-direct'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3'',4,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2564'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2564mgsm'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3'',4,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2564'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2564igsm'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3'',4,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2565'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '14000',
    'M',
    (SELECT id from species WHERE iupac='2,3'',4,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2496'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HTdep_r2_lessthan_0.9'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '6000',
    'M',
    (SELECT id from species WHERE iupac='2,3'',4,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2340'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3'',4,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3'',4,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3797'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3'',4,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;3</sup>',
    '6000',
    'V',
    (SELECT id from species WHERE iupac='2,3'',4,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3'',4,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '8100',
    'T',
    (SELECT id from species WHERE iupac='2,3'',4,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5600',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6300',
    '?',
    (SELECT id from species WHERE iupac='2,3'',4,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',4,4'',6-pentachlorobiphenyl',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>',
    'PCB-119',
    '56558-17-9',
    'OAEQTHQGPZKTQP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '4600',
    'M',
    (SELECT id from species WHERE iupac='2,3'',4,4'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '6500',
    'V',
    (SELECT id from species WHERE iupac='2,3'',4,4'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3'',4,4'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,4'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,4'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,4'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,4'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,4'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,4'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,4'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,4'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3'',4,4'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',4,5,5''-pentachlorobiphenyl',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>',
    'PCB-120',
    '68194-12-7',
    'ZLGYJAIAVPVCNF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3'',4,5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1194'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '6000',
    'V',
    (SELECT id from species WHERE iupac='2,3'',4,5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3'',4,5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3'',4,5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',4,5'',6-pentachlorobiphenyl',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>',
    'PCB-121',
    '56558-18-0',
    'XBVSGJGMWSKAKL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;3</sup>',
    '6500',
    'V',
    (SELECT id from species WHERE iupac='2,3'',4,5'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3'',4,5'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,5'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,5'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,5'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,5'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4'',5''-pentachlorobiphenyl',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>',
    'PCB-122',
    '76842-07-4',
    'GWOWBISZHLPYEK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3,3'',4'',5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;3</sup>',
    '5800',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4'',5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4'',5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4'',5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4'',5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4'',5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4'',5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',4,4'',5''-pentachlorobiphenyl',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>',
    'PCB-123',
    '65510-44-3',
    'YAHNWSSFXMVPOU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3'',4,4'',5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2565'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;3</sup>',
    '5800',
    'V',
    (SELECT id from species WHERE iupac='2,3'',4,4'',5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3'',4,4'',5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,4'',5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,4'',5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,4'',5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,4'',5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',4'',5,5''-pentachlorobiphenyl',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>',
    'PCB-124',
    '70424-70-3',
    'PIVBPZFQXKMHBD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3'',4'',5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;3</sup>',
    '5900',
    'V',
    (SELECT id from species WHERE iupac='2,3'',4'',5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3'',4'',5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4'',5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4'',5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4'',5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4'',5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',4'',5'',6-pentachlorobiphenyl',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>',
    'PCB-125',
    '74472-39-2',
    'WAZUWHGJMMZVHH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '5800',
    'V',
    (SELECT id from species WHERE iupac='2,3'',4'',5'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3'',4'',5'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4'',5'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4'',5'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4'',5'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4'',5'',6-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3'',4,4'',5-pentachlorobiphenyl',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>',
    'PCB-126',
    '57465-28-8',
    'REHONNLQRWTIFF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3,3'',4,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2565'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '12000',
    'M',
    (SELECT id from species WHERE iupac='3,3'',4,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2340'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '5400',
    'V',
    (SELECT id from species WHERE iupac='3,3'',4,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,3'',4,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;2</sup>',
    '8800',
    'T',
    (SELECT id from species WHERE iupac='3,3'',4,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',4,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3424'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',4,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',4,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',4,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',4,4'',5-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3'',4,5,5''-pentachlorobiphenyl',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>',
    'PCB-127',
    '39635-33-1',
    'MXVAYAXIPRGORY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '5600',
    'V',
    (SELECT id from species WHERE iupac='3,3'',4,5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,3'',4,5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',4,5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',4,5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',4,5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',4,5,5''-pentachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,4''-hexachlorobiphenyl',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>',
    'PCB-128',
    '38380-07-3',
    'BTAGRXWGMYTPBY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '14000',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2340'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1194'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='643'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1140'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1140'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3797'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;3</sup>',
    '6100',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2302'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='murphy83'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from643'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3424'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,5-hexachlorobiphenyl',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>',
    'PCB-129',
    '55215-18-4',
    'VQQKIXKPMJTUMP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1194'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;3</sup>',
    '6400',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,5''-hexachlorobiphenyl',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>',
    'PCB-130',
    '52663-66-8',
    'YFSLABAYQDPWPF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1194'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;3</sup>',
    '6500',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,6-hexachlorobiphenyl',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>',
    'PCB-131',
    '61798-70-7',
    'WDLTVNWWEZJMPF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '6500',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,6''-hexachlorobiphenyl',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>',
    'PCB-132',
    '38380-05-1',
    'OKBJVIVEFXPEOU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '2400',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1194'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '6400',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',5,5''-hexachlorobiphenyl',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>',
    'PCB-133',
    '35694-04-3',
    'AJKLKINFZLWHQE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '6500',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',5,6-hexachlorobiphenyl',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>',
    'PCB-134',
    '52704-70-8',
    'RVWLHPJFOKUPNM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '7300',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1194'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3797'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '6400',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',5,6''-hexachlorobiphenyl',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>',
    'PCB-135',
    '52744-13-5',
    'UUTNFLRSJBQQJM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '5500',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1194'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;3</sup>',
    '6600',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',6,6''-hexachlorobiphenyl',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>',
    'PCB-136',
    '38411-22-2',
    'FZFUUSROAHKTTF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;3</sup>',
    '5400',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3'',6,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3'',6,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1194'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3'',6,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '6300',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',6,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',6,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',6,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',6,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',6,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',6,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',6,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',6,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',6,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',6,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2'',3,3'',6,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,4'',5-hexachlorobiphenyl',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>',
    'PCB-137',
    '35694-06-5',
    'CKLLRBPBZLTGDJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '3200',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3797'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '6800',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,4'',5''-hexachlorobiphenyl',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>',
    'PCB-138',
    '35065-28-2',
    'RPUMZMSNLZHIGZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '7100',
    'L',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2540'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='LDV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '7700',
    'L',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2540'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '10000',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2340'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1194'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3793'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at294K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3797'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '6800',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2302'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '8700',
    'T',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3424'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,4'',6-hexachlorobiphenyl',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>',
    'PCB-139',
    '56030-56-9',
    'SPOPSCCFZQFGDL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '6900',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,4'',6''-hexachlorobiphenyl',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>',
    'PCB-140',
    '59291-64-4',
    'XBBRGUHRZBZMPP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '7000',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,5,5''-hexachlorobiphenyl',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>',
    'PCB-141',
    '52712-04-6',
    'UCLKLGIYGBLTSM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '8400',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,4,5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,4,5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1194'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,4,5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,4,5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3797'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '6700',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2302'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2'',3,4,5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,5,6-hexachlorobiphenyl',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>',
    'PCB-142',
    '41411-61-4',
    'RUEIBQJFGMERJD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;3</sup>',
    '6900',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,5,6''-hexachlorobiphenyl',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>',
    'PCB-143',
    '68194-15-0',
    'UQPQKLGBEKEZBV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;3</sup>',
    '6600',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,5,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,5,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2'',3,4,5,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,5'',6-hexachlorobiphenyl',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>',
    'PCB-144',
    '68194-14-9',
    'CXXRQFOKRZJAJA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,4,5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,4,5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3797'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '7000',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2302'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,6,6''-hexachlorobiphenyl',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>',
    'PCB-145',
    '74472-40-5',
    'JZFZCLFEPXCRCA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '6400',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,6,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,6,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,6,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,6,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,6,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,6,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4'',5,5''-hexachlorobiphenyl',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>',
    'PCB-146',
    '51908-16-8',
    'BQHCQAQLTCQFJZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '7100',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1194'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '6800',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4'',5,6-hexachlorobiphenyl',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>',
    'PCB-147',
    '68194-13-8',
    'AQONCPKMJSBHQT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1194'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '6500',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4'',5,6''-hexachlorobiphenyl',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>',
    'PCB-148',
    '74472-41-6',
    'CTVRBEKNQHJPLX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '7000',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4'',5'',6-hexachlorobiphenyl',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>',
    'PCB-149',
    '38380-04-0',
    'LKHLFUVHHXCNJH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '5500',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3797'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '6800',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2302'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4'',6,6''-hexachlorobiphenyl',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>',
    'PCB-150',
    '68194-08-1',
    'RPPNJBZNXQNKNM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;3</sup>',
    '6900',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4'',6,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4'',6,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',6,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',6,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',6,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',6,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,5,5'',6-hexachlorobiphenyl',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>',
    'PCB-151',
    '52663-63-5',
    'UHCLFIWDCYOTOL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '4500',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,5,5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,5,5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1194'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,5,5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,5,5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3797'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;3</sup>',
    '6700',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,5,5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,5,5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2302'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,5,5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,5,5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,5,5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,5,5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,5,5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,5,5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,5,5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,5,5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,5,5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2'',3,5,5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,5,6,6''-hexachlorobiphenyl',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>',
    'PCB-152',
    '68194-09-2',
    'CLODVDBWNVQLGO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '6300',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,5,6,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,5,6,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,5,6,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,5,6,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,5,6,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,5,6,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',4,4'',5,5''-hexachlorobiphenyl',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>',
    'PCB-153',
    '35065-27-1',
    'MVWHGTYKUMDIHL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '7100',
    'L',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2540'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='LDV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;2</sup>',
    '7900',
    'L',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2540'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '8000',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2340'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1194'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='643'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1140'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1140'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1139'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3797'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '6700',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2302'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '8400',
    'T',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='murphy83'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from643'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='643'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3424'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',4,4'',5,6''-hexachlorobiphenyl',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>',
    'PCB-154',
    '60145-22-4',
    'QXZHEJWDLVUFFB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '5600',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2340'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '7100',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3424'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',4,4'',6,6''-hexachlorobiphenyl',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>',
    'PCB-155',
    '33979-03-2',
    'ICOAEPDGFWLUTI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '7100',
    'L',
    (SELECT id from species WHERE iupac='2,2'',4,4'',6,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2540'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='LDV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '7600',
    'L',
    (SELECT id from species WHERE iupac='2,2'',4,4'',6,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2540'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,4'',6,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='643'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,4'',6,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1140'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1140'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,4'',6,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;3</sup>',
    '6900',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,4'',6,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,4'',6,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,4'',6,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,4'',6,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2302'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,4'',6,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='2,2'',4,4'',6,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='643'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,4'',6,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,4'',6,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,4'',6,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,4'',6,6''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4,4'',5-hexachlorobiphenyl',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>',
    'PCB-156',
    '38380-08-4',
    'LCXMEXLGMKFLQO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2565'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '13000',
    'M',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3797'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;3</sup>',
    '6200',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2302'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4,4'',5''-hexachlorobiphenyl',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>',
    'PCB-157',
    '69782-90-7',
    'YTWXDQVNPCIEOX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2565'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '16000',
    'M',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3797'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '5900',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2302'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6300',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5100',
    '?',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4,4'',6-hexachlorobiphenyl',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>',
    'PCB-158',
    '74472-42-7',
    'ZQUPQXINXTWCQR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '9600',
    'M',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3797'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;3</sup>',
    '6600',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2302'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4,5,5''-hexachlorobiphenyl',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>',
    'PCB-159',
    '39635-35-3',
    'YZKLGRAIIIGOHB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3,3'',4,5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1194'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '6100',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4,5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4,5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3,3'',4,5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4,5,6-hexachlorobiphenyl',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>',
    'PCB-160',
    '41411-62-5',
    'JHJMZCXLJXRCHK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3,3'',4,5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1194'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;3</sup>',
    '7100',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4,5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4,5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3,3'',4,5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4,5'',6-hexachlorobiphenyl',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>',
    'PCB-161',
    '74472-43-8',
    'UNPTZXSJGZTGJJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;3</sup>',
    '6800',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4,5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4,5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4'',5,5''-hexachlorobiphenyl',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>',
    'PCB-162',
    '39635-34-2',
    'AHZUOPSGLWYCNF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;3</sup>',
    '6200',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4'',5,6-hexachlorobiphenyl',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>',
    'PCB-163',
    '74472-44-9',
    'ZAGRQXMWMRUYRB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '9700',
    'M',
    (SELECT id from species WHERE iupac='2,3,3'',4'',5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3,3'',4'',5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1194'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;3</sup>',
    '6400',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4'',5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4'',5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4'',5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4'',5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4'',5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4'',5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4'',5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4'',5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4'',5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4'',5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3,3'',4'',5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4'',5'',6-hexachlorobiphenyl',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>',
    'PCB-164',
    '74472-45-0',
    'HAZQOLYHFUUJJN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;3</sup>',
    '6500',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4'',5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4'',5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4'',5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4'',5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4'',5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4'',5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',5,5'',6-hexachlorobiphenyl',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>',
    'PCB-165',
    '74472-46-1',
    'ZEATXTCWXKQPHO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3,3'',5,5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1194'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '6400',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',5,5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',5,5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',5,5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',5,5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',5,5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',5,5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',5,5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',5,5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',5,5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',5,5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3,3'',5,5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,4'',5,6-hexachlorobiphenyl',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>',
    'PCB-166',
    '41411-63-6',
    'BTOCFTAWZMMTNB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '6500',
    'V',
    (SELECT id from species WHERE iupac='2,3,4,4'',5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,4,4'',5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,4'',5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,4'',5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,4'',5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,4'',5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4100',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,4'',5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,4'',5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,4'',5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5800',
    '?',
    (SELECT id from species WHERE iupac='2,3,4,4'',5,6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',4,4'',5,5''-hexachlorobiphenyl',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>',
    'PCB-167',
    '52663-72-6',
    'AZXHAWRMEPZSSV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3'',4,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2565'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '13000',
    'M',
    (SELECT id from species WHERE iupac='2,3'',4,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;3</sup>',
    '6400',
    'V',
    (SELECT id from species WHERE iupac='2,3'',4,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3'',4,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',4,4'',5'',6-hexachlorobiphenyl',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>',
    'PCB-168',
    '59291-65-5',
    'PITHIPNORFGJPI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '6700',
    'V',
    (SELECT id from species WHERE iupac='2,3'',4,4'',5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3'',4,4'',5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,4'',5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,4'',5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,4'',5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,4'',5'',6-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3'',4,4'',5,5''-hexachlorobiphenyl',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>',
    'PCB-169',
    '32774-16-6',
    'ZHLICBPIXDOFFG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3,3'',4,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2565'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '19000',
    'M',
    (SELECT id from species WHERE iupac='3,3'',4,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;4</sup>',
    '5100',
    'V',
    (SELECT id from species WHERE iupac='3,3'',4,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,3'',4,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '9000',
    'T',
    (SELECT id from species WHERE iupac='3,3'',4,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',4,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',4,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',4,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',4,4'',5,5''-hexachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1141'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,4'',5-heptachlorobiphenyl',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>7</sub>',
    'PCB-170',
    '35065-30-6',
    'RMPWIIKNWPVWNG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '20000',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2340'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1194'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;3</sup>',
    '6600',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3424'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,4'',6-heptachlorobiphenyl',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>7</sub>',
    'PCB-171',
    '52663-71-5',
    'TZMHVHLTPWKZCI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '7100',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2302'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,5,5''-heptachlorobiphenyl',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>7</sub>',
    'PCB-172',
    '52663-74-8',
    'HOPMUCXYRNOABF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,5''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1194'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;3</sup>',
    '6800',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,5''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,5''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,5''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,5''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,5''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,5''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,5''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,5''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,5''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,5,6-heptachlorobiphenyl',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>7</sub>',
    'PCB-173',
    '68194-16-1',
    'PAYFWJAKKLILIT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1194'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '6500',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,5,6''-heptachlorobiphenyl',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>7</sub>',
    'PCB-174',
    '38411-25-5',
    'ZDLMBNHYTPHDLF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '14000',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1194'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;3</sup>',
    '6700',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,5'',6-heptachlorobiphenyl',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>7</sub>',
    'PCB-175',
    '40186-70-7',
    'KJBDZJFSYQUNJT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '7200',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,6,6''-heptachlorobiphenyl',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>7</sub>',
    'PCB-176',
    '52663-65-7',
    'HGMYRFJAJNYBRX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,6,6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;3</sup>',
    '7200',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,6,6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,6,6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,6,6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,6,6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,6,6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,5'',6''-heptachlorobiphenyl',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>7</sub>',
    'PCB-177',
    '52663-70-4',
    'CXOYNJAHPUASHN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '13000',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5'',6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5'',6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5'',6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3797'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '6600',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5'',6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5'',6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5'',6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5'',6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5'',6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',5,5'',6-heptachlorobiphenyl',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>7</sub>',
    'PCB-178',
    '52663-67-9',
    'WCIBKXHMIXUQHK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '11000',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1194'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '7200',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',5,6,6''-heptachlorobiphenyl',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>7</sub>',
    'PCB-179',
    '52663-64-6',
    'XYHVYEUZLSYHDP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,6,6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1194'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '7000',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,6,6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,6,6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,6,6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,6,6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,6,6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,6,6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,6,6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,6,6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,6,6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,6,6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,4'',5,5''-heptachlorobiphenyl',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>7</sub>',
    'PCB-180',
    '35065-29-3',
    'WBHQEUPUMONIKF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '7300',
    'L',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5,5''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2540'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='LDV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '7900',
    'L',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5,5''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2540'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '17000',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5,5''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2340'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5,5''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1194'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5,5''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '6900',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5,5''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5,5''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '9000',
    'T',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5,5''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5,5''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5,5''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5,5''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3424'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5,5''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5,5''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5,5''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5,5''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5,5''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5,5''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,4'',5,6-heptachlorobiphenyl',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>7</sub>',
    'PCB-181',
    '74472-47-2',
    'DJEUXBQAKBLKPO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '7200',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5,6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5,6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5,6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5,6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5,6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,4'',5,6''-heptachlorobiphenyl',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>7</sub>',
    'PCB-182',
    '60145-23-5',
    'RXRLRYZUMSYVLS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '12000',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5,6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '7200',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5,6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5,6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5,6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5,6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5,6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,4'',5'',6-heptachlorobiphenyl',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>7</sub>',
    'PCB-183',
    '52663-69-1',
    'KQBFUDNJKCZEDQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '12000',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3797'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '7400',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,4'',6,6''-heptachlorobiphenyl',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>7</sub>',
    'PCB-184',
    '74472-48-3',
    'OBIUJJSQKPGKME-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;3</sup>',
    '7200',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',6,6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',6,6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',6,6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',6,6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',6,6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,5,5'',6-heptachlorobiphenyl',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>7</sub>',
    'PCB-185',
    '52712-05-7',
    'PYZHTHZEHQHHEN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,4,5,5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1194'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;3</sup>',
    '7000',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,5,5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,5,5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5,5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5,5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5,5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5,5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5,5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5,5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5,5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2'',3,4,5,5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,5,6,6''-heptachlorobiphenyl',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>7</sub>',
    'PCB-186',
    '74472-49-4',
    'FGDPOTMRBQHPJK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;4</sup>',
    '6500',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,5,6,6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,5,6,6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5,6,6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5,6,6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5,6,6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4'',5,5'',6-heptachlorobiphenyl',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>7</sub>',
    'PCB-187',
    '52663-68-0',
    'UDMZPLROONOSEF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '12000',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5,5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2340'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5,5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='853'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '7200',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5,5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5,5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5,5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5,5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5,5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4'',5,6,6''-heptachlorobiphenyl',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>7</sub>',
    'PCB-188',
    '74487-85-7',
    'MMTJWDQKGUNSDK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;3</sup>',
    '7500',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5,6,6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2340'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;3</sup>',
    '7100',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5,6,6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5,6,6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5,6,6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3424'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5,6,6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5,6,6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5,6,6''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4,4'',5,5''-heptachlorobiphenyl',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>7</sub>',
    'PCB-189',
    '39635-31-9',
    'XUAWBXBYHDRROL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5,5''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2565'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '6300',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5,5''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5,5''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5,5''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5,5''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5,5''-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4,4'',5,6-heptachlorobiphenyl',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>7</sub>',
    'PCB-190',
    '41411-64-7',
    'TYEDCFVCFDKSBK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '7000',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5,6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5,6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5,6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5,6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5,6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4,4'',5'',6-heptachlorobiphenyl',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>7</sub>',
    'PCB-191',
    '74472-50-7',
    'TVFXBXWAXIMLAQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '7200',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4,5,5'',6-heptachlorobiphenyl',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>7</sub>',
    'PCB-192',
    '74472-51-8',
    'ZUTDUGMNROUBOX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;3</sup>',
    '6900',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4,5,5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4,5,5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,5,5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,5,5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,5,5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4'',5,5'',6-heptachlorobiphenyl',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>7</sub>',
    'PCB-193',
    '69782-91-8',
    'SSTJUBQGYXNFFP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '17000',
    'M',
    (SELECT id from species WHERE iupac='2,3,3'',4'',5,5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;3</sup>',
    '6800',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4'',5,5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4'',5,5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4'',5,5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4'',5,5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4'',5,5'',6-heptachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,4'',5,5''-octachlorobiphenyl',
    'C<sub>12</sub>H<sub>2</sub>Cl<sub>8</sub>',
    'PCB-194',
    '35694-08-7',
    'DTMRKGRREZAYAP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '7500',
    'L',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,5''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2540'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='LDV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '8200',
    'L',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,5''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2540'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '20000',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,5''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2472'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,5''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1194'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;3</sup>',
    '6900',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,5''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,5''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,5''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,5''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,5''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,5''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,5''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,5''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6500',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,5''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,5''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,5''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6600',
    '?',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,5''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,4'',5,6-octachlorobiphenyl',
    'C<sub>12</sub>H<sub>2</sub>Cl<sub>8</sub>',
    'PCB-195',
    '52663-78-2',
    'JAHJITLFJSDRCG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;2</sup>',
    '20000',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,6-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2340'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,6-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1194'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;3</sup>',
    '7100',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,6-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,6-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,6-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,6-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,6-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,6-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,6-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,6-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,6-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,6-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,4'',5,6''-octachlorobiphenyl',
    'C<sub>12</sub>H<sub>2</sub>Cl<sub>8</sub>',
    'PCB-196',
    '42740-50-1',
    'BQFCCUSDZLKBJG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1194'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '7400',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,4'',6,6''-octachlorobiphenyl',
    'C<sub>12</sub>H<sub>2</sub>Cl<sub>8</sub>',
    'PCB-197',
    '33091-17-7',
    'YPDBBDKYNWRFMF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '7600',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',6,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',6,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',6,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',6,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',6,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,5,5'',6-octachlorobiphenyl',
    'C<sub>12</sub>H<sub>2</sub>Cl<sub>8</sub>',
    'PCB-198',
    '68194-17-2',
    'PJHBSPRZHUOIAS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,5'',6-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1194'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '7000',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,5'',6-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,5'',6-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,5'',6-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,5'',6-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,5'',6-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,5'',6-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,5'',6-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,5'',6-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,5'',6-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,5'',6-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,5,5'',6''-octachlorobiphenyl',
    'C<sub>12</sub>H<sub>2</sub>Cl<sub>8</sub>',
    'PCB-199',
    '52663-75-9',
    'HJBYDWKNARZTMJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,5'',6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1194'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '7000',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,5'',6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,5'',6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,5'',6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,5'',6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,5'',6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,5'',6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,5'',6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,5'',6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,5'',6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,5'',6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,5,6,6''-octachlorobiphenyl',
    'C<sub>12</sub>H<sub>2</sub>Cl<sub>8</sub>',
    'PCB-200',
    '52663-73-7',
    'HHXNVASVVVNNDG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;3</sup>',
    '7200',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,6,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,6,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,6,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,6,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,6,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,5'',6,6''-octachlorobiphenyl',
    'C<sub>12</sub>H<sub>2</sub>Cl<sub>8</sub>',
    'PCB-201',
    '40186-71-8',
    'LJQOBQLZTUSEJA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '17000',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5'',6,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2340'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5'',6,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1194'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '7500',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5'',6,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5'',6,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5'',6,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5'',6,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5'',6,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3424'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5'',6,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5'',6,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5'',6,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5'',6,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5'',6,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5'',6,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',5,5'',6,6''-octachlorobiphenyl',
    'C<sub>12</sub>H<sub>2</sub>Cl<sub>8</sub>',
    'PCB-202',
    '2136-99-4',
    'JPOPEORRMSDUIP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,5'',6,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1194'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;3</sup>',
    '7300',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,5'',6,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,5'',6,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,5'',6,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,5'',6,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2302'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,5'',6,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,5'',6,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,5'',6,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,5'',6,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,5'',6,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,5'',6,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,5'',6,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4700',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,5'',6,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,5'',6,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,5'',6,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5000',
    '?',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,5'',6,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,4'',5,5'',6-octachlorobiphenyl',
    'C<sub>12</sub>H<sub>2</sub>Cl<sub>8</sub>',
    'PCB-203',
    '52663-76-0',
    'DCPDZFRGNJDWPP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '7800',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5,5'',6-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5,5'',6-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5,5'',6-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3424'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5,5'',6-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5,5'',6-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5,5'',6-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,4'',5,6,6''-octachlorobiphenyl',
    'C<sub>12</sub>H<sub>2</sub>Cl<sub>8</sub>',
    'PCB-204',
    '74472-52-9',
    'JDZUWXRNKHXZFE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '7800',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5,6,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5,6,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5,6,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3424'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5,6,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5,6,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5,6,6''-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4,4'',5,5'',6-octachlorobiphenyl',
    'C<sub>12</sub>H<sub>2</sub>Cl<sub>8</sub>',
    'PCB-205',
    '74472-53-0',
    'VXXBCDUYUQKWCK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;3</sup>',
    '6800',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5,5'',6-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5,5'',6-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5,5'',6-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3424'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5,5'',6-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5,5'',6-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5,5'',6-octachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,4'',5,5'',6-nonachlorobiphenyl',
    'C<sub>12</sub>HCl<sub>9</sub>',
    'PCB-206',
    '40186-72-9',
    'JFIMDKGRGPNPRQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '7300',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,5'',6-nonachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,5'',6-nonachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,5'',6-nonachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,5'',6-nonachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,5'',6-nonachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3424'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,5'',6-nonachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,5'',6-nonachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,5'',6-nonachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,4'',5,6,6''-nonachlorobiphenyl',
    'C<sub>12</sub>HCl<sub>9</sub>',
    'PCB-207',
    '52663-79-3',
    'YGDPIDTZOQGPAX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '7500',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,6,6''-nonachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,6,6''-nonachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,6,6''-nonachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3424'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,6,6''-nonachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,6,6''-nonachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,6,6''-nonachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,5,5'',6,6''-nonachlorobiphenyl',
    'C<sub>12</sub>HCl<sub>9</sub>',
    'PCB-208',
    '52663-77-1',
    'XIFFTDRFWYFAPO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '7700',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,5'',6,6''-nonachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,5'',6,6''-nonachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,5'',6,6''-nonachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3424'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,5'',6,6''-nonachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,5'',6,6''-nonachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,5'',6,6''-nonachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'decachlorobiphenyl',
    'C<sub>12</sub>Cl<sub>10</sub>',
    'PCB-209',
    '2051-24-3',
    'ONXPZLFXDMAPRO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated biphenyls (PCBs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='decachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;4</sup>',
    '7200',
    'V',
    (SELECT id from species WHERE iupac='decachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='decachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2612_pc_problem'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='decachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='633'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='decachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2302'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='decachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='850'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3424'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2932'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2932PLSR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6100',
    'Q',
    (SELECT id from species WHERE iupac='decachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2475'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7300',
    '?',
    (SELECT id from species WHERE iupac='decachlorobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Oxygenated chlorocarbons (C, H, O, Cl)',
    (SELECT id from categories WHERE catname='Organic species with chlorine (Cl)'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phosgene',
    'CCl<sub>2</sub>O',
    '',
    '75-44-5',
    'YGYAWVDWMABLBF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;4</sup>',
    '3800',
    'M',
    (SELECT id from species WHERE iupac='phosgene'),
    (SELECT id from literature WHERE bibtexkey='1125'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;4</sup>',
    '4200',
    'M',
    (SELECT id from species WHERE iupac='phosgene'),
    (SELECT id from literature WHERE bibtexkey='1992'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='phosgene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phosgene'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phosgene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phosgene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phosgene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phosgene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phosgene'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phosgene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='phosgene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='phosgene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CCL3OOH',
    'CHO<sub>2</sub>Cl<sub>3</sub>',
    '',
    '',
    'DUBMHDTUZCIGCY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CCL3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CCL3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CCL3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CH2CLOOH',
    'CH<sub>3</sub>O<sub>2</sub>Cl',
    '',
    '',
    'DUNYOPWYTOSXOC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH2CLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH2CLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH2CLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CHCL2OOH',
    'CH<sub>2</sub>O<sub>2</sub>Cl<sub>2</sub>',
    '',
    '',
    'TUIYYMKEIGYDJB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHCL2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHCL2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHCL2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CCL3OH',
    'CHOCl<sub>3</sub>',
    '',
    '',
    'GYLIOGDFGLKMOL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CCL3OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CCL3OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CCL3OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CH2CLOH',
    'CH<sub>3</sub>OCl',
    '',
    '',
    'BCUPGIHTCQJCSI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH2CLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH2CLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH2CLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CHCL2OH',
    'CH<sub>2</sub>OCl<sub>2</sub>',
    '',
    '',
    'GJYVZUKSNFSLCL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHCL2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHCL2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHCL2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CHOCL',
    'CHOCl',
    '',
    '',
    'GFAUNYMRSKVDJL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOCL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOCL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHOCL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CLCO2H',
    'CHO<sub>2</sub>Cl',
    '',
    '',
    'AOGYCOYQMAVAFD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CLCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CLCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CLCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dichloroacetaldehyde',
    'C<sub>2</sub>H<sub>2</sub>Cl<sub>2</sub>O',
    '',
    '79-02-7',
    'NWQWQKUXRJYXFH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichloroacetaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichloroacetaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichloroacetaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichloroacetaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chloroacetyl chloride',
    'C<sub>2</sub>H<sub>2</sub>Cl<sub>2</sub>O',
    '',
    '79-04-9',
    'VGCXGMAHQTYDJK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroacetyl chloride'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroacetyl chloride'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroacetyl chloride'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroacetyl chloride'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chloral hydrate',
    'C<sub>2</sub>H<sub>3</sub>Cl<sub>3</sub>O<sub>2</sub>',
    '',
    '302-17-0',
    'RNFNDJAIBTYOQL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chloral hydrate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chloroacetaldehyde',
    'C<sub>2</sub>H<sub>3</sub>ClO',
    '',
    '107-20-0',
    'QSKPIOLLBIHNAC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroacetaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroacetaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroacetaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroacetaldehyde'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-chloroethanol',
    'C<sub>2</sub>H<sub>5</sub>ClO',
    '',
    '107-07-3',
    'SZIFAVKTNFCBPC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-chloroethanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloroethanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloroethanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloroethanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloroethanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloroethanol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloroethanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloroethanol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloroethanol'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dichloroethanol',
    'C<sub>2</sub>H<sub>4</sub>Cl<sub>2</sub>O',
    '',
    '598-38-9',
    'IDJOCJAIQSKSOP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2,2-dichloroethanol'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2,2-dichloroethanol'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2-dichloroethanol'),
    (SELECT id from literature WHERE bibtexkey='3526'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dichloroethanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dichloroethanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dichloroethanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-chloroethanol-d4',
    'ClC<sub>2</sub>D<sub>4</sub>OH',
    '',
    '117067-62-6',
    'SZIFAVKTNFCBPC-LNLMKGTHSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0',
    '8700',
    'M',
    (SELECT id from species WHERE iupac='2-chloroethanol-d4'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CCL2CL2OOH',
    'C<sub>2</sub>H<sub>2</sub>O<sub>2</sub>Cl<sub>4</sub>',
    '',
    '',
    'SWNDCAXLXSSRFN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CCL2CL2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CCL2CL2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CCL2CL2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CCL3CH2OOH',
    'C<sub>2</sub>H<sub>3</sub>O<sub>2</sub>Cl<sub>3</sub>',
    '',
    '',
    'RJIYMCLTECJZCN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CCL3CH2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CCL3CH2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CCL3CH2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CCL3CO3H',
    'C<sub>2</sub>HO<sub>3</sub>Cl<sub>3</sub>',
    '',
    '',
    'DRTNVNKYVPOWCY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CCL3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CCL3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CCL3CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CH2CL3OOH',
    'C<sub>2</sub>H<sub>3</sub>O<sub>2</sub>Cl<sub>3</sub>',
    '',
    '',
    'CHVIFDTZRLKJET-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH2CL3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH2CL3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH2CL3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CH2CLCOOH',
    'C<sub>2</sub>H<sub>5</sub>O<sub>2</sub>Cl',
    '',
    '',
    'PIXGNJBYAUTOCI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH2CLCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH2CLCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH2CLCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CH3CCL2OOH',
    'C<sub>2</sub>H<sub>4</sub>O<sub>2</sub>Cl<sub>2</sub>',
    '',
    '',
    'YUVMNUKOYYKKNS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3CCL2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3CCL2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3CCL2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CH3CHCLOOH',
    'C<sub>2</sub>H<sub>5</sub>O<sub>2</sub>Cl',
    '',
    '',
    'MCYQTMMYWIXRIL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3CHCLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3CHCLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3CHCLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CHCL2CO3H',
    'C<sub>2</sub>H<sub>2</sub>O<sub>3</sub>Cl<sub>2</sub>',
    '',
    '',
    'VWNSYHZUZUFFDM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHCL2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHCL2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHCL2CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CHCL2COOH',
    'C<sub>2</sub>H<sub>4</sub>O<sub>2</sub>Cl<sub>2</sub>',
    '',
    '',
    'GJBKLBBJOKITMY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHCL2COOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHCL2COOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHCL2COOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CHCL3OOH',
    'C<sub>2</sub>H<sub>3</sub>O<sub>2</sub>Cl<sub>3</sub>',
    '',
    '',
    'AMASFZACKVPSTN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHCL3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHCL3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHCL3OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CLETO3H',
    'C<sub>2</sub>H<sub>3</sub>O<sub>3</sub>Cl',
    '',
    '',
    'JSQPGNJFQUOEPA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CLETO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CLETO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CLETO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DICLETO2H',
    'C<sub>2</sub>H<sub>4</sub>O<sub>2</sub>Cl<sub>2</sub>',
    '',
    '',
    'UPXDMONURWDHKL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DICLETO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DICLETO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DICLETO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C2CL2OH2',
    'C<sub>2</sub>H<sub>4</sub>O<sub>2</sub>Cl<sub>2</sub>',
    '',
    '',
    'HHQQTVXFKGIICR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C2CL2OH2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C2CL2OH2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C2CL2OH2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C2CL2OHOOH',
    'C<sub>2</sub>H<sub>4</sub>O<sub>3</sub>Cl<sub>2</sub>',
    '',
    '',
    'NCBKAYIJWMIXBU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C2CL2OHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C2CL2OHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C2CL2OHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C2CL32OH',
    'C<sub>2</sub>H<sub>3</sub>O<sub>2</sub>Cl<sub>3</sub>',
    '',
    '',
    'MYDJEUINZIFHKK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C2CL32OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C2CL32OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C2CL32OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C2CL3HOOOH',
    'C<sub>2</sub>H<sub>3</sub>O<sub>3</sub>Cl<sub>3</sub>',
    '',
    '',
    'KHLAQOPQQHOMKQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C2CL3HOOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C2CL3HOOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C2CL3HOOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:C2CL3OHOOH',
    'C<sub>2</sub>H<sub>3</sub>O<sub>3</sub>Cl<sub>3</sub>',
    '',
    '',
    'CEKNFZNLLTXCLL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C2CL3OHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C2CL3OHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:C2CL3OHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'trichloroethanol',
    'C<sub>2</sub>H<sub>3</sub>OCl<sub>3</sub>',
    '',
    '115-20-8',
    'KPWDGTGXUYRARH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloroethanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloroethanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloroethanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CCLOHCOOH',
    'C<sub>2</sub>H<sub>5</sub>O<sub>3</sub>Cl',
    '',
    '',
    'MIFGQALJBIDZDW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CCLOHCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CCLOHCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CCLOHCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CH2CL3OH',
    'C<sub>2</sub>H<sub>3</sub>OCl<sub>3</sub>',
    '',
    '',
    'HYCHPIPDVAXCCJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH2CL3OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH2CL3OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH2CL3OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CH2OHCCLOH',
    'C<sub>2</sub>H<sub>5</sub>O<sub>2</sub>Cl',
    '',
    '',
    'VVKFXODVPQSIHU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH2OHCCLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH2OHCCLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH2OHCCLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CH3CCL2OH',
    'C<sub>2</sub>H<sub>4</sub>OCl<sub>2</sub>',
    '',
    '',
    'DNBABSPIEDTPHK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3CCL2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3CCL2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3CCL2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CH3CHCLOH',
    'C<sub>2</sub>H<sub>5</sub>OCl',
    '',
    '',
    'KJESGYZFVCIMDE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3CHCLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3CHCLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3CHCLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CHCL2CL2OH',
    'C<sub>2</sub>H<sub>2</sub>OCl<sub>4</sub>',
    '',
    '',
    'LQINPQOSBLVJBS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHCL2CL2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHCL2CL2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHCL2CL2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CHCL3OH',
    'C<sub>2</sub>H<sub>3</sub>OCl<sub>3</sub>',
    '',
    '',
    'NIBKDWIGIKUFKL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHCL3OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHCL3OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHCL3OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CL2OHCH2OH',
    'C<sub>2</sub>H<sub>4</sub>O<sub>2</sub>Cl<sub>2</sub>',
    '',
    '',
    'ZOZPDNLNQWCVSW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CL2OHCH2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CL2OHCH2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CL2OHCH2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CL2OHCO3H',
    'C<sub>2</sub>H<sub>2</sub>O<sub>4</sub>Cl<sub>2</sub>',
    '',
    '',
    'MACSTFWYVGNISK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CL2OHCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CL2OHCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CL2OHCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CL2OHOOH',
    'C<sub>2</sub>H<sub>4</sub>O<sub>3</sub>Cl<sub>2</sub>',
    '',
    '',
    'WOJAYLCSWSBEJV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CL2OHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CL2OHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CL2OHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CLOHCO3H',
    'C<sub>2</sub>H<sub>3</sub>O<sub>4</sub>Cl',
    '',
    '',
    'IODLIDNNOHQSDW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CLOHCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CLOHCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CLOHCO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:COHCCLOOH',
    'C<sub>2</sub>H<sub>5</sub>O<sub>3</sub>Cl',
    '',
    '',
    'WXPZQCJQULOKCY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:COHCCLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:COHCCLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:COHCCLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DICLETOH',
    'C<sub>2</sub>H<sub>4</sub>OCl<sub>2</sub>',
    '',
    '',
    'QXBDFCZHAAOUBY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DICLETOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DICLETOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DICLETOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TCE2OH',
    'C<sub>2</sub>H<sub>2</sub>O<sub>2</sub>Cl<sub>4</sub>',
    '',
    '',
    'BVBMRJKFECUARX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TCE2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TCE2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TCE2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:TCEOHOOH',
    'C<sub>2</sub>H<sub>2</sub>O<sub>3</sub>Cl<sub>4</sub>',
    '',
    '',
    'YKIXQGIQZGTABG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TCEOHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TCEOHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:TCEOHOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CCLOHCHO',
    'C<sub>2</sub>H<sub>3</sub>O<sub>2</sub>Cl',
    '',
    '',
    'RYRGLFUQPWFXSD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CCLOHCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CCLOHCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CCLOHCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CL2OHCHO',
    'C<sub>2</sub>H<sub>2</sub>O<sub>2</sub>Cl<sub>2</sub>',
    '',
    '',
    'LCOUNIIIIIWZOM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CL2OHCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CL2OHCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CL2OHCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CH3COCL',
    'C<sub>2</sub>H<sub>3</sub>OCl',
    '',
    '',
    'WETWJCDKMRHUPV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3COCL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3COCL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3COCL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CHCL2COCL',
    'C<sub>2</sub>HOCl<sub>3</sub>',
    '',
    '',
    'FBCCMZVIWNDFMO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHCL2COCL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHCL2COCL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHCL2COCL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CLCOCH2OOH',
    'C<sub>2</sub>H<sub>3</sub>O<sub>3</sub>Cl',
    '',
    '',
    'ARKKUYXZQNWAAF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CLCOCH2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CLCOCH2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CLCOCH2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CLCOCL2OOH',
    'C<sub>2</sub>HO<sub>3</sub>Cl<sub>3</sub>',
    '',
    '',
    'FXUYMCPKRPYDCU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CLCOCL2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CLCOCL2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CLCOCL2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CLCOCLOOH',
    'C<sub>2</sub>H<sub>2</sub>O<sub>3</sub>Cl<sub>2</sub>',
    '',
    '',
    'WROSSTYSMNZXTC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CLCOCLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CLCOCLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CLCOCLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CLGLYOX',
    'C<sub>2</sub>O<sub>2</sub>Cl<sub>2</sub>',
    '',
    '',
    'CTSLXHKWHWQRSH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CLGLYOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CLGLYOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CLGLYOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CCL2OHCOCL',
    'C<sub>2</sub>HO<sub>2</sub>Cl<sub>3</sub>',
    '',
    '',
    'WBBOIYQGQVKNEO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CCL2OHCOCL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CCL2OHCOCL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CCL2OHCOCL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CCLOHCOCL',
    'C<sub>2</sub>H<sub>2</sub>O<sub>2</sub>Cl<sub>2</sub>',
    '',
    '',
    'NABBVDLPPITPRF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CCLOHCOCL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CCLOHCOCL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CCLOHCOCL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CH2OHCOCL',
    'C<sub>2</sub>H<sub>3</sub>O<sub>2</sub>Cl',
    '',
    '',
    'LCIMJULVQOQTEZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH2OHCOCL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH2OHCOCL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH2OHCOCL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CL1GLYOX',
    'C<sub>2</sub>HO<sub>2</sub>Cl',
    '',
    '',
    'ZNBGBHISQKMEPA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CL1GLYOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CL1GLYOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CL1GLYOX'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CLOHCO2H',
    'C<sub>2</sub>H<sub>3</sub>O<sub>3</sub>Cl',
    '',
    '',
    'SORBEIKZIPTJRS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CLOHCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CLOHCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CLOHCO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,1-trichloro-2-propanone',
    'C<sub>3</sub>H<sub>3</sub>Cl<sub>3</sub>O',
    '',
    '918-00-3',
    'SMZHKGXSEAGRTI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1-trichloro-2-propanone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1-dichloro-2-propanone',
    'C<sub>3</sub>H<sub>4</sub>Cl<sub>2</sub>O',
    '1,1-dichloroacetone',
    '513-88-2',
    'CSVFWMMPUJDVKH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,1-dichloro-2-propanone'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,1-dichloro-2-propanone'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,1-dichloro-2-propanone'),
    (SELECT id from literature WHERE bibtexkey='3526'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichloro-2-propanone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'carbonochloridic acid, 2-chloroethyl ester',
    'C<sub>3</sub>H<sub>4</sub>Cl<sub>2</sub>O<sub>2</sub>',
    'chloroethyl chloroformate',
    '627-11-2',
    'SVDDJQGVOFZBNX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='carbonochloridic acid, 2-chloroethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'carbonochloridic acid, ethyl ester',
    'C<sub>3</sub>H<sub>5</sub>ClO<sub>2</sub>',
    'ethyl chloroformate',
    '541-41-3',
    'RIFGWPKJUGCATF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='carbonochloridic acid, ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-chloropropanoic acid',
    'C<sub>3</sub>H<sub>5</sub>ClO<sub>2</sub>',
    '',
    '598-78-7',
    'GAWAYYRQGQZKCR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloropropanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dichloro-1-propanol',
    'C<sub>3</sub>H<sub>6</sub>Cl<sub>2</sub>O',
    '',
    '616-23-9',
    'ZXCYIJGIGSDJQQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dichloro-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dichloro-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dichloro-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dichloro-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3-dichloro-2-propanol',
    'C<sub>3</sub>H<sub>6</sub>Cl<sub>2</sub>O',
    '',
    '96-23-1',
    'DEWLEGDTCGBNGU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3-dichloro-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichloro-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichloro-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichloro-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichloro-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichloro-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichloro-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichloro-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-chloro-1,2-propanediol',
    'C<sub>3</sub>H<sub>7</sub>ClO<sub>2</sub>',
    '',
    '96-24-2',
    'SSZWWUDQMAHNAQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-chloro-1,2-propanediol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-chloro-2-propanol',
    'C<sub>3</sub>H<sub>7</sub>ClO',
    '',
    '127-00-4',
    'YYTSGNJTASLUOY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-2-propanol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-chloro-1-propanol',
    'C<sub>3</sub>H<sub>7</sub>ClO',
    '',
    '78-89-7',
    'VZIQXGLTRZLBEX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-chloro-1-propanol',
    'C<sub>3</sub>H<sub>7</sub>ClO',
    '',
    '627-30-5',
    'LAMUXTNQCICZQX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-chloro-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'trichloroethanal',
    'CCl<sub>3</sub>CHO',
    'trichloroacetaldehyde; chloral',
    '75-87-6',
    'HFFLGKNGCAIQMO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>3</sup>',
    '3500',
    'L',
    (SELECT id from species WHERE iupac='trichloroethanal'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='RCHOdiol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>3</sup>',
    '3500',
    'L',
    (SELECT id from species WHERE iupac='trichloroethanal'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='RCHOdiol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>3</sup>',
    '3500',
    'M',
    (SELECT id from species WHERE iupac='trichloroethanal'),
    (SELECT id from literature WHERE bibtexkey='484'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='RCHOdiol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloroethanal'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloroethanal'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloroethanal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloroethanal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloroethanal'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloroethanal'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloroethanal'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloroethanal'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '1700',
    'Q',
    (SELECT id from species WHERE iupac='trichloroethanal'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloroethanal'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='trichloroethanal'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3500',
    '?',
    (SELECT id from species WHERE iupac='trichloroethanal'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chloro-2-propanone',
    'CH<sub>2</sub>ClCOCH<sub>3</sub>',
    'chloroacetone',
    '78-95-5',
    'BULLHNJGPPOUOX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;1</sup>',
    '5400',
    'L',
    (SELECT id from species WHERE iupac='chloro-2-propanone'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;1</sup>',
    '5400',
    'L',
    (SELECT id from species WHERE iupac='chloro-2-propanone'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;1</sup>',
    '5400',
    'L',
    (SELECT id from species WHERE iupac='chloro-2-propanone'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;1</sup>',
    '5400',
    'M',
    (SELECT id from species WHERE iupac='chloro-2-propanone'),
    (SELECT id from literature WHERE bibtexkey='495'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloro-2-propanone'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloro-2-propanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloro-2-propanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloro-2-propanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloro-2-propanone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloro-2-propanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloro-2-propanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloro-2-propanone'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloro-2-propanone'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloro-2-propanone'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4400',
    'Q',
    (SELECT id from species WHERE iupac='chloro-2-propanone'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chloro-2-propanone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5500',
    '?',
    (SELECT id from species WHERE iupac='chloro-2-propanone'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chloroethanoic acid',
    'CH<sub>2</sub>ClCOOH',
    'chloroacetic acid',
    '79-11-8',
    'FOCAUTSVDIKZOP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '9700',
    'L',
    (SELECT id from species WHERE iupac='chloroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '9700',
    'L',
    (SELECT id from species WHERE iupac='chloroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '9700',
    'L',
    (SELECT id from species WHERE iupac='chloroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '9700',
    'M',
    (SELECT id from species WHERE iupac='chloroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='896'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '8100',
    'Q',
    (SELECT id from species WHERE iupac='chloroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chloroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '9400',
    '?',
    (SELECT id from species WHERE iupac='chloroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dichloroethanoic acid',
    'CHCl<sub>2</sub>COOH',
    'dichloroacetic acid',
    '79-43-6',
    'JXTHNDFMNIQAHM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '8000',
    'L',
    (SELECT id from species WHERE iupac='dichloroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '8000',
    'L',
    (SELECT id from species WHERE iupac='dichloroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '8000',
    'L',
    (SELECT id from species WHERE iupac='dichloroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '8000',
    'M',
    (SELECT id from species WHERE iupac='dichloroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='896'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichloroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichloroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichloroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichloroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichloroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichloroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichloroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichloroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichloroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichloroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '8400',
    'Q',
    (SELECT id from species WHERE iupac='dichloroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichloroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dichloroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '8000',
    '?',
    (SELECT id from species WHERE iupac='dichloroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'trichloroethanoic acid',
    'CCl<sub>3</sub>COOH',
    'trichloroacetic acid',
    '76-03-9',
    'YNJBWRMUSHSURL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>2</sup>',
    '8700',
    'L',
    (SELECT id from species WHERE iupac='trichloroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>2</sup>',
    '8700',
    'L',
    (SELECT id from species WHERE iupac='trichloroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>2</sup>',
    '8700',
    'L',
    (SELECT id from species WHERE iupac='trichloroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>2</sup>',
    '8700',
    'M',
    (SELECT id from species WHERE iupac='trichloroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='992'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '8800',
    'Q',
    (SELECT id from species WHERE iupac='trichloroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='trichloroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '8600',
    '?',
    (SELECT id from species WHERE iupac='trichloroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dichloro-propanoic acid',
    'C<sub>3</sub>H<sub>4</sub>Cl<sub>2</sub>O<sub>2</sub>',
    '',
    '75-99-0',
    'NDUPDOJHUQKPAG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2-dichloro-propanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>8</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2-dichloro-propanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dichloro-propanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'trichloroacetylchloride',
    'CCl<sub>3</sub>COCl',
    '',
    '76-02-8',
    'PVFOMCVHYWHZJE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trichloroacetylchloride'),
    (SELECT id from literature WHERE bibtexkey='671'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trichloroacetylchloride'),
    (SELECT id from literature WHERE bibtexkey='1125'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at278K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trichloroacetylchloride'),
    (SELECT id from literature WHERE bibtexkey='1126'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloroacetylchloride'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloroacetylchloride'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloroacetylchloride'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='trichloroacetylchloride'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hexachloroacetone',
    'C<sub>3</sub>Cl<sub>6</sub>O',
    '',
    '116-16-5',
    'DOJXGHGHTWFZHK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexachloroacetone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexachloroacetone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexachloroacetone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexachloroacetone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(chloromethyl)-oxirane',
    'C<sub>3</sub>H<sub>5</sub>ClO',
    'epichlorohydrin',
    '106-89-8',
    'BRLQWZUYTZBJKN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='(chloromethyl)-oxirane'),
    (SELECT id from literature WHERE bibtexkey='3646'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(chloromethyl)-oxirane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(chloromethyl)-oxirane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(chloromethyl)-oxirane'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(chloromethyl)-oxirane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='(chloromethyl)-oxirane'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '3700',
    'X',
    (SELECT id from species WHERE iupac='(chloromethyl)-oxirane'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(chloromethyl)-oxirane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(chloromethyl)-oxirane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(chloromethyl)-oxirane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl chloroethanoate',
    'C<sub>3</sub>H<sub>5</sub>ClO<sub>2</sub>',
    '',
    '96-34-4',
    'QABLOFMHHSOFRJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;1</sup>',
    '5600',
    'L',
    (SELECT id from species WHERE iupac='methyl chloroethanoate'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl chloroethanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl chloroethanoate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl chloroethanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl chloroethanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl chloroethanoate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CL12CO3H',
    'C<sub>3</sub>H<sub>4</sub>O<sub>3</sub>Cl<sub>2</sub>',
    '',
    '',
    'VMJCNPRTZBGZGF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CL12CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CL12CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CL12CO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CL12PRAOOH',
    'C<sub>3</sub>H<sub>6</sub>O<sub>2</sub>Cl<sub>2</sub>',
    '',
    '',
    'WGVINOMLJVZPKZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CL12PRAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CL12PRAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CL12PRAOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CL12PRBOOH',
    'C<sub>3</sub>H<sub>6</sub>O<sub>2</sub>Cl<sub>2</sub>',
    '',
    '',
    'OMIMXWULHYQJIC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CL12PRBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CL12PRBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CL12PRBOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CL12PRCOOH',
    'C<sub>3</sub>H<sub>6</sub>O<sub>2</sub>Cl<sub>2</sub>',
    '',
    '',
    'ULSSYZYIMOSSQB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CL12PRCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CL12PRCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CL12PRCOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CL12PRBOH',
    'C<sub>3</sub>H<sub>6</sub>OCl<sub>2</sub>',
    '',
    '',
    'QEZDCTNHTRSNMD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CL12PRBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CL12PRBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CL12PRBOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CL12PRCOH',
    'C<sub>3</sub>H<sub>6</sub>OCl<sub>2</sub>',
    '',
    '',
    'FLTSEOGWHPJWRV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CL12PRCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CL12PRCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CL12PRCOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CL12PRCHO',
    'C<sub>3</sub>H<sub>4</sub>OCl<sub>2</sub>',
    '',
    '',
    'IZRKUJREXIKAQM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CL12PRCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CL12PRCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CL12PRCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CH3CLCOCL',
    'C<sub>3</sub>H<sub>4</sub>OCl<sub>2</sub>',
    '',
    '',
    'JEQDSBVHLKBEIZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3CLCOCL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3CLCOCL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3CLCOCL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CH3COCLOOH',
    'C<sub>3</sub>H<sub>5</sub>O<sub>3</sub>Cl',
    '',
    '',
    'HLLYIZVQRAGDFF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3COCLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3COCLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3COCLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CLCOCLMOOH',
    'C<sub>3</sub>H<sub>4</sub>O<sub>3</sub>Cl<sub>2</sub>',
    '',
    '',
    'RUPGTCZALLJKQM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CLCOCLMOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CLCOCLMOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CLCOCLMOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CL12CO2H',
    'C<sub>3</sub>H<sub>4</sub>O<sub>2</sub>Cl<sub>2</sub>',
    '',
    '',
    'GKFWNPPZHDYVLI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CL12CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CL12CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CL12CO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-chloro-2-butanone',
    'C<sub>4</sub>H<sub>7</sub>ClO',
    '',
    '4091-39-8',
    'OIMRLHCSLQUXLL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-chloro-2-butanone'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyl chloroethanoate',
    'C<sub>4</sub>H<sub>7</sub>ClO<sub>2</sub>',
    '',
    '105-39-5',
    'VEUUMBGHMNQHGO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '6100',
    'L',
    (SELECT id from species WHERE iupac='ethyl chloroethanoate'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl chloroethanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl chloroethanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl chloroethanoate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl chloroethanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl chloroethanoate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethyl chloroethanoate'),
    (SELECT id from literature WHERE bibtexkey='3393'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'carbonochloridic acid, 1-methylethyl ester',
    'C<sub>4</sub>H<sub>7</sub>ClO<sub>2</sub>',
    '',
    '108-23-6',
    'IVRIRQXJSNCSPQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='carbonochloridic acid, 1-methylethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chloroacetic acid anhydride',
    'C<sub>4</sub>H<sub>4</sub>Cl<sub>2</sub>O<sub>3</sub>',
    '',
    '541-88-8',
    'PNVPNXKRAUBJGW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroacetic acid anhydride'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chlorobutanol',
    'C<sub>4</sub>H<sub>9</sub>ClO',
    '',
    '1320-66-7',
    'OSASVXMJTNOKOY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorobutanol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl 2-chloroacetoacetate',
    'C<sub>5</sub>H<sub>7</sub>ClO<sub>3</sub>',
    '',
    '4755-81-1',
    'GYQRIAVRKLRQKP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    '?',
    (SELECT id from species WHERE iupac='methyl 2-chloroacetoacetate'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-chloro-4-(dichloromethyl)-2-(5H)-furanone',
    'C<sub>5</sub>H<sub>3</sub>Cl<sub>3</sub>O<sub>2</sub>',
    '',
    '122551-89-7',
    'WNQKLIFDPFSPIZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-chloro-4-(dichloromethyl)-2-(5H)-furanone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-chloro-4-(dichloromethyl)-5-hydroxy-2-(5H)-furanone',
    'C<sub>5</sub>H<sub>3</sub>Cl<sub>3</sub>O<sub>3</sub>',
    '',
    '77439-76-0',
    'WNTRMRXAGJOLCU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-chloro-4-(dichloromethyl)-5-hydroxy-2-(5H)-furanone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4-trichloro-2-methyl-3-pentanone',
    'C<sub>6</sub>H<sub>9</sub>Cl<sub>3</sub>O',
    '',
    '145556-04-3',
    'KAUWEMQJFDRELR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-trichloro-2-methyl-3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-trichloro-2-methyl-3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-trichloro-2-methyl-3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-trichloro-2-methyl-3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bis(2-chloroisopropyl) ether',
    'C<sub>6</sub>H<sub>12</sub>Cl<sub>2</sub>O',
    '',
    '39638-32-9',
    'BULHJTXRZFEUDQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis(2-chloroisopropyl) ether'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis(2-chloroisopropyl) ether'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis(2-chloroisopropyl) ether'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis(2-chloroisopropyl) ether'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'butyl 2,2,3,4,4-pentachloro-3-butenoate',
    'C<sub>8</sub>H<sub>9</sub>Cl<sub>5</sub>O<sub>2</sub>',
    '',
    '75147-20-5',
    'JZJILZTVTMMGAR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl 2,2,3,4,4-pentachloro-3-butenoate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl 2,2,3,4,4-pentachloro-3-butenoate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl 2,2,3,4,4-pentachloro-3-butenoate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl 2,2,3,4,4-pentachloro-3-butenoate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-(2,2-dichlorovinyl)-2,2-dimethylcyclopropane carbonyl chloride',
    'C<sub>8</sub>H<sub>9</sub>Cl<sub>3</sub>O',
    '',
    '52314-67-7',
    'CHLAOFANYRDCPD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-(2,2-dichlorovinyl)-2,2-dimethylcyclopropane carbonyl chloride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-(2,2-dichlorovinyl)-2,2-dimethylcyclopropane carbonyl chloride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-(2,2-dichlorovinyl)-2,2-dimethylcyclopropane carbonyl chloride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-(2,2-dichlorovinyl)-2,2-dimethylcyclopropane carbonyl chloride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-(2,2-dichlorovinyl)-2,2-dimethylcyclopropane carboxylic acid',
    'C<sub>8</sub>H<sub>10</sub>Cl<sub>2</sub>O<sub>2</sub>',
    '',
    '55701-05-8',
    'LLMLSUSAKZVFOA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-(2,2-dichlorovinyl)-2,2-dimethylcyclopropane carboxylic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-(2,2-dichlorovinyl)-2,2-dimethylcyclopropane carboxylic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-(2,2-dichlorovinyl)-2,2-dimethylcyclopropane carboxylic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-(2,2-dichlorovinyl)-2,2-dimethylcyclopropane carboxylic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hexanoic acid, 3,3-dimethyl-4,6,6,6-tetrachloro, methyl ester',
    'C<sub>9</sub>H<sub>14</sub>Cl<sub>4</sub>O<sub>2</sub>',
    '',
    '64667-33-0',
    'POFHGKISWXYKLB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanoic acid, 3,3-dimethyl-4,6,6,6-tetrachloro, methyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanoic acid, 3,3-dimethyl-4,6,6,6-tetrachloro, methyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanoic acid, 3,3-dimethyl-4,6,6,6-tetrachloro, methyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexanoic acid, 3,3-dimethyl-4,6,6,6-tetrachloro, methyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl 3-(2,2-dichlorovinyl)-2,2-dimethylcyclopropanecarboxylate',
    'C<sub>9</sub>H<sub>12</sub>Cl<sub>2</sub>O<sub>2</sub>',
    '',
    '61898-95-1',
    'QJOOIMSFFIUFKX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl 3-(2,2-dichlorovinyl)-2,2-dimethylcyclopropanecarboxylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl 3-(2,2-dichlorovinyl)-2,2-dimethylcyclopropanecarboxylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl 3-(2,2-dichlorovinyl)-2,2-dimethylcyclopropanecarboxylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl 3-(2,2-dichlorovinyl)-2,2-dimethylcyclopropanecarboxylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'oxychlordane',
    'C<sub>10</sub>H<sub>4</sub>Cl<sub>8</sub>O',
    '',
    '27304-13-8',
    'VWGNQYSIWFHEQU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '4300',
    'T',
    (SELECT id from species WHERE iupac='oxychlordane'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='oxychlordane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'kepone',
    'C<sub>10</sub>Cl<sub>10</sub>O',
    '',
    '143-50-0',
    'LHHGDZSESBACKH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='kepone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='kepone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='kepone'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='kepone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bis-(chloromethyl) ether',
    'C<sub>2</sub>H<sub>4</sub>Cl<sub>2</sub>O',
    '',
    '542-88-1',
    'HRQGCQVOJVTVLU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bis-(chloromethyl) ether'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bis-(chloromethyl) ether'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bis-(chloromethyl) ether'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='bis-(chloromethyl) ether'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis-(chloromethyl) ether'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis-(chloromethyl) ether'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,5-dichloro-3-oxapentane',
    'C<sub>4</sub>H<sub>8</sub>Cl<sub>2</sub>O',
    'bis-(2-chloroethyl)-ether',
    '111-44-4',
    'ZNSMNVMLTJELDZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;1</sup>',
    '6200',
    'L',
    (SELECT id from species WHERE iupac='1,5-dichloro-3-oxapentane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,5-dichloro-3-oxapentane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,5-dichloro-3-oxapentane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,5-dichloro-3-oxapentane'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,5-dichloro-3-oxapentane'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,5-dichloro-3-oxapentane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,5-dichloro-3-oxapentane'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '4100',
    'X',
    (SELECT id from species WHERE iupac='1,5-dichloro-3-oxapentane'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1,5-dichloro-3-oxapentane'),
    (SELECT id from literature WHERE bibtexkey='1912'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6',
    '',
    'C',
    (SELECT id from species WHERE iupac='1,5-dichloro-3-oxapentane'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,5-dichloro-3-oxapentane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,5-dichloro-3-oxapentane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,5-dichloro-3-oxapentane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,5-dichloro-3-oxapentane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,5-dichloro-3-oxapentane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,5-dichloro-3-oxapentane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,5-dichloro-3-oxapentane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6000',
    'Q',
    (SELECT id from species WHERE iupac='1,5-dichloro-3-oxapentane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6000',
    '?',
    (SELECT id from species WHERE iupac='1,5-dichloro-3-oxapentane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-chloro-1,1-dimethoxyethane',
    'C<sub>4</sub>H<sub>9</sub>ClO<sub>2</sub>',
    '',
    '97-97-2',
    'CRZJPEIBPQWDGJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-chloro-1,1-dimethoxyethane'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(2-chloroethoxy)-ethene',
    'C<sub>4</sub>H<sub>7</sub>ClO',
    '2-chloroethylvinylether',
    '110-75-8',
    'DNJRKFKAFWSXSE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(2-chloroethoxy)-ethene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(2-chloroethoxy)-ethene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(2-chloroethoxy)-ethene'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(2-chloroethoxy)-ethene'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='(2-chloroethoxy)-ethene'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '2500',
    'X',
    (SELECT id from species WHERE iupac='(2-chloroethoxy)-ethene'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='(2-chloroethoxy)-ethene'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2-chloroethoxy)-ethene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2-chloroethoxy)-ethene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2-chloroethoxy)-ethene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bis-(2-chloroethoxy)-methane',
    'C<sub>5</sub>H<sub>10</sub>Cl<sub>2</sub>O<sub>2</sub>',
    '',
    '111-91-1',
    'NLXGURFLBLRZRO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6',
    '',
    'V',
    (SELECT id from species WHERE iupac='bis-(2-chloroethoxy)-methane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='bis-(2-chloroethoxy)-methane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bis-(2-chloroethoxy)-methane'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'V',
    (SELECT id from species WHERE iupac='bis-(2-chloroethoxy)-methane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8',
    '',
    'X',
    (SELECT id from species WHERE iupac='bis-(2-chloroethoxy)-methane'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>1</sup>',
    '5500',
    'X',
    (SELECT id from species WHERE iupac='bis-(2-chloroethoxy)-methane'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='bis-(2-chloroethoxy)-methane'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis-(2-chloroethoxy)-methane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis-(2-chloroethoxy)-methane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bis-(2-chloroisopropyl) ether',
    'C<sub>6</sub>H<sub>12</sub>Cl<sub>2</sub>O',
    'DCIP',
    '108-60-1',
    'QCFYJCYNJLBDRT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='bis-(2-chloroisopropyl) ether'),
    (SELECT id from literature WHERE bibtexkey='2229'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bis-(2-chloroisopropyl) ether'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bis-(2-chloroisopropyl) ether'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bis-(2-chloroisopropyl) ether'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='bis-(2-chloroisopropyl) ether'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;2</sup>',
    '2800',
    'X',
    (SELECT id from species WHERE iupac='bis-(2-chloroisopropyl) ether'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='bis-(2-chloroisopropyl) ether'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis-(2-chloroisopropyl) ether'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis-(2-chloroisopropyl) ether'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-bis(2-chloroethoxy)ethane',
    'C<sub>6</sub>H<sub>12</sub>Cl<sub>2</sub>O<sub>2</sub>',
    '',
    '112-26-5',
    'AGYUOJIYYGGHKV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-bis(2-chloroethoxy)ethane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-bis(2-chloroethoxy)ethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-hydroxychlorobenzene',
    'C<sub>6</sub>H<sub>5</sub>ClO',
    'o-chlorophenol',
    '95-57-8',
    'ISPYQTSUDJAMAB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1930'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6',
    '5700',
    'M',
    (SELECT id from species WHERE iupac='2-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2451'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '1943-95-57-8-erratum',
    '1943', 'Erratum for page 350 of Fogg and Sangster (2003): the equation describing the recommended temperature-dependent data appears to be incorrect and is not used here.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1943-95-57-8-erratum'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='638'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;1</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='2-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '4600',
    'X',
    (SELECT id from species WHERE iupac='2-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='howard89'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from638'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'C',
    (SELECT id from species WHERE iupac='2-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6200',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-3072'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5600',
    '?',
    (SELECT id from species WHERE iupac='2-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2979'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at297K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-hydroxychlorobenzene',
    'C<sub>6</sub>H<sub>5</sub>ClO',
    'm-chlorophenol',
    '108-43-0',
    'HORNXRXVQWOLPJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2',
    '',
    'M',
    (SELECT id from species WHERE iupac='3-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>1</sup>',
    '6400',
    'M',
    (SELECT id from species WHERE iupac='3-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2451'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='638'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>1</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='3-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='howard89'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from638'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6200',
    'Q',
    (SELECT id from species WHERE iupac='3-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-3072'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6100',
    '?',
    (SELECT id from species WHERE iupac='3-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-hydroxychlorobenzene',
    'C<sub>6</sub>H<sub>5</sub>ClO',
    'p-chlorophenol',
    '106-48-9',
    'WXNZTHHGJRFXKQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7',
    '',
    'M',
    (SELECT id from species WHERE iupac='4-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '11000',
    'M',
    (SELECT id from species WHERE iupac='4-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2451'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='638'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>1</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='4-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='howard89'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from638'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6200',
    'Q',
    (SELECT id from species WHERE iupac='4-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6400',
    '?',
    (SELECT id from species WHERE iupac='4-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-hydroxychlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2979'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at297K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dichlorophenol',
    'C<sub>6</sub>H<sub>4</sub>Cl<sub>2</sub>O',
    '',
    '576-24-9',
    'UMPSXRYVXUPCOS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3-dichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dichlorophenol',
    'C<sub>6</sub>H<sub>4</sub>Cl<sub>2</sub>O',
    '',
    '120-83-2',
    'HFZWRUODUSTPEG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,4-dichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='1930'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6',
    '6800',
    'M',
    (SELECT id from species WHERE iupac='2,4-dichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='2451'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4-dichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4-dichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4-dichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4-dichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4-dichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='638'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4-dichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='1068'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at281K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4-dichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '4900',
    'X',
    (SELECT id from species WHERE iupac='2,4-dichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'C',
    (SELECT id from species WHERE iupac='2,4-dichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6300',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7400',
    '?',
    (SELECT id from species WHERE iupac='2,4-dichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5-dichlorophenol',
    'C<sub>6</sub>H<sub>4</sub>Cl<sub>2</sub>O',
    '',
    '583-78-8',
    'RANCECPPZPIPNO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,5-dichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6-dichlorophenol',
    'C<sub>6</sub>H<sub>4</sub>Cl<sub>2</sub>O',
    '',
    '87-65-0',
    'HOLHYSJJBXSLMV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,6-dichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,6-dichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,6-dichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,6-dichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4-dichlorophenol',
    'C<sub>6</sub>H<sub>4</sub>Cl<sub>2</sub>O',
    '',
    '95-77-2',
    'WDNBURPWRNALGP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,5-dichlorophenol',
    'C<sub>6</sub>H<sub>4</sub>Cl<sub>2</sub>O',
    '',
    '591-35-5',
    'VPOMSPZBQMDLTM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,5-dichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,5-dichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4-trichlorophenol',
    'C<sub>6</sub>H<sub>3</sub>Cl<sub>3</sub>O',
    '',
    '15950-66-0',
    'HSQFVBWFPBKHEB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,4-trichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,4-trichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,5-trichlorophenol',
    'C<sub>6</sub>H<sub>3</sub>Cl<sub>3</sub>O',
    '',
    '933-78-8',
    'WWGQHTJIFOQAOC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,5-trichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,5-trichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,5-trichlorophenol',
    'C<sub>6</sub>H<sub>3</sub>Cl<sub>3</sub>O',
    '',
    '95-95-4',
    'LHJGJYXLEPZJPM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4,5-trichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4,5-trichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4,5-trichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4,5-trichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4,5-trichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4,5-trichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='1068'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at281K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5-trichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5-trichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5-trichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,6-trichlorophenol',
    'C<sub>6</sub>H<sub>3</sub>Cl<sub>3</sub>O',
    '',
    '933-75-5',
    'XGCHAIDDPMFRLJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,6-trichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,6-trichlorophenol',
    'C<sub>6</sub>H<sub>3</sub>Cl<sub>3</sub>O',
    '',
    '88-06-2',
    'LINPIYWFGCPVIE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,4,6-trichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,4,6-trichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='2292'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2292pH4',
    '', 'Value at pH = 4.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2292pH4'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4,6-trichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4,6-trichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4,6-trichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4,6-trichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4,6-trichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4,6-trichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='1068'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at281K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '5000',
    'X',
    (SELECT id from species WHERE iupac='2,4,6-trichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4,6-trichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='howard89'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from638'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '',
    'C',
    (SELECT id from species WHERE iupac='2,4,6-trichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6400',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6500',
    '?',
    (SELECT id from species WHERE iupac='2,4,6-trichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4,5-trichlorophenol',
    'C<sub>6</sub>H<sub>3</sub>Cl<sub>3</sub>O',
    '',
    '609-19-8',
    'GBNHEBQXJVDXSW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,5-trichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,5-tetrachlorophenol',
    'C<sub>6</sub>H<sub>2</sub>Cl<sub>4</sub>O',
    '',
    '4901-51-3',
    'RULKYXXCCZZKDZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,4,5-tetrachlorophenol'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,4,5-tetrachlorophenol'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,5-tetrachlorophenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,6-tetrachlorophenol',
    'C<sub>6</sub>H<sub>2</sub>Cl<sub>4</sub>O',
    '',
    '58-90-2',
    'VGVRPFIJEJYOFN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,4,6-tetrachlorophenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,4,6-tetrachlorophenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,4,6-tetrachlorophenol'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,4,6-tetrachlorophenol'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,6-tetrachlorophenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,6-tetrachlorophenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,6-tetrachlorophenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,6-tetrachlorophenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,6-tetrachlorophenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,5,6-tetrachlorophenol',
    'C<sub>6</sub>H<sub>2</sub>Cl<sub>4</sub>O',
    '',
    '935-95-5',
    'KEWNKZNZRIAIAK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,5,6-tetrachlorophenol'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,5,6-tetrachlorophenol'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5,6-tetrachlorophenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hydroxypentachlorobenzene',
    'C<sub>6</sub>HCl<sub>5</sub>O',
    'pentachlorophenol',
    '87-86-5',
    'IZUPBVBPLAPZRR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='hydroxypentachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2448'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hydroxypentachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='hydroxypentachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2614_pc_problem'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hydroxypentachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hydroxypentachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hydroxypentachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2966'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hydroxypentachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='hydroxypentachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '1300',
    'X',
    (SELECT id from species WHERE iupac='hydroxypentachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7',
    '',
    'X',
    (SELECT id from species WHERE iupac='hydroxypentachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='mccarty80'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from2556'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4',
    '',
    'C',
    (SELECT id from species WHERE iupac='hydroxypentachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydroxypentachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydroxypentachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydroxypentachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydroxypentachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydroxypentachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydroxypentachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7800',
    'Q',
    (SELECT id from species WHERE iupac='hydroxypentachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydroxypentachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'E',
    (SELECT id from species WHERE iupac='hydroxypentachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7400',
    '?',
    (SELECT id from species WHERE iupac='hydroxypentachlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4,5-trichloro-1,2-benzenediol',
    'C<sub>6</sub>H<sub>3</sub>Cl<sub>3</sub>O<sub>2</sub>',
    '3,4,5-trichlorocatechol',
    '56961-20-7',
    'FUTDYIMYZIMPBJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,4,5-trichloro-1,2-benzenediol'),
    (SELECT id from literature WHERE bibtexkey='2960'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,5-dichloro-1,2-benzenediol',
    'C<sub>6</sub>H<sub>4</sub>Cl<sub>2</sub>O<sub>2</sub>',
    '4,5-dichlorocatechol',
    '3428-24-8',
    'ACCHWUWBKYGKNM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4,5-dichloro-1,2-benzenediol'),
    (SELECT id from literature WHERE bibtexkey='2960'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4,5,6-tetrachloro-1,2-benzenediol',
    'C<sub>6</sub>H<sub>2</sub>Cl<sub>4</sub>O<sub>2</sub>',
    'tetrachlorocatechol',
    '1198-55-6',
    'RRBMVWQICIXSEO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,4,5,6-tetrachloro-1,2-benzenediol'),
    (SELECT id from literature WHERE bibtexkey='2960'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,5,6-tetrachloro-p-benzoquinone',
    'C<sub>6</sub>Cl<sub>4</sub>O<sub>2</sub>',
    'chloranil',
    '118-75-2',
    'UGNWTBMOAKPKBL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,5,6-tetrachloro-p-benzoquinone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-chloro-5-methylphenol',
    'C<sub>7</sub>H<sub>7</sub>ClO',
    '',
    '615-74-7',
    'SMFHPCZZAAMJJO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-5-methylphenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-chloro-2-methylphenol',
    'C<sub>7</sub>H<sub>7</sub>ClO',
    '',
    '1570-64-5',
    'RHPUJHQBPORFGV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-chloro-2-methylphenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-chloro-2-methylphenol'),
    (SELECT id from literature WHERE bibtexkey='3090'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chloro-2-methylphenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chloro-2-methylphenol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chloro-2-methylphenol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-chloro-3-methylphenol',
    'C<sub>7</sub>H<sub>7</sub>ClO',
    '',
    '59-50-7',
    'CFKMVGJGLGKFKI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-chloro-3-methylphenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-chloro-3-methylphenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='4-chloro-3-methylphenol'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0',
    '',
    'C',
    (SELECT id from species WHERE iupac='4-chloro-3-methylphenol'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chloro-3-methylphenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chloro-3-methylphenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chloro-3-methylphenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chloro-3-methylphenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chloro-3-methylphenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chloro-3-methylphenol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chloro-3-methylphenol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chloro-3-methylphenol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chloro-3-methylphenol'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chloro-3-methylphenol'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-chloro-2-methoxybenzene',
    'C<sub>7</sub>H<sub>7</sub>ClO',
    '2-chloroanisole',
    '766-51-8',
    'QGRPVMLBTFGQDQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-chloro-2-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1524'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '1524',
    '1524', 'When comparing H in Table&nbsp;4 with K<sub><span class="roman">gw</span></sub> in Table&nbsp;5 of Pfeifer et&nbsp;al. (2001), it can be seen that the values refer to K<sub><span class="roman">gw</span></sub>&times;100 and not K<sub><span class="roman">gw</span></sub>/100.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1524'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-chloro-2-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-2-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-chloro-3-methoxybenzene',
    'C<sub>7</sub>H<sub>7</sub>ClO',
    '3-chloroanisole',
    '2845-89-8',
    'YUKILTJWFRTXGB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-chloro-3-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1524'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1524'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-chloro-4-methoxybenzene',
    'C<sub>7</sub>H<sub>7</sub>ClO',
    '4-chloroanisole',
    '623-12-1',
    'YRGAYAGBVIXNAQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-chloro-4-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1524'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1524'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-dichloro-3-methoxybenzene',
    'C<sub>7</sub>H<sub>6</sub>Cl<sub>2</sub>O',
    '2,3-dichloroanisole',
    '1984-59-4',
    'HFEASCCDHUVYKU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichloro-3-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1524'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1524'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,5-dichloro-2-methoxybenzene',
    'C<sub>7</sub>H<sub>6</sub>Cl<sub>2</sub>O',
    '2,4-dichloroanisole',
    '553-82-2',
    'CICQUFBZCADHHX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,5-dichloro-2-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1524'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1524'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4-dichloro-2-methoxybenzene',
    'C<sub>7</sub>H<sub>6</sub>Cl<sub>2</sub>O',
    '2,5-dichloroanisole',
    '1984-58-3',
    'QKMNFFSBZRGHDJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,4-dichloro-2-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1524'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1524'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dichloro-2-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dichloro-2-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dichloro-2-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dichloro-2-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3-dichloro-2-methoxybenzene',
    'C<sub>7</sub>H<sub>6</sub>Cl<sub>2</sub>O',
    '2,6-dichloroanisole',
    '1984-65-2',
    'KZLMCDNAVVJKPX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,3-dichloro-2-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1524'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1524'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-dichloro-4-methoxybenzene',
    'C<sub>7</sub>H<sub>6</sub>Cl<sub>2</sub>O',
    '3,4-dichloroanisole',
    '36404-30-5',
    'VISJRVXHPNMYRH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichloro-4-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1524'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1524'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3-dichloro-5-methoxybenzene',
    'C<sub>7</sub>H<sub>6</sub>Cl<sub>2</sub>O',
    '3,5-dichloroanisole',
    '33719-74-3',
    'SSNXYMVLSOMJLU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,3-dichloro-5-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1524'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1524'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3-trichloro-4-methoxybenzene',
    'C<sub>7</sub>H<sub>5</sub>Cl<sub>3</sub>O',
    '2,3,4-trichloroanisole',
    '54135-80-7',
    'FRQUNVLMWIYOLV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2,3-trichloro-4-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1524'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1524'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,5-trichloro-3-methoxybenzene',
    'C<sub>7</sub>H<sub>5</sub>Cl<sub>3</sub>O',
    '2,3,5-trichloroanisole',
    '54135-81-8',
    'MKERQGLKSFEKAE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2,5-trichloro-3-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1524'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1524'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4-trichloro-3-methoxybenzene',
    'C<sub>7</sub>H<sub>5</sub>Cl<sub>3</sub>O',
    '2,3,6-trichloroanisole',
    '50375-10-5',
    'OTFNCXLUCRUNCH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '4500',
    'M',
    (SELECT id from species WHERE iupac='1,2,4-trichloro-3-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3118'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2,4-trichloro-3-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1524'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1524'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-trichloro-3-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-trichloro-3-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-trichloro-3-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4-trichloro-5-methoxybenzene',
    'C<sub>7</sub>H<sub>5</sub>Cl<sub>3</sub>O',
    '2,4,5-trichloroanisole',
    '6130-75-2',
    'SXKBHOQOOGRFJF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2,4-trichloro-5-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1524'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1524'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3,5-trichloro-2-methoxybenzene',
    'C<sub>7</sub>H<sub>5</sub>Cl<sub>3</sub>O',
    '2,4,6-trichloroanisole',
    '87-40-1',
    'WCVOGSZTONGSQY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '5500',
    'M',
    (SELECT id from species WHERE iupac='1,3,5-trichloro-2-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3719'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;3</sup>',
    '640',
    'M',
    (SELECT id from species WHERE iupac='1,3,5-trichloro-2-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3118'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,3,5-trichloro-2-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1524'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1524'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3-trichloro-5-methoxybenzene',
    'C<sub>7</sub>H<sub>5</sub>Cl<sub>3</sub>O',
    '3,4,5-trichloroanisole',
    '54135-82-9',
    'GUCFBWGWRCILHN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2,3-trichloro-5-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1524'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1524'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,4-tetrachloro-5-methoxybenzene',
    'C<sub>7</sub>H<sub>4</sub>Cl<sub>4</sub>O',
    '2,3,4,5-tetrachloroanisole',
    '938-86-3',
    'FUUHMSUPRUNWRQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrachloro-5-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1524'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1524'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,5-tetrachloro-4-methoxybenzene',
    'C<sub>7</sub>H<sub>4</sub>Cl<sub>4</sub>O',
    '2,3,4,6-tetrachloroanisole',
    '938-22-7',
    'ITXDBGLYYSJNPK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2,3,5-tetrachloro-4-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1524'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1524'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4,5-tetrachloro-3-methoxybenzene',
    'C<sub>7</sub>H<sub>4</sub>Cl<sub>4</sub>O',
    '2,3,5,6-tetrachloroanisole',
    '6936-40-9',
    'WMMFIDNWZNCBCT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2,4,5-tetrachloro-3-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1524'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1524'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pentachloromethoxybenzene',
    'C<sub>7</sub>H<sub>3</sub>Cl<sub>5</sub>O',
    'pentachloroanisole',
    '1825-21-4',
    'BBABSCYTNHOKOG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='pentachloromethoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1524'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1524'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentachloromethoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,5-dichloro-2-methoxyphenol',
    'C<sub>7</sub>H<sub>6</sub>Cl<sub>2</sub>O<sub>2</sub>',
    '4,5-dichloroguaiacol',
    '2460-49-3',
    'HAAFFTHBNFBVKY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2',
    '',
    'V',
    (SELECT id from species WHERE iupac='4,5-dichloro-2-methoxyphenol'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'V',
    (SELECT id from species WHERE iupac='4,5-dichloro-2-methoxyphenol'),
    (SELECT id from literature WHERE bibtexkey='2960'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4,5-trichloro-2-methoxyphenol',
    'C<sub>7</sub>H<sub>5</sub>Cl<sub>3</sub>O<sub>2</sub>',
    '3,4,5-trichloroguaiacol',
    '57057-83-7',
    'RKEHLKXRUVUBJN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,4,5-trichloro-2-methoxyphenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,4,5-trichloro-2-methoxyphenol'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2613_pc_problem'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,4,5-trichloro-2-methoxyphenol'),
    (SELECT id from literature WHERE bibtexkey='2960'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,5-trichloro-2-methoxyphenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,5,6-trichloro-2-methoxyphenol',
    'C<sub>7</sub>H<sub>5</sub>Cl<sub>3</sub>O<sub>2</sub>',
    '4,5,6-trichloroguaiacol',
    '2668-24-8',
    'NIAJPNQTKGWEOI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4',
    '',
    'V',
    (SELECT id from species WHERE iupac='4,5,6-trichloro-2-methoxyphenol'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='4,5,6-trichloro-2-methoxyphenol'),
    (SELECT id from literature WHERE bibtexkey='2960'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,5-tetrachloro-6-methoxyphenol',
    'C<sub>7</sub>H<sub>4</sub>Cl<sub>4</sub>O<sub>2</sub>',
    'tetrachloroguaiacol',
    '2539-17-5',
    'YZZVKLJKDFFSFL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,4,5-tetrachloro-6-methoxyphenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,4,5-tetrachloro-6-methoxyphenol'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,4,5-tetrachloro-6-methoxyphenol'),
    (SELECT id from literature WHERE bibtexkey='2960'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,5-tetrachloro-6-methoxyphenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-chlorobenzoic acid',
    'C<sub>7</sub>H<sub>5</sub>ClO<sub>2</sub>',
    '',
    '118-91-2',
    'IKCLCGXPQILATA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-chlorobenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-chlorobenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chlorobenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chlorobenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-chlorobenzoic acid',
    'C<sub>7</sub>H<sub>5</sub>ClO<sub>2</sub>',
    '',
    '535-80-8',
    'LULAYUGMBFYYEX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-chlorobenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-chlorobenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-642'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-chlorobenzoic acid',
    'C<sub>7</sub>H<sub>5</sub>ClO<sub>2</sub>',
    '',
    '74-11-3',
    'XRHGYUZYPHTUJZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chlorobenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4-dichlorobenzoic acid',
    'C<sub>7</sub>H<sub>4</sub>Cl<sub>2</sub>O<sub>2</sub>',
    '',
    '51-44-5',
    'VPHHJAOJUJHJKD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dichlorobenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,6-trichlorobenzoic acid',
    'C<sub>7</sub>H<sub>3</sub>Cl<sub>3</sub>O<sub>2</sub>',
    '',
    '50-31-7',
    'XZIDTOHMJBOSOX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,6-trichlorobenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,6-trichlorobenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3-trichloro-4,5-dimethoxybenzene',
    'C<sub>8</sub>H<sub>7</sub>Cl<sub>3</sub>O<sub>2</sub>',
    '3,4,5-trichloroveratrole',
    '16766-29-3',
    'VKNITLPENCJQOP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3-trichloro-4,5-dimethoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2960'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,4-tetrachloro-5,6-dimethoxybenzene',
    'C<sub>8</sub>H<sub>6</sub>Cl<sub>4</sub>O<sub>2</sub>',
    'tetrachloroveratrole',
    '944-61-6',
    'NCYHCGGUQGDEQW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrachloro-5,6-dimethoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2960'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrachloro-5,6-dimethoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrachloro-5,6-dimethoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrachloro-5,6-dimethoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrachloro-5,6-dimethoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-chloro-2,6-dimethoxyphenol',
    'C<sub>8</sub>H<sub>9</sub>ClO<sub>3</sub>',
    '3-chlorosyringol',
    '18113-22-9',
    'WYEMCZZCZXKDNC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-chloro-2,6-dimethoxyphenol'),
    (SELECT id from literature WHERE bibtexkey='2960'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,5-dichloro-2,6-dimethoxyphenol',
    'C<sub>8</sub>H<sub>8</sub>Cl<sub>2</sub>O<sub>3</sub>',
    '3,5-dichlorosyringol',
    '78782-46-4',
    'IDKMFABKPPHDBI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,5-dichloro-2,6-dimethoxyphenol'),
    (SELECT id from literature WHERE bibtexkey='2960'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,5-dichloro-2-hydroxybenzoic acid',
    'C<sub>7</sub>H<sub>4</sub>Cl<sub>2</sub>O<sub>3</sub>',
    '',
    '320-72-9',
    'CNJGWCQEGROXEE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dichloro-2-hydroxybenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dichloro-2-hydroxybenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dichloro-2-hydroxybenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dichloro-2-hydroxybenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,6-dichloro-2-hydroxybenzoic acid',
    'C<sub>7</sub>H<sub>4</sub>Cl<sub>2</sub>O<sub>3</sub>',
    '',
    '3401-80-7',
    'FKIKPQHMWFZFEB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,6-dichloro-2-hydroxybenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,6-dichloro-2-hydroxybenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,6-dichloro-2-hydroxybenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,6-dichloro-2-hydroxybenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-chloro-2-methoxybenzoic acid',
    'C<sub>8</sub>H<sub>7</sub>ClO<sub>3</sub>',
    '',
    '3438-16-2',
    'HULDRQRKKXRXBI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-chloro-2-methoxybenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-chloro-2-methoxybenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-chloro-2-methoxybenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-chloro-2-methoxybenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-chloroacetophenone',
    'C<sub>8</sub>H<sub>7</sub>ClO',
    '',
    '532-27-4',
    'IMACFCSSMIZSPP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloroacetophenone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2,2'',4'',5''-pentachloroacetophenone',
    'C<sub>8</sub>H<sub>3</sub>Cl<sub>5</sub>O',
    '',
    '1203-86-7',
    'WKJXVVFAALGBOH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,2'',4'',5''-pentachloroacetophenone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,2'',4'',5''-pentachloroacetophenone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,2'',4'',5''-pentachloroacetophenone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2,2'',4'',5''-pentachloroacetophenone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tetrachloroterephthaloyl chloride',
    'C<sub>8</sub>Cl<sub>6</sub>O<sub>2</sub>',
    '',
    '719-32-4',
    'YJIRZJAZKDWEIJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrachloroterephthaloyl chloride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrachloroterephthaloyl chloride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrachloroterephthaloyl chloride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrachloroterephthaloyl chloride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chloroxylenol',
    'C<sub>8</sub>H<sub>9</sub>ClO',
    '',
    '88-04-0',
    'OSDLLIBGSJNGJE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroxylenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroxylenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroxylenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroxylenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroxylenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,5,6,7-tetrachloro-1,3-isobenzofurandione',
    'C<sub>8</sub>Cl<sub>4</sub>O<sub>3</sub>',
    '',
    '117-08-8',
    'AUHHYELHRWCWEZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,5,6,7-tetrachloro-1,3-isobenzofurandione'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,5,6,7-tetrachloro-1,3-isobenzofurandione'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,5,6,7-tetrachloro-1,3-isobenzofurandione'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,5,6,7-tetrachloro-1,3-isobenzofurandione'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4,5-trichloro-2,6-dimethoxyphenol',
    'C<sub>8</sub>H<sub>7</sub>Cl<sub>3</sub>O<sub>3</sub>',
    'trichlorosyringol',
    '2539-26-6',
    'ZZCSBXFJFLSDRR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,4,5-trichloro-2,6-dimethoxyphenol'),
    (SELECT id from literature WHERE bibtexkey='2960'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,5,6,7-tetrachlorophthalide',
    'C<sub>8</sub>H<sub>2</sub>Cl<sub>4</sub>O<sub>2</sub>',
    '',
    '27355-22-2',
    'NMWKWBPNKPGATC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='4,5,6,7-tetrachlorophthalide'),
    (SELECT id from literature WHERE bibtexkey='2229'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4,5,6,7-tetrachlorophthalide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,5,6,7-tetrachlorophthalide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dicamba',
    'C<sub>8</sub>H<sub>6</sub>Cl<sub>2</sub>O<sub>3</sub>',
    'banvel',
    '1918-00-9',
    'IWEDIXLBFLAXBO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dicamba'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dicamba'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dicamba'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dicamba'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dicamba'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>4</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='dicamba'),
    (SELECT id from literature WHERE bibtexkey='3073'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dicamba'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dicamba'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dicamba'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(2,4-dichlorophenoxy)-ethanoic acid',
    'C<sub>8</sub>H<sub>6</sub>Cl<sub>2</sub>O<sub>3</sub>',
    '(2,4-dichlorophenoxy)-acetic acid; 2,4-D',
    '94-75-7',
    'OVSKIKFHRZPJSS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='(2,4-dichlorophenoxy)-ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='893'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '893',
    '', 'Measured at pH = 1.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='893'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'M',
    (SELECT id from species WHERE iupac='(2,4-dichlorophenoxy)-ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='893'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='893'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(2,4-dichlorophenoxy)-ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(2,4-dichlorophenoxy)-ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2613'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(2,4-dichlorophenoxy)-ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(2,4-dichlorophenoxy)-ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(2,4-dichlorophenoxy)-ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'V',
    (SELECT id from species WHERE iupac='(2,4-dichlorophenoxy)-ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2966'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'V',
    (SELECT id from species WHERE iupac='(2,4-dichlorophenoxy)-ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='(2,4-dichlorophenoxy)-ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='howard91b'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='(2,4-dichlorophenoxy)-ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='howard91b'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>6</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='(2,4-dichlorophenoxy)-ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3073'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2,4-dichlorophenoxy)-ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(2,4-dichlorophenoxy)-ethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,5-trichlorophenoxyethanoic acid',
    'C<sub>8</sub>H<sub>5</sub>Cl<sub>3</sub>O<sub>3</sub>',
    '2,4,5-T',
    '93-76-5',
    'SMYMJHWAQXWPDB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4,5-trichlorophenoxyethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4,5-trichlorophenoxyethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2966'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4,5-trichlorophenoxyethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,4,5-trichlorophenoxyethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4-dichloro-2,5-dimethoxybenzene',
    'C<sub>8</sub>H<sub>8</sub>Cl<sub>2</sub>O<sub>2</sub>',
    '',
    '2675-77-6',
    'PFIADAMVCJPXSF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-dichloro-2,5-dimethoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-dichloro-2,5-dimethoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-dichloro-2,5-dimethoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2614_pc_problem'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dichloro-2,5-dimethoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,6-trichlorophenylacetic acid',
    'C<sub>8</sub>H<sub>5</sub>Cl<sub>3</sub>O<sub>2</sub>',
    '',
    '85-34-7',
    'QZXCCPZJCKEPSA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,6-trichlorophenylacetic acid'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,6-trichlorophenylacetic acid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methoxy-benzoyl chloride',
    'C<sub>8</sub>H<sub>7</sub>ClO<sub>2</sub>',
    'p-anisoyl chloride',
    '100-07-2',
    'MXMOTZIXVICDSD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methoxy-benzoyl chloride'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(4-chlorophenoxy)acetic acid',
    'C<sub>8</sub>H<sub>7</sub>ClO<sub>3</sub>',
    '',
    '122-88-3',
    'SODPIMGUZLOIPE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(4-chlorophenoxy)acetic acid'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'isobenzan',
    'C<sub>9</sub>H<sub>4</sub>Cl<sub>8</sub>O',
    '',
    '297-78-9',
    'LRWHHSXTGZSMSN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isobenzan'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-chloro-4-hydroxy-3,5-dimethoxybenzaldehyde',
    'C<sub>9</sub>H<sub>9</sub>ClO<sub>4</sub>',
    '2-chlorosyringaldehyde',
    '76341-69-0',
    'GRIHRCLOUQZXPD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-chloro-4-hydroxy-3,5-dimethoxybenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='2960'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6-dichloro-4-hydroxy-3,5-dimethoxybenzaldehyde',
    'C<sub>9</sub>H<sub>8</sub>Cl<sub>2</sub>O<sub>4</sub>',
    '2,6-dichlorosyringaldehyde',
    '76330-06-8',
    'CTFRWEPMHUGVMM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,6-dichloro-4-hydroxy-3,5-dimethoxybenzaldehyde'),
    (SELECT id from literature WHERE bibtexkey='2960'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl 2,4-dichlorophenoxyethanoate',
    'C<sub>9</sub>H<sub>8</sub>Cl<sub>2</sub>O<sub>3</sub>',
    '',
    '1928-38-7',
    'HWIGZMADSFQMOI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl 2,4-dichlorophenoxyethanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl 2,4-dichlorophenoxyethanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl 2,4-dichlorophenoxyethanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl 2,4-dichlorophenoxyethanoate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(2-methyl-4-chlorophenoxy)acetic acid',
    'C<sub>9</sub>H<sub>9</sub>ClO<sub>3</sub>',
    'MCPA',
    '94-74-6',
    'WHKUVVPPKQRRBV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 9.9&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='(2-methyl-4-chlorophenoxy)acetic acid'),
    (SELECT id from literature WHERE bibtexkey='2972'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(2-methyl-4-chlorophenoxy)acetic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(2-methyl-4-chlorophenoxy)acetic acid'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(2-methyl-4-chlorophenoxy)acetic acid'),
    (SELECT id from literature WHERE bibtexkey='3090'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2-methyl-4-chlorophenoxy)acetic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(2-methyl-4-chlorophenoxy)acetic acid'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '&#945;-(2,4-dichlorophenoxy)propionic acid',
    'C<sub>9</sub>H<sub>8</sub>Cl<sub>2</sub>O<sub>3</sub>',
    'dichloroprop',
    '120-36-5',
    'MZHCENGPTKEIGP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='&#945;-(2,4-dichlorophenoxy)propionic acid'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(R)-2-(2,4-dichlorophenoxy)propanoic acid',
    'C<sub>9</sub>H<sub>8</sub>Cl<sub>2</sub>O<sub>3</sub>',
    'dichlorprop-p',
    '15165-67-0',
    'MZHCENGPTKEIGP-RXMQYKEDSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(R)-2-(2,4-dichlorophenoxy)propanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(R)-2-(2,4-dichlorophenoxy)propanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-(2,4,5-trichlorophenoxy)propanoic acid',
    'C<sub>9</sub>H<sub>7</sub>Cl<sub>3</sub>O<sub>3</sub>',
    '',
    '93-72-1',
    'ZLSWBLPERHFHIS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-(2,4,5-trichlorophenoxy)propanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cloxyfonac',
    'C<sub>9</sub>H<sub>9</sub>O<sub>4</sub>Cl',
    '',
    '6386-63-6',
    'ZJRUTGDCLVIVRD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cloxyfonac'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cloxyfonac'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tridiphane',
    'C<sub>10</sub>H<sub>7</sub>Cl<sub>5</sub>O',
    '',
    '58138-08-2',
    'IBZHOAONZVJLOB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tridiphane'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'plifenat',
    'C<sub>10</sub>H<sub>7</sub>O<sub>2</sub>Cl<sub>5</sub>',
    '',
    '21757-82-4',
    'FSGNOVKGEXRRHD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='plifenat'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chlorfenprop-methyl',
    'C<sub>10</sub>H<sub>10</sub>Cl<sub>2</sub>O<sub>2</sub>',
    '',
    '14437-17-3',
    'YJKIALIXRCSISK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4',
    '',
    '?',
    (SELECT id from species WHERE iupac='chlorfenprop-methyl'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyl 2,4-dichlorophenoxyethanoate',
    'C<sub>10</sub>H<sub>10</sub>Cl<sub>2</sub>O<sub>3</sub>',
    '',
    '533-23-3',
    'JSLBZIVMVVHMDJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl 2,4-dichlorophenoxyethanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl 2,4-dichlorophenoxyethanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl 2,4-dichlorophenoxyethanoate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl 2,4-dichlorophenoxyethanoate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'mecoprop',
    'C<sub>10</sub>H<sub>11</sub>ClO<sub>3</sub>',
    '',
    '93-65-2',
    'WNTGYJSOUMFZEP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='mecoprop'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='mecoprop'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2614_pc_problem'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='mecoprop'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='mecoprop'),
    (SELECT id from literature WHERE bibtexkey='3073'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='mecoprop'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='mecoprop'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(R)-2-(4-chloro-2-methylphenoxy)propanoic acid',
    'C<sub>10</sub>H<sub>11</sub>ClO<sub>3</sub>',
    'mecoprop-p',
    '16484-77-8',
    'WNTGYJSOUMFZEP-SSDOTTSWSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(R)-2-(4-chloro-2-methylphenoxy)propanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(R)-2-(4-chloro-2-methylphenoxy)propanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dacthal',
    'C<sub>10</sub>H<sub>6</sub>Cl<sub>4</sub>O<sub>4</sub>',
    'DCPA',
    '1861-32-1',
    'NPOJQCVWMSKXDN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4',
    '',
    'L',
    (SELECT id from species WHERE iupac='dacthal'),
    (SELECT id from literature WHERE bibtexkey='2965'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='dacthal'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='dacthal'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dacthal'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-(2,4-dichlorophenoxy)-butanoic acid',
    'C<sub>10</sub>H<sub>10</sub>Cl<sub>2</sub>O<sub>3</sub>',
    '2,4-DB',
    '94-82-6',
    'YIVXMZJTEQBPQO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-(2,4-dichlorophenoxy)-butanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-(2,4-dichlorophenoxy)-butanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dichlone',
    'C<sub>10</sub>H<sub>4</sub>Cl<sub>2</sub>O<sub>2</sub>',
    '',
    '117-80-6',
    'SVPKNMBRVBMTLB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichlone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-[(2,3,6-trichlorophenyl)methoxy]propan-2-ol',
    'C<sub>10</sub>H<sub>11</sub>Cl<sub>3</sub>O<sub>2</sub>',
    'tritac',
    '1861-44-5',
    'LJWIIRATRWPHBA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-[(2,3,6-trichlorophenyl)methoxy]propan-2-ol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-[(2,3,6-trichlorophenyl)methoxy]propan-2-ol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(2,4-dichlorophenoxy)-acetic acid 1-methylethyl ester',
    'C<sub>11</sub>H<sub>12</sub>Cl<sub>2</sub>O<sub>3</sub>',
    '',
    '94-11-1',
    'WHOKDONDRZNCBC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6',
    '',
    'V',
    (SELECT id from species WHERE iupac='(2,4-dichlorophenoxy)-acetic acid 1-methylethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='(2,4-dichlorophenoxy)-acetic acid 1-methylethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2,4-dichlorophenoxy)-acetic acid 1-methylethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-(4-chloro-2-methylphenoxy)butanoic acid',
    'C<sub>11</sub>H<sub>13</sub>ClO<sub>3</sub>',
    'MCPB',
    '94-81-5',
    'LLWADFLAOKUBDR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-(4-chloro-2-methylphenoxy)butanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-(4-chloro-2-methylphenoxy)butanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-(4-chloro-2-methylphenoxy)butanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-(4-chloro-2-methylphenoxy)butanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'triclosan',
    'C<sub>12</sub>H<sub>7</sub>Cl<sub>3</sub>O<sub>2</sub>',
    '',
    '3380-34-5',
    'XEFQLINVKFYRCS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triclosan'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triclosan'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triclosan'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triclosan'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triclosan'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'monobutyl tetrachlorophthalate',
    'C<sub>12</sub>H<sub>10</sub>Cl<sub>4</sub>O<sub>4</sub>',
    '',
    '24261-19-6',
    'WKYMTJULVAGWJM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='monobutyl tetrachlorophthalate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='monobutyl tetrachlorophthalate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='monobutyl tetrachlorophthalate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='monobutyl tetrachlorophthalate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(2,4-dichlorophenoxy)-acetic acid butyl ester',
    'C<sub>12</sub>H<sub>14</sub>Cl<sub>2</sub>O<sub>3</sub>',
    '',
    '94-80-4',
    'UQMRAFJOBWOFNS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(2,4-dichlorophenoxy)-acetic acid butyl ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(2,4-dichlorophenoxy)-acetic acid butyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2,4-dichlorophenoxy)-acetic acid butyl ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'sucralose',
    'C<sub>12</sub>H<sub>19</sub>Cl<sub>3</sub>O<sub>8</sub>',
    '',
    '56038-13-2',
    'BAQAVOSOZGMPRM-QBMZZYIRSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>13</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='sucralose'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'endrin aldehyde',
    'C<sub>12</sub>H<sub>8</sub>Cl<sub>6</sub>O',
    '',
    '7421-93-4',
    'HCTWZIFNBBCVGM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '',
    'V',
    (SELECT id from species WHERE iupac='endrin aldehyde'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'V',
    (SELECT id from species WHERE iupac='endrin aldehyde'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='endrin aldehyde'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'clorophene',
    'C<sub>13</sub>H<sub>11</sub>ClO',
    '4-chloro-2-benzylphenol',
    '120-32-1',
    'NCKMMSIFQUPKCK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='clorophene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='clorophene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='clorophene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(4-chlorophenyl)phenylmethanone',
    'C<sub>13</sub>H<sub>9</sub>ClO',
    '4-chlorobenzophenone',
    '134-85-0',
    'UGVRJVHOJNYEHR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(4-chlorophenyl)phenylmethanone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-(4-chlorophenyl)-4,4-dimethyl-3-pentanone',
    'C<sub>13</sub>H<sub>17</sub>ClO',
    '',
    '66346-01-8',
    'ILQGIJDYSLHIOX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-(4-chlorophenyl)-4,4-dimethyl-3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-(4-chlorophenyl)-4,4-dimethyl-3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-(4-chlorophenyl)-4,4-dimethyl-3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-(4-chlorophenyl)-4,4-dimethyl-3-pentanone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hexachlorophene',
    'C<sub>13</sub>H<sub>6</sub>Cl<sub>6</sub>O<sub>2</sub>',
    '',
    '70-30-4',
    'ACGUYXCXAPNIKK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexachlorophene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexachlorophene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexachlorophene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexachlorophene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexachlorophene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4''-dichlorobenzophenone',
    'C<sub>13</sub>H<sub>8</sub>Cl<sub>2</sub>O',
    '',
    '85-29-0',
    'YXMYPHLWXBXNFF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4''-dichlorobenzophenone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4''-dichlorobenzophenone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4''-dichlorobenzophenone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4''-dichlorobenzophenone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-(4-chlorophenyl)-4,4-dimethylpent-1-en-3-one',
    'C<sub>13</sub>H<sub>15</sub>ClO',
    '',
    '1577-03-3',
    'LXJZYHPGRKBVGF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-(4-chlorophenyl)-4,4-dimethylpent-1-en-3-one'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-(4-chlorophenyl)-4,4-dimethylpent-1-en-3-one'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-(4-chlorophenyl)-4,4-dimethylpent-1-en-3-one'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-(4-chlorophenyl)-4,4-dimethylpent-1-en-3-one'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dichlorophen',
    'C<sub>13</sub>H<sub>10</sub>Cl<sub>2</sub>O<sub>2</sub>',
    '',
    '97-23-4',
    'MDNWOSOZYLHTCG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dichlorophen'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dichlorophen'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCPB ethyl ester',
    'C<sub>13</sub>H<sub>17</sub>ClO<sub>3</sub>',
    '',
    '10443-70-6',
    'XNKARWLGLZGMGX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='MCPB ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCPB ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-chloro-9,10-anthracenedione',
    'C<sub>14</sub>H<sub>7</sub>ClO<sub>2</sub>',
    '',
    '131-09-9',
    'FPKCTSIVDAWGFA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-9,10-anthracenedione'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-9,10-anthracenedione'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-9,10-anthracenedione'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-9,10-anthracenedione'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dicofol',
    'C<sub>14</sub>H<sub>9</sub>Cl<sub>5</sub>O',
    '',
    '115-32-2',
    'UOAMTSKGCBMZTC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dicofol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dicofol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dicofol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dicofol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dicofol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dicofol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dicofol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bis(2,4-dichlorobenzoyl)peroxide',
    'C<sub>14</sub>H<sub>6</sub>Cl<sub>4</sub>O<sub>4</sub>',
    '',
    '133-14-2',
    'WRXCBRHBHGNNQA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis(2,4-dichlorobenzoyl)peroxide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis(2,4-dichlorobenzoyl)peroxide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis(2,4-dichlorobenzoyl)peroxide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis(2,4-dichlorobenzoyl)peroxide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dipropyl tetrachlorophthalate',
    'C<sub>14</sub>H<sub>14</sub>Cl<sub>4</sub>O<sub>4</sub>',
    '',
    '6928-67-2',
    'QJRSPJSHRYYBJL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dipropyl tetrachlorophthalate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dipropyl tetrachlorophthalate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dipropyl tetrachlorophthalate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dipropyl tetrachlorophthalate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-(4-chlorobenzoyl)benzoic acid',
    'C<sub>14</sub>H<sub>9</sub>ClO<sub>3</sub>',
    '',
    '85-56-3',
    'YWECCEXWKFHHQJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(4-chlorobenzoyl)benzoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(4-chlorobenzoyl)benzoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(4-chlorobenzoyl)benzoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(4-chlorobenzoyl)benzoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(2,4,5-trichlorophenoxy)acetic acid butoxyethanol ester',
    'C<sub>14</sub>H<sub>17</sub>Cl<sub>3</sub>O<sub>4</sub>',
    '',
    '2545-59-7',
    'GLDWASBMYWLQGG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2,4,5-trichlorophenoxy)acetic acid butoxyethanol ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(2,4-dichlorophenoxy)-acetic acid, 2-butoxyethyl ester',
    'C<sub>14</sub>H<sub>18</sub>Cl<sub>2</sub>O<sub>4</sub>',
    '',
    '1929-73-3',
    'ZMWGIGHRZQTQRE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(2,4-dichlorophenoxy)-acetic acid, 2-butoxyethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(2,4-dichlorophenoxy)-acetic acid, 2-butoxyethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2,4-dichlorophenoxy)-acetic acid, 2-butoxyethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-chloro-9,10-anthracenedione',
    'C<sub>14</sub>H<sub>7</sub>ClO<sub>2</sub>',
    '1-chloroanthraquinone',
    '82-44-0',
    'BOCJQSFSGAZAPQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-9,10-anthracenedione'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-9,10-anthracenedione'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chlorflurenol methyl',
    'C<sub>15</sub>H<sub>11</sub>ClO<sub>3</sub>',
    '',
    '2536-31-4',
    'LINPVWIEWJTEEJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chlorflurenol methyl'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,4''-(1-methylethylidene)bis(2,6-dichlorophenol)',
    'C<sub>15</sub>H<sub>12</sub>Cl<sub>4</sub>O<sub>2</sub>',
    '2,2'',6,6''-tetrachlorobisphenol A',
    '79-95-8',
    'KYPYTERUKNKOLP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4''-(1-methylethylidene)bis(2,6-dichlorophenol)'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diclofop',
    'C<sub>15</sub>H<sub>12</sub>Cl<sub>2</sub>O<sub>4</sub>',
    '',
    '40843-25-2',
    'OOLBCHYXZDXLDS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='diclofop'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methoxychlor',
    'C<sub>16</sub>H<sub>15</sub>Cl<sub>3</sub>O<sub>2</sub>',
    '',
    '72-43-5',
    'IAKOZHOLGAGEJT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methoxychlor'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'V',
    (SELECT id from species WHERE iupac='methoxychlor'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methoxychlor'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methoxychlor'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methoxychlor'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methoxychlor'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methoxychlor'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diclofop-methyl',
    'C<sub>16</sub>H<sub>14</sub>Cl<sub>2</sub>O<sub>4</sub>',
    '',
    '51338-27-3',
    'BACHBFVBHLGWSL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0',
    '',
    'V',
    (SELECT id from species WHERE iupac='diclofop-methyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0',
    '',
    'V',
    (SELECT id from species WHERE iupac='diclofop-methyl'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diclofop-methyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diclofop-methyl'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='diclofop-methyl'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chlorobenzilate',
    'C<sub>16</sub>H<sub>14</sub>Cl<sub>2</sub>O<sub>3</sub>',
    '',
    '510-15-6',
    'RAPBNVDSDCTNRC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chlorobenzilate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chlorobenzilate'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(2,4-dichlorophenoxy)-acetic acid 2-ethylhexyl ester',
    'C<sub>16</sub>H<sub>22</sub>Cl<sub>2</sub>O<sub>3</sub>',
    '',
    '1928-43-4',
    'QZSFJRIWRPJUOH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='(2,4-dichlorophenoxy)-acetic acid 2-ethylhexyl ester'),
    (SELECT id from literature WHERE bibtexkey='macbean2012'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(2,4-dichlorophenoxy)-acetic acid 2-ethylhexyl ester'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(2,4-dichlorophenoxy)-acetic acid, isooctyl ester',
    'C<sub>16</sub>H<sub>22</sub>Cl<sub>2</sub>O<sub>3</sub>',
    '',
    '25168-26-7',
    'BBPLSOGERZQYQC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(2,4-dichlorophenoxy)-acetic acid, isooctyl ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2,4-dichlorophenoxy)-acetic acid, isooctyl ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2,4-dichlorophenoxy)-acetic acid, isooctyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'mecoprop-2-butoxyethyl ester',
    'C<sub>16</sub>H<sub>23</sub>ClO<sub>4</sub>',
    '',
    '23359-62-8',
    'GWFGUAFFJVHZKY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0',
    '',
    '?',
    (SELECT id from species WHERE iupac='mecoprop-2-butoxyethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chloropropylate',
    'C<sub>17</sub>H<sub>16</sub>Cl<sub>2</sub>O<sub>3</sub>',
    '',
    '5836-10-2',
    'AXGUBXVWZBFQGA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chloropropylate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chloropropylate'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCPA-2-ethylhexyl ester',
    'C<sub>17</sub>H<sub>25</sub>ClO<sub>3</sub>',
    '',
    '29450-45-1',
    'IDGRPSMONFWWEK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='MCPA-2-ethylhexyl ester'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-(2-(2-chloroethoxy)ethoxy)-4-(1,1,3,3-tetramethylbutyl)benzene',
    'C<sub>18</sub>H<sub>29</sub>ClO<sub>2</sub>',
    '',
    '65925-28-2',
    'FITQCDWGUKECBJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-(2-(2-chloroethoxy)ethoxy)-4-(1,1,3,3-tetramethylbutyl)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-(2-(2-chloroethoxy)ethoxy)-4-(1,1,3,3-tetramethylbutyl)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-(2-(2-chloroethoxy)ethoxy)-4-(1,1,3,3-tetramethylbutyl)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-(2-(2-chloroethoxy)ethoxy)-4-(1,1,3,3-tetramethylbutyl)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fenofibrate',
    'C<sub>20</sub>H<sub>21</sub>ClO<sub>4</sub>',
    '',
    '49562-28-9',
    'YMTINGFKWWXKFG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fenofibrate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'indanofan',
    'C<sub>20</sub>H<sub>17</sub>O<sub>3</sub>Cl',
    '',
    '133220-30-1',
    'PMAAYIYCDXGUAP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='indanofan'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='indanofan'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'spirodiclofen',
    'C<sub>21</sub>H<sub>24</sub>Cl<sub>2</sub>O<sub>4</sub>',
    '',
    '148477-71-8',
    'DTDSAWVUFPGDMX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='spirodiclofen'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 5.0&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='spirodiclofen'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'permethrin',
    'C<sub>21</sub>H<sub>20</sub>Cl<sub>2</sub>O<sub>3</sub>',
    '',
    '52645-53-1',
    'RLLPVAHGXHCWKJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3',
    '',
    'V',
    (SELECT id from species WHERE iupac='permethrin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='permethrin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0',
    '',
    'V',
    (SELECT id from species WHERE iupac='permethrin'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='permethrin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chlorophacinone',
    'C<sub>23</sub>H<sub>15</sub>ClO<sub>3</sub>',
    '',
    '3691-35-8',
    'UDHXJZHVNHGCEC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chlorophacinone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorophacinone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chlormadinone acetate',
    'C<sub>23</sub>H<sub>29</sub>ClO<sub>4</sub>',
    '',
    '302-22-7',
    'QMBJSIBWORFWQT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlormadinone acetate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4,5,6-tetrachlorophthalic acid bis(2-ethylhexyl) ester',
    'C<sub>24</sub>H<sub>34</sub>Cl<sub>4</sub>O<sub>4</sub>',
    '',
    '34832-88-7',
    'BELGUQVGZMFEAQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,5,6-tetrachlorophthalic acid bis(2-ethylhexyl) ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,5,6-tetrachlorophthalic acid bis(2-ethylhexyl) ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,5,6-tetrachlorophthalic acid bis(2-ethylhexyl) ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,5,6-tetrachlorophthalic acid bis(2-ethylhexyl) ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'endosulfan alcohol',
    'C<sub>9</sub>H<sub>8</sub>Cl<sub>6</sub>O<sub>2</sub>',
    '',
    '2157-19-9',
    'GTSJHTSVFKEASK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='endosulfan alcohol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='endosulfan alcohol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='endosulfan alcohol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='endosulfan alcohol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chlorendic anhydride',
    'C<sub>9</sub>H<sub>2</sub>Cl<sub>6</sub>O<sub>3</sub>',
    '',
    '115-27-5',
    'FLBJFXNAEMSXGL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorendic anhydride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorendic anhydride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorendic anhydride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorendic anhydride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4,5,6,7,7-hexachloro-bicyclo[2.2.1]hept-5-ene-2,3-dicarboxylic acid',
    'C<sub>9</sub>H<sub>4</sub>Cl<sub>6</sub>O<sub>4</sub>',
    '',
    '115-28-6',
    'DJKGDNKYTKCJKD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4,5,6,7,7-hexachloro-bicyclo[2.2.1]hept-5-ene-2,3-dicarboxylic acid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4,5,6,7,7-hexachloro-bicyclo[2.2.1]hept-5-ene-2,3-dicarboxylic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4,5,6,7,7-hexachloro-bicyclo[2.2.1]hept-5-ene-2,3-dicarboxylic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4,5,6,7,7-hexachloro-bicyclo[2.2.1]hept-5-ene-2,3-dicarboxylic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4,5,6,7,7-hexachloro-bicyclo[2.2.1]hept-5-ene-2,3-dicarboxylic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'heptachlorepoxide',
    'C<sub>10</sub>H<sub>5</sub>Cl<sub>7</sub>O',
    '',
    '1024-57-3',
    'ZXFXBSWRVIQKOD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='heptachlorepoxide'),
    (SELECT id from literature WHERE bibtexkey='2948'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='LDV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='heptachlorepoxide'),
    (SELECT id from literature WHERE bibtexkey='2948'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='heptachlorepoxide'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;1</sup>',
    '5200',
    'M',
    (SELECT id from species WHERE iupac='heptachlorepoxide'),
    (SELECT id from literature WHERE bibtexkey='2814'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='heptachlorepoxide'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='heptachlorepoxide'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='heptachlorepoxide'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='heptachlorepoxide'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='heptachlorepoxide'),
    (SELECT id from literature WHERE bibtexkey='3083'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptachlorepoxide'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptachlorepoxide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptachlorepoxide'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptachlorepoxide'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='heptachlorepoxide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dieldrin',
    'C<sub>12</sub>H<sub>8</sub>OCl<sub>6</sub>',
    '',
    '60-57-1',
    'DFBKLUNHFCTMDC-NLUYNBKHSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'L',
    (SELECT id from species WHERE iupac='dieldrin'),
    (SELECT id from literature WHERE bibtexkey='2948'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='LDV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='dieldrin'),
    (SELECT id from literature WHERE bibtexkey='2948'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='dieldrin'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dieldrin'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;1</sup>',
    '5800',
    'M',
    (SELECT id from species WHERE iupac='dieldrin'),
    (SELECT id from literature WHERE bibtexkey='2814'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dieldrin'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dieldrin'),
    (SELECT id from literature WHERE bibtexkey='2465'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dieldrin'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dieldrin'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dieldrin'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dieldrin'),
    (SELECT id from literature WHERE bibtexkey='2471'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dieldrin'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='dieldrin'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='dieldrin'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='dieldrin'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1157-20-25'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='dieldrin'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1157-20-25'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='dieldrin'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='dieldrin'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'C',
    (SELECT id from species WHERE iupac='dieldrin'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='dieldrin'),
    (SELECT id from literature WHERE bibtexkey='3083'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dieldrin'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dieldrin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dieldrin'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dieldrin'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dieldrin'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dieldrin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    '?',
    (SELECT id from species WHERE iupac='dieldrin'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dieldrin'),
    (SELECT id from literature WHERE bibtexkey='695'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'endrin',
    'C<sub>12</sub>H<sub>8</sub>Cl<sub>6</sub>O',
    '',
    '72-20-8',
    'DFBKLUNHFCTMDC-GKRDHZSOSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'L',
    (SELECT id from species WHERE iupac='endrin'),
    (SELECT id from literature WHERE bibtexkey='2948'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='LDV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='endrin'),
    (SELECT id from literature WHERE bibtexkey='2948'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'M',
    (SELECT id from species WHERE iupac='endrin'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '4600',
    'M',
    (SELECT id from species WHERE iupac='endrin'),
    (SELECT id from literature WHERE bibtexkey='2814'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'M',
    (SELECT id from species WHERE iupac='endrin'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='endrin'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='endrin'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='endrin'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='endrin'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='endrin'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='endrin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='endrin'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='endrin'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    '?',
    (SELECT id from species WHERE iupac='endrin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4,5,6,7,7-hexachlorobicyclo[2.2.1]hept-5-ene-2,3-dicarboxylic acid, dibutyl ester',
    'C<sub>17</sub>H<sub>20</sub>Cl<sub>6</sub>O<sub>4</sub>',
    '',
    '1770-80-5',
    'UJAHPBDUQZFDLA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4,5,6,7,7-hexachlorobicyclo[2.2.1]hept-5-ene-2,3-dicarboxylic acid, dibutyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4,5,6,7,7-hexachlorobicyclo[2.2.1]hept-5-ene-2,3-dicarboxylic acid, dibutyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4,5,6,7,7-hexachlorobicyclo[2.2.1]hept-5-ene-2,3-dicarboxylic acid, dibutyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4,5,6,7,7-hexachlorobicyclo[2.2.1]hept-5-ene-2,3-dicarboxylic acid, dibutyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'di-2-ethylhexyl chlorendate',
    'C<sub>25</sub>H<sub>36</sub>Cl<sub>6</sub>O<sub>4</sub>',
    '',
    '4827-55-8',
    'ONIHOIFWLALAQH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Oxygenated chlorocarbons (C, H, O, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='di-2-ethylhexyl chlorendate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='di-2-ethylhexyl chlorendate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='di-2-ethylhexyl chlorendate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='di-2-ethylhexyl chlorendate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Polychlorinated diphenyl ethers (PCDEs)',
    (SELECT id from categories WHERE catname='Organic species with chlorine (Cl)'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-chlorodiphenyl ether',
    'C<sub>12</sub>H<sub>9</sub>ClO',
    'PCDE-1',
    '2689-07-8',
    'IPBRZLMGGXHHMS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-chlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-chlorodiphenyl ether',
    'C<sub>12</sub>H<sub>9</sub>ClO',
    'PCDE-2',
    '6452-49-9',
    'BMURONZFJJPAOK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-chlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-chlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-chlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-chlorodiphenyl ether',
    'C<sub>12</sub>H<sub>9</sub>ClO',
    'PCDE-3',
    '7005-72-3',
    'PGPNJCAMHOJTEF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-chlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-chlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-chlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='howard97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='4-chlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dichlorodiphenyl ether',
    'C<sub>12</sub>H<sub>8</sub>Cl<sub>2</sub>O',
    'PCDE-5',
    '68486-28-2',
    'VSKSUBSGORDMQX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3-dichlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dichlorodiphenyl ether',
    'C<sub>12</sub>H<sub>8</sub>Cl<sub>2</sub>O',
    'PCDE-7',
    '51892-26-3',
    'KXIPYLZZJZMMPD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4-dichlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4''-dichlorodiphenyl ether',
    'C<sub>12</sub>H<sub>8</sub>Cl<sub>2</sub>O',
    'PCDE-8',
    '6903-65-7',
    'MWKULKMSBBSGTP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4''-dichlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5-dichlorodiphenyl ether',
    'C<sub>12</sub>H<sub>8</sub>Cl<sub>2</sub>O',
    'PCDE-9',
    '24910-69-8',
    'VITXVDNQHXYQSK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,5-dichlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6-dichlorodiphenyl ether',
    'C<sub>12</sub>H<sub>8</sub>Cl<sub>2</sub>O',
    'PCDE-10',
    '28419-69-4',
    'IRLZOQDGEAEIPX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,6-dichlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4-dichlorodiphenyl ether',
    'C<sub>12</sub>H<sub>8</sub>Cl<sub>2</sub>O',
    'PCDE-12',
    '55538-69-7',
    'QFQLZVAAQOJUFS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,4-dichlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4''-dichlorodiphenyl ether',
    'C<sub>12</sub>H<sub>8</sub>Cl<sub>2</sub>O',
    'PCDE-13',
    '6842-62-2',
    'HPRGYUWRGCTBAV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,4''-dichlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,5-dichlorodiphenyl ether',
    'C<sub>12</sub>H<sub>8</sub>Cl<sub>2</sub>O',
    'PCDE-14',
    '24910-68-7',
    'LEKOWSSKXYFERR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,5-dichlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,4''-dichlorodiphenyl ether',
    'C<sub>12</sub>H<sub>8</sub>Cl<sub>2</sub>O',
    'PCDE-15',
    '2444-89-5',
    'URUJZHZLCCIILC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4,4''-dichlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',4-trichlorodiphenyl ether',
    'C<sub>12</sub>H<sub>7</sub>Cl<sub>3</sub>O',
    'PCDE-17',
    '68914-97-6',
    'YXMNUPKWUMIZAV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4-trichlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4-trichlorodiphenyl ether',
    'C<sub>12</sub>H<sub>7</sub>Cl<sub>3</sub>O',
    'PCDE-21',
    '85918-32-7',
    'ANKBTLMYMVMWBS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,4-trichlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4''-trichlorodiphenyl ether',
    'C<sub>12</sub>H<sub>7</sub>Cl<sub>3</sub>O',
    'PCDE-22',
    '157683-71-1',
    'KOTNFWJIMRGVBR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,4''-trichlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,5-trichlorodiphenyl ether',
    'C<sub>12</sub>H<sub>7</sub>Cl<sub>3</sub>O',
    'PCDE-23',
    '162853-24-9',
    'MDSPKCWGOVVFJD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,5-trichlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,6-trichlorodiphenyl ether',
    'C<sub>12</sub>H<sub>7</sub>Cl<sub>3</sub>O',
    'PCDE-24',
    '162853-25-0',
    'RQSRPDGSUDRYLH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,6-trichlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',4-trichlorodiphenyl ether',
    'C<sub>12</sub>H<sub>7</sub>Cl<sub>3</sub>O',
    'PCDE-25',
    '155999-93-2',
    'BJFOCMRBCBZFJT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3'',4-trichlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,4''-trichlorodiphenyl ether',
    'C<sub>12</sub>H<sub>7</sub>Cl<sub>3</sub>O',
    'PCDE-28',
    '59039-21-3',
    'PIORTDHJOLELKR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4,4''-trichlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,5-trichlorodiphenyl ether',
    'C<sub>12</sub>H<sub>7</sub>Cl<sub>3</sub>O',
    'PCDE-29',
    '52322-80-2',
    'UWKZWXCTDPYXHU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4,5-trichlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,6-trichlorodiphenyl ether',
    'C<sub>12</sub>H<sub>7</sub>Cl<sub>3</sub>O',
    'PCDE-30',
    '63646-52-6',
    'WXLQUFLKMICSSY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4,6-trichlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4'',5-trichlorodiphenyl ether',
    'C<sub>12</sub>H<sub>7</sub>Cl<sub>3</sub>O',
    'PCDE-31',
    '65075-00-5',
    'FZBSTAVCYOMFMD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4'',5-trichlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4'',6-trichlorodiphenyl ether',
    'C<sub>12</sub>H<sub>7</sub>Cl<sub>3</sub>O',
    'PCDE-32',
    '157683-72-2',
    'ZMRFCSWFCKICQE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4'',6-trichlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',4''-trichlorodiphenyl ether',
    'C<sub>12</sub>H<sub>7</sub>Cl<sub>3</sub>O',
    'PCDE-33',
    '61328-44-7',
    'VBNJGYOQZAENPO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3'',4''-trichlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3'',4-trichlorodiphenyl ether',
    'C<sub>12</sub>H<sub>7</sub>Cl<sub>3</sub>O',
    'PCDE-35',
    '66794-60-3',
    'BUKLLCIUMZELOH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,3'',4-trichlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4,4''-trichlorodiphenyl ether',
    'C<sub>12</sub>H<sub>7</sub>Cl<sub>3</sub>O',
    'PCDE-37',
    '63646-51-5',
    'FTZDEZOARSJHGU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,4,4''-trichlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4,5-trichlorodiphenyl ether',
    'C<sub>12</sub>H<sub>7</sub>Cl<sub>3</sub>O',
    'PCDE-38',
    '63646-53-7',
    'ZQCCHNBMSHOJAT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,4,5-trichlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4'',5-trichlorodiphenyl ether',
    'C<sub>12</sub>H<sub>7</sub>Cl<sub>3</sub>O',
    'PCDE-39',
    '24910-73-4',
    'CCEZFZGXWFJQEF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,4'',5-trichlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4-tetrachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>O',
    'PCDE-41',
    '220002-37-9',
    'VTTDWGUAWMLHPR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4-tetrachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4''-tetrachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>O',
    'PCDE-42',
    '147102-63-4',
    'UYVBJPIPRAJEKW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4''-tetrachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',4,4''-tetrachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>O',
    'PCDE-47',
    '28076-73-5',
    'ZRWRPGGXCSSBAO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,4''-tetrachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,4''-tetrachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',4,5-tetrachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>O',
    'PCDE-48',
    '162853-26-1',
    'DRVAMLZVBNYSQE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,5-tetrachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',4,5''-tetrachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>O',
    'PCDE-49',
    '155999-92-1',
    'XIXPEFLLHQAIOY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,5''-tetrachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4-tetrachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>O',
    'PCDE-55',
    '220002-39-1',
    'IZISEKJPNSBPRX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4-tetrachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4''-tetrachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>O',
    'PCDE-56',
    '162853-27-2',
    'JVFGXWCLGNACOG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4''-tetrachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,4''-tetrachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>O',
    'PCDE-60',
    '65075-01-6',
    'ZPOBHUZRVVTGKB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,4,4''-tetrachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,5-tetrachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>O',
    'PCDE-61',
    '220002-40-4',
    'QAPPZLVGIXQUJW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,4,5-tetrachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,6-tetrachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>O',
    'PCDE-62',
    '85918-33-8',
    'WJZPRRFFZWVZJL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,4,6-tetrachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4'',5-tetrachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>O',
    'PCDE-63',
    '220002-41-5',
    'YHQRYZGDQCSHFO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,4'',5-tetrachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4'',6-tetrachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>O',
    'PCDE-64',
    '220002-42-6',
    'HJCNTJIMUWQMSA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,4'',6-tetrachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,5,6-tetrachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>O',
    'PCDE-65',
    '63646-54-8',
    'UFGXCDQXRUFDMA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,5,6-tetrachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',4,4''-tetrachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>O',
    'PCDE-66',
    '61328-46-9',
    'CAWSVYYOUZEMHA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3'',4,4''-tetrachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',4,5-tetrachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>O',
    'PCDE-67',
    '152833-52-8',
    'QDQGECFQVPRMEO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3'',4,5-tetrachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',4,5''-tetrachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>O',
    'PCDE-68',
    '147102-64-5',
    'XORVNHCKWFPDLN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3'',4,5''-tetrachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',4'',5-tetrachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>O',
    'PCDE-70',
    '159553-67-0',
    'MFTPXFIGIJCNJM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3'',4'',5-tetrachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',4'',6-tetrachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>O',
    'PCDE-71',
    '130892-66-9',
    'IZZULMOBRTYHMH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3'',4'',6-tetrachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,4'',5-tetrachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>O',
    'PCDE-74',
    '61328-45-8',
    'KXOJXWNARBQHNX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4,4'',5-tetrachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,4'',6-tetrachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>O',
    'PCDE-75',
    '63553-30-0',
    'YCWRSOTXXJYCKF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4,4'',6-tetrachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3'',4,4''-tetrachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>O',
    'PCDE-77',
    '56348-72-2',
    'DHLVZXZRIZBPKG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,3'',4,4''-tetrachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3'',4,5''-tetrachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>O',
    'PCDE-79',
    '552884-22-7',
    'BUPRSRBWDJVKGG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,3'',4,5''-tetrachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4,4'',5-tetrachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>O',
    'PCDE-81',
    '62615-07-0',
    'CAUBBRCOHHHCNG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,4,4'',5-tetrachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4-pentachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>O',
    'PCDE-82',
    '160282-10-0',
    'ABRDPORILGADAP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4-pentachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,4''-pentachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>O',
    'PCDE-85',
    '71585-37-0',
    'RSBUDFTVQYJNHK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,4''-pentachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,5''-pentachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>O',
    'PCDE-87',
    '160282-09-7',
    'SCLCXTQIVCULDR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,5''-pentachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,6''-pentachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>O',
    'PCDE-89',
    '85918-35-0',
    'JGXAONSRHOSPTJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,6''-pentachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4'',5-pentachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>O',
    'PCDE-90',
    '157683-73-3',
    'QPEBRZQSEUOWPA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5-pentachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4'',6-pentachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>O',
    'PCDE-91',
    '116995-20-1',
    'BRNKJDZWZYZVNM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4'',6-pentachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4'',5''-pentachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>O',
    'PCDE-97',
    '160282-08-6',
    'ABYZYVAIOYICJQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5''-pentachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',4,4'',5-pentachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>O',
    'PCDE-99',
    '60123-64-0',
    'AVURWLKSFZBANQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5-pentachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '6100',
    'T',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5-pentachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',4,4'',6-pentachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>O',
    'PCDE-100',
    '104294-16-8',
    'FONWDRSQXQZNBN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,4'',6-pentachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '5800',
    'T',
    (SELECT id from species WHERE iupac='2,2'',4,4'',6-pentachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',4,5,5''-pentachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>O',
    'PCDE-101',
    '131138-21-1',
    'MKIAKZAWONVRFF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,5,5''-pentachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',4,5,6''-pentachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>O',
    'PCDE-102',
    '130892-67-0',
    'BOJBTUWEQMUWHT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,5,6''-pentachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4,4''-pentachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>O',
    'PCDE-105',
    '85918-31-6',
    'PKEGIXYNAGGYPN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4,4''-pentachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4,5''-pentachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>O',
    'PCDE-108',
    '160282-07-5',
    'HCTKORQPUZCIAO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4,5''-pentachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4,6-pentachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>O',
    'PCDE-109',
    '727738-64-9',
    'SEIXDCGLHKOBEO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4,6-pentachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4'',6-pentachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>O',
    'PCDE-110',
    '159553-69-2',
    'KASGFDPQAMDPAZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4'',6-pentachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,4'',5-pentachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>O',
    'PCDE-114',
    '113464-17-8',
    'WSTVMACYLXUQIM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,4,4'',5-pentachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,4'',6-pentachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>O',
    'PCDE-115',
    '160282-05-3',
    'LUNNFBBTEHRYMW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,4,4'',6-pentachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,5,6-pentachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>O',
    'PCDE-116',
    '22274-42-6',
    'JDWOFUWJURZFFF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,4,5,6-pentachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4'',5,6-pentachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>O',
    'PCDE-117',
    '63646-55-9',
    'UETIKWAWMZLQQZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,4'',5,6-pentachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',4,4'',5-pentachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>O',
    'PCDE-118',
    '60123-65-1',
    'NRAVUGAGYOBXIG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3'',4,4'',5-pentachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',4,4'',6-pentachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>O',
    'PCDE-119',
    '157683-74-4',
    'POOXVKSDWCXIBU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3'',4,4'',6-pentachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',4,5,5''-pentachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>O',
    'PCDE-120',
    '160282-04-2',
    'XIFRTJZLSYOLIU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3'',4,5,5''-pentachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',4,4'',5''-pentachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>O',
    'PCDE-123',
    '160282-06-4',
    'BUAXMSGDEZZOJD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3'',4,4'',5''-pentachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3'',4,4'',5-pentachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>5</sub>O',
    'PCDE-126',
    '94339-59-0',
    'WDBLKMRZRGLISL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,3'',4,4'',5-pentachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,4''-hexachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>O',
    'PCDE-128',
    '71585-39-2',
    'GSWMXIIUDJOXNF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4''-hexachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,5''-hexachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>O',
    'PCDE-130',
    '76621-14-2',
    'JTEWACHFMNTRBB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5''-hexachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,6''-hexachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>O',
    'PCDE-132',
    '124076-66-0',
    'YDVYLSIVXYLBBX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,6''-hexachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,4'',5-hexachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>O',
    'PCDE-137',
    '71585-38-1',
    'LDPJEMNNPDFBCQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5-hexachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '6400',
    'T',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5-hexachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,4'',5''-hexachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>O',
    'PCDE-138',
    '71585-36-9',
    'PHSJJYZIFPWCLZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5''-hexachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '6500',
    'T',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5''-hexachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,4'',6-hexachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>O',
    'PCDE-139',
    '106220-83-1',
    'BIWCEXHDIQZFHI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',6-hexachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,4'',6''-hexachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>O',
    'PCDE-140',
    '106220-82-0',
    'XDAOZRZWYVKIAK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',6''-hexachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4'',5,5''-hexachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>O',
    'PCDE-146',
    '162853-28-3',
    'SFTBUGPDOJDENF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5,5''-hexachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4'',5,6-hexachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>O',
    'PCDE-147',
    '116995-18-7',
    'DIBYIHMYEPMGKC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5,6-hexachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4'',5'',6-hexachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>O',
    'PCDE-149',
    '85918-37-2',
    'RDKSFIZNZGWNLA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5'',6-hexachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',4,4'',5,5''-hexachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>O',
    'PCDE-153',
    '71859-30-8',
    'PECXRRMHOQBOIE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5,5''-hexachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '6300',
    'T',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5,5''-hexachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',4,4'',5,6''-hexachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>O',
    'PCDE-154',
    '106220-81-9',
    'XKQUAQGQLZDDBV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5,6''-hexachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;3</sup>',
    '5900',
    'T',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5,6''-hexachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4,4'',5-hexachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>O',
    'PCDE-156',
    '109828-22-0',
    'GHTWMHLFFDEYRE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5-hexachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4,4'',5''-hexachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>O',
    'PCDE-157',
    '94339-60-3',
    'FEIDIWDEJQVIPO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5''-hexachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4'',5,6-hexachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>O',
    'PCDE-163',
    '155999-97-6',
    'YLAYOOJLJKJGCF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4'',5,6-hexachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,4'',5,6-hexachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>O',
    'PCDE-166',
    '63646-56-0',
    'MXDRLBNLTLOWGV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,4,4'',5,6-hexachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',4,4'',5,5''-hexachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>6</sub>O',
    'PCDE-167',
    '131138-20-0',
    'DYSUSQZPGJXVAL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3'',4,4'',5,5''-hexachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;3</sup>',
    '6200',
    'T',
    (SELECT id from species WHERE iupac='2,3'',4,4'',5,5''-hexachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,4'',5-heptachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>7</sub>O',
    'PCDE-170',
    '71585-40-5',
    'BLBURLWSCHSPIS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5-heptachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,5,6''-heptachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>7</sub>O',
    'PCDE-174',
    '159553-73-8',
    'DQYYZAABYZAOOC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,6''-heptachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,5'',6''-heptachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>7</sub>O',
    'PCDE-177',
    '83992-71-6',
    'RXPQVFMDOJTCKE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5'',6''-heptachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,4'',5,5''-heptachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>7</sub>O',
    'PCDE-180',
    '83992-69-2',
    'YBYYCWMPXZRBNJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5,5''-heptachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '6800',
    'T',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5,5''-heptachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,4'',5,6-heptachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>7</sub>O',
    'PCDE-181',
    '157683-75-5',
    'RPNFRXWGMTYOPA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5,6-heptachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,4'',5,6''-heptachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>7</sub>O',
    'PCDE-182',
    '88467-63-4',
    'XWRZWPPSQDHTFU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;3</sup>',
    '6400',
    'T',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5,6''-heptachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,4'',6,6''-heptachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>7</sub>O',
    'PCDE-184',
    '106220-84-2',
    'WTYSJAGEYAAIFW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '7800',
    'T',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',6,6''-heptachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4'',5,5'',6-heptachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>7</sub>O',
    'PCDE-187',
    '109828-23-1',
    'BHJCMMGUFRZLKK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5,5'',6-heptachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4,4'',5,5''-heptachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>7</sub>O',
    'PCDE-189',
    '83992-72-7',
    'JUHPMUOWCYBMEY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5,5''-heptachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4,4'',5,6-heptachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>7</sub>O',
    'PCDE-190',
    '83992-70-5',
    'QLSBRXLSQINWHM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5,6-heptachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,4'',5,5''-octachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>2</sub>Cl<sub>8</sub>O',
    'PCDE-194',
    '57379-40-5',
    'IXZVOZCULZBCDY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,5''-octachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,4'',5,6-octachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>2</sub>Cl<sub>8</sub>O',
    'PCDE-195',
    '65075-02-7',
    'YHUPMPHVHYBYJE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,6-octachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,4'',5,6''-octachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>2</sub>Cl<sub>8</sub>O',
    'PCDE-196',
    '85918-38-3',
    'HYNYIQBCBHJTOZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;3</sup>',
    '7100',
    'T',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,6''-octachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,4'',6,6''-octachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>2</sub>Cl<sub>8</sub>O',
    'PCDE-197',
    '117948-62-6',
    'GRWRDFGBFYSOKR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;3</sup>',
    '7000',
    'T',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',6,6''-octachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,5,5'',6''-octachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>2</sub>Cl<sub>8</sub>O',
    'PCDE-199',
    '83992-76-1',
    'MRHQOXCYYPFGEE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,5'',6''-octachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,4'',5,5'',6-octachlorodiphenyl ether',
    'C<sub>12</sub>H<sub>2</sub>Cl<sub>8</sub>O',
    'PCDE-203',
    '83992-75-0',
    'PKOSPVZTRLMBSK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5,5'',6-octachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,4'',5,5'',6-nonachlorodiphenyl ether',
    'C<sub>12</sub>HCl<sub>9</sub>O',
    'PCDE-206',
    '83992-73-8',
    'FPEYJPVHPGDXDD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,5'',6-nonachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'decachlorodiphenyl ether',
    'C<sub>12</sub>Cl<sub>10</sub>O',
    'PCDE-209',
    '31710-30-2',
    'CIPFDHFTBYJKQB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated diphenyl ethers (PCDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='decachlorodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='1096'));
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Polychlorinated dibenzofuranes (PCDFs)',
    (SELECT id from categories WHERE catname='Organic species with chlorine (Cl)'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-chlorodibenzofuran',
    'C<sub>12</sub>H<sub>7</sub>ClO',
    'PCDF-1',
    '84761-86-4',
    'WRSMJZYBNIAAEE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-chlorodibenzofuran',
    'C<sub>12</sub>H<sub>7</sub>ClO',
    'PCDF-2',
    '51230-49-0',
    'PRKTYWJFCODJOA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-chlorodibenzofuran',
    'C<sub>12</sub>H<sub>7</sub>ClO',
    'PCDF-3',
    '25074-67-3',
    'BBOZMMAURMEVAR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-chlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-chlorodibenzofuran',
    'C<sub>12</sub>H<sub>7</sub>ClO',
    'PCDF-4',
    '74992-96-4',
    'RHRYBWFAHXCUCR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-dichlorodibenzofuran',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>2</sub>O',
    'PCDF-12',
    '64126-85-8',
    'QVAPRJWSOUITIF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3-dichlorodibenzofuran',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>2</sub>O',
    'PCDF-13',
    '94538-00-8',
    'VKIBKEFGJSPRJC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4-dichlorodibenzofuran',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>2</sub>O',
    'PCDF-14',
    '94538-01-9',
    'VHQCMZLPHWGUDB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dichlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,6-dichlorodibenzofuran',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>2</sub>O',
    'PCDF-16',
    '74992-97-5',
    'JRSRWACZUFLWKF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,6-dichlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,7-dichlorodibenzofuran',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>2</sub>O',
    'PCDF-17',
    '94538-02-0',
    'XRQNHPGZRFKBJW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,7-dichlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,8-dichlorodibenzofuran',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>2</sub>O',
    'PCDF-18',
    '81638-37-1',
    'UAFNQQBPUWFPGC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,8-dichlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,9-dichlorodibenzofuran',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>2</sub>O',
    'PCDF-19',
    '70648-14-5',
    'AEKSGHBVWJHELW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,9-dichlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dichlorodibenzofuran',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>2</sub>O',
    'PCDF-23',
    '64126-86-9',
    'GETJJZZRPQFSFM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dichlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dichlorodibenzofuran',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>2</sub>O',
    'PCDF-24',
    '24478-74-8',
    'LHTCKMYRNOGUOA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dichlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6-dichlorodibenzofuran',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>2</sub>O',
    'PCDF-26',
    '60390-27-4',
    'XVLCNKFGFHUQNL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dichlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,7-dichlorodibenzofuran',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>2</sub>O',
    'PCDF-27',
    '74992-98-6',
    'DOZUTNBCPVUMPY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,7-dichlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,8-dichlorodibenzofuran',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>2</sub>O',
    'PCDF-28',
    '5409-83-6',
    'IVVRJIDVYSPKFZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,8-dichlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,8-dichlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,8-dichlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,8-dichlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,8-dichlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,8-dichlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4-dichlorodibenzofuran',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>2</sub>O',
    'PCDF-34',
    '94570-83-9',
    'HYQGGNWDPQZLGX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dichlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,6-dichlorodibenzofuran',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>2</sub>O',
    'PCDF-36',
    '74918-40-4',
    'DMOBGFAKTSXOHG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,6-dichlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,7-dichlorodibenzofuran',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>2</sub>O',
    'PCDF-37',
    '58802-21-4',
    'OLTYAGNRSNFHLK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,7-dichlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,6-dichlorodibenzofuran',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>2</sub>O',
    'PCDF-46',
    '64560-13-0',
    'BZFIZJNKNCJEAD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,6-dichlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3-trichlorodibenzofuran',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>3</sub>O',
    'PCDF-123',
    '83636-47-9',
    'LADSWAAWPMGHBE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-trichlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4-trichlorodibenzofuran',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>3</sub>O',
    'PCDF-124',
    '24478-73-7',
    'RQIWKWHVZLDXEJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-trichlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,6-trichlorodibenzofuran',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>3</sub>O',
    'PCDF-126',
    '64560-15-2',
    'CYRZCBUWRUACKJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,6-trichlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,7-trichlorodibenzofuran',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>3</sub>O',
    'PCDF-127',
    '83704-37-4',
    'AFOVQGPNOZDUEP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,7-trichlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,8-trichlorodibenzofuran',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>3</sub>O',
    'PCDF-128',
    '83704-34-1',
    'UYIGPSPCOXGBCS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,8-trichlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,9-trichlorodibenzofuran',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>3</sub>O',
    'PCDF-129',
    '83704-38-5',
    'ICTXINQOXPMQPM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,9-trichlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3,4-trichlorodibenzofuran',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>3</sub>O',
    'PCDF-134',
    '82911-61-3',
    'FIPOITUDJFQRRN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,4-trichlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3,6-trichlorodibenzofuran',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>3</sub>O',
    'PCDF-136',
    '83704-39-6',
    'AGPTXRLVBIRYLV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,6-trichlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3,7-trichlorodibenzofuran',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>3</sub>O',
    'PCDF-137',
    '64560-16-3',
    'INRBXOGZPDFCLQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,7-trichlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3,8-trichlorodibenzofuran',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>3</sub>O',
    'PCDF-138',
    '76621-12-0',
    'PHFSTDOPTZHECA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,8-trichlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3,9-trichlorodibenzofuran',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>3</sub>O',
    'PCDF-139',
    '83704-40-9',
    'SPPGDLROKBFNNO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,9-trichlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4,6-trichlorodibenzofuran',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>3</sub>O',
    'PCDF-146',
    '82911-60-2',
    'XDQRWSUJOURTHK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4,6-trichlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4,7-trichlorodibenzofuran',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>3</sub>O',
    'PCDF-147',
    '83704-41-0',
    'XTLMVJUSIANHND-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4,7-trichlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4,8-trichlorodibenzofuran',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>3</sub>O',
    'PCDF-148',
    '64560-14-1',
    'PCQCYDNFBUADOK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4,8-trichlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4,9-trichlorodibenzofuran',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>3</sub>O',
    'PCDF-149',
    '70648-13-4',
    'NVYUPBVXKLTYHV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4,9-trichlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,6,7-trichlorodibenzofuran',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>3</sub>O',
    'PCDF-167',
    '83704-46-5',
    'HEWLCNCSWBMZHG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,6,7-trichlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,6,8-trichlorodibenzofuran',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>3</sub>O',
    'PCDF-168',
    '82911-59-9',
    'ZOBVYDQWZXUJNO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,6,8-trichlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,7,8-trichlorodibenzofuran',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>3</sub>O',
    'PCDF-178',
    '58802-18-9',
    'YNMCXGLWHTVMQO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,7,8-trichlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4-trichlorodibenzofuran',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>3</sub>O',
    'PCDF-234',
    '57117-34-7',
    'YDLADWPBKZODCJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trichlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,6-trichlorodibenzofuran',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>3</sub>O',
    'PCDF-236',
    '57117-33-6',
    'CPMGJTLNRBIKQM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,6-trichlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,7-trichlorodibenzofuran',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>3</sub>O',
    'PCDF-237',
    '58802-17-8',
    'CKXMNTLGGAOERF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,7-trichlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,8-trichlorodibenzofuran',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>3</sub>O',
    'PCDF-238',
    '57117-32-5',
    'NUNSNNOYACKRIK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,8-trichlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,6-trichlorodibenzofuran',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>3</sub>O',
    'PCDF-246',
    '58802-14-5',
    'GTKURBTWZFQHHY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trichlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,7-trichlorodibenzofuran',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>3</sub>O',
    'PCDF-247',
    '83704-42-1',
    'SZBZRVJHPZIGAY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,7-trichlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,8-trichlorodibenzofuran',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>3</sub>O',
    'PCDF-248',
    '54589-71-8',
    'WJURXKWTCOMRCE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,8-trichlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4,6-trichlorodibenzofuran',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>3</sub>O',
    'PCDF-346',
    '83704-43-2',
    'XEUHBCMRIXEBTD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,6-trichlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4,7-trichlorodibenzofuran',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>3</sub>O',
    'PCDF-347',
    '83704-44-3',
    'RPJJBTSXPNFUTA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,7-trichlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4,8-trichlorodibenzofuran',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>3</sub>O',
    'PCDF-348',
    '83704-45-4',
    'YTZWNIQGGIJHJX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,8-trichlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,4-tetrachlorodibenzofuran',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O',
    'PCDF-1234',
    '24478-72-6',
    'AETAPIFVELRIDN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,6-tetrachlorodibenzofuran',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O',
    'PCDF-1236',
    '83704-21-6',
    'BBAXFLIBRPXRBP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,6-tetrachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,7-tetrachlorodibenzofuran',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O',
    'PCDF-1237',
    '83704-22-7',
    'MDNZFYGATDCKRB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,7-tetrachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,8-tetrachlorodibenzofuran',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O',
    'PCDF-1238',
    '62615-08-1',
    'KFQRHGKKSHJMCO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,8-tetrachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,9-tetrachlorodibenzofuran',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O',
    'PCDF-1239',
    '83704-23-8',
    'GNQHLJHTOATTOJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,9-tetrachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4,6-tetrachlorodibenzofuran',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O',
    'PCDF-1246',
    '71998-73-7',
    'NLVWEKPJFUPVMZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,6-tetrachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4,7-tetrachlorodibenzofuran',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O',
    'PCDF-1247',
    '83719-40-8',
    'MFURKMJLDQBHRA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,7-tetrachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4,8-tetrachlorodibenzofuran',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O',
    'PCDF-1248',
    '64126-87-0',
    'BFTASCFRRBHFFK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,8-tetrachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4,9-tetrachlorodibenzofuran',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O',
    'PCDF-1249',
    '83704-24-9',
    'ZUYYTCCHKQGGOV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,9-tetrachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,6,7-tetrachlorodibenzofuran',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O',
    'PCDF-1267',
    '83704-25-0',
    'AUEWYHHKDYUYMI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,6,7-tetrachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,6,8-tetrachlorodibenzofuran',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O',
    'PCDF-1268',
    '83710-07-0',
    'KCVGVSIBBGIJNZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,6,8-tetrachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,6,9-tetrachlorodibenzofuran',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O',
    'PCDF-1269',
    '70648-18-9',
    'IEPGLLVEBKXASE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,6,9-tetrachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,7,8-tetrachlorodibenzofuran',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O',
    'PCDF-1278',
    '58802-20-3',
    'JODWPAQNABOHDG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,7,8-tetrachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,7,8-tetrachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,7,9-tetrachlorodibenzofuran',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O',
    'PCDF-1279',
    '83704-26-1',
    'PDMFRPIFZAKMLH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,7,9-tetrachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,8,9-tetrachlorodibenzofuran',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O',
    'PCDF-1289',
    '70648-22-5',
    'OHYCQUKMNPHFPT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,8,9-tetrachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3,4,6-tetrachlorodibenzofuran',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O',
    'PCDF-1346',
    '83704-27-2',
    'CBBDONKZEJKFJP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,4,6-tetrachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3,4,7-tetrachlorodibenzofuran',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O',
    'PCDF-1347',
    '70648-16-7',
    'UMKCVDZTSZNWRH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,4,7-tetrachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3,4,8-tetrachlorodibenzofuran',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O',
    'PCDF-1348',
    '92341-04-3',
    'XWKRJSMNDOXIHS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,4,8-tetrachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3,4,9-tetrachlorodibenzofuran',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O',
    'PCDF-1349',
    '83704-28-3',
    'PNCYJHOTZSKZPA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,4,9-tetrachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3,6,7-tetrachlorodibenzofuran',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O',
    'PCDF-1367',
    '57117-36-9',
    'PITDPGCTIMCYEZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,6,7-tetrachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3,6,8-tetrachlorodibenzofuran',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O',
    'PCDF-1368',
    '71998-72-6',
    'BDXKVABZWRZKOS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,6,8-tetrachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3,6,9-tetrachlorodibenzofuran',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O',
    'PCDF-1369',
    '83690-98-6',
    'NJQQZRLWVLWNGD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,6,9-tetrachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3,7,8-tetrachlorodibenzofuran',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O',
    'PCDF-1378',
    '57117-35-8',
    'CSXDVUGDFSYXTD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,7,8-tetrachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3,7,9-tetrachlorodibenzofuran',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O',
    'PCDF-1379',
    '64560-17-4',
    'IEMJMCVYAORWJV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,7,9-tetrachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4,6,7-tetrachlorodibenzofuran',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O',
    'PCDF-1467',
    '66794-59-0',
    'RBFNYMHNIOKXLA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4,6,7-tetrachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4,6,8-tetrachlorodibenzofuran',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O',
    'PCDF-1468',
    '82911-58-8',
    'VHOBVPNETFRJED-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4,6,8-tetrachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4,6,9-tetrachlorodibenzofuran',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O',
    'PCDF-1469',
    '70648-19-0',
    'JAYSBJFHDJOMGZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4,6,9-tetrachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4,7,8-tetrachlorodibenzofuran',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O',
    'PCDF-1478',
    '83704-29-4',
    'IVRDRRWQABCXLY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4,7,8-tetrachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,6,7,8-tetrachlorodibenzofuran',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O',
    'PCDF-1678',
    '83704-33-0',
    'KOJMOXYETDLOPN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,6,7,8-tetrachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,6-tetrachlorodibenzofuran',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O',
    'PCDF-2346',
    '83704-30-7',
    'JNVHSHPAAMRSKK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,6-tetrachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,7-tetrachlorodibenzofuran',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O',
    'PCDF-2347',
    '83704-31-8',
    'BROFYOSLFHTGCQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,7-tetrachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,8-tetrachlorodibenzofuran',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O',
    'PCDF-2348',
    '83704-32-9',
    'IIKXRERKNIJJQY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,8-tetrachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,6,7-tetrachlorodibenzofuran',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O',
    'PCDF-2367',
    '57117-39-2',
    'MJCNKMDTLRSHNK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,6,7-tetrachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,6,8-tetrachlorodibenzofuran',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O',
    'PCDF-2368',
    '57117-37-0',
    'SPMZHWVRMWWTSY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,6,8-tetrachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,7,8-tetrachlorodibenzofuran',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O',
    'PCDF-2378',
    '51207-31-9',
    'KSMVNVHUTQZITP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3,7,8-tetrachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='2945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,7,8-tetrachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,7,8-tetrachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '3700',
    'T',
    (SELECT id from species WHERE iupac='2,3,7,8-tetrachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,7,8-tetrachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,7,8-tetrachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,7,8-tetrachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,7,8-tetrachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,7,8-tetrachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3,7,8-tetrachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,6,7-tetrachlorodibenzofuran',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O',
    'PCDF-2467',
    '57117-38-1',
    'NSDXKMRVQOSASS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6,7-tetrachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,6,8-tetrachlorodibenzofuran',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O',
    'PCDF-2468',
    '58802-19-0',
    'ZSPJEACWUWSAGS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6,8-tetrachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4,6,7-tetrachlorodibenzofuran',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O',
    'PCDF-3467',
    '57117-40-5',
    'LMJLCLBSUNZLNW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,6,7-tetrachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,4,6-pentachlorodibenzofuran',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>5</sub>O',
    'PCDF-12346',
    '83704-47-6',
    'LIQJBAPSLUZUTB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4,6-pentachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,4,7-pentachlorodibenzofuran',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>5</sub>O',
    'PCDF-12347',
    '83704-48-7',
    'DOJZTBGOWIYFAC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4,7-pentachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,4,8-pentachlorodibenzofuran',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>5</sub>O',
    'PCDF-12348',
    '67517-48-0',
    'ZCTNDJSCLPJCRA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4,8-pentachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,4,9-pentachlorodibenzofuran',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>5</sub>O',
    'PCDF-12349',
    '83704-49-8',
    'IQSZNZVZXOFRJS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4,9-pentachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,6,7-pentachlorodibenzofuran',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>5</sub>O',
    'PCDF-12367',
    '57117-42-7',
    'NZUPQBVDIWCPBX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,6,7-pentachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,6,8-pentachlorodibenzofuran',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>5</sub>O',
    'PCDF-12368',
    '83704-51-2',
    'VHQJZOFUPXEZQZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,6,8-pentachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,6,9-pentachlorodibenzofuran',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>5</sub>O',
    'PCDF-12369',
    '83704-52-3',
    'IPSFQAKXDJVQOX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,6,9-pentachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,7,8-pentachlorodibenzofuran',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>5</sub>O',
    'PCDF-12378',
    '57117-41-6',
    'SBMIVUVRFPGOEB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;4</sup>',
    '3000',
    'T',
    (SELECT id from species WHERE iupac='1,2,3,7,8-pentachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,7,8-pentachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,7,9-pentachlorodibenzofuran',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>5</sub>O',
    'PCDF-12379',
    '83704-53-4',
    'JVUSEQPOWCBYNG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,7,9-pentachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,8,9-pentachlorodibenzofuran',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>5</sub>O',
    'PCDF-12389',
    '83704-54-5',
    'NKGLWUJPCTUDEH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,8,9-pentachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,8,9-pentachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4,6,7-pentachlorodibenzofuran',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>5</sub>O',
    'PCDF-12467',
    '83704-50-1',
    'BQTCODOVGXJHRB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,6,7-pentachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4,6,8-pentachlorodibenzofuran',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>5</sub>O',
    'PCDF-12468',
    '69698-57-3',
    'JDTUAYPJSSXDNO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,6,8-pentachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4,6,9-pentachlorodibenzofuran',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>5</sub>O',
    'PCDF-12469',
    '70648-24-7',
    'QDQFGVXGPSYEJU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,6,9-pentachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4,7,8-pentachlorodibenzofuran',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>5</sub>O',
    'PCDF-12478',
    '58802-15-6',
    'GCFDWHIKRXCUPJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,7,8-pentachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4,7,9-pentachlorodibenzofuran',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>5</sub>O',
    'PCDF-12479',
    '71998-74-8',
    'IYGVHNHWORPMFU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,7,9-pentachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4,8,9-pentachlorodibenzofuran',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>5</sub>O',
    'PCDF-12489',
    '70648-23-6',
    'ZSPAPWGNAGTCCA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,8,9-pentachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,6,7,8-pentachlorodibenzofuran',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>5</sub>O',
    'PCDF-12678',
    '69433-00-7',
    'ZAAVDGLJEOXCMV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,6,7,8-pentachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,6,7,9-pentachlorodibenzofuran',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>5</sub>O',
    'PCDF-12679',
    '70872-82-1',
    'QQRRQEVOSMEVQB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,6,7,9-pentachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3,4,6,7-pentachlorodibenzofuran',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>5</sub>O',
    'PCDF-13467',
    '83704-36-3',
    'JVYYDUWJIJMOGW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,4,6,7-pentachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3,4,6,8-pentachlorodibenzofuran',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>5</sub>O',
    'PCDF-13468',
    '83704-55-6',
    'COKIAYPRHYHYCH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,4,6,8-pentachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3,4,6,9-pentachlorodibenzofuran',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>5</sub>O',
    'PCDF-13469',
    '70648-15-6',
    'MYSAFUYQSBEEDR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,4,6,9-pentachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3,4,7,8-pentachlorodibenzofuran',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>5</sub>O',
    'PCDF-13478',
    '58802-16-7',
    'ORSUQGVCWLXKLZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,4,7,8-pentachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3,4,7,9-pentachlorodibenzofuran',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>5</sub>O',
    'PCDF-13479',
    '70648-20-3',
    'GFXPLABVZOBCCW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,4,7,9-pentachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3,6,7,8-pentachlorodibenzofuran',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>5</sub>O',
    'PCDF-13678',
    '70648-21-4',
    'FRLMQDUYUJIHCZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,6,7,8-pentachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4,6,7,8-pentachlorodibenzofuran',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>5</sub>O',
    'PCDF-14678',
    '83704-35-2',
    'VANGHZRYKXDPRR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4,6,7,8-pentachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,6,7-pentachlorodibenzofuran',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>5</sub>O',
    'PCDF-23467',
    '57117-43-8',
    'SJFBZRQKGOGHEV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,6,7-pentachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,6,8-pentachlorodibenzofuran',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>5</sub>O',
    'PCDF-23468',
    '67481-22-5',
    'MKRFORPSRBMAIP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,6,8-pentachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,7,8-pentachlorodibenzofuran',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>5</sub>O',
    'PCDF-23478',
    '57117-31-4',
    'OGBQILNBLMPPDP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,4,7,8-pentachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,4,7,8-pentachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,4,7,8-pentachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,4,7,8-pentachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '2900',
    'T',
    (SELECT id from species WHERE iupac='2,3,4,7,8-pentachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,7,8-pentachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,7,8-pentachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,7,8-pentachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,4,6,7-hexachlorodibenzofuran',
    'C<sub>12</sub>H<sub>2</sub>Cl<sub>6</sub>O',
    'PCDF-123467',
    '79060-60-9',
    'SNWFMKXFMVHBKD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4,6,7-hexachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,4,6,8-hexachlorodibenzofuran',
    'C<sub>12</sub>H<sub>2</sub>Cl<sub>6</sub>O',
    'PCDF-123468',
    '69698-60-8',
    'UCFGNWHERVQWMZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;4</sup>',
    '2300',
    'T',
    (SELECT id from species WHERE iupac='1,2,3,4,6,8-hexachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4,6,8-hexachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,4,6,9-hexachlorodibenzofuran',
    'C<sub>12</sub>H<sub>2</sub>Cl<sub>6</sub>O',
    'PCDF-123469',
    '91538-83-9',
    'KFFUZIROJGXTQH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4,6,9-hexachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,4,7,8-hexachlorodibenzofuran',
    'C<sub>12</sub>H<sub>2</sub>Cl<sub>6</sub>O',
    'PCDF-123478',
    '70648-26-9',
    'LVYBAQIVPKCOEE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3,4,7,8-hexachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3,4,7,8-hexachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;4</sup>',
    '2400',
    'T',
    (SELECT id from species WHERE iupac='1,2,3,4,7,8-hexachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4,7,8-hexachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4,7,8-hexachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,4,7,9-hexachlorodibenzofuran',
    'C<sub>12</sub>H<sub>2</sub>Cl<sub>6</sub>O',
    'PCDF-123479',
    '91538-84-0',
    'BKIXWRBZCQEZAQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4,7,9-hexachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,4,8,9-hexachlorodibenzofuran',
    'C<sub>12</sub>H<sub>2</sub>Cl<sub>6</sub>O',
    'PCDF-123489',
    '92341-07-6',
    'VSDUQUBUJRNREH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4,8,9-hexachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4,8,9-hexachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,6,7,8-hexachlorodibenzofuran',
    'C<sub>12</sub>H<sub>2</sub>Cl<sub>6</sub>O',
    'PCDF-123678',
    '57117-44-9',
    'JEYJJJXOFWNEHN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3,6,7,8-hexachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '3300',
    'T',
    (SELECT id from species WHERE iupac='1,2,3,6,7,8-hexachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,6,7,8-hexachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,6,7,8-hexachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,6,7,9-hexachlorodibenzofuran',
    'C<sub>12</sub>H<sub>2</sub>Cl<sub>6</sub>O',
    'PCDF-123679',
    '92341-06-5',
    'JZVOLXQREJNTTL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,6,7,9-hexachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,6,8,9-hexachlorodibenzofuran',
    'C<sub>12</sub>H<sub>2</sub>Cl<sub>6</sub>O',
    'PCDF-123689',
    '75198-38-8',
    'WLGQZUOHEXTWFH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,6,8,9-hexachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,7,8,9-hexachlorodibenzofuran',
    'C<sub>12</sub>H<sub>2</sub>Cl<sub>6</sub>O',
    'PCDF-123789',
    '72918-21-9',
    'PYUSJFJVDVSXIU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;4</sup>',
    '2600',
    'T',
    (SELECT id from species WHERE iupac='1,2,3,7,8,9-hexachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,7,8,9-hexachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,7,8,9-hexachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4,6,7,8-hexachlorodibenzofuran',
    'C<sub>12</sub>H<sub>2</sub>Cl<sub>6</sub>O',
    'PCDF-124678',
    '67562-40-7',
    'CKDDYGBBKXIHRY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;4</sup>',
    '2300',
    'T',
    (SELECT id from species WHERE iupac='1,2,4,6,7,8-hexachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,6,7,8-hexachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4,6,7,9-hexachlorodibenzofuran',
    'C<sub>12</sub>H<sub>2</sub>Cl<sub>6</sub>O',
    'PCDF-124679',
    '75627-02-0',
    'FAHIPPHRJJJQOG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,6,7,9-hexachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4,6,8,9-hexachlorodibenzofuran',
    'C<sub>12</sub>H<sub>2</sub>Cl<sub>6</sub>O',
    'PCDF-124689',
    '69698-59-5',
    'FGZCXIPKUCJGHW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;4</sup>',
    '2600',
    'T',
    (SELECT id from species WHERE iupac='1,2,4,6,8,9-hexachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,6,8,9-hexachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3,4,6,7,8-hexachlorodibenzofuran',
    'C<sub>12</sub>H<sub>2</sub>Cl<sub>6</sub>O',
    'PCDF-134678',
    '71998-75-9',
    'OGTZINCGZYXZCR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,4,6,7,8-hexachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3,4,6,7,9-hexachlorodibenzofuran',
    'C<sub>12</sub>H<sub>2</sub>Cl<sub>6</sub>O',
    'PCDF-134679',
    '92341-05-4',
    'TURXXOIFVABBPW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,4,6,7,9-hexachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,6,7,8-hexachlorodibenzofuran',
    'C<sub>12</sub>H<sub>2</sub>Cl<sub>6</sub>O',
    'PCDF-234678',
    '60851-34-5',
    'XTAHLACQOVXINQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;4</sup>',
    '2600',
    'T',
    (SELECT id from species WHERE iupac='2,3,4,6,7,8-hexachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,6,7,8-hexachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,6,7,8-hexachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,4,6,7,8-heptachlorodibenzofuran',
    'C<sub>12</sub>HCl<sub>7</sub>O',
    'PCDF-1234678',
    '67562-39-4',
    'WDMKCPIVJOGHBF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3,4,6,7,8-heptachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3,4,6,7,8-heptachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3,4,6,7,8-heptachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;5</sup>',
    '1600',
    'T',
    (SELECT id from species WHERE iupac='1,2,3,4,6,7,8-heptachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4,6,7,8-heptachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4,6,7,8-heptachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4,6,7,8-heptachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,4,6,7,9-heptachlorodibenzofuran',
    'C<sub>12</sub>HCl<sub>7</sub>O',
    'PCDF-1234679',
    '70648-25-8',
    'JWXWOEUKHXOUSK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4,6,7,9-heptachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,4,6,8,9-heptachlorodibenzofuran',
    'C<sub>12</sub>HCl<sub>7</sub>O',
    'PCDF-1234689',
    '69698-58-4',
    'BADFHCOLISGRRW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '1800',
    'T',
    (SELECT id from species WHERE iupac='1,2,3,4,6,8,9-heptachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4,6,8,9-heptachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,4,7,8,9-heptachlorodibenzofuran',
    'C<sub>12</sub>HCl<sub>7</sub>O',
    'PCDF-1234789',
    '55673-89-7',
    'VEZCTZWLJYWARH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;4</sup>',
    '2100',
    'T',
    (SELECT id from species WHERE iupac='1,2,3,4,7,8,9-heptachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4,7,8,9-heptachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4,7,8,9-heptachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'octachlorodibenzofuran',
    'C<sub>12</sub>Cl<sub>8</sub>O',
    'PCDF-12346789',
    '39001-02-0',
    'RHIROFAGUQOFLU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzofuranes (PCDFs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2',
    '',
    'V',
    (SELECT id from species WHERE iupac='octachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='octachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2612_pc_problem'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='octachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;4</sup>',
    '2400',
    'T',
    (SELECT id from species WHERE iupac='octachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octachlorodibenzofuran'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Polychlorinated dibenzo-p-dioxins (PCDDs)',
    (SELECT id from categories WHERE catname='Organic species with chlorine (Cl)'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-chlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>7</sub>ClO<sub>2</sub>',
    'PCDD-1',
    '39227-53-7',
    'VGGGRWRBGXENKI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-chlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-chlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-chlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-chlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-chlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='854'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '7100',
    'Q',
    (SELECT id from species WHERE iupac='1-chlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6500',
    '?',
    (SELECT id from species WHERE iupac='1-chlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-chlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>7</sub>ClO<sub>2</sub>',
    'PCDD-2',
    '39227-54-8',
    'GIUGGRUEPHPVNR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-chlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-chlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-chlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-chlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='854'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-dichlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>2</sub>O<sub>2</sub>',
    'PCDD-12',
    '54536-18-4',
    'DFGDMWHUCCHXIF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3-dichlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>2</sub>O<sub>2</sub>',
    'PCDD-13',
    '50585-39-2',
    'AZYJYMAKTBXNSX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4-dichlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>2</sub>O<sub>2</sub>',
    'PCDD-14',
    '54536-19-5',
    'MBMUPQZSDWVPQU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,6-dichlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>2</sub>O<sub>2</sub>',
    'PCDD-16',
    '38178-38-0',
    'MAWMBEVNJGEDAD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,6-dichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,6-dichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,7-dichlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>2</sub>O<sub>2</sub>',
    'PCDD-17',
    '82291-26-7',
    'IJUWLAFPPVRYGY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,7-dichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,7-dichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,8-dichlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>2</sub>O<sub>2</sub>',
    'PCDD-18',
    '82291-27-8',
    'PLZYIHQBHROTFD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,8-dichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,8-dichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,9-dichlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>2</sub>O<sub>2</sub>',
    'PCDD-19',
    '82291-28-9',
    'JZDVJXBKJDADAY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,9-dichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,9-dichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dichlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>2</sub>O<sub>2</sub>',
    'PCDD-23',
    '29446-15-9',
    'YCIYTXRUZSDMRZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3-dichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3-dichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3-dichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3-dichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3-dichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='854'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,7-dichlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>2</sub>O<sub>2</sub>',
    'PCDD-27',
    '33857-26-0',
    'NBFMTHWVRBOVPE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,7-dichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='644'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '644',
    '3790', 'The same data were also published in Brandsch et&nbsp;al. (1993).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='644'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,7-dichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2612_pc_problem'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,7-dichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,7-dichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='854'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,7-dichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,7-dichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,7-dichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,7-dichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,7-dichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,7-dichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,7-dichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,7-dichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,8-dichlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>2</sub>O<sub>2</sub>',
    'PCDD-28',
    '38964-22-6',
    'WMWJCKBJUQDYLM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,8-dichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,8-dichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,8-dichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,8-dichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='854'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,8-dichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,8-dichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,8-dichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,8-dichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3-trichlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>3</sub>O<sub>2</sub>',
    'PCDD-123',
    '54536-17-3',
    'SKMFBGZVVNDVFR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-trichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-trichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4-trichlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>3</sub>O<sub>2</sub>',
    'PCDD-124',
    '39227-58-2',
    'HRVUKLBFRPWXPJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2,4-trichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='644'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='644'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,4-trichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,4-trichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,4-trichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='854'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-trichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-trichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-trichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-trichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-trichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-trichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-trichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2,4-trichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='1,2,4-trichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '1943-39227-58-2-erratum',
    '1943,644', 'Erratum for page 376 of Fogg and Sangster (2003): data from Santl et&nbsp;al. (1994) are cited incorrectly; it should be 3.64, not 3.84.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1943-39227-58-2-erratum'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,6-trichlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>3</sub>O<sub>2</sub>',
    'PCDD-126',
    '69760-96-9',
    'XQBPVWBIUBCJJO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,6-trichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,6-trichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,7-trichlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>3</sub>O<sub>2</sub>',
    'PCDD-127',
    '82291-30-3',
    'TXJMXDWFPQSYEQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,7-trichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,7-trichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,8-trichlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>3</sub>O<sub>2</sub>',
    'PCDD-128',
    '82291-31-4',
    'QBEOCKSANJLBAE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,8-trichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,8-trichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,9-trichlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>3</sub>O<sub>2</sub>',
    'PCDD-129',
    '82291-32-5',
    'DQLRDBDQLSIOIX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,9-trichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,9-trichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3,6-trichlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>3</sub>O<sub>2</sub>',
    'PCDD-136',
    '82291-33-6',
    'LNPVMVSAUXUGHH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,6-trichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,6-trichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3,7-trichlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>3</sub>O<sub>2</sub>',
    'PCDD-137',
    '67028-17-5',
    'RPKWIXFZKMDPMH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,7-trichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,7-trichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3,8-trichlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>3</sub>O<sub>2</sub>',
    'PCDD-138',
    '82306-61-4',
    'FJAKCOBYQSEWMT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,8-trichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,8-trichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3,9-trichlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>3</sub>O<sub>2</sub>',
    'PCDD-139',
    '82306-62-5',
    'DGDADRUTFAIIQQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,9-trichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,9-trichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4,6-trichlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>3</sub>O<sub>2</sub>',
    'PCDD-146',
    '82306-63-6',
    'UTTYFTWIJLRXKB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4,6-trichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4,6-trichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4,7-trichlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>3</sub>O<sub>2</sub>',
    'PCDD-147',
    '82306-64-7',
    'NBWAQBGJBSYXHV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4,7-trichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4,7-trichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,7,8-trichlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>3</sub>O<sub>2</sub>',
    'PCDD-178',
    '82306-65-8',
    'CAPCTZJHYADFNX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,7,8-trichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,7,8-trichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,7-trichlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>5</sub>Cl<sub>3</sub>O<sub>2</sub>',
    'PCDD-237',
    '33857-28-2',
    'ZSIZNEVHVVRPFF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,7-trichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,7-trichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,4-tetrachlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O<sub>2</sub>',
    'PCDD-1234',
    '30746-58-8',
    'DJHHDLMTUOLVHY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='644'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='644'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='854'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,6-tetrachlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O<sub>2</sub>',
    'PCDD-1236',
    '71669-25-5',
    'XEZBZSVTUSXISZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,6-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,6-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,7-tetrachlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O<sub>2</sub>',
    'PCDD-1237',
    '67028-18-6',
    'SKGXYFVQZVPEFP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3,7-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3,7-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3,7-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='854'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,7-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,7-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,7-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,7-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,7-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,7-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,7-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2,3,7-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,8-tetrachlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O<sub>2</sub>',
    'PCDD-1238',
    '53555-02-5',
    'BXKLTNKYLCZOHF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,8-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,8-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,9-tetrachlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O<sub>2</sub>',
    'PCDD-1239',
    '71669-26-6',
    'CMVHZKSHSHQJHS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,9-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,9-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4,6-tetrachlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O<sub>2</sub>',
    'PCDD-1246',
    '71669-27-7',
    'KQNBZUDHTCXCNA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,6-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,6-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4,7-tetrachlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O<sub>2</sub>',
    'PCDD-1247',
    '71669-28-8',
    'SMPHQCMJQUBTFZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,7-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,7-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4,8-tetrachlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O<sub>2</sub>',
    'PCDD-1248',
    '71669-29-9',
    'XGIKODBWQSAEFQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,8-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,8-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4,9-tetrachlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O<sub>2</sub>',
    'PCDD-1249',
    '71665-99-1',
    'WDAHVJCSSYOALR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,9-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,9-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,6,7-tetrachlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O<sub>2</sub>',
    'PCDD-1267',
    '40581-90-6',
    'SAMLAWFHXZIRMP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,6,7-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,6,7-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,6,8-tetrachlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O<sub>2</sub>',
    'PCDD-1268',
    '67323-56-2',
    'YYUFYZDSYHKVDP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,6,8-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,6,8-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,6,9-tetrachlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O<sub>2</sub>',
    'PCDD-1269',
    '40581-91-7',
    'ZKMXKYXNLFLUCD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,6,9-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,6,9-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,7,8-tetrachlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O<sub>2</sub>',
    'PCDD-1278',
    '34816-53-0',
    'YDZCLBKUTXYYKS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,7,8-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,7,8-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,7,9-tetrachlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O<sub>2</sub>',
    'PCDD-1279',
    '71669-23-3',
    'QIKHBBZEUNSCAF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,7,9-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,7,9-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,8,9-tetrachlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O<sub>2</sub>',
    'PCDD-1289',
    '62470-54-6',
    'WELWFAGPAZKSBG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,8,9-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,8,9-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3,6,8-tetrachlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O<sub>2</sub>',
    'PCDD-1368',
    '33423-92-6',
    'OTQFXRBLGNEOGH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,3,6,8-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2537'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3,6,8-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3,6,8-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='854'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,6,8-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,6,8-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,6,8-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,6,8-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3,6,9-tetrachlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O<sub>2</sub>',
    'PCDD-1369',
    '71669-24-4',
    'QAUIRDIJIUMMEP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,6,9-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,6,9-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3,7,8-tetrachlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O<sub>2</sub>',
    'PCDD-1378',
    '50585-46-1',
    'VPTDIAYLYJBYQG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,7,8-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,7,8-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3,7,9-tetrachlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O<sub>2</sub>',
    'PCDD-1379',
    '62470-53-5',
    'JMGYHLJVDHUACM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,7,9-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,7,9-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4,6,9-tetrachlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O<sub>2</sub>',
    'PCDD-1469',
    '40581-93-9',
    'QTIIAIRUSSSOHT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4,6,9-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4,6,9-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4,7,8-tetrachlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O<sub>2</sub>',
    'PCDD-1478',
    '40581-94-0',
    'FCRXUTCUWCJZJI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4,7,8-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4,7,8-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,7,8-tetrachlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>4</sub>O<sub>2</sub>',
    'PCDD-2378; TCDD',
    '1746-01-6',
    'HGUFODBRKLSHSI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,7,8-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,7,8-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,7,8-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,7,8-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,7,8-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2975'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at283K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,7,8-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='854'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,7,8-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='854'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,7,8-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='854'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,7,8-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2946'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,7,8-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2947'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;4</sup>',
    '3600',
    'T',
    (SELECT id from species WHERE iupac='2,3,7,8-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,7,8-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,7,8-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,7,8-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,7,8-tetrachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,4,6-pentachlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>5</sub>O<sub>2</sub>',
    'PCDD-12346',
    '67028-19-7',
    'LNWDBNKKBLRAMH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4,6-pentachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4,6-pentachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,4,7-pentachlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>5</sub>O<sub>2</sub>',
    'PCDD-12347',
    '39227-61-7',
    'WRNGAZFESPEMCN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3,4,7-pentachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3,4,7-pentachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3,4,7-pentachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3,4,7-pentachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='854'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4,7-pentachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4,7-pentachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4,7-pentachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4,7-pentachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,6,7-pentachlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>5</sub>O<sub>2</sub>',
    'PCDD-12367',
    '71925-15-0',
    'RLGWDUHOIIWPGN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,6,7-pentachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,6,7-pentachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,6,8-pentachlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>5</sub>O<sub>2</sub>',
    'PCDD-12368',
    '71925-16-1',
    'VKDGHBBUEIIEHL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,6,8-pentachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,6,8-pentachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,6,9-pentachlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>5</sub>O<sub>2</sub>',
    'PCDD-12369',
    '82291-34-7',
    'NWKWRHSKKNELND-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,6,9-pentachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,6,9-pentachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,7,8-pentachlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>5</sub>O<sub>2</sub>',
    'PCDD-12378',
    '40321-76-4',
    'FSPZPQQWDODWAU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;5</sup>',
    '2500',
    'T',
    (SELECT id from species WHERE iupac='1,2,3,7,8-pentachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,7,8-pentachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,7,8-pentachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,7,8-pentachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,7,9-pentachlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>5</sub>O<sub>2</sub>',
    'PCDD-12379',
    '71925-17-2',
    'UAOYHTXYVWEPIB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,7,9-pentachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,7,9-pentachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,8,9-pentachlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>5</sub>O<sub>2</sub>',
    'PCDD-12389',
    '71925-18-3',
    'VUMZAVNIADYKFC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,8,9-pentachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,8,9-pentachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4,6,7-pentachlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>5</sub>O<sub>2</sub>',
    'PCDD-12467',
    '82291-35-8',
    'SEKDDGLKEYEVQK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,6,7-pentachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,6,7-pentachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4,6,8-pentachlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>5</sub>O<sub>2</sub>',
    'PCDD-12468',
    '71998-76-0',
    'SJJWALZHAWITMS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,6,8-pentachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,6,8-pentachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4,6,9-pentachlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>5</sub>O<sub>2</sub>',
    'PCDD-12469',
    '82291-36-9',
    'GNQVSAMSAKZLKE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,6,9-pentachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,6,9-pentachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4,7,8-pentachlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>5</sub>O<sub>2</sub>',
    'PCDD-12478',
    '58802-08-7',
    'QUPLGUUISJOUPJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,7,8-pentachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,7,8-pentachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4,7,9-pentachlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>5</sub>O<sub>2</sub>',
    'PCDD-12479',
    '82291-37-0',
    'QLBBXWPVEFJZEC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,7,9-pentachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,7,9-pentachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4,8,9-pentachlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>3</sub>Cl<sub>5</sub>O<sub>2</sub>',
    'PCDD-12489',
    '82291-38-1',
    'KLLFLRKEOJCTGC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,8,9-pentachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,8,9-pentachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,4,6,7-hexachlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>2</sub>Cl<sub>6</sub>O<sub>2</sub>',
    'PCDD-123467',
    '58200-66-1',
    'NLBQVWJHLWAFGJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4,6,7-hexachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4,6,7-hexachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,4,6,8-hexachlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>2</sub>Cl<sub>6</sub>O<sub>2</sub>',
    'PCDD-123468',
    '58200-67-2',
    'IMALTUQZEIFHJW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4,6,8-hexachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4,6,8-hexachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,4,6,9-hexachlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>2</sub>Cl<sub>6</sub>O<sub>2</sub>',
    'PCDD-123469',
    '58200-68-3',
    'UDYXCMRDCOVQLG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4,6,9-hexachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4,6,9-hexachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,4,7,8-hexachlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>2</sub>Cl<sub>6</sub>O<sub>2</sub>',
    'PCDD-123478',
    '39227-28-6',
    'WCYYQNSQJHPVMG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3,4,7,8-hexachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3,4,7,8-hexachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3,4,7,8-hexachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3,4,7,8-hexachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='854'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '2900',
    'T',
    (SELECT id from species WHERE iupac='1,2,3,4,7,8-hexachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4,7,8-hexachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '8800',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4,7,8-hexachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4,7,8-hexachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4,7,8-hexachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4,7,8-hexachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '9400',
    '?',
    (SELECT id from species WHERE iupac='1,2,3,4,7,8-hexachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,6,7,8-hexachlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>2</sub>Cl<sub>6</sub>O<sub>2</sub>',
    'PCDD-123678',
    '57653-85-7',
    'YCLUIPQDHHPDJJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;5</sup>',
    '2800',
    'T',
    (SELECT id from species WHERE iupac='1,2,3,6,7,8-hexachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,6,7,8-hexachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,6,7,8-hexachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,6,7,8-hexachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,6,7,8-hexachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,6,7,9-hexachlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>2</sub>Cl<sub>6</sub>O<sub>2</sub>',
    'PCDD-123679',
    '64461-98-9',
    'BQOHWGKNRKCEFT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,6,7,9-hexachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,6,7,9-hexachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,6,8,9-hexachlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>2</sub>Cl<sub>6</sub>O<sub>2</sub>',
    'PCDD-123689',
    '58200-69-4',
    'GZRQZUFXVFRKBI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,6,8,9-hexachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,6,8,9-hexachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,7,8,9-hexachlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>2</sub>Cl<sub>6</sub>O<sub>2</sub>',
    'PCDD-123789',
    '19408-74-3',
    'LGIRBUBHIWTVCK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '2700',
    'T',
    (SELECT id from species WHERE iupac='1,2,3,7,8,9-hexachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,7,8,9-hexachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,7,8,9-hexachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,7,8,9-hexachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,7,8,9-hexachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4,6,7,9-hexachlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>2</sub>Cl<sub>6</sub>O<sub>2</sub>',
    'PCDD-124679',
    '39227-62-8',
    'BSJDQMWAWFTDGD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,6,7,9-hexachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,6,7,9-hexachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4,6,8,9-hexachlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>2</sub>Cl<sub>6</sub>O<sub>2</sub>',
    'PCDD-124689',
    '58802-09-8',
    'URELDHWUZUWPIU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,6,8,9-hexachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,6,8,9-hexachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,4,6,7,8-heptachlorodibenzo-p-dioxin',
    'C<sub>12</sub>HCl<sub>7</sub>O<sub>2</sub>',
    'PCDD-1234678',
    '35822-46-9',
    'WCLNVRQZUKYVAI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3,4,6,7,8-heptachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3,4,6,7,8-heptachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3,4,6,7,8-heptachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,3,4,6,7,8-heptachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='854'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;5</sup>',
    '2400',
    'T',
    (SELECT id from species WHERE iupac='1,2,3,4,6,7,8-heptachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4,6,7,8-heptachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4,6,7,8-heptachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4,6,7,8-heptachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4,6,7,8-heptachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4,6,7,8-heptachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,4,6,7,9-heptachlorodibenzo-p-dioxin',
    'C<sub>12</sub>HCl<sub>7</sub>O<sub>2</sub>',
    'PCDD-1234679',
    '58200-70-7',
    'KTJJIBIRZGQFQZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4,6,7,9-heptachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4,6,7,9-heptachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'octachlorodibenzo-p-dioxin',
    'C<sub>12</sub>Cl<sub>8</sub>O<sub>2</sub>',
    'PCDD-12346789',
    '3268-87-9',
    'FOIBFBMSLDGNHL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polychlorinated dibenzo-p-dioxins (PCDDs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='octachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='octachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='octachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='octachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='octachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='854'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '2300',
    'T',
    (SELECT id from species WHERE iupac='octachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1143'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '9600',
    'Q',
    (SELECT id from species WHERE iupac='octachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2915'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='2949'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2949GCRI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1112'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '9500',
    '?',
    (SELECT id from species WHERE iupac='octachlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Chlorocarbons with nitrogen (C, H, O, N, Cl)',
    (SELECT id from categories WHERE catname='Organic species with chlorine (Cl)'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cyanogen chloride',
    'NCCl',
    '',
    '506-77-4',
    'QPJDMGCKMHUXFD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyanogen chloride'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cyanogen chloride'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N,N-dichloromethylamine',
    'CH<sub>3</sub>NCl<sub>2</sub>',
    '',
    '7651-91-4',
    'DWEYPOWXNBAIDU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;3</sup>',
    '4300',
    'L',
    (SELECT id from species WHERE iupac='N,N-dichloromethylamine'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;3</sup>',
    '4300',
    'L',
    (SELECT id from species WHERE iupac='N,N-dichloromethylamine'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;3</sup>',
    '4300',
    'M',
    (SELECT id from species WHERE iupac='N,N-dichloromethylamine'),
    (SELECT id from literature WHERE bibtexkey='2821'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chloroacetonitrile',
    'C<sub>2</sub>H<sub>2</sub>ClN',
    '',
    '107-14-2',
    'RENMDAKOXSCIGH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroacetonitrile'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4600',
    'Q',
    (SELECT id from species WHERE iupac='chloroacetonitrile'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5400',
    '?',
    (SELECT id from species WHERE iupac='chloroacetonitrile'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dichloroacetonitrile',
    'C<sub>2</sub>HCl<sub>2</sub>N',
    '',
    '3018-12-0',
    'STZZWJCGRKXEFF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichloroacetonitrile'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'trichloroacetonitrile',
    'C<sub>2</sub>Cl<sub>3</sub>N',
    '',
    '545-06-2',
    'DRUIESSIVFYOMK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloroacetonitrile'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloroacetonitrile'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloroacetonitrile'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloroacetonitrile'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloroacetonitrile'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tetramethylammonium chloride',
    'C<sub>4</sub>H<sub>12</sub>ClN',
    '',
    '75-57-0',
    'OKIZCWYLBDKLSU-UHFFFAOYSA-M',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetramethylammonium chloride'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'metformin hydrochloride',
    'C<sub>4</sub>H<sub>12</sub>ClN<sub>5</sub>',
    '',
    '1115-70-4',
    'OETHQSJEHLVLGH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='metformin hydrochloride'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bis(2-chloroethyl)methylamine',
    'C<sub>5</sub>H<sub>11</sub>Cl<sub>2</sub>N',
    '',
    '51-75-2',
    'HAWPXGHAZFHHAD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4',
    '',
    'V',
    (SELECT id from species WHERE iupac='bis(2-chloroethyl)methylamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis(2-chloroethyl)methylamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chlormequat chloride',
    'C<sub>5</sub>H<sub>13</sub>Cl<sub>2</sub>N',
    '',
    '999-81-5',
    'OLQFELZRGYJRAZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 3.2&times;10<sup>9</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chlormequat chloride'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tris(2-chloroethyl)amine',
    'C<sub>6</sub>H<sub>12</sub>Cl<sub>3</sub>N',
    '',
    '555-77-1',
    'FDAYLTPAFBGXAB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tris(2-chloroethyl)amine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tris(2-chloroethyl)amine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tris(2-chloroethyl)amine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bis(2-chloroethyl)ethylamine',
    'C<sub>6</sub>H<sub>13</sub>Cl<sub>2</sub>N',
    'ethylbis(2-chloroethyl)amine',
    '538-07-8',
    'UQZPGHOJMQTOHB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bis(2-chloroethyl)ethylamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bis(2-chloroethyl)ethylamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis(2-chloroethyl)ethylamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cetrimonium chloride',
    'C<sub>19</sub>H<sub>42</sub>ClN',
    'trimethylhexadecylammonium chloride',
    '112-02-7',
    'WOWHHFRSBJGXCM-UHFFFAOYSA-M',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cetrimonium chloride'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimethyldioctadecylammonium chloride',
    'C<sub>38</sub>H<sub>80</sub>ClN',
    '',
    '107-64-2',
    'REZZEXDLIUJMMS-UHFFFAOYSA-M',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyldioctadecylammonium chloride'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-amino-2-chlorobenzene',
    'C<sub>6</sub>H<sub>6</sub>ClN',
    'o-chloroaniline',
    '95-51-2',
    'AKCRQHGQIJBRMN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '7900',
    'L',
    (SELECT id from species WHERE iupac='1-amino-2-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3518-95-51-2-consicheck',
    '3518', 'Values at 298&nbsp;K in Tables&nbsp;C2 and C5 of Brockbank (2013) are inconsistent, with 8&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3518-95-51-2-consicheck'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-amino-2-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-amino-2-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-amino-2-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-amino-2-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-amino-2-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-amino-2-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-amino-2-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-amino-2-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'R',
    (SELECT id from species WHERE iupac='1-amino-2-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-amino-2-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-amino-2-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-amino-2-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-amino-2-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-amino-2-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-amino-2-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-amino-2-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-amino-2-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-amino-3-chlorobenzene',
    'C<sub>6</sub>H<sub>6</sub>ClN',
    'm-chloroaniline',
    '108-42-9',
    'PNPCRKVUWYDDST-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-amino-3-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-amino-3-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-amino-3-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-amino-3-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-amino-3-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5',
    '',
    'R',
    (SELECT id from species WHERE iupac='1-amino-3-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-amino-3-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-amino-3-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-amino-3-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-amino-3-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-amino-3-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-amino-3-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-amino-3-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-amino-3-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-Test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-amino-3-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-amino-3-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-amino-3-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-amino-3-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-amino-4-chlorobenzene',
    'C<sub>6</sub>H<sub>6</sub>ClN',
    'p-chloroaniline',
    '106-47-8',
    'QSNSCYSYFYORTR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-amino-4-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-amino-4-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-amino-4-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-amino-4-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-amino-4-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-amino-4-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6',
    '',
    'R',
    (SELECT id from species WHERE iupac='1-amino-4-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-amino-4-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-amino-4-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='howard89'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-amino-4-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-amino-4-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-amino-4-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-amino-4-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-amino-4-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-amino-4-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-amino-4-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-amino-4-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-amino-4-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dichlorobenzenamine',
    'C<sub>6</sub>H<sub>5</sub>Cl<sub>2</sub>N',
    '2,3-dichloroaniline',
    '608-27-5',
    'BRPSAOUFIJSKOT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dichlorobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dichlorobenzenamine',
    'C<sub>6</sub>H<sub>5</sub>Cl<sub>2</sub>N',
    '2,4-dichloroaniline',
    '554-00-7',
    'KQCMTOWTPBNWDB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dichlorobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4-dichlorobenzenamine',
    'C<sub>6</sub>H<sub>5</sub>Cl<sub>2</sub>N',
    '3,4-dichloroaniline',
    '95-76-1',
    'SDYWXFYBZPNOFX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,4-dichlorobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,4-dichlorobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,4-dichlorobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,4-dichlorobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dichlorobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dichlorobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,5-dichlorobenzenamine',
    'C<sub>6</sub>H<sub>5</sub>Cl<sub>2</sub>N',
    '3,5-dichloroaniline',
    '626-43-7',
    'UQRLKWGPEVNVHT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dichlorobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5-dichlorobenzenamine',
    'C<sub>6</sub>H<sub>5</sub>Cl<sub>2</sub>N',
    '2,5-dichloroaniline',
    '95-82-9',
    'AVYGCQXNNJPXSS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dichlorobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dichlorobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dichlorobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dichlorobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dichlorobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,5-trichlorobenzenamine',
    'C<sub>6</sub>H<sub>4</sub>Cl<sub>3</sub>N',
    '',
    '636-30-6',
    'GUMCAKKKNKYFEB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5-trichlorobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5-trichlorobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5-trichlorobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5-trichlorobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,6-trichlorobenzenamine',
    'C<sub>6</sub>H<sub>4</sub>Cl<sub>3</sub>N',
    '',
    '634-93-5',
    'NATVSFWWYVJTAZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4,6-trichlorobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trichlorobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trichlorobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trichlorobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trichlorobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,5,6-pentachloroaniline',
    'C<sub>6</sub>H<sub>2</sub>Cl<sub>5</sub>N',
    '',
    '527-20-8',
    'KHCZSJXTDDHLGJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,5,6-pentachloroaniline'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6-dichlorobenzenenitrile',
    'C<sub>6</sub>H<sub>3</sub>Cl<sub>2</sub>CN',
    'dichlobenil',
    '1194-65-6',
    'YOYAIZYFCNQIRF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;1</sup>',
    '5400',
    'M',
    (SELECT id from species WHERE iupac='2,6-dichlorobenzenenitrile'),
    (SELECT id from literature WHERE bibtexkey='1331'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,6-dichlorobenzenenitrile'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,6-dichlorobenzenenitrile'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,6-dichlorobenzenenitrile'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,6-dichlorobenzenenitrile'),
    (SELECT id from literature WHERE bibtexkey='2165'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,6-dichlorobenzenenitrile'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,6-dichlorobenzenenitrile'),
    (SELECT id from literature WHERE bibtexkey='2968'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,6-dichlorobenzenenitrile'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dichlorobenzenenitrile'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dichlorobenzenenitrile'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dichlorobenzenenitrile'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6000',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dichlorobenzenenitrile'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5500',
    '?',
    (SELECT id from species WHERE iupac='2,6-dichlorobenzenenitrile'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(2,4,6-trichlorophenyl)hydrazine',
    'C<sub>6</sub>H<sub>5</sub>Cl<sub>3</sub>N<sub>2</sub>',
    '',
    '5329-12-4',
    'MULHANRBCQBHII-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2,4,6-trichlorophenyl)hydrazine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2,4,6-trichlorophenyl)hydrazine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2,4,6-trichlorophenyl)hydrazine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2,4,6-trichlorophenyl)hydrazine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-chlorobenzonitrile',
    'C<sub>7</sub>H<sub>4</sub>ClN',
    '',
    '623-03-0',
    'GJNGXPDXRVXSEH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chlorobenzonitrile'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chlorobenzonitrile'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chlorobenzonitrile'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chlorobenzonitrile'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-chloro-2-methylbenzenamine',
    'C<sub>7</sub>H<sub>8</sub>ClN',
    '',
    '87-60-5',
    'ZUVPLKVDZNDZCM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-chloro-2-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-chloro-4-methylbenzenamine',
    'C<sub>7</sub>H<sub>8</sub>ClN',
    '',
    '95-74-9',
    'RQKFYFNZSHWXAW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-chloro-4-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-chloro-2-methylbenzenamine',
    'C<sub>7</sub>H<sub>8</sub>ClN',
    '',
    '95-69-2',
    'CXNVOWPRHWWCQR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chloro-2-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-chloro-2-methylbenzenamine',
    'C<sub>7</sub>H<sub>8</sub>ClN',
    '',
    '95-79-4',
    'WRZOMWDJOLIVQP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-chloro-2-methylbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-642'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,5,6-tetrachloro-1,3-dicyanobenzene',
    'C<sub>8</sub>Cl<sub>4</sub>N<sub>2</sub>',
    'chlorothalonil',
    '1897-45-6',
    'CRQQGFGUEAVUIL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,4,5,6-tetrachloro-1,3-dicyanobenzene'),
    (SELECT id from literature WHERE bibtexkey='2229'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4,5,6-tetrachloro-1,3-dicyanobenzene'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4,5,6-tetrachloro-1,3-dicyanobenzene'),
    (SELECT id from literature WHERE bibtexkey='macbean2012'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='2,4,5,6-tetrachloro-1,3-dicyanobenzene'),
    (SELECT id from literature WHERE bibtexkey='3073'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5,6-tetrachloro-1,3-dicyanobenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5,6-tetrachloro-1,3-dicyanobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5,6-tetrachloro-1,3-dicyanobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5,6-tetrachloro-1,3-dicyanobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5,6-tetrachloro-1,3-dicyanobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5,6-tetrachloro-1,3-dicyanobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5,6-tetrachloro-1,3-dicyanobenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5,6-tetrachloro-1,3-dicyanobenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5,6-tetrachloro-1,3-dicyanobenzene'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,4,5,6-tetrachloro-1,3-dicyanobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-chlorobenzalmalononitrile',
    'C<sub>10</sub>H<sub>5</sub>ClN<sub>2</sub>',
    '',
    '2698-41-1',
    'JJNZXLAFIPKXIG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chlorobenzalmalononitrile'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benzyltrimethylammonium chloride',
    'C<sub>10</sub>H<sub>16</sub>ClN',
    '',
    '56-93-9',
    'KXHPPCXNWTUNSB-UHFFFAOYSA-M',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzyltrimethylammonium chloride'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chlordimeform',
    'C<sub>10</sub>H<sub>13</sub>ClN<sub>2</sub>',
    '',
    '6164-98-3',
    'STUSTWKEFDQFFZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chlordimeform'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chlordimeform'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,4''-dichloroazobenzene',
    'C<sub>12</sub>H<sub>8</sub>Cl<sub>2</sub>N<sub>2</sub>',
    '',
    '1602-00-2',
    'XHQLXCFUPJSGOE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4''-dichloroazobenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bis(3,4-dichlorophenyl)diazene',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>N<sub>2</sub>',
    '3,4,3'',4''-tetrachloroazobenzene',
    '14047-09-7',
    'SOBGIMQKWDUEPY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis(3,4-dichlorophenyl)diazene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-(p-chlorophenyl)-3-methylbutyronitrile',
    'C<sub>11</sub>H<sub>12</sub>ClN',
    '',
    '2012-81-9',
    'RBGSZIRWNWQDOK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(p-chlorophenyl)-3-methylbutyronitrile'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(p-chlorophenyl)-3-methylbutyronitrile'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(p-chlorophenyl)-3-methylbutyronitrile'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(p-chlorophenyl)-3-methylbutyronitrile'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3''-dichloro-(1,1''-biphenyl)-4,4''-diamine',
    'C<sub>12</sub>H<sub>10</sub>Cl<sub>2</sub>N<sub>2</sub>',
    '3,3''-dichlorobenzidine',
    '91-94-1',
    'HUWXDEQWWKGHRV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,3''-dichloro-(1,1''-biphenyl)-4,4''-diamine'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,3''-dichloro-(1,1''-biphenyl)-4,4''-diamine'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='3,3''-dichloro-(1,1''-biphenyl)-4,4''-diamine'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3''-dichloro-(1,1''-biphenyl)-4,4''-diamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-chloroazobenzene',
    'C<sub>12</sub>H<sub>9</sub>ClN<sub>2</sub>',
    '',
    '4340-77-6',
    'NJFDMENHTAYHMA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-chloroazobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chloroazobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,4''-methylenebis(2-chlorobenzenamine)',
    'C<sub>13</sub>H<sub>12</sub>Cl<sub>2</sub>N<sub>2</sub>',
    '',
    '101-14-4',
    'IBOFVQJTBBUKMU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4''-methylenebis(2-chlorobenzenamine)'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4''-methylenebis(2-chlorobenzenamine)'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4''-methylenebis(2-chlorobenzenamine)'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4''-methylenebis(2-chlorobenzenamine)'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4''-methylenebis(2-chlorobenzenamine)'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'clofentezine',
    'C<sub>14</sub>H<sub>8</sub>N<sub>4</sub>Cl<sub>2</sub>',
    '',
    '74115-24-5',
    'UXADOQPNKNTIHB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='clofentezine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='clofentezine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'aniline, 4,4''-(imidocarbonyl)bis-(N,N-dimethyl)-, hydrochloride',
    'C<sub>17</sub>H<sub>22</sub>ClN<sub>3</sub>',
    'auramine hydrochloride',
    '2465-27-2',
    'KSCQDDRPFHTIRL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='aniline, 4,4''-(imidocarbonyl)bis-(N,N-dimethyl)-, hydrochloride'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'amitriptyline hydrochloride',
    'C<sub>20</sub>H<sub>24</sub>ClN',
    '',
    '549-18-8',
    'KFYRPLNVJVHZGT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='amitriptyline hydrochloride'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chlorhexidine',
    'C<sub>22</sub>H<sub>30</sub>Cl<sub>2</sub>N<sub>10</sub>',
    '',
    '55-56-1',
    'GHXZTYHSJHQHIJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>24</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorhexidine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'malachite green',
    'C<sub>23</sub>H<sub>25</sub>ClN<sub>2</sub>',
    '',
    '569-64-2',
    'FDZZZRQASAIRJF-UHFFFAOYSA-M',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='malachite green'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tetradecylbenzyldimethyl ammonium chloride',
    'C<sub>23</sub>H<sub>42</sub>ClN',
    '',
    '139-08-2',
    'OCBHHZMJRVXXQK-UHFFFAOYSA-M',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetradecylbenzyldimethyl ammonium chloride'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'stearyldimethylbenzylammonium chloride',
    'C<sub>27</sub>H<sub>50</sub>ClN',
    'benzyldimethylstearylammonium chloride',
    '122-19-0',
    'SFVFIFLLYFPGHH-UHFFFAOYSA-M',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='stearyldimethylbenzylammonium chloride'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,6-trichloro-1,3,5-triazine',
    'C<sub>3</sub>Cl<sub>3</sub>N<sub>3</sub>',
    '',
    '108-77-0',
    'MGNCLNQXLYJVJD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trichloro-1,3,5-triazine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trichloro-1,3,5-triazine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trichloro-1,3,5-triazine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trichloro-1,3,5-triazine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-trichloro-1,3,5-triazine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-chloropyridine',
    'C<sub>5</sub>H<sub>4</sub>ClN',
    '',
    '109-09-1',
    'OKDGRDCXVWSXDC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;1</sup>',
    '5900',
    'M',
    (SELECT id from species WHERE iupac='2-chloropyridine'),
    (SELECT id from literature WHERE bibtexkey='2378'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2378like0917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-chloropyridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloropyridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloropyridine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloropyridine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6100',
    'Q',
    (SELECT id from species WHERE iupac='2-chloropyridine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloropyridine'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloropyridine'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-Test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloropyridine'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloropyridine'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6600',
    '?',
    (SELECT id from species WHERE iupac='2-chloropyridine'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-chloropyridine',
    'C<sub>5</sub>H<sub>4</sub>ClN',
    '',
    '626-60-8',
    'PWRBCZZQRRPXAB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '5600',
    'M',
    (SELECT id from species WHERE iupac='3-chloropyridine'),
    (SELECT id from literature WHERE bibtexkey='2378'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2378like0917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-chloropyridine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-chloropyridine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-chloropyridine'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-chloropyridine'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-chloropyridine'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,6-tetrachloropyridine',
    'C<sub>5</sub>HCl<sub>4</sub>N',
    '',
    '14121-36-9',
    'FZFNDUTVMQOPCT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,6-tetrachloropyridine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,6-tetrachloropyridine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,6-tetrachloropyridine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,6-tetrachloropyridine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,5,6-tetrachloropyridine',
    'C<sub>5</sub>HCl<sub>4</sub>N',
    '',
    '2402-79-1',
    'FATBKZJZAHWCSL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5,6-tetrachloropyridine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5,6-tetrachloropyridine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5,6-tetrachloropyridine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5,6-tetrachloropyridine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5,6-tetrachloropyridine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pentachloropyridine',
    'C<sub>5</sub>Cl<sub>5</sub>N',
    '',
    '2176-62-7',
    'DNDPLEAVNVOOQZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentachloropyridine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentachloropyridine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentachloropyridine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentachloropyridine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentachloropyridine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'desethylatrazine',
    'C<sub>6</sub>H<sub>10</sub>ClN<sub>5</sub>',
    '',
    '6190-65-4',
    'DFWFIQKMSFGDCQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='desethylatrazine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-chloro-6-(trichloromethyl)-pyridine',
    'C<sub>6</sub>H<sub>3</sub>Cl<sub>4</sub>N',
    '',
    '1929-82-4',
    'DCUJJWWUNKIJPH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-6-(trichloromethyl)-pyridine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-6-(trichloromethyl)-pyridine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-6-(trichloromethyl)-pyridine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-6-(trichloromethyl)-pyridine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-6-(trichloromethyl)-pyridine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-6-(trichloromethyl)-pyridine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,5-tetrachloro-6-methylpyridine',
    'C<sub>6</sub>H<sub>3</sub>Cl<sub>4</sub>N',
    '',
    '10469-02-0',
    'OZLPEWBQZDDFCQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,5-tetrachloro-6-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,5-tetrachloro-6-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,5-tetrachloro-6-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,5-tetrachloro-6-methylpyridine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-chloro-5-(trichloromethyl)pyridine',
    'C<sub>6</sub>H<sub>3</sub>Cl<sub>4</sub>N',
    '',
    '69045-78-9',
    'VLJIVLGVKMTBOD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-5-(trichloromethyl)pyridine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-5-(trichloromethyl)pyridine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-5-(trichloromethyl)pyridine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-5-(trichloromethyl)pyridine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dichloro-5-(trichloromethyl)pyridine',
    'C<sub>6</sub>H<sub>2</sub>Cl<sub>5</sub>N',
    '',
    '69045-83-6',
    'XVBWGQSXLITICX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dichloro-5-(trichloromethyl)pyridine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dichloro-5-(trichloromethyl)pyridine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dichloro-5-(trichloromethyl)pyridine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dichloro-5-(trichloromethyl)pyridine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5-dichloro-6-(trichloromethyl)pyridine',
    'C<sub>6</sub>H<sub>2</sub>Cl<sub>5</sub>N',
    '',
    '1817-13-6',
    'MWFCRQNUHFSUNY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dichloro-6-(trichloromethyl)pyridine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dichloro-6-(trichloromethyl)pyridine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dichloro-6-(trichloromethyl)pyridine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dichloro-6-(trichloromethyl)pyridine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4,5-trichloro-2-(trichloromethyl)pyridine',
    'C<sub>6</sub>HCl<sub>6</sub>N',
    '',
    '1201-30-5',
    'YWSFDYUMEBEQNZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,5-trichloro-2-(trichloromethyl)pyridine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,5-trichloro-2-(trichloromethyl)pyridine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,5-trichloro-2-(trichloromethyl)pyridine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,5-trichloro-2-(trichloromethyl)pyridine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,5-tetrachloro-6-(trichloromethyl)pyridine',
    'C<sub>6</sub>Cl<sub>7</sub>N',
    '',
    '1134-04-9',
    'YMBFWRZKTZICHS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,5-tetrachloro-6-(trichloromethyl)pyridine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,5-tetrachloro-6-(trichloromethyl)pyridine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,5-tetrachloro-6-(trichloromethyl)pyridine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,5-tetrachloro-6-(trichloromethyl)pyridine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4,5,6-tetrachloropyridine-2-carbonitrile',
    'C<sub>6</sub>Cl<sub>4</sub>N<sub>2</sub>',
    '',
    '17824-83-8',
    'KFPBGJYBKSQIAI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,5,6-tetrachloropyridine-2-carbonitrile'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,5,6-tetrachloropyridine-2-carbonitrile'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,5,6-tetrachloropyridine-2-carbonitrile'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,5,6-tetrachloropyridine-2-carbonitrile'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-amino-3,5,6-trichloropyridine-2-carbonitrile',
    'C<sub>6</sub>H<sub>2</sub>Cl<sub>3</sub>N<sub>3</sub>',
    '',
    '14143-60-3',
    'AZYYQVGBVUCIEO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-amino-3,5,6-trichloropyridine-2-carbonitrile'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-amino-3,5,6-trichloropyridine-2-carbonitrile'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-amino-3,5,6-trichloropyridine-2-carbonitrile'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-amino-3,5,6-trichloropyridine-2-carbonitrile'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'crimidine',
    'C<sub>7</sub>H<sub>10</sub>ClN<sub>3</sub>',
    '',
    '535-89-7',
    'HJIUPFPIEBPYIE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='crimidine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'simazine',
    'C<sub>7</sub>H<sub>12</sub>ClN<sub>5</sub>',
    '',
    '122-34-9',
    'ODCWYMIRDDJXKW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='simazine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='simazine'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='simazine'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='simazine'),
    (SELECT id from literature WHERE bibtexkey='2452'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='simazine'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>7</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='simazine'),
    (SELECT id from literature WHERE bibtexkey='1931'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='simazine'),
    (SELECT id from literature WHERE bibtexkey='1931'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='simazine'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='simazine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='simazine'),
    (SELECT id from literature WHERE bibtexkey='2526'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='simazine'),
    (SELECT id from literature WHERE bibtexkey='1931'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='simazine'),
    (SELECT id from literature WHERE bibtexkey='1931'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'desethylterbuthylazine',
    'C<sub>7</sub>H<sub>12</sub>ClN<sub>5</sub>',
    '',
    '30125-63-4',
    'LMKQNTMFZLAJDV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='desethylterbuthylazine'),
    (SELECT id from literature WHERE bibtexkey='2836'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'mepiquat chloride',
    'C<sub>7</sub>H<sub>16</sub>NCl',
    '',
    '24307-26-4',
    'VHOVSQVSAAQANU-UHFFFAOYSA-M',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>11</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='mepiquat chloride'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'atrazine',
    'C<sub>8</sub>H<sub>14</sub>ClN<sub>5</sub>',
    '',
    '1912-24-9',
    'MXWJVTOOROXGIU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='atrazine'),
    (SELECT id from literature WHERE bibtexkey='2965'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='atrazine'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='atrazine'),
    (SELECT id from literature WHERE bibtexkey='2967'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='atrazine'),
    (SELECT id from literature WHERE bibtexkey='2966'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='atrazine'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='atrazine'),
    (SELECT id from literature WHERE bibtexkey='2452'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='atrazine'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>6</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='atrazine'),
    (SELECT id from literature WHERE bibtexkey='1931'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='atrazine'),
    (SELECT id from literature WHERE bibtexkey='1931'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='atrazine'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='atrazine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='atrazine'),
    (SELECT id from literature WHERE bibtexkey='2526'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='atrazine'),
    (SELECT id from literature WHERE bibtexkey='1931'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='atrazine'),
    (SELECT id from literature WHERE bibtexkey='1931'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'clonidine',
    'C<sub>9</sub>H<sub>9</sub>Cl<sub>2</sub>N<sub>3</sub>',
    '',
    '4205-90-7',
    'GJSURZIOUXUGAL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='clonidine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cyprazine',
    'C<sub>9</sub>H<sub>12</sub>ClN<sub>5</sub>',
    '',
    '22936-86-3',
    'OOHIAOSLOGDBCE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cyprazine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyprazine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyprazine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propazine',
    'C<sub>9</sub>H<sub>16</sub>ClN<sub>5</sub>',
    '',
    '139-40-2',
    'WJNRPILHGGKWCK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propazine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='propazine'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2614_pc_problem'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propazine'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='propazine'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propazine'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propazine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propazine'),
    (SELECT id from literature WHERE bibtexkey='2526'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'sebuthylazine',
    'C<sub>9</sub>H<sub>16</sub>ClN<sub>5</sub>',
    '',
    '7286-69-3',
    'BZRUVKZGXNSXMB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='sebuthylazine'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'terbuthylazine',
    'C<sub>9</sub>H<sub>16</sub>ClN<sub>5</sub>',
    '',
    '5915-41-3',
    'FZXISNSWEXTPMF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='terbuthylazine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='terbuthylazine'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='terbuthylazine'),
    (SELECT id from literature WHERE bibtexkey='2836'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='terbuthylazine'),
    (SELECT id from literature WHERE bibtexkey='2967'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='terbuthylazine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='terbuthylazine'),
    (SELECT id from literature WHERE bibtexkey='2526'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='terbuthylazine'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cyanazine',
    'C<sub>9</sub>H<sub>13</sub>ClN<sub>6</sub>',
    '',
    '21725-46-2',
    'MZZBPDKVEFVLFF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cyanazine'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='cyanazine'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>9</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='cyanazine'),
    (SELECT id from literature WHERE bibtexkey='1931'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>6</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='cyanazine'),
    (SELECT id from literature WHERE bibtexkey='1931'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyanazine'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyanazine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyanazine'),
    (SELECT id from literature WHERE bibtexkey='2526'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyanazine'),
    (SELECT id from literature WHERE bibtexkey='1931'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyanazine'),
    (SELECT id from literature WHERE bibtexkey='1931'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'anilazine',
    'C<sub>9</sub>H<sub>5</sub>Cl<sub>3</sub>N<sub>4</sub>',
    '',
    '101-05-3',
    'IMHBYKMAHXWHRP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='anilazine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='anilazine'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='anilazine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='anilazine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='anilazine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='anilazine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='anilazine'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,7-dichloroquinoline',
    'C<sub>9</sub>H<sub>5</sub>Cl<sub>2</sub>N',
    '',
    '86-98-6',
    'HXEWMTXDBOQQKO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,7-dichloroquinoline'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,7-dichloroquinoline'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,7-dichloroquinoline'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,7-dichloroquinoline'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fenclorim',
    'C<sub>10</sub>H<sub>6</sub>Cl<sub>2</sub>N<sub>2</sub>',
    '',
    '3740-92-9',
    'NRFQZTCQAYEXEE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fenclorim'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'acetamiprid',
    'C<sub>10</sub>H<sub>11</sub>ClN<sub>4</sub>',
    '',
    '135410-20-7',
    'WCXDHFDTOYPNIE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='acetamiprid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 1.9&times;10<sup>7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='acetamiprid'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pyrimethamine',
    'C<sub>12</sub>H<sub>13</sub>ClN<sub>4</sub>',
    '',
    '58-14-0',
    'WKSAUQYGYAYLPV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pyrimethamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'penconazole',
    'C<sub>13</sub>H<sub>15</sub>Cl<sub>2</sub>N<sub>3</sub>',
    '',
    '66246-88-6',
    'WKBPZYKAUNRMKP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='penconazole'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='penconazole'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='penconazole'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='penconazole'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'myclobutanil',
    'C<sub>15</sub>H<sub>17</sub>ClN<sub>4</sub>',
    '',
    '88671-89-0',
    'HZJKXKUJVSEEFU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='myclobutanil'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='myclobutanil'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='myclobutanil'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='myclobutanil'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-chloro-4,6-bis(2,4-dimethylphenyl)-1,3,5-triazine',
    'C<sub>19</sub>H<sub>18</sub>N<sub>3</sub>Cl',
    '',
    '1237-53-2',
    'LVWOBZPDFCTAOU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-4,6-bis(2,4-dimethylphenyl)-1,3,5-triazine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-4,6-bis(2,4-dimethylphenyl)-1,3,5-triazine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-4,6-bis(2,4-dimethylphenyl)-1,3,5-triazine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-4,6-bis(2,4-dimethylphenyl)-1,3,5-triazine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fenbuconazole',
    'C<sub>19</sub>H<sub>17</sub>ClN<sub>4</sub>',
    '',
    '114369-43-6',
    'RQDJADAKIFFEKQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fenbuconazole'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'trichloronitromethane',
    'CCl<sub>3</sub>NO<sub>2</sub>',
    'chloropicrin',
    '76-06-2',
    'LFHISGNCFUNFFM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='trichloronitromethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='trichloronitromethane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='trichloronitromethane'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trichloronitromethane'),
    (SELECT id from literature WHERE bibtexkey='2804'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trichloronitromethane'),
    (SELECT id from literature WHERE bibtexkey='3646'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trichloronitromethane'),
    (SELECT id from literature WHERE bibtexkey='2229'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='trichloronitromethane'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2614_pc_problem'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='trichloronitromethane'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloronitromethane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloronitromethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloronitromethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloronitromethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloronitromethane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloronitromethane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='trichloronitromethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phosgene oxime',
    'CHCl<sub>2</sub>NO',
    '',
    '1794-86-1',
    'JIRJHEXNDQBKRZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phosgene oxime'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1-dichloro-1-nitroethane',
    'C<sub>2</sub>H<sub>3</sub>Cl<sub>2</sub>NO<sub>2</sub>',
    '',
    '594-72-9',
    'OQOGEOLRYAOSKO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1-dichloro-1-nitroethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichloro-1-nitroethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichloro-1-nitroethane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichloro-1-nitroethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichloro-1-nitroethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-chloroacetamide',
    'C<sub>2</sub>H<sub>4</sub>ClNO',
    '',
    '79-07-2',
    'VXIVSQZSERGHQP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloroacetamide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CCL3PAN',
    'C<sub>2</sub>NO<sub>5</sub>Cl<sub>3</sub>',
    '',
    '',
    'LLOMRHYBAIQQGH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CCL3PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CCL3PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CCL3PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CCLNO3COOH',
    'C<sub>2</sub>H<sub>4</sub>NO<sub>5</sub>Cl',
    '',
    '',
    'GVGGZHVOOFUNFY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CCLNO3COOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CCLNO3COOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CCLNO3COOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CHCL2PAN',
    'C<sub>2</sub>HNO<sub>5</sub>Cl<sub>2</sub>',
    '',
    '',
    'BORKLXDOXKHVRO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHCL2PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHCL2PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CHCL2PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CLETPAN',
    'C<sub>2</sub>H<sub>2</sub>NO<sub>5</sub>Cl',
    '',
    '',
    'IEQWXJNETVFAEB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CLETPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CLETPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CLETPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CNO3CLOOH',
    'C<sub>2</sub>H<sub>4</sub>NO<sub>5</sub>Cl',
    '',
    '',
    'FBIXZLOOAAICML-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CNO3CLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CNO3CLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CNO3CLOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CCLNO3COH',
    'C<sub>2</sub>H<sub>4</sub>NO<sub>4</sub>Cl',
    '',
    '',
    'PMLDKFZZOPGPNK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CCLNO3COH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CCLNO3COH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CCLNO3COH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CL2OHPAN',
    'C<sub>2</sub>HNO<sub>6</sub>Cl<sub>2</sub>',
    '',
    '',
    'YJZUCQDIDXVPNP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CL2OHPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CL2OHPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CL2OHPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CLOHPAN',
    'C<sub>2</sub>H<sub>2</sub>NO<sub>6</sub>Cl',
    '',
    '',
    'ZNYKQWDXHYNGTP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CLOHPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CLOHPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CLOHPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-chloro-1-nitroethane',
    'C<sub>2</sub>H<sub>4</sub>ClNO<sub>2</sub>',
    '',
    '598-92-5',
    'LPIWIOBGUAPNQW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-chloro-1-nitroethane'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CNO3CLOH',
    'C<sub>2</sub>H<sub>4</sub>NO<sub>4</sub>Cl',
    '',
    '',
    'OUFVLIWCNZOATK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CNO3CLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CNO3CLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CNO3CLOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CCLCONO3',
    'C<sub>2</sub>H<sub>2</sub>NO<sub>4</sub>Cl',
    '',
    '',
    'XDEFPIDZLAIVCM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CCLCONO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CCLCONO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CCLCONO3'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CNO3OCL',
    'C<sub>2</sub>H<sub>2</sub>NO<sub>4</sub>Cl',
    '',
    '',
    'ODQFUUDIEKKDDJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CNO3OCL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CNO3OCL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CNO3OCL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'symclosene',
    'C<sub>3</sub>Cl<sub>3</sub>N<sub>3</sub>O<sub>3</sub>',
    'trichloroisocyanuric acid',
    '87-90-1',
    'YRIZYWQGELRKNT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='symclosene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CL12PAN',
    'C<sub>3</sub>H<sub>3</sub>NO<sub>5</sub>Cl<sub>2</sub>',
    '',
    '',
    'MSMFQRZPTBDNBF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CL12PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CL12PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CL12PAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-chloro-1-nitropropane',
    'C<sub>3</sub>H<sub>6</sub>ClNO<sub>2</sub>',
    '',
    '600-25-9',
    'XEKUXTMJEFPWCG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-chloro-1-nitropropane'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3-dichloro-5,5-dimethylhydantoin',
    'C<sub>5</sub>H<sub>6</sub>Cl<sub>2</sub>N<sub>2</sub>O<sub>2</sub>',
    '',
    '118-52-5',
    'KEQGZUUPPQEDPF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichloro-5,5-dimethylhydantoin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'carmustine',
    'C<sub>5</sub>H<sub>9</sub>Cl<sub>2</sub>N<sub>3</sub>O<sub>2</sub>',
    '',
    '154-93-8',
    'DLGOEMSEDOSKAD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='carmustine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-chloro-N,N-di-2-propenylacetamide',
    'C<sub>8</sub>H<sub>12</sub>ClNO',
    '',
    '93-71-0',
    'MDBGGTQNNUOQRC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-chloro-N,N-di-2-propenylacetamide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-chloro-N,N-di-2-propenylacetamide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-N,N-di-2-propenylacetamide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-N,N-di-2-propenylacetamide'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-N,N-di-2-propenylacetamide'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dichloro-N,N-di-2-propenylacetamide',
    'C<sub>8</sub>H<sub>11</sub>Cl<sub>2</sub>NO',
    'dichlormid',
    '37764-25-3',
    'YRMLFORXOOIJDR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dichloro-N,N-di-2-propenylacetamide'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dichloro-N,N-di-2-propenylacetamide'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'lomustine',
    'C<sub>9</sub>H<sub>16</sub>ClN<sub>3</sub>O<sub>2</sub>',
    '',
    '13010-47-4',
    'GQYIWUVLTXOXAJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='lomustine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'semustine',
    'C<sub>10</sub>H<sub>18</sub>ClN<sub>3</sub>O<sub>2</sub>',
    '',
    '13909-09-6',
    'FVLVBPDQNARYJU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='semustine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'furilazole',
    'C<sub>11</sub>H<sub>13</sub>Cl<sub>2</sub>NO<sub>3</sub>',
    '',
    '121776-33-8',
    'MCNOFYBITGAAGM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='furilazole'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='furilazole'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimethazone',
    'C<sub>12</sub>H<sub>14</sub>ClNO<sub>2</sub>',
    'clomazone',
    '81777-89-1',
    'KIEDNEWSYUYDSN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dimethazone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dimethazone'),
    (SELECT id from literature WHERE bibtexkey='macbean2012'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethazone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dimethazone'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-chloronitrobenzene',
    'C<sub>6</sub>H<sub>4</sub>ClNO<sub>2</sub>',
    'o-chloronitrobenzene',
    '88-73-3',
    'BFCFYVKQTRLZHA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-chloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-chloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2448'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-chloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4700',
    'Q',
    (SELECT id from species WHERE iupac='2-chloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-chloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6000',
    '?',
    (SELECT id from species WHERE iupac='2-chloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-chloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-chloronitrobenzene',
    'C<sub>6</sub>H<sub>4</sub>ClNO<sub>2</sub>',
    'm-chloronitrobenzene',
    '121-73-3',
    'KMAQZIILEGKYQZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'M',
    (SELECT id from species WHERE iupac='3-chloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3-chloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-chloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2165'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-chloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-chloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-chloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-chloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-chloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-chloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-chloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-chloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-chloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-chloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-chloronitrobenzene',
    'C<sub>6</sub>H<sub>4</sub>ClNO<sub>2</sub>',
    'p-chloronitrobenzene',
    '100-00-5',
    'CZGCEKJOLUNIFY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;1</sup>',
    '5900',
    'L',
    (SELECT id from species WHERE iupac='4-chloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'M',
    (SELECT id from species WHERE iupac='4-chloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'M',
    (SELECT id from species WHERE iupac='4-chloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='4-chloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2448'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-chloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4700',
    'Q',
    (SELECT id from species WHERE iupac='4-chloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-chloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4000',
    '?',
    (SELECT id from species WHERE iupac='4-chloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-dichloro-4-nitrobenzene',
    'C<sub>6</sub>H<sub>3</sub>Cl<sub>2</sub>NO<sub>2</sub>',
    '',
    '99-54-7',
    'NTBYINQTYWZXLH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichloro-4-nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloro-4-nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloro-4-nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloro-4-nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloro-4-nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloro-4-nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloro-4-nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloro-4-nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloro-4-nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloro-4-nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-dichloro-4-nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4-dichloro-2-nitrobenzene',
    'C<sub>6</sub>H<sub>3</sub>Cl<sub>2</sub>NO<sub>2</sub>',
    '',
    '89-61-2',
    'RZKKOBGFCAHLCZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,4-dichloro-2-nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dichloro-2-nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dichloro-2-nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dichloro-2-nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dichloro-2-nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dichloro-2-nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dichloro-2-nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dichloro-2-nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dichloro-2-nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dichloro-2-nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,4-dichloro-2-nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dichloronitrobenzene',
    'C<sub>6</sub>H<sub>3</sub>Cl<sub>2</sub>NO<sub>2</sub>',
    '',
    '3209-22-1',
    'CMVQZRLQEOAYSW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dichloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dichloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dichloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dichloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dichloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dichloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dichloronitrobenzene',
    'C<sub>6</sub>H<sub>3</sub>Cl<sub>2</sub>NO<sub>2</sub>',
    '',
    '611-06-3',
    'QUIMTLZDMCNYGY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dichloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dichloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dichloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dichloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dichloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,5-dichloronitrobenzene',
    'C<sub>6</sub>H<sub>3</sub>Cl<sub>2</sub>NO<sub>2</sub>',
    '',
    '618-62-2',
    'RNABGKOKSBUFHW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dichloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dichloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dichloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dichloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pentachloronitrobenzene',
    'C<sub>6</sub>Cl<sub>5</sub>NO<sub>2</sub>',
    'quintozene',
    '82-68-8',
    'LKPLKUMXSAEKID-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    'M',
    (SELECT id from species WHERE iupac='pentachloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2229'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pentachloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pentachloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pentachloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='pentachloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='howard97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentachloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentachloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentachloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentachloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentachloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentachloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentachloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-chloro-2-nitrophenol',
    'C<sub>6</sub>H<sub>4</sub>ClNO<sub>3</sub>',
    '',
    '89-64-5',
    'NWSIFTLPLKCTSX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-chloro-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-chloro-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='941'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chloro-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chloro-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chloro-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-chloro-4-nitrobenzenamine',
    'C<sub>6</sub>H<sub>5</sub>ClN<sub>2</sub>O<sub>2</sub>',
    '',
    '121-87-9',
    'LOCWBQIWHWIRGN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-chloro-4-nitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-4-nitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-4-nitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-4-nitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-4-nitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-4-nitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-4-nitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-4-nitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-4-nitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-chloro-4-nitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-chloro-5-nitrobenzenamine',
    'C<sub>6</sub>H<sub>5</sub>ClN<sub>2</sub>O<sub>2</sub>',
    '',
    '6283-25-6',
    'KWIXNFOTNVKIGM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-5-nitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-chloro-2,6-dinitrobenzenamine',
    'C<sub>6</sub>H<sub>4</sub>ClN<sub>3</sub>O<sub>4</sub>',
    '',
    '5388-62-5',
    'CLMQUEQFVUMDPC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chloro-2,6-dinitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-chloro-2,4-dinitrobenzene',
    'C<sub>6</sub>H<sub>3</sub>ClN<sub>2</sub>O<sub>4</sub>',
    '',
    '97-00-7',
    'VYZAHLCBVHPDDF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-chloro-2,4-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-chloro-2,4-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-chloro-2,4-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-2,4-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-2,4-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-2,4-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-2,4-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-2,4-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-2,4-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-chloro-2,6-dinitrobenzene',
    'C<sub>6</sub>H<sub>3</sub>ClN<sub>2</sub>O<sub>4</sub>',
    '',
    '606-21-3',
    'BPPMIQPXQVIZNJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-2,6-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-2,6-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-2,6-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-2,6-dinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-chloro-1,3,5-trinitrobenzene',
    'C<sub>6</sub>H<sub>2</sub>ClN<sub>3</sub>O<sub>6</sub>',
    '',
    '88-88-0',
    'HJRJRUMKQCMYDL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-1,3,5-trinitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4-trichloronitrobenzene',
    'C<sub>6</sub>H<sub>2</sub>Cl<sub>3</sub>NO<sub>2</sub>',
    '',
    '17700-09-3',
    'BGKIECJVXXHLDP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trichloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trichloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trichloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trichloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,5-tetrachloronitrobenzene',
    'C<sub>6</sub>HCl<sub>4</sub>NO<sub>2</sub>',
    '',
    '879-39-0',
    'MTBYTWZDRVOMBR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,5-tetrachloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4,5-tetrachloronitrobenzene',
    'C<sub>6</sub>HCl<sub>4</sub>NO<sub>2</sub>',
    'tecnazene',
    '117-18-0',
    'XQTLDIFVVHJORV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,5-tetrachloronitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-chloro-2-nitrobenzenamine',
    'C<sub>6</sub>H<sub>5</sub>ClN<sub>2</sub>O<sub>2</sub>',
    '',
    '89-63-4',
    'PBGKNXWGYQPUJK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chloro-2-nitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chloro-2-nitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chloro-2-nitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chloro-2-nitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chloro-2-nitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-chloro-3-nitrobenzenamine',
    'C<sub>6</sub>H<sub>5</sub>ClN<sub>2</sub>O<sub>2</sub>',
    '',
    '635-22-3',
    'FOHHWGVAOVDVLP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chloro-3-nitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chloro-3-nitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chloro-3-nitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chloro-3-nitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chloro-3-nitrobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'botran',
    'C<sub>6</sub>H<sub>4</sub>Cl<sub>2</sub>N<sub>2</sub>O<sub>2</sub>',
    '',
    '99-30-9',
    'BIXZHMJUSMUDOQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='botran'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='botran'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='botran'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='botran'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='botran'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,5-dichlorophenyl isocyanate',
    'C<sub>7</sub>H<sub>3</sub>Cl<sub>2</sub>NO',
    '',
    '34893-92-0',
    'XEFUJGURFLOFAN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dichlorophenyl isocyanate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dichlorophenyl isocyanate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dichlorophenyl isocyanate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dichlorophenyl isocyanate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-chloro-5-nitrobenzoic acid',
    'C<sub>7</sub>H<sub>4</sub>ClNO<sub>4</sub>',
    '',
    '2516-96-3',
    'QUEKGYQTRJVEQC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-5-nitrobenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-chloro-3-nitrobenzoic acid',
    'C<sub>7</sub>H<sub>4</sub>ClNO<sub>4</sub>',
    '',
    '96-99-1',
    'DFXQXFGFOLXAPO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chloro-3-nitrobenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chloro-3-nitrobenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chloro-3-nitrobenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chloro-3-nitrobenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chloro-3-nitrobenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-chloro-4-isocyanatobenzene',
    'C<sub>7</sub>H<sub>4</sub>ClNO',
    '',
    '104-12-1',
    'ADAKRBAJFHTIEW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-4-isocyanatobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-4-isocyanatobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-4-isocyanatobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-4-isocyanatobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-dichloro-4-isocyanatobenzene',
    'C<sub>7</sub>H<sub>3</sub>Cl<sub>2</sub>NO',
    '',
    '102-36-3',
    'MFUVCHZWGSJKEQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloro-4-isocyanatobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloro-4-isocyanatobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloro-4-isocyanatobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloro-4-isocyanatobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-chloro-1-methyl-4-nitrobenzene',
    'C<sub>7</sub>H<sub>6</sub>ClNO<sub>2</sub>',
    '',
    '121-86-8',
    'LLYXJBROWQDVMI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-1-methyl-4-nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-1-methyl-4-nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-1-methyl-4-nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-1-methyl-4-nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-1-methyl-4-nitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dichloro-3-methyl-6-nitrophenol',
    'C<sub>7</sub>H<sub>5</sub>Cl<sub>2</sub>NO<sub>3</sub>',
    '',
    '39549-27-4',
    'VMBRJHMTAZXHES-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dichloro-3-methyl-6-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dichloro-3-methyl-6-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dichloro-3-methyl-6-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dichloro-3-methyl-6-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-chloro-5-methyl-2-nitrophenol',
    'C<sub>7</sub>H<sub>6</sub>ClNO<sub>3</sub>',
    '4-chloro-6-nitro-m-cresol',
    '7147-89-9',
    'JBMGJOKJUYGIJH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-chloro-5-methyl-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='941'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-amino-2,5-dichlorobenzoic acid',
    'C<sub>7</sub>H<sub>5</sub>Cl<sub>2</sub>NO<sub>2</sub>',
    '',
    '133-90-4',
    'HSSBORCLYSCBJR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-amino-2,5-dichlorobenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-amino-2,5-dichlorobenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-amino-2,5-dichlorobenzoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,5,6-tetrachloro-4-nitroanisole',
    'C<sub>7</sub>H<sub>3</sub>Cl<sub>4</sub>NO<sub>3</sub>',
    'TCNA',
    '2438-88-2',
    'BGPPUXMKKQMWLV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5,6-tetrachloro-4-nitroanisole'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6-dichlorobenzamide',
    'C<sub>7</sub>H<sub>5</sub>Cl<sub>2</sub>NO',
    '',
    '2008-58-4',
    'JHSPCUHPSIUQRB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dichlorobenzamide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'swep',
    'C<sub>8</sub>H<sub>7</sub>Cl<sub>2</sub>NO',
    '',
    '1918-18-9',
    'WOZQBERUBLYCEG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='swep'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-(4-chlorophenyl)acetamide',
    'C<sub>8</sub>H<sub>8</sub>ClNO',
    'p-chloroacetanilide',
    '539-03-7',
    'GGUOCFNAWIODMF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-(4-chlorophenyl)acetamide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl 5-chloro-2-nitrobenzoate',
    'C<sub>8</sub>H<sub>6</sub>ClNO<sub>4</sub>',
    '',
    '51282-49-6',
    'JGBJHRKCUKTQOE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl 5-chloro-2-nitrobenzoate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl 5-chloro-2-nitrobenzoate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl 5-chloro-2-nitrobenzoate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl 5-chloro-2-nitrobenzoate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-chloro-2,5-dimethoxynitrobenzene',
    'C<sub>8</sub>H<sub>8</sub>ClNO<sub>4</sub>',
    '',
    '6940-53-0',
    'ORLPGMKKCAEWOW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chloro-2,5-dimethoxynitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chloro-2,5-dimethoxynitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chloro-2,5-dimethoxynitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chloro-2,5-dimethoxynitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chloraniformethan',
    'C<sub>9</sub>H<sub>7</sub>Cl<sub>5</sub>N<sub>2</sub>O',
    '',
    '20856-57-9',
    'REEFSLKDEDEWAO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 2.3&times;10<sup>10</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chloraniformethan'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'monuron',
    'C<sub>9</sub>H<sub>11</sub>ClN<sub>2</sub>O',
    '',
    '150-68-5',
    'BMLIZLVNXIYGCK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='monuron'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='monuron'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='monuron'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='monuron'),
    (SELECT id from literature WHERE bibtexkey='2968'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='monuron'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='monuron'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'monolinuron',
    'C<sub>9</sub>H<sub>11</sub>ClN<sub>2</sub>O<sub>2</sub>',
    '',
    '1746-81-2',
    'LKJPSUCKSLORMF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='monolinuron'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='monolinuron'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diuron',
    'C<sub>9</sub>H<sub>10</sub>Cl<sub>2</sub>N<sub>2</sub>O',
    '',
    '330-54-1',
    'XMTQQYYKAHVGBJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='diuron'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diuron'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='diuron'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2614_pc_problem'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diuron'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2',
    '',
    'X',
    (SELECT id from species WHERE iupac='diuron'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diuron'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diuron'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'linuron',
    'C<sub>9</sub>H<sub>10</sub>Cl<sub>2</sub>N<sub>2</sub>O<sub>2</sub>',
    '',
    '330-55-2',
    'XKJMBINCVNINCA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='linuron'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='linuron'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2614_pc_problem'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='linuron'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='linuron'),
    (SELECT id from literature WHERE bibtexkey='macbean2012'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'X',
    (SELECT id from species WHERE iupac='linuron'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='linuron'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='linuron'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_test'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propanil',
    'C<sub>9</sub>H<sub>9</sub>Cl<sub>2</sub>NO',
    '',
    '709-98-8',
    'LFULEKSKNZEWOE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='propanil'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propanil'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propanil'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propanil'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propanil'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    'X',
    (SELECT id from species WHERE iupac='propanil'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanil'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanil'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanil'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanil'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanil'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanil'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_test'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methazole',
    'C<sub>9</sub>H<sub>6</sub>Cl<sub>2</sub>N<sub>2</sub>O<sub>3</sub>',
    '',
    '20354-26-1',
    'LRUUNMYPIBZBQH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methazole'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methazole'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methazole'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4-naphthalenedione, 2-amino-3-chloro-',
    'C<sub>10</sub>H<sub>6</sub>ClNO<sub>2</sub>',
    'quinoclamine',
    '2797-51-5',
    'OBLNWSCLAYSJJR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,4-naphthalenedione, 2-amino-3-chloro-'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chlortoluron',
    'C<sub>10</sub>H<sub>13</sub>ClN<sub>2</sub>O',
    'chlorotoluron',
    '15545-48-9',
    'JXCGFZXSOMJFOA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chlortoluron'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chlortoluron'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='chlortoluron'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlortoluron'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_test'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'metoxuron',
    'C<sub>10</sub>H<sub>13</sub>ClN<sub>2</sub>O<sub>2</sub>',
    '',
    '19937-59-8',
    'DSRNRYQBBJQVCW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='metoxuron'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='metoxuron'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6',
    '',
    'X',
    (SELECT id from species WHERE iupac='metoxuron'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='metoxuron'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='metoxuron'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chlorpropham',
    'C<sub>10</sub>H<sub>12</sub>ClNO<sub>2</sub>',
    '',
    '101-21-3',
    'CWJSHJJYOPWUGX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='chlorpropham'),
    (SELECT id from literature WHERE bibtexkey='2538'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chlorpropham'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chlorpropham'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='chlorpropham'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2614_pc_problem'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chlorpropham'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='chlorpropham'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorpropham'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorpropham'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_test'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pyrazon',
    'C<sub>10</sub>H<sub>8</sub>ClN<sub>3</sub>O',
    '',
    '1698-60-8',
    'WYKYKTKDBLFHCY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pyrazon'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pyrazon'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pyrazon'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pyrazon'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pyrazon'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>9</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pyrazon'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-D dimethylamine',
    'C<sub>10</sub>H<sub>13</sub>Cl<sub>2</sub>NO<sub>3</sub>',
    '(2,4-dichlorophenoxy)acetic acid dimethylamine',
    '2008-39-1',
    'IUQJDHJVPLLKFL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>10</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4-D dimethylamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-D dimethylamine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-D dimethylamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3'',4''-dichlorocyclopropanecarboxanilide',
    'C<sub>10</sub>H<sub>9</sub>Cl<sub>2</sub>NO',
    'cypromid',
    '2759-71-9',
    'PLQDLOBGKJCDSZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3'',4''-dichlorocyclopropanecarboxanilide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'triazoxide',
    'C<sub>10</sub>H<sub>6</sub>N<sub>5</sub>OCl',
    '',
    '72459-58-6',
    'IQGKIPDJXCAMSM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='triazoxide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triazoxide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chlorbufam',
    'C<sub>11</sub>H<sub>10</sub>ClNO<sub>2</sub>',
    '',
    '1967-16-4',
    'ULBXWWGWDPVHAO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chlorbufam'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chlorbufam'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'zarilamid',
    'C<sub>11</sub>H<sub>11</sub>N<sub>2</sub>O<sub>2</sub>Cl',
    '',
    '84527-51-5',
    'VLBZAQJMGULJIU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='zarilamid'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chloramphenicol',
    'C<sub>11</sub>H<sub>12</sub>Cl<sub>2</sub>N<sub>2</sub>O<sub>5</sub>',
    '',
    '56-75-7',
    'WIIZWVCIJKGZOK-IUCAKERBSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>12</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloramphenicol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cloethocarb',
    'C<sub>11</sub>H<sub>14</sub>ClNO<sub>4</sub>',
    '',
    '51487-69-5',
    'PITWUHDDNUVBPT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cloethocarb'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'formetanate hydrochloride',
    'C<sub>11</sub>H<sub>16</sub>ClN<sub>3</sub>O<sub>2</sub>',
    '',
    '23422-53-9',
    'MYPKGPZHHQEODQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>13</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='formetanate hydrochloride'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>9</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='formetanate hydrochloride'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cyclanilide',
    'C<sub>11</sub>H<sub>9</sub>Cl<sub>2</sub>NO<sub>3</sub>',
    '',
    '113136-77-9',
    'GLWWLNJJJCTFMZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='cyclanilide'),
    (SELECT id from literature WHERE bibtexkey='macbean2012'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclanilide'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclanilide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cyclanilide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propachlor',
    'C<sub>11</sub>H<sub>14</sub>ClNO',
    '',
    '1918-16-7',
    'MFOUDYKPLGXPGO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propachlor'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propachlor'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propachlor'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='propachlor'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propachlor'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'barban',
    'C<sub>11</sub>H<sub>9</sub>Cl<sub>2</sub>NO<sub>2</sub>',
    '',
    '101-27-9',
    'MCOQHIWZJUDQIC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='barban'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='barban'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='barban'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='barban'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='barban'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'aclonifen',
    'C<sub>12</sub>H<sub>9</sub>ClN<sub>2</sub>O<sub>3</sub>',
    '',
    '74070-46-5',
    'DDBMQDADIHOWIC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='aclonifen'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='aclonifen'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='aclonifen'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propyzamide',
    'C<sub>12</sub>H<sub>11</sub>Cl<sub>2</sub>NO',
    'pronamide',
    '23950-58-5',
    'PHNUZKMIPFFYSO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propyzamide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2',
    '',
    'V',
    (SELECT id from species WHERE iupac='propyzamide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='propyzamide'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyzamide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyzamide'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>8</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propyzamide'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='propyzamide'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2614_23950-58-5',
    '2614', 'Although pronamide and propyzamide are the same species, Mackay et&nbsp;al. (2006d) list two different values for them. It is unclear which number is correct (if any), and the data are not reproduced here.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2614_23950-58-5'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,6-trichlorophenyl 4-nitrophenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>3</sub>NO<sub>3</sub>',
    'chlornitrofen',
    '1836-77-7',
    'XQNAUQUKWRBODG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 8.1',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,4,6-trichlorophenyl 4-nitrophenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2229'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nitrofen',
    'C<sub>12</sub>H<sub>7</sub>Cl<sub>2</sub>NO<sub>3</sub>',
    '',
    '1836-75-5',
    'XITQUSLLOSKDTB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3',
    '',
    'V',
    (SELECT id from species WHERE iupac='nitrofen'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nitrofen'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nitrofen'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nitrofen'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nitrofen'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'buturon',
    'C<sub>12</sub>H<sub>13</sub>ClN<sub>2</sub>O',
    '',
    '3766-60-7',
    'BYYMILHAKOURNM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='buturon'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'triclocarban',
    'C<sub>13</sub>H<sub>9</sub>Cl<sub>3</sub>N<sub>2</sub>O',
    '',
    '101-20-2',
    'ICUTUKXCWQYESQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triclocarban'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triclocarban'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triclocarban'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triclocarban'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triclocarban'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimethachlor',
    'C<sub>13</sub>H<sub>18</sub>ClNO<sub>2</sub>',
    '',
    '50563-36-5',
    'SCCDDNKJYDZXMM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dimethachlor'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,5-dichloro-N-(3,4-dichlorophenyl)-2-hydroxybenzamide',
    'C<sub>13</sub>H<sub>7</sub>Cl<sub>4</sub>NO<sub>2</sub>',
    '',
    '1154-59-2',
    'SJQBHPJLLIJASD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dichloro-N-(3,4-dichlorophenyl)-2-hydroxybenzamide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dichloro-N-(3,4-dichlorophenyl)-2-hydroxybenzamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dichloro-N-(3,4-dichlorophenyl)-2-hydroxybenzamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dichloro-N-(3,4-dichlorophenyl)-2-hydroxybenzamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dichloro-N-(3,4-dichlorophenyl)-2-hydroxybenzamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'procymidone',
    'C<sub>13</sub>H<sub>11</sub>Cl<sub>2</sub>NO<sub>2</sub>',
    '',
    '32809-16-8',
    'QXJKBPAVAHBARF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='procymidone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='procymidone'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='procymidone'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='procymidone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='procymidone'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'melphalan',
    'C<sub>13</sub>H<sub>18</sub>Cl<sub>2</sub>N<sub>2</sub>O<sub>2</sub>',
    '',
    '148-82-3',
    'SGDBTWWWUNNDEQ-LBPRGKRZSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='melphalan'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'niclosamide',
    'C<sub>13</sub>H<sub>8</sub>Cl<sub>2</sub>N<sub>2</sub>O<sub>4</sub>',
    '',
    '50-65-7',
    'RJMUSRYZPJIFPJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='niclosamide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'iprodione',
    'C<sub>13</sub>H<sub>13</sub>Cl<sub>2</sub>N<sub>3</sub>O<sub>3</sub>',
    '',
    '36734-19-7',
    'ONUFESLQCSAYKA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='iprodione'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='iprodione'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='iprodione'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='iprodione'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='iprodione'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'zoxamide',
    'C<sub>14</sub>H<sub>16</sub>Cl<sub>3</sub>NO<sub>2</sub>',
    '',
    '156052-68-5',
    'SOUGWDPPRBKJEX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='zoxamide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 1.5&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='zoxamide'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fenhexamid',
    'C<sub>14</sub>H<sub>17</sub>Cl<sub>2</sub>NO<sub>2</sub>',
    '',
    '126833-17-8',
    'VDLGAVXLJYLFDH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='fenhexamid'),
    (SELECT id from literature WHERE bibtexkey='macbean2012'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fenhexamid'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH7'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fenhexamid'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH9'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fenhexamid'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH5'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chlorambucil',
    'C<sub>14</sub>H<sub>19</sub>Cl<sub>2</sub>NO<sub>2</sub>',
    '',
    '305-03-3',
    'JCKYGMPEJWAADB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorambucil'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-chloro-N-(ethoxymethyl)-N-(2-ethyl-6-methylphenyl)acetamide',
    'C<sub>14</sub>H<sub>20</sub>ClNO<sub>2</sub>',
    'acetochlor',
    '34256-82-1',
    'VTNQPKFIQCLBDU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-chloro-N-(ethoxymethyl)-N-(2-ethyl-6-methylphenyl)acetamide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'alachlor',
    'C<sub>14</sub>H<sub>20</sub>ClNO<sub>2</sub>',
    '',
    '15972-60-8',
    'XCSGPAVHZFQHGE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='alachlor'),
    (SELECT id from literature WHERE bibtexkey='2965'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='alachlor'),
    (SELECT id from literature WHERE bibtexkey='2965'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='LDV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4',
    '',
    'M',
    (SELECT id from species WHERE iupac='alachlor'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '9200',
    'M',
    (SELECT id from species WHERE iupac='alachlor'),
    (SELECT id from literature WHERE bibtexkey='2438'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='alachlor'),
    (SELECT id from literature WHERE bibtexkey='901'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at296K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='alachlor'),
    (SELECT id from literature WHERE bibtexkey='900'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at296K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='alachlor'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='alachlor'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='alachlor'),
    (SELECT id from literature WHERE bibtexkey='2452'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'X',
    (SELECT id from species WHERE iupac='alachlor'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='alachlor'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='alachlor'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='alachlor'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '11000',
    'Q',
    (SELECT id from species WHERE iupac='alachlor'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='alachlor'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '9300',
    '?',
    (SELECT id from species WHERE iupac='alachlor'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='alachlor'),
    (SELECT id from literature WHERE bibtexkey='3076'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bifenox',
    'C<sub>14</sub>H<sub>9</sub>Cl<sub>2</sub>NO<sub>3</sub>',
    '',
    '42576-02-3',
    'SUSRORUBZHMPCO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bifenox'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7',
    '',
    'V',
    (SELECT id from species WHERE iupac='bifenox'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2',
    '',
    'V',
    (SELECT id from species WHERE iupac='bifenox'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='bifenox'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bifenox'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bifenox'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&lt; 6.2&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='bifenox'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'S-metolachlor',
    'C<sub>15</sub>H<sub>22</sub>ClNO<sub>2</sub>',
    '',
    '87392-12-9',
    'WVQBLGZPHOPPFO-LBPRGKRZSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='S-metolachlor'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'metolachlor',
    'C<sub>15</sub>H<sub>22</sub>ClNO<sub>2</sub>',
    '',
    '51218-45-2',
    'WVQBLGZPHOPPFO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='metolachlor'),
    (SELECT id from literature WHERE bibtexkey='2965'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='metolachlor'),
    (SELECT id from literature WHERE bibtexkey='2965'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='LDV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>2</sup>',
    '15000',
    'L',
    (SELECT id from species WHERE iupac='metolachlor'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>2</sup>',
    '10000',
    'M',
    (SELECT id from species WHERE iupac='metolachlor'),
    (SELECT id from literature WHERE bibtexkey='2818'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='metolachlor'),
    (SELECT id from literature WHERE bibtexkey='893'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>2</sup>',
    '15000',
    'M',
    (SELECT id from species WHERE iupac='metolachlor'),
    (SELECT id from literature WHERE bibtexkey='3947'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3947',
    '', 'The value at 20&nbsp;<sup>&#176;</sup>C was calculated from published values of vapor pressure and water solubility. Data between 25&nbsp;<sup>&#176;</sup>C and 40&nbsp;<sup>&#176;</sup>C were calculated from the measured evaporation rate.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3947'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='metolachlor'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='metolachlor'),
    (SELECT id from literature WHERE bibtexkey='2836'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='metolachlor'),
    (SELECT id from literature WHERE bibtexkey='2452'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='metolachlor'),
    (SELECT id from literature WHERE bibtexkey='2968'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='metolachlor'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='metolachlor'),
    (SELECT id from literature WHERE bibtexkey='893'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='metolachlor'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='metolachlor'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='metolachlor'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '12000',
    'Q',
    (SELECT id from species WHERE iupac='metolachlor'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '10000',
    '?',
    (SELECT id from species WHERE iupac='metolachlor'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='metolachlor'),
    (SELECT id from literature WHERE bibtexkey='3076'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'clonitralid',
    'C<sub>15</sub>H<sub>15</sub>Cl<sub>2</sub>N<sub>3</sub>O<sub>5</sub>',
    '',
    '1420-04-8',
    'XYCDHXSQODHSLG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 2.6&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='clonitralid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chloroxuron',
    'C<sub>15</sub>H<sub>15</sub>ClN<sub>2</sub>O<sub>2</sub>',
    '',
    '1982-47-4',
    'IVUXTESCPZUGJC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chloroxuron'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chloroxuron'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'CGA 80000',
    'C<sub>15</sub>H<sub>18</sub>ClNO<sub>4</sub>',
    '',
    '67932-85-8',
    'FHZMAAGOSXDIBJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='CGA 80000'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'oxadiargyl',
    'C<sub>15</sub>H<sub>14</sub>N<sub>2</sub>O<sub>3</sub>Cl<sub>2</sub>',
    '',
    '39807-15-3',
    'DVOODWOZJVJKQR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='oxadiargyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='oxadiargyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diniconazole',
    'C<sub>15</sub>H<sub>17</sub>Cl<sub>2</sub>N<sub>3</sub>O',
    '',
    '83657-24-3',
    'FBOUIAKEJMZPQG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diniconazole'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diniconazole'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pethoxamid',
    'C<sub>16</sub>H<sub>22</sub>ClNO<sub>2</sub>',
    '',
    '106700-29-2',
    'CSWIKHNSBZVWNQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pethoxamid'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pigment red 4',
    'C<sub>16</sub>H<sub>10</sub>ClN<sub>3</sub>O<sub>3</sub>',
    '',
    '2814-77-9',
    'XLTMWFMRJZDFFD-VHEBQXMUSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pigment red 4'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'darendoside b',
    'C<sub>17</sub>H<sub>15</sub>Cl<sub>2</sub>N<sub>5</sub>O<sub>2</sub>',
    '',
    '13301-61-6',
    'KHZRTXVUEZJYNE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='darendoside b'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='darendoside b'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='darendoside b'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='darendoside b'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'butenachlor',
    'C<sub>17</sub>H<sub>24</sub>NO<sub>2</sub>Cl',
    '',
    '87310-56-3',
    'HZDIJTXDRLNTIS-DAXSKMNVSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='butenachlor'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'butachlor',
    'C<sub>17</sub>H<sub>26</sub>ClNO<sub>2</sub>',
    '',
    '23184-66-9',
    'HKPHPIREJKHECO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='butachlor'),
    (SELECT id from literature WHERE bibtexkey='2538'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butachlor'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butachlor'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butachlor'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pretilachlor',
    'C<sub>17</sub>H<sub>26</sub>ClNO<sub>2</sub>',
    '',
    '51218-49-6',
    'YLPGTOIOYRQOHV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pretilachlor'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pretilachlor'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'halofenozide',
    'C<sub>18</sub>H<sub>19</sub>ClN<sub>2</sub>O<sub>2</sub>',
    '',
    '112226-61-6',
    'CNKHSLKYRMDDNQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='halofenozide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benzoximate',
    'C<sub>18</sub>H<sub>18</sub>ClNO<sub>5</sub>',
    '',
    '29104-30-1',
    'BZMIHNKNQJJVRO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzoximate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzoximate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pencycuron',
    'C<sub>19</sub>H<sub>21</sub>ClN<sub>2</sub>O',
    '',
    '66063-05-6',
    'OGYFATSSENRIKG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pencycuron'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'valifenalate',
    'C<sub>19</sub>H<sub>27</sub>ClN<sub>2</sub>O<sub>5</sub>',
    '',
    '283159-90-0',
    'DBXFMOWZRXXBRN-LWKPJOBUSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='valifenalate'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3549-pH5.4',
    '', 'At pH = 5.4.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH5.4'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pyrazoxyfen',
    'C<sub>20</sub>H<sub>16</sub>Cl<sub>2</sub>N<sub>2</sub>O<sub>3</sub>',
    '',
    '71561-11-0',
    'FKERUJTUOYLBKB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pyrazoxyfen'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pyrazoxyfen'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '&#945;-cypermethrin',
    'C<sub>22</sub>H<sub>19</sub>Cl<sub>2</sub>NO<sub>3</sub>',
    '',
    '67375-30-8',
    'KAATUXNTWXVJKI-DXCJPMOASA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'V',
    (SELECT id from species WHERE iupac='&#945;-cypermethrin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='&#945;-cypermethrin'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='&#945;-cypermethrin'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cypermethrin-&#946;',
    'C<sub>22</sub>H<sub>19</sub>Cl<sub>2</sub>NO<sub>3</sub>',
    '',
    '1224510-29-5',
    'KAATUXNTWXVJKI-FLXSOZOKSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cypermethrin-&#946;'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '&#946;-cypermethrin',
    'C<sub>22</sub>H<sub>19</sub>Cl<sub>2</sub>NO<sub>3</sub>',
    '',
    '65731-84-2',
    'KAATUXNTWXVJKI-NSHGMRRFSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='&#946;-cypermethrin'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2614_pc_problem'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '&#948;-cypermethrin',
    'C<sub>22</sub>H<sub>19</sub>Cl<sub>2</sub>NO<sub>3</sub>',
    'cypermethrin; alphamethrin',
    '52315-07-8',
    'KAATUXNTWXVJKI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='&#948;-cypermethrin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='&#948;-cypermethrin'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='&#948;-cypermethrin'),
    (SELECT id from literature WHERE bibtexkey='2973'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='&#948;-cypermethrin'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#948;-cypermethrin'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='&#948;-cypermethrin'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='&#948;-cypermethrin'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '&#952;-cypermethrin',
    'C<sub>22</sub>H<sub>19</sub>Cl<sub>2</sub>NO<sub>3</sub>',
    '',
    '71697-59-1',
    'KAATUXNTWXVJKI-GGPKGHCWSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='&#952;-cypermethrin'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '&#950;-cypermethrin',
    'C<sub>22</sub>H<sub>19</sub>Cl<sub>2</sub>NO<sub>3</sub>',
    '',
    '1315501-18-8',
    'KAATUXNTWXVJKI-QPIRBTGLSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='&#950;-cypermethrin'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ochratoxin C',
    'C<sub>22</sub>H<sub>22</sub>ClNO<sub>6</sub>',
    '',
    '4865-85-4',
    'BPZZWRPHVVDAPT-PXAZEXFGSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ochratoxin C'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'quizalofop-p-tefuryl',
    'C<sub>22</sub>H<sub>21</sub>N<sub>2</sub>O<sub>5</sub>Cl',
    '',
    '119738-06-6',
    'BBKDWPHJZANJGB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='quizalofop-p-tefuryl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='quizalofop-p-tefuryl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'mandipropamid',
    'C<sub>23</sub>H<sub>22</sub>ClNO<sub>4</sub>',
    '',
    '374726-62-2',
    'KWLVWJPJKJMCSH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='mandipropamid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 1.1&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='mandipropamid'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fenvalerate',
    'C<sub>25</sub>H<sub>22</sub>ClNO<sub>3</sub>',
    '',
    '51630-58-1',
    'NYPJDWWKZLNGGM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='fenvalerate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='fenvalerate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='fenvalerate'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='fenvalerate'),
    (SELECT id from literature WHERE bibtexkey='1995'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fenvalerate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'esfenvalerate',
    'C<sub>25</sub>H<sub>22</sub>ClNO<sub>3</sub>',
    '',
    '66230-04-4',
    'NYPJDWWKZLNGGM-ZEQRLZLVSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='esfenvalerate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='esfenvalerate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='esfenvalerate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='esfenvalerate'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'clopyralid',
    'C<sub>6</sub>H<sub>3</sub>Cl<sub>2</sub>NO<sub>2</sub>',
    '',
    '1702-17-6',
    'HUBANNPOLNYSAD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='clopyralid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='clopyralid'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='clopyralid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='clopyralid'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>9</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='clopyralid'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>10</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='clopyralid'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH5'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>10</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='clopyralid'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH9'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>10</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='clopyralid'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH7'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'picloram',
    'C<sub>6</sub>H<sub>3</sub>Cl<sub>3</sub>N<sub>2</sub>O<sub>2</sub>',
    '',
    '1918-02-1',
    'NQQVFXUMIDALNH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='picloram'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='picloram'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='picloram'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='picloram'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='picloram'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='picloram'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='picloram'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='picloram'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='picloram'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'aminopyralid',
    'C<sub>6</sub>H<sub>4</sub>Cl<sub>2</sub>N<sub>2</sub>O<sub>2</sub>',
    '',
    '150114-71-9',
    'NIXXQNOQHKNPEJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='aminopyralid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>11</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='aminopyralid'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH7'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4,5,6-tetrachloropyridine-2-carboxylic acid',
    'C<sub>6</sub>HCl<sub>4</sub>NO<sub>2</sub>',
    '',
    '10469-09-7',
    'GXFRQLQUKBSYQL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,5,6-tetrachloropyridine-2-carboxylic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,5,6-tetrachloropyridine-2-carboxylic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,5,6-tetrachloropyridine-2-carboxylic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4,5,6-tetrachloropyridine-2-carboxylic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '[(3,5,6-trichloro-2-pyridinyl)oxy]-acetic acid',
    'C<sub>7</sub>H<sub>4</sub>Cl<sub>3</sub>NO<sub>3</sub>',
    'triclopyr',
    '55335-06-3',
    'REEQLXCGVXDJSQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='[(3,5,6-trichloro-2-pyridinyl)oxy]-acetic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='[(3,5,6-trichloro-2-pyridinyl)oxy]-acetic acid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>4</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='[(3,5,6-trichloro-2-pyridinyl)oxy]-acetic acid'),
    (SELECT id from literature WHERE bibtexkey='3073'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='[(3,5,6-trichloro-2-pyridinyl)oxy]-acetic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='[(3,5,6-trichloro-2-pyridinyl)oxy]-acetic acid'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='[(3,5,6-trichloro-2-pyridinyl)oxy]-acetic acid'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH5'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='[(3,5,6-trichloro-2-pyridinyl)oxy]-acetic acid'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH7'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'clopidol',
    'C<sub>7</sub>H<sub>7</sub>Cl<sub>2</sub>NO',
    '',
    '2971-90-6',
    'ZDPIZLCVJAAHHR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='clopidol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '[(3,5,6-trichloro-2-pyridinyl)oxy]-acetic acid, methyl ester',
    'C<sub>8</sub>H<sub>6</sub>Cl<sub>3</sub>NO<sub>3</sub>',
    '',
    '60825-26-5',
    'MNYBZEHWPRTNJY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='[(3,5,6-trichloro-2-pyridinyl)oxy]-acetic acid, methyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='[(3,5,6-trichloro-2-pyridinyl)oxy]-acetic acid, methyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='[(3,5,6-trichloro-2-pyridinyl)oxy]-acetic acid, methyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='[(3,5,6-trichloro-2-pyridinyl)oxy]-acetic acid, methyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'aminocyclopyrachlor',
    'C<sub>8</sub>H<sub>8</sub>ClN<sub>3</sub>O<sub>2</sub>',
    '',
    '858956-08-8',
    'KWAIHLIXESXTJL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='aminocyclopyrachlor'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'uracil mustard',
    'C<sub>8</sub>H<sub>11</sub>Cl<sub>2</sub>N<sub>3</sub>O<sub>2</sub>',
    '',
    '66-75-1',
    'IDPUKCWIGUEADI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='uracil mustard'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'imidacloprid',
    'C<sub>9</sub>H<sub>10</sub>ClN<sub>5</sub>O<sub>2</sub>',
    '',
    '138261-41-3',
    'YWTYJOPNNQFBPC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>9</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='imidacloprid'),
    (SELECT id from literature WHERE bibtexkey='3073'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>9</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='imidacloprid'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyl [(3,5,6-trichloro-2-pyridinyl)oxy]acetate',
    'C<sub>9</sub>H<sub>8</sub>Cl<sub>3</sub>NO<sub>3</sub>',
    '',
    '60825-27-6',
    'KXAVVWXJUDQGDA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl [(3,5,6-trichloro-2-pyridinyl)oxy]acetate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl [(3,5,6-trichloro-2-pyridinyl)oxy]acetate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl [(3,5,6-trichloro-2-pyridinyl)oxy]acetate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl [(3,5,6-trichloro-2-pyridinyl)oxy]acetate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-methyl-3,4,5,6-tetrachlorophthalimide',
    'C<sub>9</sub>H<sub>3</sub>Cl<sub>4</sub>NO<sub>2</sub>',
    '',
    '14737-80-5',
    'OHCSZUQRNNNMRG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-methyl-3,4,5,6-tetrachlorophthalimide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-methyl-3,4,5,6-tetrachlorophthalimide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-methyl-3,4,5,6-tetrachlorophthalimide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-methyl-3,4,5,6-tetrachlorophthalimide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'terbacil',
    'C<sub>9</sub>H<sub>13</sub>ClN<sub>2</sub>O<sub>2</sub>',
    '',
    '5902-51-2',
    'NBQCNZYJJMBDKY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='terbacil'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='terbacil'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='terbacil'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='terbacil'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='terbacil'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='terbacil'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'eglinazine-ethyl',
    'C<sub>9</sub>H<sub>14</sub>ClN<sub>5</sub>O<sub>2</sub>',
    '',
    '6616-80-4',
    'YESXTECNXIKUMM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='eglinazine-ethyl'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'proglinazine ethyl ester',
    'C<sub>10</sub>H<sub>16</sub>ClN<sub>5</sub>O<sub>2</sub>',
    '',
    '68228-18-2',
    'QQADVTSTCZBBOE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='proglinazine ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'triforine',
    'C<sub>10</sub>H<sub>14</sub>Cl<sub>6</sub>N<sub>4</sub>O<sub>2</sub>',
    '',
    '26644-46-2',
    'RROQIUMZODEXOR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='triforine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='triforine'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'drazoxolon',
    'C<sub>10</sub>H<sub>8</sub>ClN<sub>3</sub>O<sub>2</sub>',
    '',
    '5707-69-7',
    'OOTHTARUZHONSW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='drazoxolon'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'anagrelide',
    'C<sub>10</sub>H<sub>7</sub>Cl<sub>2</sub>N<sub>3</sub>O',
    '',
    '68475-42-3',
    'OTBXOEAOVRKTNQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='anagrelide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fenpiclonil',
    'C<sub>11</sub>H<sub>6</sub>Cl<sub>2</sub>N<sub>2</sub>',
    '',
    '74738-17-3',
    'FKLFBQCQQYDUAM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='fenpiclonil'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fenpiclonil'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fenpiclonil'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benoxacor',
    'C<sub>11</sub>H<sub>11</sub>Cl<sub>2</sub>NO<sub>2</sub>',
    '',
    '98730-04-2',
    'PFJJMJDEVDLPNE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benoxacor'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benoxacor'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='benoxacor'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethychlozate',
    'C<sub>11</sub>H<sub>11</sub>ClN<sub>2</sub>O<sub>2</sub>',
    '',
    '27512-72-7',
    'GLPZEHFBLBYFHN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethychlozate'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'quinmerac',
    'C<sub>11</sub>H<sub>8</sub>ClNO<sub>2</sub>',
    '',
    '90717-03-6',
    'ALZOLUNSQWINIR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>10</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='quinmerac'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'quinonamid',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>3</sub>NO<sub>3</sub>',
    '',
    '27541-88-4',
    'ZIEWAMOXCOLNSJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='quinonamid'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fenchlorazole-ethyl',
    'C<sub>12</sub>H<sub>8</sub>N<sub>3</sub>O<sub>2</sub>Cl<sub>5</sub>',
    '',
    '103112-35-2',
    'GMBRUAIJEFRHFQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fenchlorazole-ethyl'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'vinclozoline',
    'C<sub>12</sub>H<sub>9</sub>Cl<sub>2</sub>NO<sub>3</sub>',
    'vinclozolin',
    '50471-44-8',
    'FSCWZHGZWWDELK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='vinclozoline'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='vinclozoline'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='vinclozoline'),
    (SELECT id from literature WHERE bibtexkey='2967'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6',
    '',
    'X',
    (SELECT id from species WHERE iupac='vinclozoline'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='vinclozoline'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'forchlorfenuron',
    'C<sub>12</sub>H<sub>10</sub>ClN<sub>3</sub>O',
    '',
    '68157-60-8',
    'GPXLRLUVLMHHIK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='forchlorfenuron'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='forchlorfenuron'),
    (SELECT id from literature WHERE bibtexkey='macbean2012'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='forchlorfenuron'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='forchlorfenuron'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'azaconazole',
    'C<sub>12</sub>H<sub>11</sub>Cl<sub>2</sub>N<sub>3</sub>O<sub>2</sub>',
    '',
    '60207-31-0',
    'AKNQMEBLVAMSNZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='azaconazole'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'myclozolin',
    'C<sub>12</sub>H<sub>11</sub>NO<sub>4</sub>Cl<sub>2</sub>',
    '',
    '54864-61-8',
    'FTCOKXNKPOUEFH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='myclozolin'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'triclopyr-butotyl',
    'C<sub>13</sub>H<sub>16</sub>Cl<sub>3</sub>NO<sub>4</sub>',
    '',
    '64700-56-7',
    'IVDRCZNHVGQBHZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='triclopyr-butotyl'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'clofencet',
    'C<sub>13</sub>H<sub>11</sub>ClN<sub>2</sub>O<sub>3</sub>',
    '',
    '129025-54-3',
    'PIZCXVUFSNPNON-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 1.9&times;10<sup>8</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='clofencet'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 2.3&times;10<sup>10</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='clofencet'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chlozolinate',
    'C<sub>13</sub>H<sub>11</sub>NO<sub>5</sub>Cl<sub>2</sub>',
    '',
    '84332-86-5',
    'IGUYEXXAGBDLLX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chlozolinate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chlozolinate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlozolinate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlozolinate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chlozolinate'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'monalide',
    'C<sub>13</sub>H<sub>18</sub>ClNO',
    '',
    '7287-36-7',
    'KXGYBSNVFXBPNO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='monalide'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chlomethoxyfen',
    'C<sub>13</sub>H<sub>9</sub>Cl<sub>2</sub>NO<sub>4</sub>',
    '',
    '32861-85-1',
    'DXXVCXKMSWHGTF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chlomethoxyfen'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'metazachlor',
    'C<sub>14</sub>H<sub>16</sub>ClN<sub>3</sub>O',
    '',
    '67129-08-2',
    'STEPQTYSZVCJPV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='metazachlor'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='metazachlor'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='metazachlor'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='metazachlor'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'etaconazole',
    'C<sub>14</sub>H<sub>15</sub>Cl<sub>2</sub>N<sub>3</sub>O<sub>2</sub>',
    '',
    '60207-93-4',
    'DWRKFAJEBUWTQM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='etaconazole'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'triadimenol',
    'C<sub>14</sub>H<sub>18</sub>ClN<sub>3</sub>O<sub>2</sub>',
    '',
    '55219-65-3',
    'BAZVSMNPJJMILC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='triadimenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='triadimenol'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='triadimenol'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hexaconazole',
    'C<sub>14</sub>H<sub>17</sub>Cl<sub>2</sub>N<sub>3</sub>O',
    '',
    '79983-71-4',
    'STMIIPIFODONDC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='hexaconazole'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexaconazole'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'triadimefon',
    'C<sub>14</sub>H<sub>16</sub>ClN<sub>3</sub>O<sub>2</sub>',
    '',
    '43121-43-3',
    'WURBVZBTWMNKQT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='triadimefon'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='triadimefon'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='triadimefon'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triadimefon'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'imazalil',
    'C<sub>14</sub>H<sub>14</sub>Cl<sub>2</sub>N<sub>2</sub>O',
    '',
    '35554-44-0',
    'PZBPKYOVPCNPJY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='imazalil'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='imazalil'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='imazalil'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pyrifenox',
    'C<sub>14</sub>H<sub>12</sub>Cl<sub>2</sub>N<sub>2</sub>O',
    '',
    '88283-41-4',
    'CKPCAYZTYMHQEX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pyrifenox'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chlorphthalim',
    'C<sub>14</sub>H<sub>12</sub>ClNO<sub>2</sub>',
    '',
    '39985-63-2',
    'MJQBFSWPMMHVSM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chlorphthalim'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cyprofuram',
    'C<sub>14</sub>H<sub>14</sub>ClNO<sub>3</sub>',
    '',
    '69581-33-5',
    'KRZUZYJEQBXUIN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cyprofuram'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ofurace',
    'C<sub>14</sub>H<sub>16</sub>ClNO<sub>3</sub>',
    '',
    '58810-48-3',
    'OWDLFBLNMPCXSD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ofurace'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'triadimenol B',
    'C<sub>14</sub>H<sub>18</sub>ClN<sub>3</sub>O<sub>2</sub>',
    '',
    '82200-72-4',
    '',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='triadimenol B'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'triadimenol A',
    'C<sub>14</sub>H<sub>18</sub>ClN<sub>3</sub>O<sub>2</sub>',
    '',
    '89482-17-7',
    '',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='triadimenol A'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propiconazole',
    'C<sub>15</sub>H<sub>17</sub>Cl<sub>2</sub>N<sub>3</sub>O<sub>2</sub>',
    '',
    '60207-90-1',
    'STJLVHWMYQXCPB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propiconazole'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propiconazole'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propiconazole'),
    (SELECT id from literature WHERE bibtexkey='2967'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='propiconazole'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propiconazole'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_test'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'clonazepam',
    'C<sub>15</sub>H<sub>10</sub>ClN<sub>3</sub>O<sub>3</sub>',
    '',
    '1622-61-3',
    'DGBIGWXXNGSACT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='clonazepam'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'oxazepam',
    'C<sub>15</sub>H<sub>12</sub>ClN<sub>2</sub>O<sub>2</sub>',
    '',
    '604-75-1',
    'ADIMAYPTOBDMTL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='oxazepam'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'oxadiazon',
    'C<sub>15</sub>H<sub>18</sub>Cl<sub>2</sub>N<sub>2</sub>O<sub>3</sub>',
    '',
    '19666-30-9',
    'CHNUNORXWHYHNE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='oxadiazon'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='oxadiazon'),
    (SELECT id from literature WHERE bibtexkey='3073'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cyproconazole',
    'C<sub>15</sub>H<sub>18</sub>ClN<sub>3</sub>O',
    '',
    '94361-06-5',
    'UFNOUKDBUJZYDE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cyproconazole'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='cyproconazole'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyproconazole'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cyproconazole'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diclobutrazol',
    'C<sub>15</sub>H<sub>19</sub>Cl<sub>2</sub>N<sub>3</sub>O',
    '',
    '75736-33-3',
    'URDNHJIVMYZFRT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='diclobutrazol'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'paclobutrazol',
    'C<sub>15</sub>H<sub>20</sub>ClN<sub>3</sub>O',
    '',
    '76738-62-0',
    'RMOGWMIKYWRTKW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='paclobutrazol'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'prochloraz',
    'C<sub>15</sub>H<sub>16</sub>Cl<sub>3</sub>N<sub>3</sub>O<sub>2</sub>',
    '',
    '67747-09-5',
    'TVLSRXXIMLFWEO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='prochloraz'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8',
    '',
    'X',
    (SELECT id from species WHERE iupac='prochloraz'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='prochloraz'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='prochloraz'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='prochloraz'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>cis</i>-propiconazole',
    'C<sub>15</sub>H<sub>17</sub>Cl<sub>2</sub>N<sub>3</sub>O<sub>2</sub>',
    '',
    '112721-87-6',
    '',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='<i>cis</i>-propiconazole'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>trans</i>-propiconazole',
    'C<sub>15</sub>H<sub>17</sub>Cl<sub>2</sub>N<sub>3</sub>O<sub>2</sub>',
    '',
    '120523-07-1',
    '',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='<i>trans</i>-propiconazole'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fenoxanil',
    'C<sub>15</sub>H<sub>18</sub>Cl<sub>2</sub>N<sub>2</sub>O<sub>2</sub>',
    '',
    '115852-48-7',
    'IUOKJNROJISWRO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fenoxanil'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'carpropamid',
    'C<sub>15</sub>H<sub>18</sub>Cl<sub>3</sub>NO',
    '',
    '104030-54-8',
    'RXDMAYSSBPYBFW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='carpropamid'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propisochlor',
    'C<sub>15</sub>H<sub>22</sub>ClNO<sub>2</sub>',
    '',
    '86763-47-5',
    'KZNDFYDURHAESM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propisochlor'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'mefenpyr-diethyl',
    'C<sub>16</sub>H<sub>18</sub>Cl<sub>2</sub>N<sub>2</sub>O<sub>4</sub>',
    '',
    '135590-91-9',
    'OPGCOAPTHCZZIW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='mefenpyr-diethyl'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='mefenpyr-diethyl'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diazepam',
    'C<sub>16</sub>H<sub>13</sub>ClN<sub>2</sub>O',
    '',
    '439-14-5',
    'AAOVKJBEBIDNHE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diazepam'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bendamustine',
    'C<sub>16</sub>H<sub>21</sub>Cl<sub>2</sub>N<sub>3</sub>O<sub>2</sub>',
    '',
    '16506-27-7',
    'YTKUWDBFDASYHO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bendamustine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fentrazamide',
    'C<sub>16</sub>H<sub>20</sub>ClN<sub>5</sub>O<sub>2</sub>',
    '',
    '158237-07-1',
    'LLQPHQFNMLZJMP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fentrazamide'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'piperalin',
    'C<sub>16</sub>H<sub>21</sub>Cl<sub>2</sub>NO<sub>2</sub>',
    '',
    '3478-94-2',
    'BZGLBXYQOMFXAU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='piperalin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tebuconazole',
    'C<sub>16</sub>H<sub>22</sub>ClN<sub>3</sub>O',
    '',
    '107534-96-3',
    'PXMNMQRDXWABCY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tebuconazole'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='tebuconazole'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tebuconazole'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tebuconazole'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diethatyl-ethyl',
    'C<sub>16</sub>H<sub>22</sub>ClNO<sub>3</sub>',
    '',
    '38727-55-8',
    'WFKSADNZWSKCRZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='diethatyl-ethyl'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fenarimol',
    'C<sub>17</sub>H<sub>12</sub>Cl<sub>2</sub>N<sub>2</sub>O',
    '',
    '60168-88-9',
    'NHOWDZOIZKMVAI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='fenarimol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='fenarimol'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fenarimol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cumyluron',
    'C<sub>17</sub>H<sub>19</sub>ClN<sub>2</sub>O',
    '',
    '99485-76-4',
    'VYNOULHXXDFBLU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cumyluron'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'triticonazole',
    'C<sub>17</sub>H<sub>20</sub>N<sub>3</sub>OCl',
    '',
    '131983-72-7',
    'PPDBOQMNKNNODG-ZROIWOOFSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triticonazole'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='triticonazole'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'furametpyr',
    'C<sub>17</sub>H<sub>20</sub>ClN<sub>3</sub>O<sub>2</sub>',
    '',
    '123572-88-3',
    'NRTLIYOWLVMQBO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='furametpyr'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'metconazole',
    'C<sub>17</sub>H<sub>22</sub>ClN<sub>3</sub>O',
    '',
    '125116-23-6',
    'XWPZUHJBOLQNMN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='metconazole'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='metconazole'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='metconazole'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tepraloxydim',
    'C<sub>17</sub>H<sub>24</sub>ClNO<sub>4</sub>',
    '',
    '149979-41-9',
    'IOYNQIMAUDJVEI-BMVIKAAMSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tepraloxydim'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cloquintocet-mexyl',
    'C<sub>18</sub>H<sub>22</sub>ClNO<sub>3</sub>',
    '',
    '99607-70-2',
    'COYBRKAVBMYYSF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cloquintocet-mexyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cloquintocet-mexyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cloquintocet-mexyl'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fenoxaprop-p-ethyl',
    'C<sub>18</sub>H<sub>16</sub>ClNO<sub>5</sub>',
    '',
    '71283-80-2',
    'PQKBPHSEKWERTG-LLVKDONJSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='fenoxaprop-p-ethyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fenoxaprop-p-ethyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fenoxaprop-p-ethyl'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ipconazole',
    'C<sub>18</sub>H<sub>24</sub>ClN<sub>3</sub>O',
    '',
    '125225-28-7',
    'QTYCMDBMOLSEAM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ipconazole'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ipconazole'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ipconazole'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pyriofenone',
    'C<sub>18</sub>H<sub>20</sub>ClNO<sub>5</sub>',
    '',
    '688046-61-9',
    'NMVCBWZLCXANER-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pyriofenone'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cintofen',
    'C<sub>18</sub>H<sub>15</sub>ClN<sub>2</sub>O<sub>5</sub>',
    'sintofen',
    '130561-48-7',
    'QLMNCUHSDAGQGT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cintofen'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH4'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>9</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cintofen'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH9'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>9</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cintofen'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH7'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'boscalid',
    'C<sub>18</sub>H<sub>12</sub>Cl<sub>2</sub>N<sub>2</sub>O',
    '',
    '188425-85-6',
    'WYEMLYFITZORAB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='boscalid'),
    (SELECT id from literature WHERE bibtexkey='macbean2012'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='boscalid'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tebufenpyrad',
    'C<sub>18</sub>H<sub>24</sub>ClN<sub>3</sub>O',
    '',
    '119168-77-3',
    'ZZYSLNWGKKDOML-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 8.2&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tebufenpyrad'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 9.1&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tebufenpyrad'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '8,9,10,11-tetrachloro-12-phthaloperinone',
    'C<sub>18</sub>H<sub>6</sub>Cl<sub>4</sub>N<sub>2</sub>O',
    '',
    '20749-68-2',
    'UBZVRROHBDDCQY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='8,9,10,11-tetrachloro-12-phthaloperinone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='8,9,10,11-tetrachloro-12-phthaloperinone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='8,9,10,11-tetrachloro-12-phthaloperinone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='8,9,10,11-tetrachloro-12-phthaloperinone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pigment red 254',
    'C<sub>18</sub>H<sub>10</sub>Cl<sub>2</sub>N<sub>2</sub>O<sub>2</sub>',
    '',
    '84632-65-5',
    'JNNHVXMCVRYTTN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pigment red 254'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pigment red 254'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>13</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pigment red 254'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>12</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pigment red 254'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fenoxaprop-ethyl',
    'C<sub>18</sub>H<sub>16</sub>ClNO<sub>5</sub>',
    '',
    '66441-23-4',
    'PQKBPHSEKWERTG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fenoxaprop-ethyl'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benzoylprop-ethyl',
    'C<sub>18</sub>H<sub>17</sub>Cl<sub>2</sub>NO<sub>3</sub>',
    '',
    '22212-55-1',
    'SLCGUGMPSUYJAY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='benzoylprop-ethyl'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3766_M1',
    '3766', 'Ebert et&nbsp;al. (2023) present "curated experimental" Henry''s law constants from the literature but do not provide any references. It is only mentioned that the value is from multiple sources and measured directly.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'difenoconazole',
    'C<sub>19</sub>H<sub>17</sub>Cl<sub>2</sub>N<sub>3</sub>O<sub>3</sub>',
    '',
    '119446-68-3',
    'BQYJATMQXGBDHF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='difenoconazole'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='difenoconazole'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='difenoconazole'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='difenoconazole'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='difenoconazole'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'quizalofop ethyl',
    'C<sub>19</sub>H<sub>17</sub>ClN<sub>2</sub>O<sub>4</sub>',
    '',
    '76578-14-8',
    'OSUHJPCHFDQAIT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='quizalofop ethyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='quizalofop ethyl'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='quizalofop ethyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='quizalofop ethyl'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'quizalofop-p-ethyl',
    'C<sub>19</sub>H<sub>17</sub>ClN<sub>2</sub>O<sub>4</sub>',
    '',
    '100646-51-3',
    'OSUHJPCHFDQAIT-GFCCVEGCSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='quizalofop-p-ethyl'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pyraclostrobine',
    'C<sub>19</sub>H<sub>18</sub>ClN<sub>3</sub>O<sub>4</sub>',
    '',
    '175013-18-0',
    'HZRSNVGNWUDEFX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='pyraclostrobine'),
    (SELECT id from literature WHERE bibtexkey='macbean2012'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pyraclostrobine'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pyrimidifen',
    'C<sub>20</sub>H<sub>28</sub>ClN<sub>3</sub>O<sub>2</sub>',
    '',
    '105779-78-0',
    'ITKAIUGKVKDENI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pyrimidifen'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ponsol red violet 2rnx',
    'C<sub>21</sub>H<sub>8</sub>Cl<sub>3</sub>NO<sub>3</sub>',
    '',
    '6373-31-5',
    'SQAQTWYUQXFOMH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ponsol red violet 2rnx'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ponsol red violet 2rnx'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ponsol red violet 2rnx'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ponsol red violet 2rnx'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimethomorph',
    'C<sub>21</sub>H<sub>22</sub>NO<sub>4</sub>Cl',
    '',
    '110488-70-5',
    'QNBTYORWCCMPQP-JXAWBTAJSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dimethomorph'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethomorph'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethomorph'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dimethomorph'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dimethomorph'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propaquizafop',
    'C<sub>22</sub>H<sub>22</sub>ClN<sub>3</sub>O<sub>5</sub>',
    '',
    '111479-05-1',
    'FROBCXTULYFHEJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propaquizafop'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propaquizafop'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propaquizafop'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'aripiprazole',
    'C<sub>23</sub>H<sub>27</sub>Cl<sub>2</sub>N<sub>3</sub>O<sub>2</sub>',
    '',
    '129722-12-9',
    'CEUORZQYGODEFX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='aripiprazole'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ag-g-86814',
    'C<sub>26</sub>H<sub>6</sub>Cl<sub>8</sub>N<sub>2</sub>O<sub>4</sub>',
    '',
    '30125-47-4',
    'ZEHOVWPIGREOPO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>14</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ag-g-86814'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>12</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ag-g-86814'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ag-g-86814'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>14</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ag-g-86814'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '8,18-dichloro-5,15-diethyl-5,15-dihydrodiindolo(3,2-b:3'',2''-m)triphenodioxazine',
    'C<sub>34</sub>H<sub>22</sub>Cl<sub>2</sub>N<sub>4</sub>O<sub>2</sub>',
    '',
    '6358-30-1',
    'CGLVZFOCZLHKOH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorocarbons with nitrogen (C, H, O, N, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='8,18-dichloro-5,15-diethyl-5,15-dihydrodiindolo(3,2-b:3'',2''-m)triphenodioxazine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>12</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='8,18-dichloro-5,15-diethyl-5,15-dihydrodiindolo(3,2-b:3'',2''-m)triphenodioxazine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='8,18-dichloro-5,15-diethyl-5,15-dihydrodiindolo(3,2-b:3'',2''-m)triphenodioxazine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='8,18-dichloro-5,15-diethyl-5,15-dihydrodiindolo(3,2-b:3'',2''-m)triphenodioxazine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Chlorofluorocarbons (C, H, O, N, F, Cl)',
    (SELECT id from categories WHERE catname='Organic species with chlorine (Cl)'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chlorofluoromethane',
    'CH<sub>2</sub>FCl',
    'R31',
    '593-70-4',
    'XWCDCDSDNJVCLO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '2600',
    'L',
    (SELECT id from species WHERE iupac='chlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '2300',
    'M',
    (SELECT id from species WHERE iupac='chlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2552'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='chlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2600',
    'Q',
    (SELECT id from species WHERE iupac='chlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2500',
    '?',
    (SELECT id from species WHERE iupac='chlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chlorodifluoromethane',
    'CHF<sub>2</sub>Cl',
    'R22',
    '75-45-6',
    'VOPWNXZWBYDODV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;4</sup>',
    '2600',
    'L',
    (SELECT id from species WHERE iupac='chlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;4</sup>',
    '2700',
    'L',
    (SELECT id from species WHERE iupac='chlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;4</sup>',
    '2600',
    'L',
    (SELECT id from species WHERE iupac='chlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;4</sup>',
    '2700',
    'L',
    (SELECT id from species WHERE iupac='chlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '3400',
    'L',
    (SELECT id from species WHERE iupac='chlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '3400',
    'L',
    (SELECT id from species WHERE iupac='chlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;4</sup>',
    '3100',
    'M',
    (SELECT id from species WHERE iupac='chlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3564'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '3000',
    'M',
    (SELECT id from species WHERE iupac='chlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='921'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0921-75-45-6-ABC',
    '921', 'The data from Zheng et&nbsp;al. (1997) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;206.94328 +11372.60160/T +28.22232&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0921-75-45-6-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;4</sup>',
    '3100',
    'M',
    (SELECT id from species WHERE iupac='chlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='923'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0923-75-45-6-ABC',
    '923', 'The data from Maaßen (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;200.57402 +11192.93914/T +27.21798&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0923-75-45-6-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;4</sup>',
    '3000',
    'M',
    (SELECT id from species WHERE iupac='chlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2013'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2013-75-45-6-ABC',
    '2013', 'The data from Reichl (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;208.06388 +11491.48483/T +28.35421&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2013-75-45-6-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;4</sup>',
    '3500',
    'M',
    (SELECT id from species WHERE iupac='chlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2121'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2121-75-45-6-ABC',
    '2121', 'The data from Chang and Criddle (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;1756.79407 +80807.02552/T +259.24906&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2121-75-45-6-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;4</sup>',
    '2600',
    'M',
    (SELECT id from species WHERE iupac='chlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2552'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;4</sup>',
    '3600',
    'V',
    (SELECT id from species WHERE iupac='chlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='1014'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref1014-75-45-6-ABC',
    '1014', 'The data from McLinden (1989) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;387.81156 +19950.78638/T +54.91348&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref1014-75-45-6-ABC'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '498R22',
    '1014', 'The temperature dependence was recalculated from the data on p.&nbsp;20 of McLinden (1989).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='498R22'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='chlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'C',
    (SELECT id from species WHERE iupac='chlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='498'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '498-75-45-6',
    '1014,498', 'The data from McLinden (1989) for HCFC-22 are incorrectly cited by Kanakidou et&nbsp;al. (1995).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='498-75-45-6'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '3100',
    'Q',
    (SELECT id from species WHERE iupac='chlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3570'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2600',
    'Q',
    (SELECT id from species WHERE iupac='chlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3000',
    '?',
    (SELECT id from species WHERE iupac='chlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dichlorofluoromethane',
    'CHFCl<sub>2</sub>',
    'R21',
    '75-43-4',
    'UMNKXPULIDJLSU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chlorotrifluoromethane',
    'CF<sub>3</sub>Cl',
    'R13',
    '75-72-9',
    'AFYPFACVUDMOHA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;6</sup>',
    '1700',
    'L',
    (SELECT id from species WHERE iupac='chlorotrifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3500-75-72-9-consicheck',
    '3500', 'The H298 and A, B data listed in Table&nbsp;5-4 of Burkholder et&nbsp;al. (2019) are inconsistent, with 5&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3500-75-72-9-consicheck'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;6</sup>',
    '1500',
    'L',
    (SELECT id from species WHERE iupac='chlorotrifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;6</sup>',
    '1700',
    'L',
    (SELECT id from species WHERE iupac='chlorotrifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3245-75-72-9-consicheck',
    '3245', 'The H298 and A, B data listed in Table&nbsp;5-4 of Burkholder et&nbsp;al. (2015) are inconsistent, with 5&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3245-75-72-9-consicheck'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;6</sup>',
    '1500',
    'L',
    (SELECT id from species WHERE iupac='chlorotrifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;6</sup>',
    '1700',
    'L',
    (SELECT id from species WHERE iupac='chlorotrifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2626-75-72-9-consicheck',
    '2626', 'The H298 and A, B data listed in Table&nbsp;5.4 of Sander et&nbsp;al. (2011) are inconsistent, with 5&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2626-75-72-9-consicheck'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;6</sup>',
    '1600',
    'L',
    (SELECT id from species WHERE iupac='chlorotrifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;6</sup>',
    '1900',
    'M',
    (SELECT id from species WHERE iupac='chlorotrifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2013'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2013-75-72-9-ABC',
    '2013', 'The data from Reichl (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( 100.23590 &#8722;3339.68982/T &#8722;17.66849&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2013-75-72-9-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;6</sup>',
    '2100',
    'M',
    (SELECT id from species WHERE iupac='chlorotrifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3569'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3569-75-72-9-ABC',
    '3569', 'The data from Scharlin and Battino (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;291.40685 +14224.53456/T +40.73325&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3569-75-72-9-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;6</sup>',
    '2100',
    'M',
    (SELECT id from species WHERE iupac='chlorotrifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2485'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2485-75-72-9-ABC',
    '2485', 'The data from Scharlin and Battino (1994) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;291.40685 +14224.53456/T +40.73325&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2485-75-72-9-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;6</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='chlorotrifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2486'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chlorotrifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chlorotrifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='chlorotrifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;6</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='chlorotrifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;6</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='chlorotrifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorotrifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorotrifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorotrifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorotrifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorotrifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorotrifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorotrifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2600',
    'Q',
    (SELECT id from species WHERE iupac='chlorotrifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorotrifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorotrifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorotrifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorotrifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chlorotrifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2000',
    '?',
    (SELECT id from species WHERE iupac='chlorotrifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chlorotrifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chlorotrifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dichlorodifluoromethane',
    'CF<sub>2</sub>Cl<sub>2</sub>',
    'R12',
    '75-71-8',
    'PXBRQCKWGAHEHS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;5</sup>',
    '3500',
    'L',
    (SELECT id from species WHERE iupac='dichlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;5</sup>',
    '2100',
    'L',
    (SELECT id from species WHERE iupac='dichlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;5</sup>',
    '3500',
    'L',
    (SELECT id from species WHERE iupac='dichlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;5</sup>',
    '2100',
    'L',
    (SELECT id from species WHERE iupac='dichlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;5</sup>',
    '3200',
    'L',
    (SELECT id from species WHERE iupac='dichlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;5</sup>',
    '3400',
    'L',
    (SELECT id from species WHERE iupac='dichlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2828'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;5</sup>',
    '3500',
    'L',
    (SELECT id from species WHERE iupac='dichlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;5</sup>',
    '3500',
    'L',
    (SELECT id from species WHERE iupac='dichlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;5</sup>',
    '3500',
    'L',
    (SELECT id from species WHERE iupac='dichlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;5</sup>',
    '1800',
    'L',
    (SELECT id from species WHERE iupac='dichlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '5500',
    'M',
    (SELECT id from species WHERE iupac='dichlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;5</sup>',
    '3000',
    'M',
    (SELECT id from species WHERE iupac='dichlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2013'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2013-75-71-8-ABC',
    '2013', 'The data from Reichl (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;147.53824 +8643.05363/T +18.97752&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2013-75-71-8-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;5</sup>',
    '2900',
    'M',
    (SELECT id from species WHERE iupac='dichlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3569'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3569-75-71-8-ABC',
    '3569', 'The data from Scharlin and Battino (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;211.99699 +11400.41036/T +28.66283&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3569-75-71-8-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;5</sup>',
    '2900',
    'M',
    (SELECT id from species WHERE iupac='dichlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2485'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2485-75-71-8-ABC',
    '2485', 'The data from Scharlin and Battino (1994) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;211.99699 +11400.41036/T +28.66283&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2485-75-71-8-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;5</sup>',
    '3500',
    'M',
    (SELECT id from species WHERE iupac='dichlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2243'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;5</sup>',
    '3200',
    'M',
    (SELECT id from species WHERE iupac='dichlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2240'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;5</sup>',
    '3400',
    'M',
    (SELECT id from species WHERE iupac='dichlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2830'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;5</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dichlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2486'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dichlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='544'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='544'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dichlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dichlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dichlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dichlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dichlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;6</sup>',
    '-210',
    'X',
    (SELECT id from species WHERE iupac='dichlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;5</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='dichlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;6</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='dichlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;5</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='dichlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;5</sup>',
    '3300',
    'Q',
    (SELECT id from species WHERE iupac='dichlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3570'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3000',
    'Q',
    (SELECT id from species WHERE iupac='dichlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dichlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3400',
    '?',
    (SELECT id from species WHERE iupac='dichlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dichlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dichlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dichlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'trichlorofluoromethane',
    'CFCl<sub>3</sub>',
    'R11',
    '75-69-4',
    'CYRMSUTZVYGINF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '3300',
    'L',
    (SELECT id from species WHERE iupac='trichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;5</sup>',
    '3900',
    'L',
    (SELECT id from species WHERE iupac='trichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '3300',
    'L',
    (SELECT id from species WHERE iupac='trichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;5</sup>',
    '3900',
    'L',
    (SELECT id from species WHERE iupac='trichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;4</sup>',
    '3400',
    'L',
    (SELECT id from species WHERE iupac='trichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '3400',
    'L',
    (SELECT id from species WHERE iupac='trichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2828'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '3300',
    'L',
    (SELECT id from species WHERE iupac='trichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '3300',
    'L',
    (SELECT id from species WHERE iupac='trichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '3300',
    'L',
    (SELECT id from species WHERE iupac='trichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;4</sup>',
    '3100',
    'L',
    (SELECT id from species WHERE iupac='trichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;4</sup>',
    '5100',
    'M',
    (SELECT id from species WHERE iupac='trichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;5</sup>',
    '4900',
    'M',
    (SELECT id from species WHERE iupac='trichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3564'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;4</sup>',
    '3700',
    'M',
    (SELECT id from species WHERE iupac='trichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='923'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0923-75-69-4-ABC',
    '923', 'The data from Maaßen (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;278.68448 +15169.41095/T +38.36974&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0923-75-69-4-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;4</sup>',
    '3700',
    'M',
    (SELECT id from species WHERE iupac='trichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2013'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2013-75-69-4-ABC',
    '2013', 'The data from Reichl (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;129.78084 +8533.77911/T +16.20428&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2013-75-69-4-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;5</sup>',
    '3500',
    'M',
    (SELECT id from species WHERE iupac='trichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='1156'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1156'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;4</sup>',
    '3600',
    'M',
    (SELECT id from species WHERE iupac='trichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2240'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;5</sup>',
    '3900',
    'M',
    (SELECT id from species WHERE iupac='trichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2830'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '2700',
    'M',
    (SELECT id from species WHERE iupac='trichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='608'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='608'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2486'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '2100',
    'M',
    (SELECT id from species WHERE iupac='trichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2952'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='544'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='544'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='trichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;5</sup>',
    '6100',
    'V',
    (SELECT id from species WHERE iupac='trichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='trichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='trichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2971'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='trichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='trichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='trichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='trichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at303K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;4</sup>',
    '730',
    'X',
    (SELECT id from species WHERE iupac='trichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;4</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='trichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;4</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='trichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;4</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='trichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3083'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;5</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='trichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3300',
    'Q',
    (SELECT id from species WHERE iupac='trichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='trichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='trichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3800',
    '?',
    (SELECT id from species WHERE iupac='trichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='trichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at303K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='trichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='trichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='trichlorofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,1,2-tetrachlorodifluoroethane',
    'C<sub>2</sub>Cl<sub>4</sub>F<sub>2</sub>',
    '',
    '76-11-9',
    'SLGOCMATMKJJCE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrachlorodifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrachlorodifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrachlorodifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrachlorodifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrachlorodifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrachlorodifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2-tetrachlorodifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,2,2-tetrachlorodifluoroethane',
    'C<sub>2</sub>F<sub>2</sub>Cl<sub>4</sub>',
    'R112',
    '76-12-0',
    'UGCSPKPEHQEOSR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachlorodifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachlorodifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachlorodifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachlorodifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachlorodifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachlorodifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachlorodifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachlorodifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachlorodifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,1-trichloro-2,2,2-trifluoroethane',
    'C<sub>2</sub>F<sub>3</sub>Cl<sub>3</sub>',
    'R113a',
    '354-58-5',
    'BOSAWIQFTJIYIS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1-trichloro-2,2,2-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1-trichloro-2,2,2-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1-trichloro-2,2,2-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1-trichloro-2,2,2-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1-trichloro-2,2,2-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,2-trichloro-1,2,2-trifluoroethane',
    'C<sub>2</sub>F<sub>3</sub>Cl<sub>3</sub>',
    'R113',
    '76-13-1',
    'AJDIZQLSFPQPEY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;5</sup>',
    '3200',
    'L',
    (SELECT id from species WHERE iupac='1,1,2-trichloro-1,2,2-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;5</sup>',
    '3200',
    'L',
    (SELECT id from species WHERE iupac='1,1,2-trichloro-1,2,2-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;5</sup>',
    '4100',
    'L',
    (SELECT id from species WHERE iupac='1,1,2-trichloro-1,2,2-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;4</sup>',
    '5700',
    'M',
    (SELECT id from species WHERE iupac='1,1,2-trichloro-1,2,2-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;5</sup>',
    '4300',
    'M',
    (SELECT id from species WHERE iupac='1,1,2-trichloro-1,2,2-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='1107'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;5</sup>',
    '4000',
    'M',
    (SELECT id from species WHERE iupac='1,1,2-trichloro-1,2,2-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='1775'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref1775-76-13-1-ABC',
    '1775', 'The data from Bu and Warner (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;415.59157 +21411.24346/T +58.50528&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref1775-76-13-1-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;5</sup>',
    '6500',
    'M',
    (SELECT id from species WHERE iupac='1,1,2-trichloro-1,2,2-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2013'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2013-76-13-1-ABC',
    '2013', 'The data from Reichl (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( 0.13353 +5070.08549/T &#8722;4.84639&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2013-76-13-1-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;5</sup>',
    '3200',
    'M',
    (SELECT id from species WHERE iupac='1,1,2-trichloro-1,2,2-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='1156'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1156'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1,2-trichloro-1,2,2-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1,2-trichloro-1,2,2-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2612_pc_problem'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1,2-trichloro-1,2,2-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1,2-trichloro-1,2,2-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,1,2-trichloro-1,2,2-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2-trichloro-1,2,2-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2-trichloro-1,2,2-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2-trichloro-1,2,2-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2-trichloro-1,2,2-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3700',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2-trichloro-1,2,2-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1,2-trichloro-1,2,2-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3800',
    '?',
    (SELECT id from species WHERE iupac='1,1,2-trichloro-1,2,2-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1,2-trichloro-1,2,2-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1,2-trichloro-1,2,2-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1,2-trichloro-1,2,2-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1,2-trichloro-1,2,2-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1-dichlorotetrafluoroethane',
    'C<sub>2</sub>F<sub>4</sub>Cl<sub>2</sub>',
    'R114a',
    '374-07-2',
    'BAMUEXIPKSRTBS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1-dichlorotetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1-dichlorotetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;6</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1,1-dichlorotetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;6</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1,1-dichlorotetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at294K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichlorotetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichlorotetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-dichlorotetrafluoroethane',
    'C<sub>2</sub>F<sub>4</sub>Cl<sub>2</sub>',
    'R114',
    '76-14-2',
    'DDMOUSALMHHKOS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;6</sup>',
    '2800',
    'M',
    (SELECT id from species WHERE iupac='1,2-dichlorotetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2013'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2013-76-14-2-ABC',
    '2013', 'The data from Reichl (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;113.07654 +6884.36758/T +13.75470&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2013-76-14-2-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dichlorotetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dichlorotetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,2-dichlorotetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;6</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1,2-dichlorotetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichlorotetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichlorotetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichlorotetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichlorotetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichlorotetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3300',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichlorotetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichlorotetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichlorotetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2700',
    '?',
    (SELECT id from species WHERE iupac='1,2-dichlorotetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-dichlorotetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-dichlorotetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-dichlorotetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chloropentafluoroethane',
    'C<sub>2</sub>F<sub>5</sub>Cl',
    'R115',
    '76-15-3',
    'RFCAUADVODFSLZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;6</sup>',
    '2800',
    'L',
    (SELECT id from species WHERE iupac='chloropentafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;6</sup>',
    '2100',
    'M',
    (SELECT id from species WHERE iupac='chloropentafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2013'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2013-76-15-3-ABC',
    '2013', 'The data from Reichl (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;149.62353 +7869.46528/T +19.40044&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2013-76-15-3-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chloropentafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chloropentafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chloropentafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chloropentafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chloropentafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;6</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='chloropentafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;6</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='chloropentafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloropentafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloropentafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloropentafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloropentafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloropentafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloropentafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2900',
    'Q',
    (SELECT id from species WHERE iupac='chloropentafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloropentafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloropentafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloropentafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2000',
    '?',
    (SELECT id from species WHERE iupac='chloropentafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chloropentafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chloropentafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,2,2-tetrachloro-1-fluoroethane',
    'C<sub>2</sub>HCl<sub>4</sub>F',
    '',
    '354-14-3',
    'LUBCGHUOCJOIJA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachloro-1-fluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1-dichloro-1,2,2-trifluoroethane',
    'C<sub>2</sub>HCl<sub>2</sub>F<sub>3</sub>',
    '',
    '812-04-4',
    'AFTSHZRGGNMLHC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichloro-1,2,2-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-dichloro-1,1,2-trifluoroethane',
    'C<sub>2</sub>HCl<sub>2</sub>F<sub>3</sub>',
    '',
    '354-23-4',
    'YMRMDGSNYHCUCL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloro-1,1,2-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dichloro-1,1,1-trifluoroethane',
    'C<sub>2</sub>HF<sub>3</sub>Cl<sub>2</sub>',
    'R123',
    '306-83-2',
    'OHMHBGPWCHTMQE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;4</sup>',
    '2400',
    'M',
    (SELECT id from species WHERE iupac='2,2-dichloro-1,1,1-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2939'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;4</sup>',
    '3100',
    'M',
    (SELECT id from species WHERE iupac='2,2-dichloro-1,1,1-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2121'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2121-306-83-2-ABC',
    '2121', 'The data from Chang and Criddle (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;402.28495 +20229.16189/T +57.28419&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2121-306-83-2-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;4</sup>',
    '2600',
    'V',
    (SELECT id from species WHERE iupac='2,2-dichloro-1,1,1-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='1014'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dichloro-1,1,1-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dichloro-1,1,1-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-chloro-1,1,2,2-tetrafluoroethane',
    'C<sub>2</sub>HClF<sub>4</sub>',
    '',
    '354-25-6',
    'JQZFYIGAYWLRCC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-1,1,2,2-tetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-chloro-1,2,2,2-tetrafluoroethane',
    'C<sub>2</sub>HF<sub>4</sub>Cl',
    'R124',
    '2837-89-0',
    'BOUGCJDAQLKBQH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '2800',
    'M',
    (SELECT id from species WHERE iupac='1-chloro-1,2,2,2-tetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2939'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;4</sup>',
    '3500',
    'M',
    (SELECT id from species WHERE iupac='1-chloro-1,2,2,2-tetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='923'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0923-2837-89-0-ABC',
    '923', 'The data from Maaßen (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;277.88370 +14905.51805/T +38.38688&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0923-2837-89-0-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '3400',
    'M',
    (SELECT id from species WHERE iupac='1-chloro-1,2,2,2-tetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2013'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2013-2837-89-0-ABC',
    '2013', 'The data from Reichl (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;195.56650 +11207.08869/T +26.12575&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2013-2837-89-0-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-chloro-1,2,2,2-tetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;4</sup>',
    '3200',
    'V',
    (SELECT id from species WHERE iupac='1-chloro-1,2,2,2-tetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='1014'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-1,2,2,2-tetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-1,2,2,2-tetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2900',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-1,2,2,2-tetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3400',
    '?',
    (SELECT id from species WHERE iupac='1-chloro-1,2,2,2-tetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-dichloro-1,1-difluoroethane',
    'C<sub>2</sub>H<sub>2</sub>Cl<sub>2</sub>F<sub>2</sub>',
    '',
    '1649-08-7',
    'SKDFWEPBABSFMG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dichloro-1,1-difluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dichloro-1,1-difluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dichloro-1,1-difluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-chloro-1,1,1-trifluoroethane',
    'C<sub>2</sub>H<sub>2</sub>F<sub>3</sub>Cl',
    'R133a',
    '75-88-7',
    'CYXIKYKBLDZZNW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;4</sup>',
    '3600',
    'M',
    (SELECT id from species WHERE iupac='2-chloro-1,1,1-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='923'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0923-75-88-7-ABC',
    '923', 'The data from Maaßen (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;249.15404 +13774.89590/T +34.23234&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0923-75-88-7-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;4</sup>',
    '3500',
    'M',
    (SELECT id from species WHERE iupac='2-chloro-1,1,1-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2013'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2013-75-88-7-ABC',
    '2013', 'The data from Reichl (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;210.55601 +11968.42846/T +28.54087&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2013-75-88-7-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-chloro-1,1,1-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;4</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='2-chloro-1,1,1-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-1,1,1-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-1,1,1-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-1,1,1-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-1,1,1-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-1,1,1-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-1,1,1-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-chloro-1,1,1-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1-dichloro-1-fluoroethane',
    'CH<sub>3</sub>CFCl<sub>2</sub>',
    'R141b',
    '1717-00-6',
    'FRCHKSNAZZFGCA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;4</sup>',
    '2800',
    'M',
    (SELECT id from species WHERE iupac='1,1-dichloro-1-fluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2939'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;4</sup>',
    '3700',
    'M',
    (SELECT id from species WHERE iupac='1,1-dichloro-1-fluoroethane'),
    (SELECT id from literature WHERE bibtexkey='923'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0923-1717-00-6-ABC',
    '923', 'The data from Maaßen (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;155.04312 +9704.04801/T +20.06575&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0923-1717-00-6-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1-dichloro-1-fluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1-dichloro-1-fluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;5</sup>',
    '5200',
    'V',
    (SELECT id from species WHERE iupac='1,1-dichloro-1-fluoroethane'),
    (SELECT id from literature WHERE bibtexkey='1014'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichloro-1-fluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichloro-1-fluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;4</sup>',
    '3500',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichloro-1-fluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3570'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3300',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dichloro-1-fluoroethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3700',
    '?',
    (SELECT id from species WHERE iupac='1,1-dichloro-1-fluoroethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-chloro-1,1-difluoroethane',
    'CH<sub>3</sub>CF<sub>2</sub>Cl',
    'R142b',
    '75-68-3',
    'BHNZEZWIUMJCGF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;4</sup>',
    '2600',
    'M',
    (SELECT id from species WHERE iupac='1-chloro-1,1-difluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2939'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;4</sup>',
    '3200',
    'M',
    (SELECT id from species WHERE iupac='1-chloro-1,1-difluoroethane'),
    (SELECT id from literature WHERE bibtexkey='923'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0923-75-68-3-ABC',
    '923', 'The data from Maaßen (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;270.78344 +14413.03953/T +37.48366&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0923-75-68-3-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;4</sup>',
    '3200',
    'M',
    (SELECT id from species WHERE iupac='1-chloro-1,1-difluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2013'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2013-75-68-3-ABC',
    '2013', 'The data from Reichl (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;184.96240 +10541.13831/T +24.70437&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2013-75-68-3-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;4</sup>',
    '3000',
    'M',
    (SELECT id from species WHERE iupac='1-chloro-1,1-difluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2121'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2121-75-68-3-ABC',
    '2121', 'The data from Chang and Criddle (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;190.58060 +10602.65774/T +25.66197&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2121-75-68-3-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;4</sup>',
    '2500',
    'V',
    (SELECT id from species WHERE iupac='1-chloro-1,1-difluoroethane'),
    (SELECT id from literature WHERE bibtexkey='1014'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;4</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1-chloro-1,1-difluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at294K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-1,1-difluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;4</sup>',
    '3200',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-1,1-difluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3570'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-1,1-difluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-1,1-difluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-1,1-difluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-1,1-difluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-chloro-1,2-difluoroethane',
    'C<sub>2</sub>H<sub>3</sub>ClF<sub>2</sub>',
    '',
    '338-64-7',
    'UOVSDUIHNGNMBZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2900',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-1,2-difluoroethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3200',
    '?',
    (SELECT id from species WHERE iupac='1-chloro-1,2-difluoroethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-chloro-1,1,2-trifluoroethane',
    'C<sub>2</sub>H<sub>2</sub>F<sub>3</sub>Cl',
    'R133b',
    '421-04-5',
    'HILNUELUDBMBJQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2900',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-1,1,2-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3500',
    '?',
    (SELECT id from species WHERE iupac='1-chloro-1,1,2-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-chloro-1,1-difluoroethene',
    'C<sub>2</sub>HClF<sub>2</sub>',
    'R1122',
    '359-10-4',
    'HTHNTJCVPNKCPZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;4</sup>',
    '3300',
    'M',
    (SELECT id from species WHERE iupac='2-chloro-1,1-difluoroethene'),
    (SELECT id from literature WHERE bibtexkey='923'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0923-359-10-4-ABC',
    '923', 'The data from Maaßen (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;237.50724 +13032.41274/T +32.48569&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0923-359-10-4-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;4</sup>',
    '3300',
    'M',
    (SELECT id from species WHERE iupac='2-chloro-1,1-difluoroethene'),
    (SELECT id from literature WHERE bibtexkey='2013'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2013-359-10-4-ABC',
    '2013', 'The data from Reichl (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;200.95912 +11406.81841/T +27.03092&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2013-359-10-4-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-1,1-difluoroethene'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2800',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-1,1-difluoroethene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3300',
    '?',
    (SELECT id from species WHERE iupac='2-chloro-1,1-difluoroethene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-chloro-1,1-difluoroethene'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chlorotrifluoroethene',
    'C<sub>2</sub>ClF<sub>3</sub>',
    '',
    '79-38-9',
    'UUAGAQFQZIEFAH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorotrifluoroethene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3-dichloro-1,1,1,2,2-pentafluoropropane',
    'CF<sub>3</sub>CF<sub>2</sub>CHCl<sub>2</sub>',
    'R225ca',
    '422-56-0',
    'COAUHYBSXMIJDK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;5</sup>',
    '3500',
    'M',
    (SELECT id from species WHERE iupac='3,3-dichloro-1,1,1,2,2-pentafluoropropane'),
    (SELECT id from literature WHERE bibtexkey='2939'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dichloro-1,1,1,2,2-pentafluoropropane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dichloro-1,1,1,2,2-pentafluoropropane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dichloro-1,1,1,2,2-pentafluoropropane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dichloro-1,1,1,2,2-pentafluoropropane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dichloro-1,1,1,2,2-pentafluoropropane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dichloro-1,1,1,2,2-pentafluoropropane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dichloro-1,1,1,2,2-pentafluoropropane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,3-dichloro-1,1,1,2,2-pentafluoropropane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3-dichloro-1,1,2,2,3-pentafluoro-propane',
    'CClF<sub>2</sub>CF<sub>2</sub>CHClF',
    'R225cb',
    '507-55-1',
    'UJIGKESMIPTWJH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '3100',
    'M',
    (SELECT id from species WHERE iupac='1,3-dichloro-1,1,2,2,3-pentafluoro-propane'),
    (SELECT id from literature WHERE bibtexkey='2939'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dichloro-1,1,2,2,3-pentafluoro-propane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-chloro-2-fluorobenzene',
    'C<sub>6</sub>H<sub>4</sub>ClF',
    '',
    '348-51-6',
    'ZCJAYDKWZAWMPR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-chloro-2-fluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-chloro-3-fluorobenzene',
    'C<sub>6</sub>H<sub>4</sub>ClF',
    '',
    '625-98-9',
    'VZHJIJZEOCBKRA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-chloro-3-fluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-chloro-3-(trifluoromethyl)benzene',
    'C<sub>7</sub>H<sub>4</sub>ClF<sub>3</sub>',
    '',
    '98-15-7',
    'YTCGOUNVIAWCMG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-3-(trifluoromethyl)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-3-(trifluoromethyl)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-3-(trifluoromethyl)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-3-(trifluoromethyl)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-chloro-4-(trifluoromethyl)benzene',
    'C<sub>7</sub>H<sub>4</sub>ClF<sub>3</sub>',
    '',
    '98-56-6',
    'QULYNCCPRWKEMF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-4-(trifluoromethyl)benzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-4-(trifluoromethyl)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-4-(trifluoromethyl)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-4-(trifluoromethyl)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-4-(trifluoromethyl)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-chloro-4-fluorobenzotrifluoride',
    'C<sub>7</sub>H<sub>3</sub>ClF<sub>4</sub>',
    '',
    '78068-85-6',
    'BKHVEYHSOXVAOP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-chloro-4-fluorobenzotrifluoride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-chloro-4-fluorobenzotrifluoride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-chloro-4-fluorobenzotrifluoride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-chloro-4-fluorobenzotrifluoride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4-dichlorobenzotrifluoride',
    'C<sub>7</sub>H<sub>3</sub>Cl<sub>2</sub>F<sub>3</sub>',
    '',
    '328-84-7',
    'XILPLWOGHPSJBK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dichlorobenzotrifluoride'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dichlorobenzotrifluoride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dichlorobenzotrifluoride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dichlorobenzotrifluoride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dichlorobenzotrifluoride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chlorodifluoroethanoic acid',
    'CF<sub>2</sub>ClCOOH',
    'chlorodifluoroacetic acid',
    '76-04-0',
    'OAWAZQITIZDJRB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '10000',
    'L',
    (SELECT id from species WHERE iupac='chlorodifluoroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '10000',
    'L',
    (SELECT id from species WHERE iupac='chlorodifluoroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '10000',
    'L',
    (SELECT id from species WHERE iupac='chlorodifluoroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>2</sup>',
    '10000',
    'M',
    (SELECT id from species WHERE iupac='chlorodifluoroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='896'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorodifluoroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorodifluoroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorodifluoroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorodifluoroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorodifluoroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chlorodifluoroethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'carbonic chloride fluoride',
    'COFCl',
    '',
    '353-49-1',
    'OXVVNXMNLYYMOL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='carbonic chloride fluoride'),
    (SELECT id from literature WHERE bibtexkey='george93'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from498'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'trifluoroacetylchloride',
    'CF<sub>3</sub>COCl',
    '',
    '354-32-5',
    'PNQBEPDZQUOCNY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trifluoroacetylchloride'),
    (SELECT id from literature WHERE bibtexkey='671'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trifluoroacetylchloride'),
    (SELECT id from literature WHERE bibtexkey='1125'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at278K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trifluoroacetylchloride'),
    (SELECT id from literature WHERE bibtexkey='1127'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at284K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trifluoroacetylchloride'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trifluoroacetylchloride'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='trifluoroacetylchloride'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dichloro-1,1-difluoro-1-methoxyethane',
    'C<sub>3</sub>H<sub>4</sub>Cl<sub>2</sub>F<sub>2</sub>O',
    'methoxyflurane',
    '76-38-0',
    'RFKMCNOHBTXSMU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '4100',
    'L',
    (SELECT id from species WHERE iupac='2,2-dichloro-1,1-difluoro-1-methoxyethane'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2,2-dichloro-1,1-difluoro-1-methoxyethane'),
    (SELECT id from literature WHERE bibtexkey='2441'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '4300',
    'L',
    (SELECT id from species WHERE iupac='2,2-dichloro-1,1-difluoro-1-methoxyethane'),
    (SELECT id from literature WHERE bibtexkey='3696'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2-dichloro-1,1-difluoro-1-methoxyethane'),
    (SELECT id from literature WHERE bibtexkey='2444'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '3600',
    'M',
    (SELECT id from species WHERE iupac='2,2-dichloro-1,1-difluoro-1-methoxyethane'),
    (SELECT id from literature WHERE bibtexkey='2445'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2445-76-38-0-ABC',
    '2445', 'The data from Smith et&nbsp;al. (1981b) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( 678.00770 &#8722;27346.39638/T &#8722;103.92351&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2445-76-38-0-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2-dichloro-1,1-difluoro-1-methoxyethane'),
    (SELECT id from literature WHERE bibtexkey='2467'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dichloro-1,1-difluoro-1-methoxyethane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dichloro-1,1-difluoro-1-methoxyethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dichloro-1,1-difluoro-1-methoxyethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dichloro-1,1-difluoro-1-methoxyethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4800',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dichloro-1,1-difluoro-1-methoxyethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2-dichloro-1,1-difluoro-1-methoxyethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2-dichloro-1,1-difluoro-1-methoxyethane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-3072'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4000',
    '?',
    (SELECT id from species WHERE iupac='2,2-dichloro-1,1-difluoro-1-methoxyethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2-dichloro-1,1-difluoro-1-methoxyethane'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2-dichloro-1,1-difluoro-1-methoxyethane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-(chlorodifluoromethoxy)-1,1,1-trifluoroethane',
    'C<sub>3</sub>H<sub>2</sub>ClF<sub>5</sub>O',
    '',
    '33018-78-9',
    'HPDPVPUXPBZBOJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-(chlorodifluoromethoxy)-1,1,1-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-(chlorofluoromethoxy)-1,1,1,2-tetrafluoroethane',
    'C<sub>3</sub>H<sub>2</sub>ClF<sub>5</sub>O',
    '',
    '56885-28-0',
    'GGEBMRHBGQLKGJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-(chlorofluoromethoxy)-1,1,1,2-tetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-chloro-2,2,2-trifluoroethyl difluoromethyl ether',
    'C<sub>3</sub>H<sub>2</sub>ClF<sub>5</sub>O',
    'forane; isoflurane',
    '26675-46-7',
    'PIWKPBJCKXDKJR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-chloro-2,2,2-trifluoroethyl difluoromethyl ether'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-chloro-2,2,2-trifluoroethyl difluoromethyl ether'),
    (SELECT id from literature WHERE bibtexkey='2441'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-chloro-2,2,2-trifluoroethyl difluoromethyl ether'),
    (SELECT id from literature WHERE bibtexkey='3696'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-chloro-2,2,2-trifluoroethyl difluoromethyl ether'),
    (SELECT id from literature WHERE bibtexkey='2444'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;4</sup>',
    '5300',
    'M',
    (SELECT id from species WHERE iupac='1-chloro-2,2,2-trifluoroethyl difluoromethyl ether'),
    (SELECT id from literature WHERE bibtexkey='2445'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-2,2,2-trifluoroethyl difluoromethyl ether'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-2,2,2-trifluoroethyl difluoromethyl ether'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-2,2,2-trifluoroethyl difluoromethyl ether'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-2,2,2-trifluoroethyl difluoromethyl ether'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4400',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-2,2,2-trifluoroethyl difluoromethyl ether'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-2,2,2-trifluoroethyl difluoromethyl ether'),
    (SELECT id from literature WHERE bibtexkey='3780'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-chloro-2,2,2-trifluoroethyl difluoromethyl ether'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-chloro-2,2,2-trifluoroethyl difluoromethyl ether'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-3072'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4500',
    '?',
    (SELECT id from species WHERE iupac='1-chloro-2,2,2-trifluoroethyl difluoromethyl ether'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-chloro-2,2,2-trifluoroethyl difluoromethyl ether'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-chloro-2,2,2-trifluoroethyl difluoromethyl ether'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-chloro-1,1,2-trifluoroethyl difluoromethyl ether',
    'C<sub>3</sub>H<sub>2</sub>ClF<sub>5</sub>O',
    'enflurane',
    '13838-16-9',
    'JPGQOUSTVILISH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2-chloro-1,1,2-trifluoroethyl difluoromethyl ether'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2-chloro-1,1,2-trifluoroethyl difluoromethyl ether'),
    (SELECT id from literature WHERE bibtexkey='3696'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-chloro-1,1,2-trifluoroethyl difluoromethyl ether'),
    (SELECT id from literature WHERE bibtexkey='2924'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-chloro-1,1,2-trifluoroethyl difluoromethyl ether'),
    (SELECT id from literature WHERE bibtexkey='2444'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-chloro-1,1,2-trifluoroethyl difluoromethyl ether'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;4</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='2-chloro-1,1,2-trifluoroethyl difluoromethyl ether'),
    (SELECT id from literature WHERE bibtexkey='2441'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-1,1,2-trifluoroethyl difluoromethyl ether'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-chloro-1,1,2-trifluoroethyl difluoromethyl ether'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-[2-chloro-4-(trifluoromethyl)phenoxy]benzoic acid',
    'C<sub>14</sub>H<sub>8</sub>ClF<sub>3</sub>O<sub>3</sub>',
    '',
    '63734-62-3',
    'ONKRUAQFUNKYAX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-[2-chloro-4-(trifluoromethyl)phenoxy]benzoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-[2-chloro-4-(trifluoromethyl)phenoxy]benzoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-[2-chloro-4-(trifluoromethyl)phenoxy]benzoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-[2-chloro-4-(trifluoromethyl)phenoxy]benzoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-(2-chloro-4-(trifluoromethyl)phenoxy)phenyl acetate',
    'C<sub>15</sub>H<sub>10</sub>ClF<sub>3</sub>O<sub>3</sub>',
    '',
    '50594-77-9',
    'KNFRYRRZMRETJX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-(2-chloro-4-(trifluoromethyl)phenoxy)phenyl acetate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-(2-chloro-4-(trifluoromethyl)phenoxy)phenyl acetate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-(2-chloro-4-(trifluoromethyl)phenoxy)phenyl acetate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-(2-chloro-4-(trifluoromethyl)phenoxy)phenyl acetate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'transfluthrin',
    'C<sub>15</sub>H<sub>12</sub>Cl<sub>2</sub>F<sub>4</sub>O<sub>2</sub>',
    '',
    '118712-89-3',
    'DDVNRFNDOPPVQJ-HQJQHLMTSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='transfluthrin'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tefluthrin',
    'C<sub>17</sub>H<sub>14</sub>O<sub>2</sub>ClF<sub>7</sub>',
    '',
    '79538-32-2',
    'ZFHGXWPMULPQSE-GPCIZFCYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tefluthrin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tefluthrin'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'clobetasol',
    'C<sub>22</sub>H<sub>28</sub>ClFO<sub>4</sub>',
    '',
    '25122-41-2',
    'FCSHDIVRCWTZOX-DVTGEIKXSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='clobetasol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'flufenprox',
    'C<sub>24</sub>H<sub>22</sub>ClF<sub>3</sub>O<sub>3</sub>',
    '',
    '107713-58-6',
    'RURQAJURNPMSSK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='flufenprox'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'EINECS 273-236-7',
    'C<sub>28</sub>H<sub>33</sub>Cl<sub>3</sub>F<sub>6</sub>O<sub>11</sub>',
    '',
    '68954-01-8',
    'KVXVLCBFSKMBAR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>14</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='EINECS 273-236-7'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>18</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='EINECS 273-236-7'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>12</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='EINECS 273-236-7'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>15</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='EINECS 273-236-7'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,5-dichloro-2,4,6-trifluoropyridine',
    'C<sub>5</sub>Cl<sub>2</sub>F<sub>3</sub>N',
    '',
    '1737-93-5',
    'PKSORSNCSXBXOT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dichloro-2,4,6-trifluoropyridine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dichloro-2,4,6-trifluoropyridine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dichloro-2,4,6-trifluoropyridine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dichloro-2,4,6-trifluoropyridine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chlorodifluoronitrooxymethane',
    'CClF<sub>2</sub>OONO<sub>2</sub>',
    '',
    '70490-95-8',
    'HWHZTSGXJYKIPK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '5900',
    'E',
    (SELECT id from species WHERE iupac='chlorodifluoronitrooxymethane'),
    (SELECT id from literature WHERE bibtexkey='498'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '498XPAN',
    '498', 'Kanakidou et&nbsp;al. (1995) assume H<sub>s</sub>(CClF<sub>2</sub>OONO<sub>2</sub>) = H<sub>s</sub>(PAN).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='498XPAN'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-chloro-2-nitro-4-(trifluoromethyl)-benzene',
    'C<sub>7</sub>H<sub>3</sub>ClF<sub>3</sub>NO<sub>2</sub>',
    '',
    '121-17-5',
    'TZGFQIXRVUHDLE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-2-nitro-4-(trifluoromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-2-nitro-4-(trifluoromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-2-nitro-4-(trifluoromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-2-nitro-4-(trifluoromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-chloro-1,3-dinitro-5-(trifluoromethyl)-benzene',
    'C<sub>7</sub>H<sub>2</sub>ClF<sub>3</sub>N<sub>2</sub>O<sub>4</sub>',
    '',
    '393-75-9',
    'HFHAVERNVFNSHL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-1,3-dinitro-5-(trifluoromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-1,3-dinitro-5-(trifluoromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-1,3-dinitro-5-(trifluoromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloro-1,3-dinitro-5-(trifluoromethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fluroxypyr',
    'C<sub>7</sub>H<sub>5</sub>Cl<sub>2</sub>FN<sub>2</sub>O<sub>3</sub>',
    '',
    '69377-81-7',
    'MEFQWPUMEMWTJP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='fluroxypyr'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>9</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fluroxypyr'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fluoroimide',
    'C<sub>10</sub>H<sub>4</sub>Cl<sub>2</sub>FNO<sub>2</sub>',
    '',
    '41205-21-4',
    'IPENDKRRWFURRE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fluoroimide'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'norflurazon',
    'C<sub>12</sub>H<sub>9</sub>ClF<sub>3</sub>N<sub>3</sub>O',
    '',
    '27314-13-2',
    'NVGOPFQZYCNLDU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='norflurazon'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='norflurazon'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='norflurazon'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fluchloralin',
    'C<sub>12</sub>H<sub>13</sub>ClF<sub>3</sub>N<sub>3</sub>O<sub>4</sub>',
    '',
    '33245-39-5',
    'MNFMIVVPXOGUMX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='fluchloralin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='fluchloralin'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'flurochloridone',
    'C<sub>12</sub>H<sub>10</sub>Cl<sub>2</sub>F<sub>3</sub>NO',
    '',
    '61213-25-0',
    'OQZCSNDVOWYALR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='flurochloridone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='flurochloridone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='flurochloridone'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'flupyradifurone',
    'C<sub>12</sub>H<sub>11</sub>ClF<sub>2</sub>N<sub>2</sub>O<sub>2</sub>',
    '',
    '951659-40-8',
    'QOIYTRGFOFZNKF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='flupyradifurone'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fluxofenim',
    'C<sub>12</sub>H<sub>11</sub>NO<sub>3</sub>ClF<sub>3</sub>',
    '',
    '88485-37-4',
    'UKSLKNUCVPZQCQ-GZTJUZNOSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6',
    '',
    'V',
    (SELECT id from species WHERE iupac='fluxofenim'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fluxofenim'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fluazinam',
    'C<sub>13</sub>H<sub>4</sub>Cl<sub>2</sub>F<sub>6</sub>N<sub>4</sub>O<sub>4</sub>',
    '',
    '79622-59-6',
    'UZCGKGPEKUCDTF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='fluazinam'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fluazinam'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-(2-chloro-4-(trifluoromethyl)phenoxy)-2-nitrophenol',
    'C<sub>13</sub>H<sub>7</sub>ClF<sub>3</sub>NO<sub>4</sub>',
    '',
    '42874-63-5',
    'WYTRKEWETULQOA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-(2-chloro-4-(trifluoromethyl)phenoxy)-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-(2-chloro-4-(trifluoromethyl)phenoxy)-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-(2-chloro-4-(trifluoromethyl)phenoxy)-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-(2-chloro-4-(trifluoromethyl)phenoxy)-2-nitrophenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'florpyrauxifen',
    'C<sub>13</sub>H<sub>8</sub>Cl<sub>2</sub>F<sub>2</sub>N<sub>2</sub>O<sub>3</sub>',
    '',
    '943832-81-3',
    'XFZUQTKDBCOXPP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='florpyrauxifen'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tetraconazole',
    'C<sub>13</sub>H<sub>11</sub>Cl<sub>2</sub>F<sub>4</sub>N<sub>3</sub>O',
    '',
    '112281-77-3',
    'LQDARGUHUSPFNL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tetraconazole'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tetraconazole'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fluopicolide',
    'C<sub>14</sub>H<sub>8</sub>Cl<sub>3</sub>F<sub>3</sub>N<sub>2</sub>O',
    '',
    '239110-15-7',
    'GBOYJIHYACSLGN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='fluopicolide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fluopicolide'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diflubenzuron',
    'C<sub>14</sub>H<sub>9</sub>ClF<sub>2</sub>N<sub>2</sub>O<sub>2</sub>',
    'difluron',
    '35367-38-5',
    'QQQYTWIFVNKMRW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diflubenzuron'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diflubenzuron'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diflubenzuron'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='diflubenzuron'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diflubenzuron'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diflubenzuron'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='diflubenzuron'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'efavirenz',
    'C<sub>14</sub>H<sub>9</sub>ClF<sub>3</sub>NO<sub>2</sub>',
    '',
    '154598-52-4',
    'XPOQHMRABVBWPR-ZDUSSCGKSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='efavirenz'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'halauxifen-methyl',
    'C<sub>14</sub>H<sub>11</sub>Cl<sub>2</sub>FN<sub>2</sub>O<sub>3</sub>',
    '',
    '943831-98-9',
    'KDHKOPYYWOHESS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='halauxifen-methyl'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH5'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='halauxifen-methyl'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH7'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='halauxifen-methyl'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH9'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='halauxifen-methyl'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fluroxypyr-butometyl',
    'C<sub>14</sub>H<sub>19</sub>Cl<sub>2</sub>FN<sub>2</sub>O<sub>4</sub>',
    '',
    '154486-27-8',
    'ZKFARSBUEBZZJT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fluroxypyr-butometyl'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'teflubenzuron',
    'C<sub>14</sub>H<sub>6</sub>N<sub>2</sub>O<sub>2</sub>Cl<sub>2</sub>F<sub>4</sub>',
    '',
    '83121-18-0',
    'CJDWRQLODFKPEL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='teflubenzuron'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='teflubenzuron'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fluroxypyr-meptyl',
    'C<sub>15</sub>H<sub>21</sub>Cl<sub>2</sub>FN<sub>2</sub>O<sub>3</sub>',
    'attain A',
    '81406-37-3',
    'OLZQTUCTGLHFTQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fluroxypyr-meptyl'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'quinoxyfen',
    'C<sub>15</sub>H<sub>8</sub>Cl<sub>2</sub>FNO',
    '',
    '124495-18-7',
    'WRPIRSINYZBGPK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='quinoxyfen'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-(2-chloro-4-(trifluoromethyl)phenoxy)-2-nitrophenyl acetate',
    'C<sub>15</sub>H<sub>9</sub>ClF<sub>3</sub>NO<sub>5</sub>',
    '',
    '50594-44-0',
    'PSWSPFSDVZVVDC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-(2-chloro-4-(trifluoromethyl)phenoxy)-2-nitrophenyl acetate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-(2-chloro-4-(trifluoromethyl)phenoxy)-2-nitrophenyl acetate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-(2-chloro-4-(trifluoromethyl)phenoxy)-2-nitrophenyl acetate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-(2-chloro-4-(trifluoromethyl)phenoxy)-2-nitrophenyl acetate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'triflumuron',
    'C<sub>15</sub>H<sub>10</sub>ClF<sub>3</sub>N<sub>2</sub>O<sub>3</sub>',
    '',
    '64628-44-0',
    'XAIPTRIXGHTTNT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='triflumuron'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'oxyfluorfen',
    'C<sub>15</sub>H<sub>11</sub>ClF<sub>3</sub>NO<sub>4</sub>',
    '',
    '42874-03-3',
    'OQMBBFQZGJFLBU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='oxyfluorfen'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='oxyfluorfen'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='oxyfluorfen'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='oxyfluorfen'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pyraflufen-ethyl',
    'C<sub>15</sub>H<sub>13</sub>Cl<sub>2</sub>F<sub>3</sub>N<sub>2</sub>O<sub>4</sub>',
    '',
    '129630-19-9',
    'APTZNLHMIGJTEW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='pyraflufen-ethyl'),
    (SELECT id from literature WHERE bibtexkey='macbean2012'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pyraflufen-ethyl'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>cis</i>-furconazole',
    'C<sub>15</sub>H<sub>14</sub>Cl<sub>2</sub>F<sub>3</sub>N<sub>3</sub>O<sub>2</sub>',
    '',
    '112839-32-4',
    'ULCWZQJLFZEXCS-KGLIPLIRSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='<i>cis</i>-furconazole'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'carfentrazone ethyl',
    'C<sub>15</sub>H<sub>14</sub>Cl<sub>2</sub>F<sub>3</sub>N<sub>3</sub>O<sub>3</sub>',
    '',
    '128639-02-1',
    'MLKCGVHIFJBRCD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='carfentrazone ethyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='carfentrazone ethyl'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='carfentrazone ethyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='carfentrazone ethyl'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'triflumizole',
    'C<sub>15</sub>H<sub>15</sub>ClF<sub>3</sub>N<sub>3</sub>O',
    '',
    '68694-11-1',
    'HSMVPDGQOIQYSR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='triflumizole'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>7</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='triflumizole'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triflumizole'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diflumetorim',
    'C<sub>15</sub>H<sub>16</sub>N<sub>3</sub>OClF<sub>2</sub>',
    '',
    '130339-07-0',
    'NEKULYKCZPJMMJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diflumetorim'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diflumetorim'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-(2,4-dichlorophenyl)-6-fluoro-2-(1H-1,2,4-triazol-1-yl)-quinazolin-4(3H)-one',
    'C<sub>16</sub>H<sub>8</sub>Cl<sub>2</sub>FN<sub>5</sub>O',
    'fluquinconazole',
    '136426-54-5',
    'IJJVMEJXYNJXOJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-(2,4-dichlorophenyl)-6-fluoro-2-(1H-1,2,4-triazol-1-yl)-quinazolin-4(3H)-one'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-(2,4-dichlorophenyl)-6-fluoro-2-(1H-1,2,4-triazol-1-yl)-quinazolin-4(3H)-one'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-(2,4-dichlorophenyl)-6-fluoro-2-(1H-1,2,4-triazol-1-yl)-quinazolin-4(3H)-one'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hexaflumuron',
    'C<sub>16</sub>H<sub>8</sub>Cl<sub>2</sub>F<sub>6</sub>N<sub>2</sub>O<sub>3</sub>',
    '',
    '86479-06-3',
    'RGNPBRKPHBKNKX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexaflumuron'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexaflumuron'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexaflumuron'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fluopyram',
    'C<sub>16</sub>H<sub>11</sub>ClF<sub>6</sub>N<sub>2</sub>O',
    '',
    '658066-35-4',
    'KVDJTXBXMWJJEF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fluopyram'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'haloxyfop-p-methyl',
    'C<sub>16</sub>H<sub>13</sub>ClF<sub>3</sub>NO<sub>4</sub>',
    '',
    '72619-32-0',
    'MFSWTRQUCLNFOM-SECBINFHSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='haloxyfop-p-methyl'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'flumetralin',
    'C<sub>16</sub>H<sub>12</sub>ClF<sub>4</sub>N<sub>3</sub>O<sub>4</sub>',
    '',
    '62924-70-3',
    'PWNAWOCHVWERAR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2',
    '',
    'V',
    (SELECT id from species WHERE iupac='flumetralin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='flumetralin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'haloxyfop-methyl',
    'C<sub>16</sub>H<sub>13</sub>ClF<sub>3</sub>NO<sub>4</sub>',
    '',
    '69806-40-2',
    'MFSWTRQUCLNFOM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='haloxyfop-methyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='haloxyfop-methyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pydiflumetofen',
    'C<sub>16</sub>H<sub>16</sub>Cl<sub>3</sub>F<sub>2</sub>N<sub>3</sub>O<sub>2</sub>',
    '',
    '1228284-64-7',
    'DGOAXBPOVUPPEB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pydiflumetofen'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nuarimol',
    'C<sub>17</sub>H<sub>12</sub>ClFN<sub>2</sub>O',
    '',
    '63284-71-9',
    'SAPGTCDSBGMXCD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='nuarimol'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'clodinafop-propargyl',
    'C<sub>17</sub>H<sub>13</sub>ClFNO<sub>4</sub>',
    '',
    '105512-06-9',
    'JBDHZKLJNAIJNC-LLVKDONJSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='clodinafop-propargyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='clodinafop-propargyl'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='clodinafop-propargyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='clodinafop-propargyl'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'flamprop-methyl',
    'C<sub>17</sub>H<sub>15</sub>ClFNO<sub>3</sub>',
    '',
    '52756-25-9',
    'RBNIGDFIUWJJEV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='flamprop-methyl'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pyridalyl',
    'C<sub>18</sub>H<sub>14</sub>Cl<sub>4</sub>F<sub>3</sub>NO<sub>3</sub>',
    '',
    '179101-81-6',
    'UBSUICNYBBPFHD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pyridalyl'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'mefentrifluconazole',
    'C<sub>18</sub>H<sub>15</sub>ClF<sub>3</sub>N<sub>3</sub>O<sub>2</sub>',
    '',
    '1417782-03-6',
    'JERZEQUMJNCPRJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='mefentrifluconazole'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bixafen',
    'C<sub>18</sub>H<sub>12</sub>N<sub>3</sub>OCl<sub>2</sub>F<sub>3</sub>',
    '',
    '581809-46-3',
    'LDLMOOXUCMHBMZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='bixafen'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benzovindiflupyr',
    'C<sub>18</sub>H<sub>15</sub>Cl<sub>2</sub>F<sub>2</sub>N<sub>3</sub>O',
    '',
    '1072957-71-1',
    'CCCGEKHKTPTUHJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='benzovindiflupyr'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'lactofen',
    'C<sub>19</sub>H<sub>15</sub>ClF<sub>3</sub>NO<sub>7</sub>',
    '',
    '77501-63-4',
    'CONWAEURSVPLRM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='lactofen'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='lactofen'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='lactofen'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'flupoxam',
    'C<sub>19</sub>H<sub>14</sub>N<sub>4</sub>O<sub>2</sub>ClF<sub>5</sub>',
    '',
    '119126-15-7',
    'AOQMRUTZEYVDIL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='flupoxam'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='flupoxam'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'flamprop-m-isopropyl',
    'C<sub>19</sub>H<sub>19</sub>NO<sub>3</sub>ClF',
    '',
    '63782-90-1',
    'IKVXBIIHQGXQRQ-CYBMUJFWSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='flamprop-m-isopropyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='flamprop-m-isopropyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'haloxyfop-ethoxyethyl',
    'C<sub>19</sub>H<sub>19</sub>ClF<sub>3</sub>NO<sub>5</sub>',
    '',
    '87237-48-7',
    'MIJLZGZLQLAQCM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='haloxyfop-ethoxyethyl'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chlorfluazuron',
    'C<sub>20</sub>H<sub>9</sub>Cl<sub>3</sub>F<sub>5</sub>N<sub>3</sub>O<sub>3</sub>',
    '',
    '71422-67-8',
    'UISUNVFOGSJSKD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorfluazuron'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorfluazuron'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorfluazuron'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorfluazuron'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chlorfluazuron'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fluazuron',
    'C<sub>20</sub>H<sub>10</sub>N<sub>3</sub>O<sub>3</sub>Cl<sub>2</sub>F<sub>5</sub>',
    '',
    '86811-58-7',
    'YOWNVPAUWYHLQX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 2.3&times;10<sup>10</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fluazuron'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'flufenoxuron',
    'C<sub>21</sub>H<sub>11</sub>ClF<sub>6</sub>N<sub>2</sub>O<sub>3</sub>',
    '',
    '101463-69-8',
    'RYLHNOVXKPXDIP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='flufenoxuron'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fluoxastrobin',
    'C<sub>21</sub>H<sub>16</sub>N<sub>4</sub>O<sub>5</sub>ClF',
    '',
    '361377-29-9',
    'UFEODZBUAFNAEU-NLRVBDNBSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='fluoxastrobin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fluoxastrobin'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'haloperidol',
    'C<sub>21</sub>H<sub>23</sub>ClFNO<sub>2</sub>',
    '',
    '52-86-8',
    'LNEPOXFFQSENCJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='haloperidol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'indoxacarb',
    'C<sub>22</sub>H<sub>17</sub>ClF<sub>3</sub>N<sub>3</sub>O<sub>7</sub>',
    '',
    '173584-44-6',
    'VBCVPMMZEGZULK-NRFANRHFSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='indoxacarb'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 1.7&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='indoxacarb'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cyfluthrin',
    'C<sub>22</sub>H<sub>18</sub>Cl<sub>2</sub>FNO<sub>3</sub>',
    '',
    '68359-37-5',
    'QQODLKZGRKWIFG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cyfluthrin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cyfluthrin'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    '?',
    (SELECT id from species WHERE iupac='cyfluthrin'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cyfluthrin I',
    'C<sub>22</sub>H<sub>18</sub>Cl<sub>2</sub>FNO<sub>3</sub>',
    '',
    '86560-92-1',
    'QQODLKZGRKWIFG-QSFXBCCZSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    '?',
    (SELECT id from species WHERE iupac='cyfluthrin I'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '&#946;-cyfluthrin (cis)',
    'C<sub>22</sub>H<sub>18</sub>Cl<sub>2</sub>FNO<sub>3</sub>',
    '',
    '86560-93-2',
    'QQODLKZGRKWIFG-XFQXTVEOSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='&#946;-cyfluthrin (cis)'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cyfluthrin II',
    'C<sub>22</sub>H<sub>18</sub>Cl<sub>2</sub>FNO<sub>3</sub>',
    '',
    '86560-94-3',
    'QQODLKZGRKWIFG-BPAFIMBUSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cyfluthrin II'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '&#946;-cyfluthrin (trans)',
    'C<sub>22</sub>H<sub>18</sub>Cl<sub>2</sub>FNO<sub>3</sub>',
    '',
    '86560-95-4',
    'QQODLKZGRKWIFG-QKYXUNIQSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='&#946;-cyfluthrin (trans)'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'metamifop',
    'C<sub>23</sub>H<sub>18</sub>N<sub>2</sub>O<sub>4</sub>ClF',
    '',
    '256412-89-2',
    'ADDQHLREJDZPMT-CQSZACIVSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='metamifop'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pyriminostrobin',
    'C<sub>23</sub>H<sub>18</sub>Cl<sub>2</sub>F<sub>3</sub>N<sub>3</sub>O<sub>4</sub>',
    '',
    '1257598-43-8',
    'YYXSCUSVVALMNW-FOWTUZBSSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pyriminostrobin'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cyhalothrin',
    'C<sub>23</sub>H<sub>19</sub>NO<sub>3</sub>ClF<sub>3</sub>',
    '',
    '68085-85-8',
    'ZXQYGBMAQZUVMI-BWHPXCRDSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyhalothrin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bifenthrin',
    'C<sub>23</sub>H<sub>22</sub>ClF<sub>3</sub>O<sub>2</sub>',
    '',
    '82657-04-3',
    'OMFRMAHOUUJSGP-UNOMPAQXSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9',
    '',
    'V',
    (SELECT id from species WHERE iupac='bifenthrin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9',
    '',
    'V',
    (SELECT id from species WHERE iupac='bifenthrin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9',
    '',
    'C',
    (SELECT id from species WHERE iupac='bifenthrin'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bifenthrin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bifenthrin'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '&#955;-cyhalothrin',
    'C<sub>23</sub>H<sub>19</sub>ClF<sub>3</sub>NO<sub>3</sub>',
    '',
    '91465-08-6',
    'DFVKOWFGNASVPK-QQDHXZELSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='&#955;-cyhalothrin'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '&#947;-cyhalothrin',
    'C<sub>23</sub>H<sub>19</sub>ClF<sub>3</sub>NO<sub>3</sub>',
    '',
    '76703-62-3',
    'ZXQYGBMAQZUVMI-GCMPRSNUSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='&#947;-cyhalothrin'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'flucycloxuron',
    'C<sub>25</sub>H<sub>20</sub>ClF<sub>2</sub>N<sub>3</sub>O<sub>3</sub>',
    '',
    '94050-52-9',
    'PCKNFPQPGUWFHO-UQRQXUALSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='flucycloxuron'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '&#964;-fluvalinate',
    'C<sub>26</sub>H<sub>22</sub>ClF<sub>3</sub>N<sub>2</sub>O<sub>3</sub>',
    '',
    '102851-06-9',
    'INISTDXBRIBGOC-XMMISQBUSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='&#964;-fluvalinate'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fluvalinate',
    'C<sub>26</sub>H<sub>22</sub>ClF<sub>3</sub>N<sub>2</sub>O<sub>3</sub>',
    '',
    '69409-94-5',
    'INISTDXBRIBGOC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Chlorofluorocarbons (C, H, O, N, F, Cl)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fluvalinate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO categories (catname) VALUES (
    'Organic species with bromine (Br)');
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Bromocarbons (C, H, O, N, Br)',
    (SELECT id from categories WHERE catname='Organic species with bromine (Br)'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bromomethane',
    'CH<sub>3</sub>Br',
    'methyl bromide',
    '74-83-9',
    'GZUXJHMPEANEGY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '3300',
    'L',
    (SELECT id from species WHERE iupac='bromomethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3500-74-83-9-consicheck',
    '3500', 'The H298 and A, B data listed in Table&nbsp;5-4 of Burkholder et&nbsp;al. (2019) are inconsistent, with 11&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3500-74-83-9-consicheck'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '3000',
    'L',
    (SELECT id from species WHERE iupac='bromomethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '3100',
    'L',
    (SELECT id from species WHERE iupac='bromomethane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '3000',
    'L',
    (SELECT id from species WHERE iupac='bromomethane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '3800',
    'L',
    (SELECT id from species WHERE iupac='bromomethane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '3100',
    'L',
    (SELECT id from species WHERE iupac='bromomethane'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '3100',
    'L',
    (SELECT id from species WHERE iupac='bromomethane'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '3100',
    'L',
    (SELECT id from species WHERE iupac='bromomethane'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '3100',
    'L',
    (SELECT id from species WHERE iupac='bromomethane'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '2800',
    'M',
    (SELECT id from species WHERE iupac='bromomethane'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='bromomethane'),
    (SELECT id from literature WHERE bibtexkey='3948'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at290K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3948_exptl'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '2500',
    'M',
    (SELECT id from species WHERE iupac='bromomethane'),
    (SELECT id from literature WHERE bibtexkey='3573'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3573-74-83-9-ABC',
    '3573', 'The data from De Bruyn and Saltzman (1997) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;521.17646 +25057.64644/T +75.60914&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3573-74-83-9-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='bromomethane'),
    (SELECT id from literature WHERE bibtexkey='892'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at294K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '3400',
    'M',
    (SELECT id from species WHERE iupac='bromomethane'),
    (SELECT id from literature WHERE bibtexkey='1342'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '2600',
    'M',
    (SELECT id from species WHERE iupac='bromomethane'),
    (SELECT id from literature WHERE bibtexkey='1340'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '3200',
    'M',
    (SELECT id from species WHERE iupac='bromomethane'),
    (SELECT id from literature WHERE bibtexkey='2222'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2222-74-83-9-ABC',
    '2222', 'The data from Glew and Moelwyn-Hughes (1953) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;184.73597 +10636.09284/T +25.03175&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2222-74-83-9-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bromomethane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bromomethane'),
    (SELECT id from literature WHERE bibtexkey='477'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bromomethane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bromomethane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bromomethane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='bromomethane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;5</sup>',
    '350',
    'X',
    (SELECT id from species WHERE iupac='bromomethane'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromomethane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromomethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromomethane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromomethane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromomethane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromomethane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromomethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromomethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromomethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromomethane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromomethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3400',
    'Q',
    (SELECT id from species WHERE iupac='bromomethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromomethane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromomethane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromomethane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromomethane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromomethane'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromomethane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromomethane'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='bromomethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='bromomethane'),
    (SELECT id from literature WHERE bibtexkey='3948'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at290K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3948_theor'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3200',
    '?',
    (SELECT id from species WHERE iupac='bromomethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='bromomethane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='bromomethane'),
    (SELECT id from literature WHERE bibtexkey='1330'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='bromomethane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='bromomethane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dibromomethane',
    'CH<sub>2</sub>Br<sub>2</sub>',
    '',
    '74-95-3',
    'FJBFPHVGVWTDIP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '4300',
    'L',
    (SELECT id from species WHERE iupac='dibromomethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;3</sup>',
    '4600',
    'L',
    (SELECT id from species WHERE iupac='dibromomethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;3</sup>',
    '4600',
    'L',
    (SELECT id from species WHERE iupac='dibromomethane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '4300',
    'L',
    (SELECT id from species WHERE iupac='dibromomethane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3518-74-95-3-consicheck',
    '3518', 'Values at 298&nbsp;K in Tables&nbsp;C2 and C5 of Brockbank (2013) are inconsistent, with 6&nbsp;% difference.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3518-74-95-3-consicheck'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='dibromomethane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '5000',
    'M',
    (SELECT id from species WHERE iupac='dibromomethane'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;3</sup>',
    '4400',
    'M',
    (SELECT id from species WHERE iupac='dibromomethane'),
    (SELECT id from literature WHERE bibtexkey='3564'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dibromomethane'),
    (SELECT id from literature WHERE bibtexkey='2938'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dibromomethane'),
    (SELECT id from literature WHERE bibtexkey='2450'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '4900',
    'M',
    (SELECT id from species WHERE iupac='dibromomethane'),
    (SELECT id from literature WHERE bibtexkey='2904'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;3</sup>',
    '3800',
    'M',
    (SELECT id from species WHERE iupac='dibromomethane'),
    (SELECT id from literature WHERE bibtexkey='583'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0583-74-95-3-ABC',
    '583', 'The data from Moore et&nbsp;al. (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;395.20167 +20638.03484/T +56.40082&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0583-74-95-3-ABC'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '4000',
    'M',
    (SELECT id from species WHERE iupac='dibromomethane'),
    (SELECT id from literature WHERE bibtexkey='855'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0855-74-95-3-ABC',
    '855', 'The data from Wright et&nbsp;al. (1992) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;82.06673 +6867.92071/T +9.56720&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0855-74-95-3-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '4100',
    'M',
    (SELECT id from species WHERE iupac='dibromomethane'),
    (SELECT id from literature WHERE bibtexkey='856'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '4400',
    'M',
    (SELECT id from species WHERE iupac='dibromomethane'),
    (SELECT id from literature WHERE bibtexkey='863'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dibromomethane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '4200',
    'V',
    (SELECT id from species WHERE iupac='dibromomethane'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dibromomethane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dibromomethane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dibromomethane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibromomethane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibromomethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibromomethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibromomethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibromomethane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibromomethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibromomethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4500',
    'Q',
    (SELECT id from species WHERE iupac='dibromomethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibromomethane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibromomethane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibromomethane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibromomethane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dibromomethane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4300',
    '?',
    (SELECT id from species WHERE iupac='dibromomethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dibromomethane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dibromomethane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dibromomethane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tribromomethane',
    'CHBr<sub>3</sub>',
    'bromoform',
    '75-25-2',
    'DIKBFYAXUHHXCS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '5200',
    'L',
    (SELECT id from species WHERE iupac='tribromomethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '6200',
    'L',
    (SELECT id from species WHERE iupac='tribromomethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '5200',
    'L',
    (SELECT id from species WHERE iupac='tribromomethane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '6200',
    'L',
    (SELECT id from species WHERE iupac='tribromomethane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '4800',
    'L',
    (SELECT id from species WHERE iupac='tribromomethane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '5200',
    'L',
    (SELECT id from species WHERE iupac='tribromomethane'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '5200',
    'L',
    (SELECT id from species WHERE iupac='tribromomethane'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '5200',
    'L',
    (SELECT id from species WHERE iupac='tribromomethane'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '5200',
    'L',
    (SELECT id from species WHERE iupac='tribromomethane'),
    (SELECT id from literature WHERE bibtexkey='747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='tribromomethane'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '6300',
    'M',
    (SELECT id from species WHERE iupac='tribromomethane'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;3</sup>',
    '6200',
    'M',
    (SELECT id from species WHERE iupac='tribromomethane'),
    (SELECT id from literature WHERE bibtexkey='3564'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='tribromomethane'),
    (SELECT id from literature WHERE bibtexkey='3572'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='tribromomethane'),
    (SELECT id from literature WHERE bibtexkey='2940'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='tribromomethane'),
    (SELECT id from literature WHERE bibtexkey='2450'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '4500',
    'M',
    (SELECT id from species WHERE iupac='tribromomethane'),
    (SELECT id from literature WHERE bibtexkey='2904'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '4300',
    'M',
    (SELECT id from species WHERE iupac='tribromomethane'),
    (SELECT id from literature WHERE bibtexkey='583'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0583-75-25-2-ABC',
    '583', 'The data from Moore et&nbsp;al. (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;408.59491 +21699.59623/T +58.19801&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0583-75-25-2-ABC'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;3</sup>',
    '1500',
    'M',
    (SELECT id from species WHERE iupac='tribromomethane'),
    (SELECT id from literature WHERE bibtexkey='2895'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '4100',
    'M',
    (SELECT id from species WHERE iupac='tribromomethane'),
    (SELECT id from literature WHERE bibtexkey='855'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0855-75-25-2-ABC',
    '855', 'The data from Wright et&nbsp;al. (1992) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( 1124.79951 &#8722;46767.40872/T &#8722;170.54217&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0855-75-25-2-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '5000',
    'M',
    (SELECT id from species WHERE iupac='tribromomethane'),
    (SELECT id from literature WHERE bibtexkey='856'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '4700',
    'M',
    (SELECT id from species WHERE iupac='tribromomethane'),
    (SELECT id from literature WHERE bibtexkey='2243'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '5700',
    'M',
    (SELECT id from species WHERE iupac='tribromomethane'),
    (SELECT id from literature WHERE bibtexkey='531'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='tribromomethane'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tribromomethane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '5300',
    'V',
    (SELECT id from species WHERE iupac='tribromomethane'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tribromomethane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tribromomethane'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tribromomethane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '2700',
    'X',
    (SELECT id from species WHERE iupac='tribromomethane'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='tribromomethane'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='tribromomethane'),
    (SELECT id from literature WHERE bibtexkey='531'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='tribromomethane'),
    (SELECT id from literature WHERE bibtexkey='3083'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tribromomethane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tribromomethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tribromomethane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tribromomethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tribromomethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tribromomethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tribromomethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tribromomethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5600',
    'Q',
    (SELECT id from species WHERE iupac='tribromomethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tribromomethane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tribromomethane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tribromomethane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tribromomethane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tribromomethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tribromomethane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5000',
    '?',
    (SELECT id from species WHERE iupac='tribromomethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tribromomethane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tribromomethane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tribromomethane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tetrabromomethane',
    'CBr<sub>4</sub>',
    '',
    '558-13-4',
    'HJUGFYREWKUQJT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tetrabromomethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tetrabromomethane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tetrabromomethane'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '1943-558-13-4-erratum',
    '1943', 'Erratum for page 274 of Fogg and Sangster (2003): the value in the table is k<sub>H</sub>, not lnk<sub>H</sub>.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1943-558-13-4-erratum'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at303K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='tetrabromomethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrabromomethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrabromomethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrabromomethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bromoethane',
    'C<sub>2</sub>H<sub>5</sub>Br',
    '',
    '74-96-4',
    'RDHPKYGYEGBMSE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '3900',
    'L',
    (SELECT id from species WHERE iupac='bromoethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '3900',
    'L',
    (SELECT id from species WHERE iupac='bromoethane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='bromoethane'),
    (SELECT id from literature WHERE bibtexkey='2493'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '3900',
    'M',
    (SELECT id from species WHERE iupac='bromoethane'),
    (SELECT id from literature WHERE bibtexkey='863'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bromoethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='bromoethane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2612_pc_problem'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bromoethane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bromoethane'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bromoethane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='bromoethane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;5</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='bromoethane'),
    (SELECT id from literature WHERE bibtexkey='2235'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromoethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromoethane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromoethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromoethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromoethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromoethane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromoethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromoethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3700',
    'Q',
    (SELECT id from species WHERE iupac='bromoethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromoethane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromoethane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromoethane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromoethane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromoethane'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromoethane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3800',
    '?',
    (SELECT id from species WHERE iupac='bromoethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='bromoethane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='bromoethane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='bromoethane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1-dibromoethane',
    'C<sub>2</sub>H<sub>4</sub>Br<sub>2</sub>',
    '',
    '557-91-5',
    'APQIUTYORBAGEZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1-dibromoethane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-dibromoethane',
    'C<sub>2</sub>H<sub>4</sub>Br<sub>2</sub>',
    'ethylene dibromide',
    '106-93-4',
    'PAAZPARNPHGIKF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '4300',
    'L',
    (SELECT id from species WHERE iupac='1,2-dibromoethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '3900',
    'L',
    (SELECT id from species WHERE iupac='1,2-dibromoethane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '4200',
    'L',
    (SELECT id from species WHERE iupac='1,2-dibromoethane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '5500',
    'M',
    (SELECT id from species WHERE iupac='1,2-dibromoethane'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-dibromoethane'),
    (SELECT id from literature WHERE bibtexkey='2938'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-dibromoethane'),
    (SELECT id from literature WHERE bibtexkey='3646'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-dibromoethane'),
    (SELECT id from literature WHERE bibtexkey='2450'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '5500',
    'M',
    (SELECT id from species WHERE iupac='1,2-dibromoethane'),
    (SELECT id from literature WHERE bibtexkey='2904'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '3000',
    'M',
    (SELECT id from species WHERE iupac='1,2-dibromoethane'),
    (SELECT id from literature WHERE bibtexkey='2895'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HTdep_r2_lessthan_0.9'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '3900',
    'M',
    (SELECT id from species WHERE iupac='1,2-dibromoethane'),
    (SELECT id from literature WHERE bibtexkey='1156'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1156'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dibromoethane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dibromoethane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dibromoethane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,2-dibromoethane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '1900',
    'X',
    (SELECT id from species WHERE iupac='1,2-dibromoethane'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1,2-dibromoethane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dibromoethane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dibromoethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dibromoethane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dibromoethane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dibromoethane'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dibromoethane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dibromoethane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dibromoethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dibromoethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4800',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dibromoethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dibromoethane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dibromoethane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dibromoethane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-dibromoethane'),
    (SELECT id from literature WHERE bibtexkey='3539'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'at50K',
    '', 'Value at T = 50&nbsp;K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at50K'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3539-106-93-4',
    '3539,2891', 'Rumble (2021) refers to Hiatt (2013) as the source, but this value cannot be found there.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3539-106-93-4'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-dibromoethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-dibromoethane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4200',
    '?',
    (SELECT id from species WHERE iupac='1,2-dibromoethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-dibromoethane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-dibromoethane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-dibromoethane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-dibromoethane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-dibromoethane'),
    (SELECT id from literature WHERE bibtexkey='2233'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-dibromoethane'),
    (SELECT id from literature WHERE bibtexkey='2979'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at297K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-dibromoethane-d4',
    'C<sub>2</sub>D<sub>4</sub>Br<sub>2</sub>',
    'ethylene dibromide-d4',
    '22581-63-1',
    'PAAZPARNPHGIKF-LNLMKGTHSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '4800',
    'M',
    (SELECT id from species WHERE iupac='1,2-dibromoethane-d4'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,2-tribromoethane',
    'C<sub>2</sub>H<sub>3</sub>Br<sub>3</sub>',
    '',
    '78-74-0',
    'QUMDOMSJJIFTCA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1,2-tribromoethane'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,2,2-tetrabromoethane',
    'C<sub>2</sub>H<sub>2</sub>Br<sub>4</sub>',
    '',
    '79-27-6',
    'QXSZNDIIPUOQMB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '1300',
    'L',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrabromoethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '1300',
    'L',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrabromoethane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '840',
    'M',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrabromoethane'),
    (SELECT id from literature WHERE bibtexkey='2895'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrabromoethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrabromoethane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrabromoethane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrabromoethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrabromoethane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrabromoethane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrabromoethane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrabromoethane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrabromoethane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrabromoethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrabromoethane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrabromoethane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrabromoethane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-bromopropane',
    'C<sub>3</sub>H<sub>7</sub>Br',
    '',
    '106-94-5',
    'CYNYIHKIEHGYOZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '4600',
    'L',
    (SELECT id from species WHERE iupac='1-bromopropane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-bromopropane'),
    (SELECT id from literature WHERE bibtexkey='2493'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '4500',
    'M',
    (SELECT id from species WHERE iupac='1-bromopropane'),
    (SELECT id from literature WHERE bibtexkey='863'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-bromopropane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-bromopropane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-bromopropane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-bromopropane'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-bromopropane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-bromopropane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromopropane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromopropane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromopropane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromopropane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromopropane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromopropane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromopropane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromopropane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromopropane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromopropane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-Test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromopropane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromopropane'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromopropane'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromopropane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-bromopropane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-bromopropane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-bromopropane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-bromopropane',
    'C<sub>3</sub>H<sub>7</sub>Br',
    '',
    '75-26-3',
    'NAMYKGVDVNBCFQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;4</sup>',
    '3900',
    'L',
    (SELECT id from species WHERE iupac='2-bromopropane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-bromopropane'),
    (SELECT id from literature WHERE bibtexkey='2493'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;4</sup>',
    '4500',
    'M',
    (SELECT id from species WHERE iupac='2-bromopropane'),
    (SELECT id from literature WHERE bibtexkey='863'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-bromopropane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-bromopropane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-bromopropane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-bromopropane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-bromopropane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-bromopropane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-bromopropane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-bromopropane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-bromopropane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-bromopropane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-bromopropane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-bromopropane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-bromopropane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-bromopropane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-bromopropane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-bromopropane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-bromopropane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-bromopropane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-bromopropane'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-bromopropane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-bromopropane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-bromopropane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-bromopropane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-dibromopropane',
    'C<sub>3</sub>H<sub>6</sub>Br<sub>2</sub>',
    '',
    '78-75-1',
    'XFNJYAKDBJUJAJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2-dibromopropane'),
    (SELECT id from literature WHERE bibtexkey='3946'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dibromopropane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dibromopropane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dibromopropane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dibromopropane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,2-dibromopropane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dibromopropane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dibromopropane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dibromopropane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dibromopropane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dibromopropane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dibromopropane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dibromopropane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dibromopropane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-dibromopropane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3-dibromopropane',
    'C<sub>3</sub>H<sub>6</sub>Br<sub>2</sub>',
    '',
    '109-64-8',
    'VEFLKXRACNJHOV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3-dibromopropane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3-dibromopropane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dibromopropane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dibromopropane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dibromopropane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dibromopropane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dibromopropane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dibromopropane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dibromopropane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,3-dibromopropane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-bromobutane',
    'C<sub>4</sub>H<sub>9</sub>Br',
    '',
    '109-65-9',
    'MPPPKRYCTPRNTB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-bromobutane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-bromobutane'),
    (SELECT id from literature WHERE bibtexkey='637'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-bromobutane'),
    (SELECT id from literature WHERE bibtexkey='2493'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-bromobutane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-bromobutane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-bromobutane'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-bromobutane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-bromobutane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromobutane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromobutane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromobutane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromobutane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromobutane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromobutane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromobutane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromobutane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromobutane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromobutane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromobutane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromobutane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromobutane'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromobutane'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromobutane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-bromobutane'),
    (SELECT id from literature WHERE bibtexkey='3034'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'CRCwrong3',
    '3034,635', 'Haynes (2014) refers to Mackay et&nbsp;al. (1993) as the source, but this value cannot be found there.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='CRCwrong3'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-bromobutane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-bromobutane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-bromobutane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-bromobutane',
    'C<sub>4</sub>H<sub>9</sub>Br',
    '',
    '78-76-2',
    'UPSXAPQYNGXVBF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2-bromobutane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-bromobutane'),
    (SELECT id from literature WHERE bibtexkey='2493'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-bromobutane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-bromobutane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-bromo-2-methylpropane',
    'C<sub>4</sub>H<sub>9</sub>Br',
    '',
    '78-77-3',
    'HLVFKOKELQSXIQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-bromo-2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-bromo-2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-bromo-2-methylpropane',
    'C<sub>4</sub>H<sub>9</sub>Br',
    '',
    '507-19-7',
    'RKSOPLXZQNSWAS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-bromo-2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-bromo-2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-bromo-2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-bromo-2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-bromo-2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-bromo-2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-bromo-2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-bromo-2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-bromo-2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-bromo-2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-bromo-2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-bromo-2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at291K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-bromo-2-methylpropane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-bromo-3-methylbutane',
    'C<sub>5</sub>H<sub>11</sub>Br',
    '',
    '107-82-4',
    'YXZFFTJAHVMMLF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-bromo-3-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-bromo-3-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-3-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-3-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-3-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-3-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-3-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-3-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-3-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-bromo-3-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4-dibromobutane',
    'C<sub>4</sub>H<sub>8</sub>Br<sub>2</sub>',
    '',
    '110-52-1',
    'ULTHEAFYOOPTTB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,4-dibromobutane'),
    (SELECT id from literature WHERE bibtexkey='3946'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dibromobutane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dibromobutane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-bromopentane',
    'C<sub>5</sub>H<sub>11</sub>Br',
    '',
    '110-53-2',
    'YZWKKMVJZFACSU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-bromopentane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-bromopentane'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-bromopentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromopentane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromopentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromopentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromopentane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromopentane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromopentane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromopentane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromopentane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromopentane'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-bromopentane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-bromopentane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-bromopentane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-bromo-2-methylbutane',
    'C<sub>5</sub>H<sub>11</sub>Br',
    '',
    '10422-35-2',
    'XKVLZBNEPALHIO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-2-methylbutane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-bromohexane',
    'C<sub>6</sub>H<sub>13</sub>Br',
    '',
    '111-25-1',
    'MNDIARAMWBIKFW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-bromohexane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-bromohexane'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromohexane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromohexane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromohexane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromohexane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromohexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromohexane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromohexane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromohexane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromohexane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromohexane'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-bromohexane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-bromo-3-methylpentane',
    'C<sub>6</sub>H<sub>13</sub>Br',
    '',
    '51116-73-5',
    'MDCCBJLCTOTLKM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-3-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-3-methylpentane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bromocyclohexane',
    'C<sub>6</sub>H<sub>11</sub>Br',
    '',
    '108-85-0',
    'AQNQQHJNRPDOQV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-bromoheptane',
    'C<sub>7</sub>H<sub>15</sub>Br',
    '',
    '629-04-9',
    'LSXKDWGTSHCFPP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-bromoheptane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-bromoheptane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-bromoheptane'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-bromoheptane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromoheptane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromoheptane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromoheptane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromoheptane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromoheptane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromoheptane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromoheptane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromoheptane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromoheptane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromoheptane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromoheptane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-Test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromoheptane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromoheptane'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-bromoheptane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-bromoheptane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-bromooctane',
    'C<sub>8</sub>H<sub>17</sub>Br',
    '',
    '111-83-1',
    'VMKOFRJSULQZRM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-bromooctane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;4</sup>',
    '4600',
    'V',
    (SELECT id from species WHERE iupac='1-bromooctane'),
    (SELECT id from literature WHERE bibtexkey='2554'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-bromooctane'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromooctane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromooctane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromooctane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromooctane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromooctane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromooctane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromooctane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromooctane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromooctane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromooctane'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-bromooctane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,8-dibromooctane',
    'C<sub>8</sub>H<sub>16</sub>Br<sub>2</sub>',
    '',
    '4549-32-0',
    'DKEGCUDAFWNSSO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '6900',
    'M',
    (SELECT id from species WHERE iupac='1,8-dibromooctane'),
    (SELECT id from literature WHERE bibtexkey='2122'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2122-4549-32-0-ABC',
    '2122', 'The data from Sarraute et&nbsp;al. (2006) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;370.06283 +22192.71634/T +51.12683&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2122-4549-32-0-ABC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-dibromo-4-(1,2-dibromoethyl)cyclohexane',
    'C<sub>8</sub>H<sub>12</sub>Br<sub>4</sub>',
    '',
    '3322-93-8',
    'PQRRSJBLKOPVJV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dibromo-4-(1,2-dibromoethyl)cyclohexane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dibromo-4-(1,2-dibromoethyl)cyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dibromo-4-(1,2-dibromoethyl)cyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dibromo-4-(1,2-dibromoethyl)cyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dibromo-4-(1,2-dibromoethyl)cyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-bromononane',
    'C<sub>9</sub>H<sub>19</sub>Br',
    '',
    '693-58-3',
    'AYMUQTNXKPEMLM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromononane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-bromodecane',
    'C<sub>10</sub>H<sub>21</sub>Br',
    '',
    '112-29-8',
    'MYMSJFSOOQERIO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-bromodecane'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hexabromocyclododecane',
    'C<sub>12</sub>H<sub>18</sub>Br<sub>6</sub>',
    '',
    '3194-55-6',
    'DEIGXXQKDWULML-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexabromocyclododecane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexabromocyclododecane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexabromocyclododecane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexabromocyclododecane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexabromocyclododecane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexabromocyclododecane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexabromocyclododecane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexabromocyclododecane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'vinyl bromide',
    'C<sub>2</sub>H<sub>3</sub>Br',
    '',
    '593-60-2',
    'INLLPKCGLOXCIV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='vinyl bromide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='vinyl bromide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='vinyl bromide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='vinyl bromide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='vinyl bromide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-dibromoethene',
    'C<sub>2</sub>H<sub>2</sub>Br<sub>2</sub>',
    '',
    '540-49-8',
    'UWTUEMKLYAGTNQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dibromoethene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dibromoethene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dibromoethene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(Z)-1,2-dibromoethene',
    'C<sub>2</sub>H<sub>2</sub>Br<sub>2</sub>',
    '<i>cis</i>-1,2-dibromoethene',
    '590-11-4',
    'UWTUEMKLYAGTNQ-UPHRSURJSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(Z)-1,2-dibromoethene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-bromo-1-propene',
    'C<sub>3</sub>H<sub>5</sub>Br',
    'allyl bromide',
    '106-95-6',
    'BHELZAPQIKSEDF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-bromo-1-propene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-bromo-1-propene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-bromo-1-propene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-bromo-1-propene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-bromo-1-propene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-bromo-1-propene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-bromo-1-propene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-bromo-1-propene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-bromo-1-propene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-bromo-1-propene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-bromo-1-propyne',
    'C<sub>3</sub>H<sub>3</sub>Br',
    'propargyl bromide',
    '106-96-7',
    'YORCIIVHUBAYBQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;3</sup>',
    '4000',
    'M',
    (SELECT id from species WHERE iupac='3-bromo-1-propyne'),
    (SELECT id from literature WHERE bibtexkey='1330'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-bromo-1-propyne'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-bromo-1-propyne'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3200',
    'Q',
    (SELECT id from species WHERE iupac='3-bromo-1-propyne'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-bromo-1-propyne'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4200',
    '?',
    (SELECT id from species WHERE iupac='3-bromo-1-propyne'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='3-bromo-1-propyne'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '1943-106-96-7-erratum',
    '1943,1330', 'Erratum for page 321 of Fogg and Sangster (2003): data from Yates and Gan (1998) are cited with a typo. The value at 313.2&nbsp;K should probably be 4.78&times;10<sup>&#8722;6</sup>, not 4.78&times;10<sup>&#8722;2</sup>.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1943-106-96-7-erratum'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-bromocyclohexene',
    'C<sub>6</sub>H<sub>9</sub>Br',
    '',
    '2044-08-8',
    'QBUMXSSCYUMVAW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromocyclohexene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-bromo-4-methylcyclohexene',
    'C<sub>7</sub>H<sub>11</sub>Br',
    '',
    '31053-84-6',
    'LIUFYLLBQSSKQS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-4-methylcyclohexene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bromobenzene',
    'C<sub>6</sub>H<sub>5</sub>Br',
    '',
    '108-86-1',
    'QARVLSVVCXYDNA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;3</sup>',
    '4500',
    'L',
    (SELECT id from species WHERE iupac='bromobenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;3</sup>',
    '4200',
    'L',
    (SELECT id from species WHERE iupac='bromobenzene'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='bromobenzene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;3</sup>',
    '4300',
    'M',
    (SELECT id from species WHERE iupac='bromobenzene'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '2900',
    'M',
    (SELECT id from species WHERE iupac='bromobenzene'),
    (SELECT id from literature WHERE bibtexkey='2982'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='bromobenzene'),
    (SELECT id from literature WHERE bibtexkey='2950'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='bromobenzene'),
    (SELECT id from literature WHERE bibtexkey='2339'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='bromobenzene'),
    (SELECT id from literature WHERE bibtexkey='2450'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;3</sup>',
    '4200',
    'M',
    (SELECT id from species WHERE iupac='bromobenzene'),
    (SELECT id from literature WHERE bibtexkey='2904'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;3</sup>',
    '5300',
    'M',
    (SELECT id from species WHERE iupac='bromobenzene'),
    (SELECT id from literature WHERE bibtexkey='903'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='903'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='bromobenzene'),
    (SELECT id from literature WHERE bibtexkey='2457'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='bromobenzene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bromobenzene'),
    (SELECT id from literature WHERE bibtexkey='2339'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bromobenzene'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bromobenzene'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bromobenzene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='bromobenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='bromobenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='bromobenzene'),
    (SELECT id from literature WHERE bibtexkey='2165'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromobenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromobenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromobenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromobenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromobenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4800',
    'Q',
    (SELECT id from species WHERE iupac='bromobenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromobenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromobenzene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromobenzene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromobenzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromobenzene'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromobenzene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='bromobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4300',
    '?',
    (SELECT id from species WHERE iupac='bromobenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='bromobenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='bromobenzene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='bromobenzene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bromobenzene-d5',
    'C<sub>6</sub>D<sub>5</sub>Br',
    '',
    '4165-57-5',
    'QARVLSVVCXYDNA-RALIUCGRSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;3</sup>',
    '4200',
    'M',
    (SELECT id from species WHERE iupac='bromobenzene-d5'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-dibromobenzene',
    'C<sub>6</sub>H<sub>4</sub>Br<sub>2</sub>',
    '',
    '583-53-9',
    'WQONPSCCEXUXTQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dibromobenzene'),
    (SELECT id from literature WHERE bibtexkey='2165'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3-dibromobenzene',
    'C<sub>6</sub>H<sub>4</sub>Br<sub>2</sub>',
    '',
    '108-36-1',
    'JSRLURSZEMLAFO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1,3-dibromobenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3-dibromobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3-dibromobenzene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at308K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1,3-dibromobenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dibromobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dibromobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dibromobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dibromobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dibromobenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dibromobenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dibromobenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dibromobenzene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dibromobenzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,3-dibromobenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4-dibromobenzene',
    'C<sub>6</sub>H<sub>4</sub>Br<sub>2</sub>',
    '',
    '106-37-6',
    'SWJPEBQEEAHIGZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,4-dibromobenzene'),
    (SELECT id from literature WHERE bibtexkey='1932'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-dibromobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-dibromobenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-dibromobenzene'),
    (SELECT id from literature WHERE bibtexkey='2165'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-dibromobenzene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at308K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-dibromobenzene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1,4-dibromobenzene'),
    (SELECT id from literature WHERE bibtexkey='1932'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dibromobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dibromobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dibromobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dibromobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dibromobenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dibromobenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5600',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dibromobenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dibromobenzene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-Test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dibromobenzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dibromobenzene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '6900',
    '?',
    (SELECT id from species WHERE iupac='1,4-dibromobenzene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4-tribromobenzene',
    'C<sub>6</sub>H<sub>3</sub>Br<sub>3</sub>',
    '',
    '615-54-3',
    'FWAJPSIPOULHHH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2,4-tribromobenzene'),
    (SELECT id from literature WHERE bibtexkey='1932'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1,2,4-tribromobenzene'),
    (SELECT id from literature WHERE bibtexkey='1932'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-tribromobenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3,5-tribromobenzene',
    'C<sub>6</sub>H<sub>3</sub>Br<sub>3</sub>',
    '',
    '626-39-1',
    'YWDUZLFWHVQCHY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,3,5-tribromobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-tribromobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-tribromobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-tribromobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-tribromobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-tribromobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-tribromobenzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4,5-tetrabromobenzene',
    'C<sub>6</sub>H<sub>2</sub>Br<sub>4</sub>',
    '',
    '636-28-2',
    'QCKHVNQHBOGZER-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,2,4,5-tetrabromobenzene'),
    (SELECT id from literature WHERE bibtexkey='1932'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,5-tetrabromobenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hexabromobenzene',
    'C<sub>6</sub>Br<sub>6</sub>',
    '',
    '87-82-1',
    'CAYGQBVSOZLICD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='hexabromobenzene'),
    (SELECT id from literature WHERE bibtexkey='1932'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexabromobenzene'),
    (SELECT id from literature WHERE bibtexkey='3024'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexabromobenzene'),
    (SELECT id from literature WHERE bibtexkey='2494'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexabromobenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexabromobenzene'),
    (SELECT id from literature WHERE bibtexkey='2990'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexabromobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexabromobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexabromobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexabromobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexabromobenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(bromomethyl)-benzene',
    'C<sub>7</sub>H<sub>7</sub>Br',
    'benzyl bromide',
    '100-39-0',
    'AGEZXYOZHKGVCM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(bromomethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(bromomethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(bromomethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'p-bromobenzyl bromide',
    'C<sub>7</sub>H<sub>6</sub>Br<sub>2</sub>',
    '',
    '589-15-1',
    'YLRBJYMANQKEAW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='p-bromobenzyl bromide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='p-bromobenzyl bromide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='p-bromobenzyl bromide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='p-bromobenzyl bromide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-bromo-2-methylbenzene',
    'BrC<sub>6</sub>H<sub>4</sub>CH<sub>3</sub>',
    'o-bromotoluene',
    '95-46-5',
    'QSSXJPIWXQTSIX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-bromo-3-methylbenzene',
    'BrC<sub>6</sub>H<sub>4</sub>CH<sub>3</sub>',
    'm-bromotoluene',
    '591-17-3',
    'WJIFKOVZNJTSGO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-bromo-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-bromo-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-bromo-4-methylbenzene',
    'BrC<sub>6</sub>H<sub>4</sub>CH<sub>3</sub>',
    'p-bromotoluene',
    '106-38-7',
    'ZBTMRBYMKUEVEU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '4800',
    'L',
    (SELECT id from species WHERE iupac='1-bromo-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '4600',
    'M',
    (SELECT id from species WHERE iupac='1-bromo-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2926'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-bromo-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-bromo-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-bromo-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,5-dibromotoluene',
    'C<sub>7</sub>H<sub>6</sub>Br<sub>2</sub>',
    '',
    '1611-92-3',
    'DPKKOVGCHDUSAI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '4800',
    'M',
    (SELECT id from species WHERE iupac='3,5-dibromotoluene'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pentabromotoluene',
    'C<sub>7</sub>H<sub>3</sub>Br<sub>5</sub>',
    '',
    '87-83-2',
    'OZHJEQVYCBTHJT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentabromotoluene'),
    (SELECT id from literature WHERE bibtexkey='2990'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-bromo-2-ethylbenzene',
    'C<sub>8</sub>H<sub>9</sub>Br',
    '',
    '1973-22-4',
    'HVRUGFJYCAFAAN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-bromo-2-ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-2-ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-2-ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-2-ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-2-ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-bromo-4-ethylbenzene',
    'C<sub>8</sub>H<sub>9</sub>Br',
    '',
    '1585-07-5',
    'URFPRAHGGBYNPW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-4-ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-4-ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-4-ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-4-ethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-(bromomethyl)-2-methylbenzene',
    'C<sub>8</sub>H<sub>9</sub>Br',
    'o-xylyl bromide',
    '89-92-9',
    'WGVYCXYGPNNUQA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-(bromomethyl)-2-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-(bromomethyl)-3-methylbenzene',
    'C<sub>8</sub>H<sub>9</sub>Br',
    'm-xylyl bromide',
    '620-13-3',
    'FWLWTILKTABGKQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-(bromomethyl)-3-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-(bromomethyl)-4-methylbenzene',
    'C<sub>8</sub>H<sub>9</sub>Br',
    'p-xylyl bromide',
    '104-81-4',
    'WZRKSPFYXUXINF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-(bromomethyl)-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(2-bromoethyl)-benzene',
    'C<sub>8</sub>H<sub>9</sub>Br',
    '',
    '103-63-9',
    'WMPPDTMATNBGJN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(2-bromoethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(2-bromoethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2-bromoethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2-bromoethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2-bromoethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2-bromoethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-bromostyrene',
    'C<sub>8</sub>H<sub>7</sub>Br',
    '',
    '125904-11-2',
    'SSZOCHFYWWVSAI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-bromostyrene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-bromostyrene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-bromostyrene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-bromostyrene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(2-bromoethenyl)benzene',
    'C<sub>8</sub>H<sub>7</sub>Br',
    '',
    '103-64-0',
    'YMOONIIMQBGTDU-VOTSOKGWSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2-bromoethenyl)benzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,5,6-pentabromoethylbenzene',
    'C<sub>8</sub>H<sub>5</sub>Br<sub>5</sub>',
    '',
    '85-22-3',
    'FIAXCDIQXHJNIX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,5,6-pentabromoethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,5,6-pentabromoethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,5,6-pentabromoethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,5,6-pentabromoethylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-bromo-2-(2-propyl)-benzene',
    'BrC<sub>6</sub>H<sub>4</sub>C<sub>3</sub>H<sub>7</sub>',
    'o-bromocumene',
    '7073-94-1',
    'LECYCYNAEJDSIL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-bromo-2-(2-propyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-2-(2-propyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-2-(2-propyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-2-(2-propyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-bromonaphthalene',
    'C<sub>10</sub>H<sub>7</sub>Br',
    '',
    '90-11-9',
    'DLKQHBOKULLWDQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-bromonaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-bromonaphthalene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at294K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromonaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromonaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromonaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromonaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromonaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-bromonaphthalene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at294K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-bromonaphthalene',
    'C<sub>10</sub>H<sub>7</sub>Br',
    '',
    '580-13-2',
    'APSMUYYLXZULMS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-bromonaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4-dibromonaphthalene',
    'C<sub>10</sub>H<sub>6</sub>Br<sub>2</sub>',
    '',
    '83-53-4',
    'IBGUDZMIAZLJNY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,4-dibromonaphthalene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'decabromobiphenyl',
    'C<sub>12</sub>Br<sub>10</sub>',
    '',
    '13654-09-6',
    'AQPHBYQUCKHJLT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decabromobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decabromobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decabromobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decabromobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decabromobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-bromo-1,1''-biphenyl',
    'C<sub>12</sub>H<sub>9</sub>Br',
    '',
    '92-66-0',
    'PKJBWOWQJHHAHG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-bromo-1,1''-biphenyl'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-bromo-1,1''-biphenyl'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-bromo-1,1''-biphenyl'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-bromo-1,1''-biphenyl'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'octabromobiphenyl',
    'C<sub>12</sub>H<sub>2</sub>Br<sub>8</sub>',
    '',
    '27858-07-7',
    'NDRKXFLZSRHAJE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='octabromobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',4,4'',5,5''-hexabromobiphenyl',
    'C<sub>12</sub>H<sub>4</sub>Br<sub>6</sub>',
    '',
    '59080-40-9',
    'HMBBJSKXDBUNNT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5,5''-hexabromobiphenyl'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-bis(pentabromophenyl) ethane',
    'C<sub>14</sub>H<sub>4</sub>Br<sub>10</sub>',
    '',
    '84852-53-9',
    'BZQKBFHEWDPQHD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-bis(pentabromophenyl) ethane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-bis(pentabromophenyl) ethane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-bis(pentabromophenyl) ethane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-bis(pentabromophenyl) ethane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3,6,8-tetrabromopyrene',
    'C<sub>16</sub>H<sub>6</sub>Br<sub>4</sub>',
    '',
    '128-63-2',
    'ZKBKRTZIYOKNRG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,6,8-tetrabromopyrene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,6,8-tetrabromopyrene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,6,8-tetrabromopyrene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,6,8-tetrabromopyrene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '6-bromobenzo[a]pyrene',
    'C<sub>20</sub>H<sub>11</sub>Br',
    '',
    '21248-00-0',
    'MJSYSGSEEADMTK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-bromobenzo[a]pyrene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bromomethanol',
    'CH<sub>2</sub>BrOH',
    '',
    '50398-29-3',
    'OEDMOCYNWLHUDP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromomethanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromomethanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromomethanol'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromomethanol'),
    (SELECT id from literature WHERE bibtexkey='2927'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dibromomethanol',
    'CHBr<sub>2</sub>OH',
    '',
    '166600-78-8',
    'WICMSCLXMMZMFF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibromomethanol'),
    (SELECT id from literature WHERE bibtexkey='2927'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tribromomethanol',
    'CBr<sub>3</sub>OH',
    '',
    '5405-30-1',
    'ACRXLLXANWELLX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tribromomethanol'),
    (SELECT id from literature WHERE bibtexkey='2927'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'formyl bromide',
    'CHBrO',
    '',
    '7726-11-6',
    'AIFARXRIYKCEEV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='formyl bromide'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='formyl bromide'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='formyl bromide'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='formyl bromide'),
    (SELECT id from literature WHERE bibtexkey='2927'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'carbonyl bromide',
    'CBr<sub>2</sub>O',
    '',
    '593-95-3',
    'MOIPGXQKZSZOQX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='carbonyl bromide'),
    (SELECT id from literature WHERE bibtexkey='2927'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bromomethyl peroxide',
    'CH<sub>2</sub>BrO<sub>2</sub>H',
    '',
    '',
    'WXVCUAGYVVWQBP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromomethyl peroxide'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromomethyl peroxide'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromomethyl peroxide'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromomethyl peroxide'),
    (SELECT id from literature WHERE bibtexkey='2927'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dibromomethyl peroxide',
    'CHBr<sub>2</sub>O<sub>2</sub>H',
    '',
    '',
    'JBKQCSQVMCXDPZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibromomethyl peroxide'),
    (SELECT id from literature WHERE bibtexkey='2927'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tribromomethyl peroxide',
    'CBr<sub>3</sub>O<sub>2</sub>H',
    '',
    '',
    'WJYKCADCZNTKBI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tribromomethyl peroxide'),
    (SELECT id from literature WHERE bibtexkey='2927'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bromoethanoic acid',
    'CH<sub>2</sub>BrCOOH',
    'bromoacetic acid',
    '79-08-3',
    'KDPAWGWELVVRCH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '9300',
    'L',
    (SELECT id from species WHERE iupac='bromoethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '9300',
    'L',
    (SELECT id from species WHERE iupac='bromoethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '9300',
    'L',
    (SELECT id from species WHERE iupac='bromoethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '9300',
    'M',
    (SELECT id from species WHERE iupac='bromoethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='896'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromoethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromoethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromoethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromoethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromoethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromoethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromoethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromoethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '8800',
    'Q',
    (SELECT id from species WHERE iupac='bromoethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='bromoethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '9300',
    '?',
    (SELECT id from species WHERE iupac='bromoethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dibromoethanoic acid',
    'CHBr<sub>2</sub>COOH',
    'dibromoacetic acid',
    '631-64-1',
    'SIEILFNCEFEENQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>3</sup>',
    '8900',
    'L',
    (SELECT id from species WHERE iupac='dibromoethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>3</sup>',
    '8900',
    'L',
    (SELECT id from species WHERE iupac='dibromoethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>3</sup>',
    '8900',
    'L',
    (SELECT id from species WHERE iupac='dibromoethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>3</sup>',
    '8900',
    'M',
    (SELECT id from species WHERE iupac='dibromoethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='896'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibromoethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibromoethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibromoethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibromoethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibromoethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '9900',
    'Q',
    (SELECT id from species WHERE iupac='dibromoethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dibromoethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '9000',
    '?',
    (SELECT id from species WHERE iupac='dibromoethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tribromoethanoic acid',
    'CBr<sub>3</sub>COOH',
    'tribromoacetic acid',
    '75-96-7',
    'QIONYIKHPASLHO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>3</sup>',
    '9000',
    'L',
    (SELECT id from species WHERE iupac='tribromoethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>3</sup>',
    '9000',
    'L',
    (SELECT id from species WHERE iupac='tribromoethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>3</sup>',
    '9000',
    'L',
    (SELECT id from species WHERE iupac='tribromoethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>3</sup>',
    '9000',
    'M',
    (SELECT id from species WHERE iupac='tribromoethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='896'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tribromoethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tribromoethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tribromoethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tribromoethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tribromoethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tribromoethanoic acid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BRETO3H',
    'C<sub>2</sub>H<sub>3</sub>O<sub>3</sub>Br',
    '',
    '',
    'RGXORGOPJDPEIK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BRETO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BRETO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BRETO3H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DIBRETO2H',
    'C<sub>2</sub>H<sub>4</sub>O<sub>2</sub>Br<sub>2</sub>',
    '',
    '',
    'ZXSZEFURCAPOPD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DIBRETO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DIBRETO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DIBRETO2H'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DIBRETOH',
    'C<sub>2</sub>H<sub>4</sub>OBr<sub>2</sub>',
    '',
    '',
    'IYJYRKYSUOTLAE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DIBRETOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DIBRETOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DIBRETOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BRETAL',
    'C<sub>2</sub>H<sub>3</sub>OBr',
    '',
    '',
    'NMPVEAUIHMEAQP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BRETAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BRETAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BRETAL'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-bromopropanol',
    'C<sub>3</sub>H<sub>7</sub>BrO',
    '',
    '627-18-9',
    'RQFUZUMFPRMVDX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-bromopropanol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dibromopropanol',
    'C<sub>3</sub>H<sub>6</sub>Br<sub>2</sub>O',
    '',
    '96-13-9',
    'QWVCIORZLNBIIC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dibromopropanol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dibromopropanol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dibromopropanol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dibromopropanol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dibromopropanol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bromoacetone',
    'C<sub>3</sub>H<sub>5</sub>BrO',
    '',
    '598-31-2',
    'VQFAIAKCILWQPZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromoacetone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(bromomethyl)oxirane',
    'C<sub>3</sub>H<sub>5</sub>BrO',
    'epibromohydrin',
    '3132-64-7',
    'GKIPXFAANLTWBM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(bromomethyl)oxirane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dibromobutane-1,4-diol',
    'C<sub>4</sub>H<sub>8</sub>Br<sub>2</sub>O<sub>2</sub>',
    '',
    '90801-18-6',
    'OXYNQEOLHRWEPE-QWWZWVQMSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dibromobutane-1,4-diol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dibromobutane-1,4-diol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dibromobutane-1,4-diol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dibromobutane-1,4-diol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bromoacetic acid, ethyl ester',
    'C<sub>4</sub>H<sub>7</sub>BrO<sub>2</sub>',
    '',
    '105-36-2',
    'PQJJJMRNHATNKG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromoacetic acid, ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'brometone',
    'C<sub>4</sub>H<sub>7</sub>Br<sub>3</sub>O',
    '1,1,1-tribromo-2-methyl-2-propanol',
    '76-08-4',
    'JUGRTVJQTFZHOM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='brometone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-bis(bromomethyl)-1,3-propanediol',
    'C<sub>5</sub>H<sub>10</sub>Br<sub>2</sub>O<sub>2</sub>',
    '',
    '3296-90-0',
    'CHUGKEQJSLOLHL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-bis(bromomethyl)-1,3-propanediol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'trisbromoneopentyl alcohol',
    'C<sub>5</sub>H<sub>9</sub>Br<sub>3</sub>O',
    '',
    '36483-57-5',
    'HQWKMYFWGMCJSW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trisbromoneopentyl alcohol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trisbromoneopentyl alcohol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trisbromoneopentyl alcohol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trisbromoneopentyl alcohol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-bromophenol',
    'HOC<sub>6</sub>H<sub>4</sub>Br',
    '',
    '95-56-7',
    'VADKRMSMGWJZCF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-bromophenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-bromophenol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-bromophenol',
    'HOC<sub>6</sub>H<sub>4</sub>Br',
    '',
    '591-20-8',
    'MNOJRWOWILAHAV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-bromophenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-bromophenol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-bromophenol',
    'HOC<sub>6</sub>H<sub>4</sub>Br',
    '',
    '106-41-2',
    'GZFGOTFRPZRKDS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>1</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='4-bromophenol'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>1</sup>',
    '8200',
    'T',
    (SELECT id from species WHERE iupac='4-bromophenol'),
    (SELECT id from literature WHERE bibtexkey='724'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='assumedMatm'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-bromophenol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-bromophenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-bromophenol'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-bromophenol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-bromophenol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-bromophenol'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-bromophenol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-bromophenol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-bromophenol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-bromophenol'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-bromophenol'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-bromophenol'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-bromophenol'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-bromophenol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-bromophenol'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dibromophenol',
    'C<sub>6</sub>H<sub>4</sub>Br<sub>2</sub>O',
    '',
    '615-58-7',
    'FAXWFCTVSHEODL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dibromophenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6-dibromophenol',
    'C<sub>6</sub>H<sub>4</sub>Br<sub>2</sub>O',
    '',
    '608-33-3',
    'SSIZLKDLDKIHEV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dibromophenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,6-tribromophenol',
    'C<sub>6</sub>H<sub>3</sub>Br<sub>3</sub>O',
    '',
    '118-79-6',
    'BSWWXRFVMJHFBN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-tribromophenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-tribromophenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-tribromophenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-tribromophenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-tribromophenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,6-tetrabromophenol',
    'C<sub>6</sub>H<sub>2</sub>Br<sub>4</sub>O',
    '',
    '14400-94-3',
    'CXPJZISGVIVNEL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,6-tetrabromophenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pentabromophenol',
    'C<sub>6</sub>HBr<sub>5</sub>O',
    '',
    '608-71-9',
    'SVHOVVJFOWGYJO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentabromophenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentabromophenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentabromophenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentabromophenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentabromophenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-bromo-2-methoxybenzene',
    'C<sub>7</sub>H<sub>7</sub>BrO',
    '2-bromoanisole',
    '578-57-4',
    'HTDQSWDEWGSAMN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-bromo-2-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1524'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1524'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-bromo-3-methoxybenzene',
    'C<sub>7</sub>H<sub>7</sub>BrO',
    '3-bromoanisole',
    '2398-37-0',
    'PLDWAJLZAAHOGG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-bromo-3-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1524'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1524'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-bromo-4-methoxybenzene',
    'C<sub>7</sub>H<sub>7</sub>BrO',
    '4-bromoanisole',
    '104-92-7',
    'QJPJQTDYNZXKQF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-bromo-4-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1524'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1524'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,5-dibromo-2-methoxybenzene',
    'C<sub>7</sub>H<sub>6</sub>Br<sub>2</sub>O',
    '2,4-dibromoanisole',
    '21702-84-1',
    'XGXUGXPKRBQINS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,5-dibromo-2-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1524'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1524'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3-dibromo-2-methoxybenzene',
    'C<sub>7</sub>H<sub>6</sub>Br<sub>2</sub>O',
    '2,6-dibromoanisole',
    '38603-09-7',
    'BMZVDHQOAJUZJL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,3-dibromo-2-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1524'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1524'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3-tribromo-4-methoxybenzene',
    'C<sub>7</sub>H<sub>5</sub>Br<sub>3</sub>O',
    '2,3,4-tribromoanisole',
    '95970-13-1',
    'NKWYZAWFQZLPSU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2,3-tribromo-4-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3766_O4',
    '3766', 'Ebert et&nbsp;al. (2023) present "curated experimental" Henry''s law constants from the literature but do not provide any references. It is only mentioned that the value is from a single original paper and obtained from the experimental octanol-water partition coefficient and the octanol-air partition coefficient.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_O4'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3,4-tribromo-2-methoxybenzene',
    'C<sub>7</sub>H<sub>5</sub>Br<sub>3</sub>O',
    '2,3,6-tribromoanisole',
    '95970-19-7',
    'XZYCSFIRWAPGJV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;3</sup>',
    '2800',
    'M',
    (SELECT id from species WHERE iupac='1,3,4-tribromo-2-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3118'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3118',
    '3118,1524', 'Diaz et&nbsp;al. (2005) also cite a Henry''s law constant from Pfeifer et&nbsp;al. (2001) even though this species is not mentioned there. There might be a mix up of the different haloanisoles.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3118'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3,5-tribromo-2-methoxybenzene',
    'C<sub>7</sub>H<sub>5</sub>Br<sub>3</sub>O',
    '2,4,6-tribromoanisole',
    '607-99-8',
    'YXTRCOAFNXQTKL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '6400',
    'M',
    (SELECT id from species WHERE iupac='1,3,5-tribromo-2-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3118'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,3,5-tribromo-2-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1524'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1524'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-tribromo-2-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pentabromomethoxybenzene',
    'C<sub>7</sub>H<sub>3</sub>Br<sub>5</sub>O',
    'pentabromoanisole',
    '1825-26-9',
    'VEFNQGLEDJPUJF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'M',
    (SELECT id from species WHERE iupac='pentabromomethoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1524'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1524'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3,5-tribromo-2-methoxy-4-methylbenzene',
    'C<sub>8</sub>H<sub>7</sub>Br<sub>3</sub>O',
    '',
    '41424-36-6',
    'NMPPAMFEYWGNCI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-tribromo-2-methoxy-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-tribromo-2-methoxy-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-tribromo-2-methoxy-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3,5-tribromo-2-methoxy-4-methylbenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,5,6,7-tetrabromo-1,3-isobenzofurandione',
    'C<sub>8</sub>Br<sub>4</sub>O<sub>3</sub>',
    '',
    '632-79-1',
    'QHWKHLYUUZGSCW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,5,6,7-tetrabromo-1,3-isobenzofurandione'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,5,6,7-tetrabromo-1,3-isobenzofurandione'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,5,6,7-tetrabromo-1,3-isobenzofurandione'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,5,6,7-tetrabromo-1,3-isobenzofurandione'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'allyl 2,4,6-tribromophenyl ether',
    'C<sub>9</sub>H<sub>7</sub>Br<sub>3</sub>O',
    '',
    '3278-89-5',
    'RZLLIOPGUFOWOD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='allyl 2,4,6-tribromophenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='allyl 2,4,6-tribromophenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='allyl 2,4,6-tribromophenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='allyl 2,4,6-tribromophenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dibromo-6-methylphenyl glycidyl ether',
    'C<sub>10</sub>H<sub>10</sub>Br<sub>2</sub>O<sub>2</sub>',
    '',
    '75150-13-9',
    'XQTJZNGNEJLXTR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dibromo-6-methylphenyl glycidyl ether'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dibromo-6-methylphenyl glycidyl ether'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dibromo-6-methylphenyl glycidyl ether'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dibromo-6-methylphenyl glycidyl ether'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-(2,4,6-tribromophenoxy)ethyl acrylate',
    'C<sub>11</sub>H<sub>9</sub>Br<sub>3</sub>O<sub>3</sub>',
    '',
    '7347-19-5',
    'AMBJXYFIMKHOQE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(2,4,6-tribromophenoxy)ethyl acrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(2,4,6-tribromophenoxy)ethyl acrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(2,4,6-tribromophenoxy)ethyl acrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(2,4,6-tribromophenoxy)ethyl acrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,7,8-tetrabromodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>4</sub>Br<sub>4</sub>O<sub>2</sub>',
    '',
    '50585-41-6',
    'JZLQUWSWOJPCAK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3,7,8-tetrabromodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'octabromodibenzo-p-dioxin',
    'C<sub>12</sub>Br<sub>8</sub>O<sub>2</sub>',
    '',
    '2170-45-8',
    'XAHTWKGGNHXJRP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='octabromodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,4''-methylenebis(2,6-dibromophenol)',
    'C<sub>13</sub>H<sub>8</sub>Br<sub>4</sub>O<sub>2</sub>',
    '',
    '21825-03-6',
    'WPZJSWWEEJJSIZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4''-methylenebis(2,6-dibromophenol)'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4''-methylenebis(2,6-dibromophenol)'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4''-methylenebis(2,6-dibromophenol)'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4''-methylenebis(2,6-dibromophenol)'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1''-[1,2-ethanediylbis(oxy)]bis pentabromobenzene',
    'C<sub>14</sub>H<sub>4</sub>Br<sub>10</sub>O<sub>2</sub>',
    '',
    '61262-53-1',
    'JJEPQBZQAGCZTH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1''-[1,2-ethanediylbis(oxy)]bis pentabromobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1''-[1,2-ethanediylbis(oxy)]bis pentabromobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1''-[1,2-ethanediylbis(oxy)]bis pentabromobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1''-[1,2-ethanediylbis(oxy)]bis pentabromobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,4''-dibromobenzil',
    'C<sub>14</sub>H<sub>8</sub>Br<sub>2</sub>O<sub>2</sub>',
    '',
    '35578-47-3',
    'NYCBYBDDECLFPE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4''-dibromobenzil'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4''-dibromobenzil'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4''-dibromobenzil'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4''-dibromobenzil'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-bis(2,4,6-tribromophenoxy)ethane',
    'C<sub>14</sub>H<sub>8</sub>Br<sub>6</sub>O<sub>2</sub>',
    'BTBPE',
    '37853-59-1',
    'YATIGPZCMOYEGE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-bis(2,4,6-tribromophenoxy)ethane'),
    (SELECT id from literature WHERE bibtexkey='3024'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-bis(2,4,6-tribromophenoxy)ethane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-bis(2,4,6-tribromophenoxy)ethane'),
    (SELECT id from literature WHERE bibtexkey='2990'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-bis(2,4,6-tribromophenoxy)ethane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-bis(2,4,6-tribromophenoxy)ethane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-bis(2,4,6-tribromophenoxy)ethane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-bis(2,4,6-tribromophenoxy)ethane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-ethylhexyl-2,3,4,5-tetrabromobenzoate',
    'C<sub>15</sub>H<sub>18</sub>Br<sub>4</sub>O<sub>2</sub>',
    'EHTeBB',
    '183658-27-7',
    'HVDXCGSGEQKWGB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylhexyl-2,3,4,5-tetrabromobenzoate'),
    (SELECT id from literature WHERE bibtexkey='2990'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tribromobisphenol A',
    'C<sub>15</sub>H<sub>13</sub>Br<sub>3</sub>O<sub>2</sub>',
    '',
    '6386-73-8',
    'WYBOEVJIVYIEJL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tribromobisphenol A'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,4''-(1-methylethylidene)bis(2,6-dibromophenol)',
    'C<sub>15</sub>H<sub>12</sub>Br<sub>4</sub>O<sub>2</sub>',
    '',
    '79-94-7',
    'VEORPZCZECFIRK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4,4''-(1-methylethylidene)bis(2,6-dibromophenol)'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4''-(1-methylethylidene)bis(2,6-dibromophenol)'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4''-(1-methylethylidene)bis(2,6-dibromophenol)'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4''-(1-methylethylidene)bis(2,6-dibromophenol)'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4''-(1-methylethylidene)bis(2,6-dibromophenol)'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-[2-[2,6-bis(bromanyl)-4-oxidanyl-phenyl]propan-2-yl]-3,5-bis(bromanyl)phenol',
    'C<sub>15</sub>H<sub>12</sub>Br<sub>4</sub>O<sub>2</sub>',
    '',
    '94334-64-2',
    'KIZJVNGSIWXYTL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-[2-[2,6-bis(bromanyl)-4-oxidanyl-phenyl]propan-2-yl]-3,5-bis(bromanyl)phenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-[2-[2,6-bis(bromanyl)-4-oxidanyl-phenyl]propan-2-yl]-3,5-bis(bromanyl)phenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-[2-[2,6-bis(bromanyl)-4-oxidanyl-phenyl]propan-2-yl]-3,5-bis(bromanyl)phenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-[2-[2,6-bis(bromanyl)-4-oxidanyl-phenyl]propan-2-yl]-3,5-bis(bromanyl)phenol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-(2-hydroxyethoxy)ethyl 2-hydroxypropyl 3,4,5,6-tetrabromophthalate',
    'C<sub>15</sub>H<sub>16</sub>Br<sub>4</sub>O<sub>7</sub>',
    '',
    '20566-35-2',
    'OQHHASWHOGRCRC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(2-hydroxyethoxy)ethyl 2-hydroxypropyl 3,4,5,6-tetrabromophthalate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(2-hydroxyethoxy)ethyl 2-hydroxypropyl 3,4,5,6-tetrabromophthalate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>13</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(2-hydroxyethoxy)ethyl 2-hydroxypropyl 3,4,5,6-tetrabromophthalate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(2-hydroxyethoxy)ethyl 2-hydroxypropyl 3,4,5,6-tetrabromophthalate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bromopropylate',
    'C<sub>17</sub>H<sub>16</sub>Br<sub>2</sub>O<sub>3</sub>',
    '',
    '18181-80-1',
    'FOANIXZHAMJWOI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bromopropylate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bromopropylate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromopropylate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4,5-tetrabromo-3,6-bis(pentabromophenoxy)benzene',
    'C<sub>18</sub>O<sub>2</sub>Br<sub>14</sub>',
    '',
    '58965-66-5',
    'YMIUHIAWWDYGGU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,5-tetrabromo-3,6-bis(pentabromophenoxy)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,5-tetrabromo-3,6-bis(pentabromophenoxy)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,5-tetrabromo-3,6-bis(pentabromophenoxy)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4,5-tetrabromo-3,6-bis(pentabromophenoxy)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-bis(3,5-dibromo-4-(2-hydroxyethoxy)phenyl)propane',
    'C<sub>19</sub>H<sub>20</sub>Br<sub>4</sub>O<sub>4</sub>',
    '',
    '4162-45-2',
    'RVHUMFJSCJBNGS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-bis(3,5-dibromo-4-(2-hydroxyethoxy)phenyl)propane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-bis(3,5-dibromo-4-(2-hydroxyethoxy)phenyl)propane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-bis(3,5-dibromo-4-(2-hydroxyethoxy)phenyl)propane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-bis(3,5-dibromo-4-(2-hydroxyethoxy)phenyl)propane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'metrafenone',
    'C<sub>19</sub>H<sub>21</sub>BrO<sub>5</sub>',
    '',
    '220899-03-6',
    'AMSPWOYQQAWRRM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6',
    '',
    '?',
    (SELECT id from species WHERE iupac='metrafenone'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'solvent red 43',
    'C<sub>20</sub>H<sub>8</sub>Br<sub>4</sub>O<sub>5</sub>',
    '',
    '15086-94-9',
    'DBZJJPROPLPMSN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>12</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='solvent red 43'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='solvent red 43'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='solvent red 43'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='solvent red 43'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-bis[4-(2,3-dibromopropoxy)-3,5-dibromophenyl]-propane',
    'C<sub>21</sub>H<sub>20</sub>Br<sub>8</sub>O<sub>2</sub>',
    '',
    '21850-44-2',
    'LXIZRZRTWSDLKK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-bis[4-(2,3-dibromopropoxy)-3,5-dibromophenyl]-propane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-bis[4-(2,3-dibromopropoxy)-3,5-dibromophenyl]-propane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-bis[4-(2,3-dibromopropoxy)-3,5-dibromophenyl]-propane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-bis[4-(2,3-dibromopropoxy)-3,5-dibromophenyl]-propane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-bis(4-allyloxy-3,5-dibromophenyl)propane',
    'C<sub>21</sub>H<sub>20</sub>Br<sub>4</sub>O<sub>2</sub>',
    '',
    '25327-89-3',
    'PWXTUWQHMIFLKL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-bis(4-allyloxy-3,5-dibromophenyl)propane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-bis(4-allyloxy-3,5-dibromophenyl)propane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-bis(4-allyloxy-3,5-dibromophenyl)propane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-bis(4-allyloxy-3,5-dibromophenyl)propane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'AC1MJ2TG',
    'C<sub>21</sub>H<sub>24</sub>Br<sub>4</sub>O<sub>4</sub>',
    '',
    '33294-14-3',
    'UTMWVHZWNKBNKF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='AC1MJ2TG'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='AC1MJ2TG'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='AC1MJ2TG'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='AC1MJ2TG'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tetrabromophenolphthalein, ethyl ester',
    'C<sub>22</sub>H<sub>14</sub>Br<sub>4</sub>O<sub>4</sub>',
    '',
    '1176-74-5',
    'SQFXATUXPUCFFO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrabromophenolphthalein, ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrabromophenolphthalein, ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrabromophenolphthalein, ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrabromophenolphthalein, ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,10-dibromodibenzo[def,mno]chrysene-6,12-dione',
    'C<sub>22</sub>H<sub>8</sub>Br<sub>2</sub>O<sub>2</sub>',
    '',
    '4378-61-4',
    'HTENFZMEHKCNMD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,10-dibromodibenzo[def,mno]chrysene-6,12-dione'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,10-dibromodibenzo[def,mno]chrysene-6,12-dione'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,10-dibromodibenzo[def,mno]chrysene-6,12-dione'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,10-dibromodibenzo[def,mno]chrysene-6,12-dione'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bis(2-ethylhexyl)-3,4,5,6-tetrabromophthalate',
    'C<sub>24</sub>H<sub>34</sub>Br<sub>4</sub>O<sub>4</sub>',
    'TBPH',
    '26040-51-7',
    'UUEDINPOVKWVAZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis(2-ethylhexyl)-3,4,5,6-tetrabromophthalate'),
    (SELECT id from literature WHERE bibtexkey='2990'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bromadiolone',
    'C<sub>30</sub>H<sub>23</sub>BrO<sub>4</sub>',
    '',
    '28772-56-7',
    'OWNRRUFOJXFKCU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bromadiolone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='bromadiolone'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'brodifacoum',
    'C<sub>31</sub>H<sub>23</sub>BrO<sub>3</sub>',
    '',
    '56073-10-0',
    'VEUZZDOCACZPRY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromocarbons (C, H, O, N, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='brodifacoum'),
    (SELECT id from literature WHERE bibtexkey='3089'));
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Polybrominated diphenyl ethers (PBDEs)',
    (SELECT id from categories WHERE catname='Organic species with bromine (Br)'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-bromodiphenyl ether',
    'C<sub>12</sub>H<sub>9</sub>BrO',
    'PBDE-1',
    '36563-47-0',
    'RRWFUWRLNIZICP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2-bromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-bromodiphenyl ether',
    'C<sub>12</sub>H<sub>9</sub>BrO',
    'PBDE-2',
    '6876-00-2',
    'AHDAKFFMKLQPTD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='3-bromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-bromodiphenyl ether',
    'C<sub>12</sub>H<sub>9</sub>BrO',
    'PBDE-3',
    '101-55-3',
    'JDUYPUMQALQRCN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='4-bromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2564'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2564mgsm'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='4-bromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2564'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2564igsm'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '5500',
    'M',
    (SELECT id from species WHERE iupac='4-bromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2496'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-bromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='4-bromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-bromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2''-dibromodiphenyl ether',
    'C<sub>12</sub>H<sub>8</sub>Br<sub>2</sub>O',
    'PBDE-4',
    '51452-87-0',
    'JMSKYMHFNWGUJG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;2</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2''-dibromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dibromodiphenyl ether',
    'C<sub>12</sub>H<sub>8</sub>Br<sub>2</sub>O',
    'PBDE-5',
    '446254-14-4',
    'JTYRXXKXOULVAP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;2</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dibromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3''-dibromodiphenyl ether',
    'C<sub>12</sub>H<sub>8</sub>Br<sub>2</sub>O',
    'PBDE-6',
    '147217-72-9',
    'GODQTPRKFHOLPH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;2</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3''-dibromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dibromodiphenyl ether',
    'C<sub>12</sub>H<sub>8</sub>Br<sub>2</sub>O',
    'PBDE-7',
    '171977-44-9',
    'JMCIHKKTRDLVCO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;2</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dibromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4''-dibromodiphenyl ether',
    'C<sub>12</sub>H<sub>8</sub>Br<sub>2</sub>O',
    'PBDE-8',
    '147217-71-8',
    'RJQLQJZMLISKRJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,4''-dibromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5-dibromodiphenyl ether',
    'C<sub>12</sub>H<sub>8</sub>Br<sub>2</sub>O',
    'PBDE-9',
    '337513-66-3',
    'URDWJMUOJJSXAE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;2</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dibromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6-dibromodiphenyl ether',
    'C<sub>12</sub>H<sub>8</sub>Br<sub>2</sub>O',
    'PBDE-10',
    '51930-04-2',
    'MUVDKHMQIZJFTC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;2</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dibromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3''-dibromodiphenyl ether',
    'C<sub>12</sub>H<sub>8</sub>Br<sub>2</sub>O',
    'PBDE-11',
    '6903-63-5',
    'ALSVFJIXSNRBLE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;2</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='3,3''-dibromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4-dibromodiphenyl ether',
    'C<sub>12</sub>H<sub>8</sub>Br<sub>2</sub>O',
    'PBDE-12',
    '189084-59-1',
    'SUUJFDKVPDCZQZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dibromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4''-dibromodiphenyl ether',
    'C<sub>12</sub>H<sub>8</sub>Br<sub>2</sub>O',
    'PBDE-13',
    '83694-71-7',
    'BGPOVBPKODCMMN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;2</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='3,4''-dibromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,5-dibromodiphenyl ether',
    'C<sub>12</sub>H<sub>8</sub>Br<sub>2</sub>O',
    'PBDE-14',
    '46438-88-4',
    'FOXBZJLXVUHYQZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='3,5-dibromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,4''-dibromodiphenyl ether',
    'C<sub>12</sub>H<sub>8</sub>Br<sub>2</sub>O',
    'PBDE-15',
    '2050-47-7',
    'YAWIAFUBXXPJMQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='4,4''-dibromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2564'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2564mgsm'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='4,4''-dibromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2564'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2564igsm'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;2</sup>',
    '4500',
    'M',
    (SELECT id from species WHERE iupac='4,4''-dibromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2496'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4,4''-dibromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2494'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='4,4''-dibromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2536'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='4,4''-dibromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4''-dibromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3-tribromodiphenyl ether',
    'C<sub>12</sub>H<sub>7</sub>Br<sub>3</sub>O',
    'PBDE-16',
    '147217-74-1',
    'VRNGWCVCSHJUEJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3-tribromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',4-tribromodiphenyl ether',
    'C<sub>12</sub>H<sub>7</sub>Br<sub>3</sub>O',
    'PBDE-17',
    '147217-75-2',
    'VYBFILXLBMWOLI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4-tribromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',5-tribromodiphenyl ether',
    'C<sub>12</sub>H<sub>7</sub>Br<sub>3</sub>O',
    'PBDE-18',
    '407606-55-7',
    'FAZLXBWRNJAGSV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',5-tribromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',6-tribromodiphenyl ether',
    'C<sub>12</sub>H<sub>7</sub>Br<sub>3</sub>O',
    'PBDE-19',
    '147217-73-0',
    'YDFQHBRKURQGAH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',6-tribromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3''-tribromodiphenyl ether',
    'C<sub>12</sub>H<sub>7</sub>Br<sub>3</sub>O',
    'PBDE-20',
    '147217-76-3',
    'RQJUBSPXDSGLRB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3''-tribromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4-tribromodiphenyl ether',
    'C<sub>12</sub>H<sub>7</sub>Br<sub>3</sub>O',
    'PBDE-21',
    '337513-67-4',
    'RXWRVYYPLRPDOS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-tribromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4''-tribromodiphenyl ether',
    'C<sub>12</sub>H<sub>7</sub>Br<sub>3</sub>O',
    'PBDE-22',
    '446254-15-5',
    'WZHNIFQVNBINLF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4''-tribromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,5-tribromodiphenyl ether',
    'C<sub>12</sub>H<sub>7</sub>Br<sub>3</sub>O',
    'PBDE-23',
    '446254-16-6',
    'XQHLKDAUZRXBGC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5-tribromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,6-tribromodiphenyl ether',
    'C<sub>12</sub>H<sub>7</sub>Br<sub>3</sub>O',
    'PBDE-24',
    '218304-36-0',
    'GFLRHBRMAZDOIG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3,6-tribromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',4-tribromodiphenyl ether',
    'C<sub>12</sub>H<sub>7</sub>Br<sub>3</sub>O',
    'PBDE-25',
    '147217-77-4',
    'AURKEOPYVUYTLO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4-tribromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',5-tribromodiphenyl ether',
    'C<sub>12</sub>H<sub>7</sub>Br<sub>3</sub>O',
    'PBDE-26',
    '337513-75-4',
    'VUOBKVBAFJQQDB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',5-tribromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',6-tribromodiphenyl ether',
    'C<sub>12</sub>H<sub>7</sub>Br<sub>3</sub>O',
    'PBDE-27',
    '337513-53-8',
    'JUPZALSVNWJHII-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',6-tribromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,4''-tribromodiphenyl ether',
    'C<sub>12</sub>H<sub>7</sub>Br<sub>3</sub>O',
    'PBDE-28',
    '41318-75-6',
    'UPNBETHEXPIWQX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '8100',
    'M',
    (SELECT id from species WHERE iupac='2,4,4''-tribromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,4,4''-tribromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2564'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2564mgsm'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,4,4''-tribromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2564'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2564igsm'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '7400',
    'M',
    (SELECT id from species WHERE iupac='2,4,4''-tribromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2468'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '12000',
    'M',
    (SELECT id from species WHERE iupac='2,4,4''-tribromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2496'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HTdep_r2_lessthan_0.9'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4,4''-tribromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2494'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;1</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='2,4,4''-tribromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2536'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4''-tribromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4''-tribromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,5-tribromodiphenyl ether',
    'C<sub>12</sub>H<sub>7</sub>Br<sub>3</sub>O',
    'PBDE-29',
    '337513-56-1',
    'LTMKAFUXYKEDLR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,4,5-tribromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,6-tribromodiphenyl ether',
    'C<sub>12</sub>H<sub>7</sub>Br<sub>3</sub>O',
    'PBDE-30',
    '155999-95-4',
    'TVZAPPGLBLTACB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-tribromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4'',5-tribromodiphenyl ether',
    'C<sub>12</sub>H<sub>7</sub>Br<sub>3</sub>O',
    'PBDE-31',
    '65075-08-3',
    'PURZBWMLFRWRMG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,4'',5-tribromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4'',6-tribromodiphenyl ether',
    'C<sub>12</sub>H<sub>7</sub>Br<sub>3</sub>O',
    'PBDE-32',
    '189084-60-4',
    'TYDVYKIQSZGUMV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,4'',6-tribromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',4''-tribromodiphenyl ether',
    'C<sub>12</sub>H<sub>7</sub>Br<sub>3</sub>O',
    'PBDE-33',
    '49690-94-0',
    'BUQBQEYUVAKJQK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4''-tribromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',5''-tribromodiphenyl ether',
    'C<sub>12</sub>H<sub>7</sub>Br<sub>3</sub>O',
    'PBDE-34',
    '446254-17-7',
    'XMNXHCHZIPYCNA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',5''-tribromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3'',4-tribromodiphenyl ether',
    'C<sub>12</sub>H<sub>7</sub>Br<sub>3</sub>O',
    'PBDE-35',
    '147217-80-9',
    'CDVYKQPKJYPWRO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',4-tribromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3'',5-tribromodiphenyl ether',
    'C<sub>12</sub>H<sub>7</sub>Br<sub>3</sub>O',
    'PBDE-36',
    '147217-79-6',
    'XUKPJLVONRTECE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',5-tribromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4,4''-tribromodiphenyl ether',
    'C<sub>12</sub>H<sub>7</sub>Br<sub>3</sub>O',
    'PBDE-37',
    '147217-81-0',
    'YALAYFVVZFORPV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;2</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='3,4,4''-tribromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4,5-tribromodiphenyl ether',
    'C<sub>12</sub>H<sub>7</sub>Br<sub>3</sub>O',
    'PBDE-38',
    '337513-54-9',
    'DPGVQKLGQZZLMI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;2</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='3,4,5-tribromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4'',5-tribromodiphenyl ether',
    'C<sub>12</sub>H<sub>7</sub>Br<sub>3</sub>O',
    'PBDE-39',
    '407606-57-9',
    'UFFNOPDHJNQYKD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='3,4'',5-tribromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3''-tetrabromodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Br<sub>4</sub>O',
    'PBDE-40',
    '337513-77-6',
    'SXSUUFZWSVMTRL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3''-tetrabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4-tetrabromodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Br<sub>4</sub>O',
    'PBDE-41',
    '337513-68-5',
    'UAEBSKBXZAIRMX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4-tetrabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4''-tetrabromodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Br<sub>4</sub>O',
    'PBDE-42',
    '446254-18-8',
    'HQDQKPAHIDGGMH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4''-tetrabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,5-tetrabromodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Br<sub>4</sub>O',
    'PBDE-43',
    '446254-19-9',
    'LKMQHSYDVDIECC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,5-tetrabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,5''-tetrabromodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Br<sub>4</sub>O',
    'PBDE-44',
    '446254-20-2',
    'VBGBGTYMDIVKNK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,5''-tetrabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,6-tetrabromodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Br<sub>4</sub>O',
    'PBDE-45',
    '446254-21-3',
    'VTFWUBIOZQCMQS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,6-tetrabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,6''-tetrabromodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Br<sub>4</sub>O',
    'PBDE-46',
    '446254-22-4',
    'GBUUKJRFSKCMTB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,6''-tetrabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',4,4''-tetrabromodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Br<sub>4</sub>O',
    'PBDE-47',
    '5436-43-1',
    'XYBSIYMGXVUVGY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;1</sup>',
    '7400',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,4''-tetrabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,4''-tetrabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2564'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2564mgsm'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,4''-tetrabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2564'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2564igsm'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;1</sup>',
    '7300',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,4''-tetrabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2468'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '620',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,4''-tetrabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2496'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HTdep_r2_lessthan_0.5'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,4''-tetrabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3024'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,4''-tetrabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2494'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;1</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='2,2'',4,4''-tetrabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2536'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,4''-tetrabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,4''-tetrabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',4,5-tetrabromodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Br<sub>4</sub>O',
    'PBDE-48',
    '337513-55-0',
    'FJGDNHOVDFREMP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,5-tetrabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',4,5''-tetrabromodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Br<sub>4</sub>O',
    'PBDE-49',
    '243982-82-3',
    'QWVDUBDYUPHNHY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,5''-tetrabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',4,6-tetrabromodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Br<sub>4</sub>O',
    'PBDE-50',
    '446254-23-5',
    'FXUAKFRJBKFDSY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,6-tetrabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',4,6''-tetrabromodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Br<sub>4</sub>O',
    'PBDE-51',
    '189084-57-9',
    'WKBBBTLDLKYGBI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,6''-tetrabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',5,5''-tetrabromodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Br<sub>4</sub>O',
    'PBDE-52',
    '446254-24-6',
    'CDTHXJORUCZHMD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',5,5''-tetrabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',5,6''-tetrabromodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Br<sub>4</sub>O',
    'PBDE-53',
    '446254-25-7',
    'SDVQGIMOFXMKHR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',5,6''-tetrabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',6,6''-tetrabromodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Br<sub>4</sub>O',
    'PBDE-54',
    '446254-26-8',
    'WCDCHQGVTZHVSO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',6,6''-tetrabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4-tetrabromodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Br<sub>4</sub>O',
    'PBDE-55',
    '446254-27-9',
    'VIHUMJGEWQPWOT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4-tetrabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4''-tetrabromodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Br<sub>4</sub>O',
    'PBDE-56',
    '446254-28-0',
    'NFOIVCGFYJIYIB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4''-tetrabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',5-tetrabromodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Br<sub>4</sub>O',
    'PBDE-57',
    '337513-82-3',
    'CSIFWDKYUJLQEB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',5-tetrabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',5''-tetrabromodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Br<sub>4</sub>O',
    'PBDE-58',
    '446254-29-1',
    'SWOYBZHGPZIRHS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',5''-tetrabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',6-tetrabromodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Br<sub>4</sub>O',
    'PBDE-59',
    '446254-30-4',
    'DMAMJZQQOWYEHT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',6-tetrabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,4''-tetrabromodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Br<sub>4</sub>O',
    'PBDE-60',
    '446254-31-5',
    'ARERIMFZYPFJAV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,4''-tetrabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,5-tetrabromodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Br<sub>4</sub>O',
    'PBDE-61',
    '446254-32-6',
    'NDRSXNBQWAOQPP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,5-tetrabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,6-tetrabromodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Br<sub>4</sub>O',
    'PBDE-62',
    '446254-33-7',
    'YIQYWYZZLOZVRM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,6-tetrabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4'',5-tetrabromodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Br<sub>4</sub>O',
    'PBDE-63',
    '446254-34-8',
    'HNICYXFGCWPYGC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4'',5-tetrabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4'',6-tetrabromodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Br<sub>4</sub>O',
    'PBDE-64',
    '446254-35-9',
    'LDCXVFJUWKKBNY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4'',6-tetrabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,5,6-tetrabromodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Br<sub>4</sub>O',
    'PBDE-65',
    '446254-36-0',
    'HPEUYVBOPJQVPN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5,6-tetrabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',4,4''-tetrabromodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Br<sub>4</sub>O',
    'PBDE-66',
    '189084-61-5',
    'DHUMTYRHKMCVAG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3'',4,4''-tetrabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2494'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,4''-tetrabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',4,5-tetrabromodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Br<sub>4</sub>O',
    'PBDE-67',
    '446254-37-1',
    'OARGWSONVLGXQA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,5-tetrabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',4,5''-tetrabromodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Br<sub>4</sub>O',
    'PBDE-68',
    '446254-38-2',
    'UFWGRLCUOLLWAO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,5''-tetrabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',4,6-tetrabromodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Br<sub>4</sub>O',
    'PBDE-69',
    '327185-09-1',
    'NHZNRCYNZJADTG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,6-tetrabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',4'',5-tetrabromodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Br<sub>4</sub>O',
    'PBDE-70',
    '446254-39-3',
    'GHQMTYWQVJZWAR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4'',5-tetrabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',4'',6-tetrabromodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Br<sub>4</sub>O',
    'PBDE-71',
    '189084-62-6',
    'COPAGYRSCJVION-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4'',6-tetrabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',5,5''-tetrabromodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Br<sub>4</sub>O',
    'PBDE-72',
    '446254-40-6',
    'GBBNZKQTOOZGIS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',5,5''-tetrabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',5'',6-tetrabromodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Br<sub>4</sub>O',
    'PBDE-73',
    '446254-41-7',
    'WQFLVWXBCRJAQN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',5'',6-tetrabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,4'',5-tetrabromodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Br<sub>4</sub>O',
    'PBDE-74',
    '446254-42-8',
    'LXCFDVVDUVPAGR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4'',5-tetrabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,4'',6-tetrabromodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Br<sub>4</sub>O',
    'PBDE-75',
    '189084-63-7',
    'BWCNKMFFUGBFGB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,4,4'',6-tetrabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',4'',5''-tetrabromodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Br<sub>4</sub>O',
    'PBDE-76',
    '446254-43-9',
    'NCSWBJSFVPJPPK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4'',5''-tetrabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3'',4,4''-tetrabromodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Br<sub>4</sub>O',
    'PBDE-77',
    '93703-48-1',
    'RYGLOWMCGZHYRQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,3'',4,4''-tetrabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2494'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',4,4''-tetrabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3'',4,5-tetrabromodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Br<sub>4</sub>O',
    'PBDE-78',
    '446254-45-1',
    'HWOBLTZZSVXBOJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',4,5-tetrabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3'',4,5''-tetrabromodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Br<sub>4</sub>O',
    'PBDE-79',
    '446254-48-4',
    'LELQGHJEUVRPEV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',4,5''-tetrabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3'',5,5''-tetrabromodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Br<sub>4</sub>O',
    'PBDE-80',
    '103173-66-6',
    'HFIOZJQRZKNPKJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',5,5''-tetrabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4,4'',5-tetrabromodiphenyl ether',
    'C<sub>12</sub>H<sub>6</sub>Br<sub>4</sub>O',
    'PBDE-81',
    '446254-50-8',
    'ULFOIXCXIWHJDS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='3,4,4'',5-tetrabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4-pentabromodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Br<sub>5</sub>O',
    'PBDE-82',
    '327185-11-5',
    'RQMSPGJESCCPQX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',5-pentabromodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Br<sub>5</sub>O',
    'PBDE-83',
    '446254-51-9',
    'XAHYSNUYJLNDBX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',6-pentabromodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Br<sub>5</sub>O',
    'PBDE-84',
    '446254-52-0',
    'PPIZNRAVQHNLJM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',6-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,4''-pentabromodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Br<sub>5</sub>O',
    'PBDE-85',
    '182346-21-0',
    'DMLQSUZPTTUUDP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,4''-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2494'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4''-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,5-pentabromodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Br<sub>5</sub>O',
    'PBDE-86',
    '446254-53-1',
    'YMVWYUWOUOQCQP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,5''-pentabromodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Br<sub>5</sub>O',
    'PBDE-87',
    '446254-54-2',
    'WKYQUGCIKNOXFW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5''-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,6-pentabromodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Br<sub>5</sub>O',
    'PBDE-88',
    '446254-55-3',
    'OPZUHBCVIZNZFB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,6-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,6''-pentabromodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Br<sub>5</sub>O',
    'PBDE-89',
    '446254-56-4',
    'XGFLJLJXVIMCNR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,6''-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4'',5-pentabromodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Br<sub>5</sub>O',
    'PBDE-90',
    '446254-57-5',
    'BATFXMGTVIESIQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4'',6-pentabromodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Br<sub>5</sub>O',
    'PBDE-91',
    '446254-58-6',
    'HWNJTZKDPNZUSO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',6-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,5,5''-pentabromodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Br<sub>5</sub>O',
    'PBDE-92',
    '446254-59-7',
    'QWSQOVAGRDRZLM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,5,5''-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,5,6-pentabromodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Br<sub>5</sub>O',
    'PBDE-93',
    '446254-60-0',
    'BRTPVPJQMWLDNO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,5,6-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,5,6''-pentabromodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Br<sub>5</sub>O',
    'PBDE-94',
    '446254-61-1',
    'JOPASNJHCFYVHD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,5,6''-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,5'',6-pentabromodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Br<sub>5</sub>O',
    'PBDE-95',
    '446254-62-2',
    'BZDYRALIEYVMEP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,5'',6-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,6,6''-pentabromodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Br<sub>5</sub>O',
    'PBDE-96',
    '446254-63-3',
    'ZFCJNRDWGBZUED-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,6,6''-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4'',5''-pentabromodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Br<sub>5</sub>O',
    'PBDE-97',
    '446254-64-4',
    'MAGYDGJRSCULJL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5''-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4'',6''-pentabromodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Br<sub>5</sub>O',
    'PBDE-98',
    '38463-82-0',
    'OCLWEJVGAUFXQU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',6''-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',4,4'',5-pentabromodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Br<sub>5</sub>O',
    'PBDE-99',
    '60348-60-9',
    'WHPVYXDFIXRKLN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '8900',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2564'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2564mgsm'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2564'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2564igsm'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '8800',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2468'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '-6700',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2496'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HTdep_r2_lessthan_0.5'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3024'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2494'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    'R',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2536'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',4,4'',6-pentabromodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Br<sub>5</sub>O',
    'PBDE-100',
    '189084-64-8',
    'NSKIRYMHNFTRLR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6',
    '7300',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,4'',6-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,4'',6-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2564'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2564mgsm'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,4'',6-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2564'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2564igsm'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8',
    '6800',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,4'',6-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2468'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '12',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,4'',6-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2496'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HTdep_r2_lessthan_0.5'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,4'',6-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2494'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6',
    '',
    'R',
    (SELECT id from species WHERE iupac='2,2'',4,4'',6-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2536'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,4'',6-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,4'',6-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',4,5,5''-pentabromodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Br<sub>5</sub>O',
    'PBDE-101',
    '446254-65-5',
    'QUZWDWNIWWAQDI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,5,5''-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',4,5,6''-pentabromodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Br<sub>5</sub>O',
    'PBDE-102',
    '446254-66-6',
    'JHFMCUVMAIQWRI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,5,6''-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',4,5'',6-pentabromodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Br<sub>5</sub>O',
    'PBDE-103',
    '446254-67-7',
    'RJEMKRNASVHYKR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,5'',6-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',4,6,6''-pentabromodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Br<sub>5</sub>O',
    'PBDE-104',
    '446254-68-8',
    'CRSCWEYUPUKHPI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,6,6''-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4,4''-pentabromodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Br<sub>5</sub>O',
    'PBDE-105',
    '373594-78-6',
    'LBPWAGZGYNOKAM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,4''-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4,5-pentabromodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Br<sub>5</sub>O',
    'PBDE-106',
    '446254-69-9',
    'KLQKWMYXEWUAFP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,5-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4'',5-pentabromodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Br<sub>5</sub>O',
    'PBDE-107',
    '446254-70-2',
    'OMGVAMFMRSETEG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4'',5-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4,5''-pentabromodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Br<sub>5</sub>O',
    'PBDE-108',
    '446254-71-3',
    'VBKPKHVLHGOKOJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,5''-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4,6-pentabromodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Br<sub>5</sub>O',
    'PBDE-109',
    '446254-72-4',
    'FXXXWTMLIQLDRP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,6-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4'',6-pentabromodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Br<sub>5</sub>O',
    'PBDE-110',
    '446254-73-5',
    'LESZGJVTZILBTK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4'',6-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',5,5''-pentabromodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Br<sub>5</sub>O',
    'PBDE-111',
    '446254-74-6',
    'PCHDCOXHJBWEPW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',5,5''-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',5,6-pentabromodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Br<sub>5</sub>O',
    'PBDE-112',
    '446254-75-7',
    'MFBMNSFADPTAKZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',5,6-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',5'',6-pentabromodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Br<sub>5</sub>O',
    'PBDE-113',
    '446254-76-8',
    'OGZHLJXRGZFVLI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',5'',6-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,4'',5-pentabromodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Br<sub>5</sub>O',
    'PBDE-114',
    '446254-77-9',
    'SFNAUTSNWPPDSY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3,4,4'',5-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2564'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2564mgsm'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3,4,4'',5-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2564'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2564igsm'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;1</sup>',
    '4000',
    'M',
    (SELECT id from species WHERE iupac='2,3,4,4'',5-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2496'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HTdep_r2_lessthan_0.5'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,4'',5-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,4'',6-pentabromodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Br<sub>5</sub>O',
    'PBDE-115',
    '446254-78-0',
    'BKTLDVXDOVSTEV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,4'',6-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,5,6-pentabromodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Br<sub>5</sub>O',
    'PBDE-116',
    '189084-65-9',
    'ACRQLFSHISNWRY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,5,6-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4'',5,6-pentabromodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Br<sub>5</sub>O',
    'PBDE-117',
    '446254-79-1',
    'SOJBOGWFDBDWEG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4'',5,6-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',4,4'',5-pentabromodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Br<sub>5</sub>O',
    'PBDE-118',
    '446254-80-4',
    'VTMFEPLDDHZBGI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,4'',5-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',4,4'',6-pentabromodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Br<sub>5</sub>O',
    'PBDE-119',
    '189084-66-0',
    'KXEOYBYEJCRPGB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,4'',6-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',4,5,5''-pentabromodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Br<sub>5</sub>O',
    'PBDE-120',
    '417727-71-0',
    'AKSBEUHDCRZJAN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,5,5''-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',4,5'',6-pentabromodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Br<sub>5</sub>O',
    'PBDE-121',
    '446254-81-5',
    'GVGNVZBJVFDAAO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,5'',6-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4'',5''-pentabromodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Br<sub>5</sub>O',
    'PBDE-122',
    '446254-82-6',
    'CDNHGSPFIUITTN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4'',5''-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',4,4'',5''-pentabromodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Br<sub>5</sub>O',
    'PBDE-123',
    '446254-83-7',
    'SBKMUEQNZNDYFW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,4'',5''-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',4'',5,5''-pentabromodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Br<sub>5</sub>O',
    'PBDE-124',
    '446254-84-8',
    'FGHJTAAHIFEHLT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4'',5,5''-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',4'',5'',6-pentabromodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Br<sub>5</sub>O',
    'PBDE-125',
    '446254-85-9',
    'SESXKFPOVUVGLR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4'',5'',6-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3'',4,4'',5-pentabromodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Br<sub>5</sub>O',
    'PBDE-126',
    '366791-32-4',
    'SJNIIWPIAVQNRK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',4,4'',5-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3'',4,5,5''-pentabromodiphenyl ether',
    'C<sub>12</sub>H<sub>5</sub>Br<sub>5</sub>O',
    'PBDE-127',
    '446254-86-0',
    'RATMRXKBPDCKCZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',4,5,5''-pentabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,4''-hexabromodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Br<sub>6</sub>O',
    'PBDE-128',
    '182677-28-7',
    'WFLVELCLEGVBIH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4''-hexabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,5-hexabromodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Br<sub>6</sub>O',
    'PBDE-129',
    '446254-87-1',
    'PRNCVYAUCSGSOE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5-hexabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,5''-hexabromodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Br<sub>6</sub>O',
    'PBDE-130',
    '446254-88-2',
    'YURCHLXPAGSJHU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5''-hexabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,6-hexabromodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Br<sub>6</sub>O',
    'PBDE-131',
    '446254-89-3',
    'MGKVPJFIGGBCBA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,6-hexabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,6''-hexabromodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Br<sub>6</sub>O',
    'PBDE-132',
    '446254-90-6',
    'FFEKBOKDYRZGRV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,6''-hexabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',5,5''-hexabromodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Br<sub>6</sub>O',
    'PBDE-133',
    '446254-91-7',
    'XTBFPFHQPGZZJX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,5''-hexabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',5,6-hexabromodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Br<sub>6</sub>O',
    'PBDE-134',
    '446254-92-8',
    'MIBDGPWSGDWIQR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,6-hexabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',5,6''-hexabromodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Br<sub>6</sub>O',
    'PBDE-135',
    '446254-93-9',
    'AMGHASDTWACNCS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,6''-hexabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',6,6''-hexabromodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Br<sub>6</sub>O',
    'PBDE-136',
    '446254-94-0',
    'NTWGDSLWLUPCDW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',6,6''-hexabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,4'',5-hexabromodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Br<sub>6</sub>O',
    'PBDE-137',
    '446254-95-1',
    'HSTYYNPYXZYIAG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5-hexabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,4'',5''-hexabromodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Br<sub>6</sub>O',
    'PBDE-138',
    '182677-30-1',
    'IZFQCEZFGCMHOM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5''-hexabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,4'',6''-hexabromodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Br<sub>6</sub>O',
    'PBDE-140',
    '243982-83-4',
    'FLRODCDHJZNIGA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',6''-hexabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,5,5''-hexabromodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Br<sub>6</sub>O',
    'PBDE-141',
    '446254-97-3',
    'XTXIYMGRRUJOIT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5,5''-hexabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,5,6-hexabromodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Br<sub>6</sub>O',
    'PBDE-142',
    '446254-98-4',
    'LJDGJCNHVGGOFW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5,6-hexabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,5,6''-hexabromodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Br<sub>6</sub>O',
    'PBDE-143',
    '446254-99-5',
    'RQLZDUSZXOOBTM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5,6''-hexabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,5'',6-hexabromodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Br<sub>6</sub>O',
    'PBDE-144',
    '446255-00-1',
    'ZMSJCQOCTPYCQP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5'',6-hexabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,6,6''-hexabromodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Br<sub>6</sub>O',
    'PBDE-145',
    '446255-01-2',
    'BTKLHMBWCRVCLC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,6,6''-hexabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4'',5,5''-hexabromodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Br<sub>6</sub>O',
    'PBDE-146',
    '446255-02-3',
    'HGXPYDNHBUCRTR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5,5''-hexabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4'',5,6-hexabromodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Br<sub>6</sub>O',
    'PBDE-147',
    '116995-33-6',
    'OWBKWMDBTWHGHS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5,6-hexabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4'',5,6''-hexabromodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Br<sub>6</sub>O',
    'PBDE-148',
    '446255-03-4',
    'OJMHGSMSQZEBFH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5,6''-hexabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4'',5'',6-hexabromodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Br<sub>6</sub>O',
    'PBDE-149',
    '446255-04-5',
    'UJOUSZKYGGTPFQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5'',6-hexabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4'',6,6''-hexabromodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Br<sub>6</sub>O',
    'PBDE-150',
    '446255-05-6',
    'SQNOZOVDXXSLSG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',6,6''-hexabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,5,5'',6-hexabromodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Br<sub>6</sub>O',
    'PBDE-151',
    '446255-06-7',
    'NGOQQUYCSISZMY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,5,5'',6-hexabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,5,6,6''-hexabromodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Br<sub>6</sub>O',
    'PBDE-152',
    '446255-07-8',
    'BYBJJARTBKUIJD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,5,6,6''-hexabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',4,4'',5,5''-hexabromodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Br<sub>6</sub>O',
    'PBDE-153',
    '68631-49-2',
    'RZXIRSKYBISPGF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7',
    '7200',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5,5''-hexabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5',
    '7800',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5,5''-hexabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2468'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5,5''-hexabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3024'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5,5''-hexabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2494'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9',
    '',
    'R',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5,5''-hexabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2536'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5,5''-hexabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5,5''-hexabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',4,4'',5,6''-hexabromodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Br<sub>6</sub>O',
    'PBDE-154',
    '207122-15-4',
    'VHNPZYZQKWIWOD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1',
    '6800',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5,6''-hexabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3',
    '6800',
    'M',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5,6''-hexabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2468'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5,6''-hexabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2494'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5,6''-hexabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,4'',5,6''-hexabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',4,4'',6,6''-hexabromodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Br<sub>6</sub>O',
    'PBDE-155',
    '35854-94-5',
    'HRSCBOSGEKXXSI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',4,4'',6,6''-hexabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4,4'',5-hexabromodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Br<sub>6</sub>O',
    'PBDE-156',
    '405237-85-6',
    'JSDPCMJWYRDQEV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5-hexabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4,4'',5''-hexabromodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Br<sub>6</sub>O',
    'PBDE-157',
    '446255-08-9',
    'JUOAMVUIJQJZSZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5''-hexabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4,4'',6-hexabromodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Br<sub>6</sub>O',
    'PBDE-158',
    '446255-09-0',
    'KRYHHTVQOOJNHQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',6-hexabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4,5,5''-hexabromodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Br<sub>6</sub>O',
    'PBDE-159',
    '446255-10-3',
    'IDYFFNCFLRCOPZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,5,5''-hexabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4,5,6-hexabromodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Br<sub>6</sub>O',
    'PBDE-160',
    '446255-11-4',
    'OCVOYHGOXIIONK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,5,6-hexabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4,5'',6-hexabromodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Br<sub>6</sub>O',
    'PBDE-161',
    '446255-12-5',
    'WEYWRBBPPKSRGU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,5'',6-hexabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4'',5,5''-hexabromodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Br<sub>6</sub>O',
    'PBDE-162',
    '446255-13-6',
    'UKPNCLHMNJCGCJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4'',5,5''-hexabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4'',5,6-hexabromodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Br<sub>6</sub>O',
    'PBDE-163',
    '446255-14-7',
    'NUEAHMLXQFHEJN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4'',5,6-hexabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4'',5'',6-hexabromodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Br<sub>6</sub>O',
    'PBDE-164',
    '446255-15-8',
    'UJVYVXIHTJOJBZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4'',5'',6-hexabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',5,5'',6-hexabromodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Br<sub>6</sub>O',
    'PBDE-165',
    '446255-16-9',
    'KXERERDGMTWBGZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',5,5'',6-hexabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4,4'',5,6-hexabromodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Br<sub>6</sub>O',
    'PBDE-166',
    '189084-58-0',
    'KVYODBMKQYVNEK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4,4'',5,6-hexabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',4,4'',5,5''-hexabromodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Br<sub>6</sub>O',
    'PBDE-167',
    '446255-17-0',
    'NMUPLZRHSXJCJQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,4'',5,5''-hexabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3'',4,4'',5'',6-hexabromodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Br<sub>6</sub>O',
    'PBDE-168',
    '53551-87-4',
    'HWZAPXGFMVEGPW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3'',4,4'',5'',6-hexabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3'',4,4'',5,5''-hexabromodiphenyl ether',
    'C<sub>12</sub>H<sub>4</sub>Br<sub>6</sub>O',
    'PBDE-169',
    '446255-18-1',
    'JKFBMDHBJYKFKL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='3,3'',4,4'',5,5''-hexabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,4'',5-heptabromodiphenyl ether',
    'C<sub>12</sub>H<sub>3</sub>Br<sub>7</sub>O',
    'PBDE-170',
    '327185-13-7',
    'DLPNCMQTNWLTHD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5-heptabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,4'',6-heptabromodiphenyl ether',
    'C<sub>12</sub>H<sub>3</sub>Br<sub>7</sub>O',
    'PBDE-171',
    '446255-19-2',
    'FRMMMROUUPQUMZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',6-heptabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,5,5''-heptabromodiphenyl ether',
    'C<sub>12</sub>H<sub>3</sub>Br<sub>7</sub>O',
    'PBDE-172',
    '407606-59-1',
    'DSRRSKFMOJQETR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,5''-heptabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,5,6-heptabromodiphenyl ether',
    'C<sub>12</sub>H<sub>3</sub>Br<sub>7</sub>O',
    'PBDE-173',
    '446255-20-5',
    'NLBLNZDNOSSGPW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,6-heptabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,5,6''-heptabromodiphenyl ether',
    'C<sub>12</sub>H<sub>3</sub>Br<sub>7</sub>O',
    'PBDE-174',
    '446255-21-6',
    'VUUWOHUOYUGBEO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,6''-heptabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,5'',6-heptabromodiphenyl ether',
    'C<sub>12</sub>H<sub>3</sub>Br<sub>7</sub>O',
    'PBDE-175',
    '6255-22-7',
    'YATZWTXATDYQCK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5'',6-heptabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,6,6''-heptabromodiphenyl ether',
    'C<sub>12</sub>H<sub>3</sub>Br<sub>7</sub>O',
    'PBDE-176',
    '407606-61-5',
    'SWUALKCOTZOSMY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,6,6''-heptabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,5'',6''-heptabromodiphenyl ether',
    'C<sub>12</sub>H<sub>3</sub>Br<sub>7</sub>O',
    'PBDE-177',
    '446255-23-8',
    'ZHUHLPXIJIBQBJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5'',6''-heptabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',5,5'',6-heptabromodiphenyl ether',
    'C<sub>12</sub>H<sub>3</sub>Br<sub>7</sub>O',
    'PBDE-178',
    '446255-24-9',
    'UWUVZUPEEORCRG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,5'',6-heptabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',5,6,6''-heptabromodiphenyl ether',
    'C<sub>12</sub>H<sub>3</sub>Br<sub>7</sub>O',
    'PBDE-179',
    '446255-25-0',
    'COVXWWKOLMNRQE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,6,6''-heptabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,4'',5,5''-heptabromodiphenyl ether',
    'C<sub>12</sub>H<sub>3</sub>Br<sub>7</sub>O',
    'PBDE-180',
    '446255-26-1',
    'STMBXVOJNOJRPZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5,5''-heptabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,4'',5,6-heptabromodiphenyl ether',
    'C<sub>12</sub>H<sub>3</sub>Br<sub>7</sub>O',
    'PBDE-181',
    '189084-67-1',
    'GVNRIAPLVGNZPL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5,6-heptabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,4'',5,6''-heptabromodiphenyl ether',
    'C<sub>12</sub>H<sub>3</sub>Br<sub>7</sub>O',
    'PBDE-182',
    '442690-45-1',
    'ZYHDTADADSNMLV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5,6''-heptabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,4'',5'',6-heptabromodiphenyl ether',
    'C<sub>12</sub>H<sub>3</sub>Br<sub>7</sub>O',
    'PBDE-183',
    '207122-16-5',
    'ILPSCQCLBHQUEM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5'',6-heptabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2494'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5'',6-heptabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,4'',6,6''-heptabromodiphenyl ether',
    'C<sub>12</sub>H<sub>3</sub>Br<sub>7</sub>O',
    'PBDE-184',
    '117948-63-7',
    'JHDCZVAQPRXHEL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',6,6''-heptabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,5,5'',6-heptabromodiphenyl ether',
    'C<sub>12</sub>H<sub>3</sub>Br<sub>7</sub>O',
    'PBDE-185',
    '405237-86-7',
    'YRNMIFAQDSUFTR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5,5'',6-heptabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,5,6,6''-heptabromodiphenyl ether',
    'C<sub>12</sub>H<sub>3</sub>Br<sub>7</sub>O',
    'PBDE-186',
    '446255-27-2',
    'WUFQDCMRKKDNSF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,5,6,6''-heptabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4'',5,5'',6-heptabromodiphenyl ether',
    'C<sub>12</sub>H<sub>3</sub>Br<sub>7</sub>O',
    'PBDE-187',
    '446255-28-3',
    'RFZPXOBFDARWHV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5,5'',6-heptabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4'',5,6,6''-heptabromodiphenyl ether',
    'C<sub>12</sub>H<sub>3</sub>Br<sub>7</sub>O',
    'PBDE-188',
    '116995-32-5',
    'YGYDHFDPVGAMTL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4'',5,6,6''-heptabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4,4'',5,5''-heptabromodiphenyl ether',
    'C<sub>12</sub>H<sub>3</sub>Br<sub>7</sub>O',
    'PBDE-189',
    '259087-35-9',
    'CQVLRTUESBMMJW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5,5''-heptabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4,4'',5,6-heptabromodiphenyl ether',
    'C<sub>12</sub>H<sub>3</sub>Br<sub>7</sub>O',
    'PBDE-190',
    '189084-68-2',
    'OUEYHQIMJGHOQN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5,6-heptabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4,4'',5'',6-heptabromodiphenyl ether',
    'C<sub>12</sub>H<sub>3</sub>Br<sub>7</sub>O',
    'PBDE-191',
    '446255-30-7',
    'BNBFKFHSIPERIM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5'',6-heptabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4,5,5'',6-heptabromodiphenyl ether',
    'C<sub>12</sub>H<sub>3</sub>Br<sub>7</sub>O',
    'PBDE-192',
    '407578-53-4',
    'ABLZOLAUBUSUHT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,5,5'',6-heptabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4'',5,5'',6-heptabromodiphenyl ether',
    'C<sub>12</sub>H<sub>3</sub>Br<sub>7</sub>O',
    'PBDE-193',
    '446255-34-1',
    'AUFJSWANTKXCFZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4'',5,5'',6-heptabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,4'',5,5''-octabromodiphenyl ether',
    'C<sub>12</sub>H<sub>2</sub>Br<sub>8</sub>O',
    'PBDE-194',
    '32536-52-0',
    'ORYGKUIDIMIRNN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,5''-octabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,4'',5,6-octabromodiphenyl ether',
    'C<sub>12</sub>H<sub>2</sub>Br<sub>8</sub>O',
    'PBDE-195',
    '446255-38-5',
    'GPQLSLKPHQEEOP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,6-octabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,4'',5,6''-octabromodiphenyl ether',
    'C<sub>12</sub>H<sub>2</sub>Br<sub>8</sub>O',
    'PBDE-196',
    '446255-39-6',
    'IEWFKOVTVJNWFF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,6''-octabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,4'',6,6''-octabromodiphenyl ether',
    'C<sub>12</sub>H<sub>2</sub>Br<sub>8</sub>O',
    'PBDE-197',
    '117964-21-3',
    'AAFUUKPTSPVXJH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',6,6''-octabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,5,5'',6-octabromodiphenyl ether',
    'C<sub>12</sub>H<sub>2</sub>Br<sub>8</sub>O',
    'PBDE-198',
    '446255-42-1',
    'IBKRHVDFFHQOSC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,5'',6-octabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,5,5'',6''-octabromodiphenyl ether',
    'C<sub>12</sub>H<sub>2</sub>Br<sub>8</sub>O',
    'PBDE-199',
    '446255-43-2',
    'JNSLJYRXDGBNBE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,5'',6''-octabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,5,6,6''-octabromodiphenyl ether',
    'C<sub>12</sub>H<sub>2</sub>Br<sub>8</sub>O',
    'PBDE-200',
    '446255-46-5',
    'JWMXGEPFVCRXQR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,6,6''-octabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,5'',6,6''-octabromodiphenyl ether',
    'C<sub>12</sub>H<sub>2</sub>Br<sub>8</sub>O',
    'PBDE-201',
    '446255-50-1',
    'HQWFMMKREWXIGN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5'',6,6''-octabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',5,5'',6,6''-octabromodiphenyl ether',
    'C<sub>12</sub>H<sub>2</sub>Br<sub>8</sub>O',
    'PBDE-202',
    '67797-09-5',
    'AHNZLQAZTWRRDW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',5,5'',6,6''-octabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,4'',5,5'',6-octabromodiphenyl ether',
    'C<sub>12</sub>H<sub>2</sub>Br<sub>8</sub>O',
    'PBDE-203',
    '337513-72-1',
    'RTUZOQFRIPIWPS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5,5'',6-octabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,4,4'',5,6,6''-octabromodiphenyl ether',
    'C<sub>12</sub>H<sub>2</sub>Br<sub>8</sub>O',
    'PBDE-204',
    '446255-54-5',
    'YZABCBOJTHQTSX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,4,4'',5,6,6''-octabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,3'',4,4'',5,5'',6-octabromodiphenyl ether',
    'C<sub>12</sub>H<sub>2</sub>Br<sub>8</sub>O',
    'PBDE-205',
    '446255-56-7',
    'CVMKCYDBEYHNBM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,3,3'',4,4'',5,5'',6-octabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,4'',5,5'',6-nonabromodiphenyl ether',
    'C<sub>12</sub>HBr<sub>9</sub>O',
    'PBDE-206',
    '63387-28-0',
    'CYRHBNRLQMLULE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,5'',6-nonabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,4'',5,6,6''-nonabromodiphenyl ether',
    'C<sub>12</sub>HBr<sub>9</sub>O',
    'PBDE-207',
    '437701-79-6',
    'IEEVDIAVLGLVOW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,4'',5,6,6''-nonabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2'',3,3'',4,5,5'',6,6''-nonabromodiphenyl ether',
    'C<sub>12</sub>HBr<sub>9</sub>O',
    'PBDE-208',
    '437701-78-5',
    'ASGZXYIDLFWXID-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='2,2'',3,3'',4,5,5'',6,6''-nonabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'decabromodiphenyl ether',
    'C<sub>12</sub>Br<sub>10</sub>O',
    'PBDE-209',
    '1163-19-5',
    'WHHGLZMJPXIBIX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '7600',
    'M',
    (SELECT id from species WHERE iupac='decabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '7900',
    'M',
    (SELECT id from species WHERE iupac='decabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2468'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>1</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='decabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3683'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decabromodiphenyl ether'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dibromoacetonitrile',
    'C<sub>2</sub>HBr<sub>2</sub>N',
    '',
    '3252-43-5',
    'NDSBDLSWTGLNQA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibromoacetonitrile'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bromoacetonitrile',
    'C<sub>2</sub>H<sub>2</sub>BrN',
    '',
    '590-17-0',
    'REXUYBKPWIPONM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromoacetonitrile'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-bromopyridine',
    'C<sub>5</sub>H<sub>4</sub>BrN',
    '',
    '109-04-6',
    'IMRWILPUOVGIMU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-bromopyridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-bromopyridine'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-bromopyridine',
    'C<sub>5</sub>H<sub>4</sub>BrN',
    '',
    '626-55-1',
    'NYPYPOZNGOXYSU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-bromopyridine'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-dibromo-2,4-dicyanobutane',
    'C<sub>6</sub>H<sub>6</sub>Br<sub>2</sub>N<sub>2</sub>',
    '',
    '35691-65-7',
    'DHVLDKHFGIVEIP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dibromo-2,4-dicyanobutane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-bromobenzenamine',
    'C<sub>6</sub>H<sub>6</sub>BrN',
    '',
    '106-40-1',
    'WDFQBORIUYODSI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-bromobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,6-tribromobenzenamine',
    'C<sub>6</sub>H<sub>4</sub>Br<sub>3</sub>N',
    '',
    '147-82-0',
    'GVPODVKBTHCGFU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-tribromobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-tribromobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-tribromobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,6-tribromobenzenamine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N,N''-dimethyl-3,3'',4,4'',5,5''-hexabromo-2,2''-bipyrrole',
    'C<sub>10</sub>H<sub>6</sub>Br<sub>6</sub>N<sub>2</sub>',
    'DBP-Br6',
    '253798-63-9',
    'BUKWTHPBLJVYMZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='N,N''-dimethyl-3,3'',4,4'',5,5''-hexabromo-2,2''-bipyrrole'),
    (SELECT id from literature WHERE bibtexkey='2469'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N''-dimethyl-3,3'',4,4'',5,5''-hexabromo-2,2''-bipyrrole'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1''-ethylene 2,2''-dipyridylium dibromide',
    'C<sub>12</sub>H<sub>12</sub>N<sub>2</sub>Br',
    'diquat dibromide',
    '85-00-7',
    'JXEXEPZXXFNEHA-UHFFFAOYSA-M',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1''-ethylene 2,2''-dipyridylium dibromide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tralomethrin',
    'C<sub>22</sub>H<sub>19</sub>NO<sub>3</sub>Br<sub>4</sub>',
    '',
    '66841-25-6',
    'YWSCPYYRJXKUDB-KAKFPZCNSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tralomethrin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tralomethrin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tralomethrin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bromomethyl peroxynitrate',
    'CH<sub>2</sub>BrO<sub>2</sub>NO<sub>2</sub>',
    '',
    '',
    'JTAFUKGUWIYDNI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromomethyl peroxynitrate'),
    (SELECT id from literature WHERE bibtexkey='2927'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dibromomethyl peroxynitrate',
    'CHBr<sub>2</sub>O<sub>2</sub>NO<sub>2</sub>',
    '',
    '',
    'CRBGJNSRTFAVGH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibromomethyl peroxynitrate'),
    (SELECT id from literature WHERE bibtexkey='2927'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tribromomethyl peroxynitrate',
    'CBr<sub>3</sub>O<sub>2</sub>NO<sub>2</sub>',
    '',
    '',
    'BVMOLEXBJGZUAI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tribromomethyl peroxynitrate'),
    (SELECT id from literature WHERE bibtexkey='2927'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:BRETPAN',
    'C<sub>2</sub>H<sub>2</sub>NO<sub>5</sub>Br',
    '',
    '',
    'OOFSXJVGALRPLK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BRETPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BRETPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:BRETPAN'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dibromo-2-cyanoacetamide',
    'C<sub>3</sub>H<sub>2</sub>Br<sub>2</sub>N<sub>2</sub>O',
    '2,2-dibromo-3-nitrilopropionamide',
    '10222-01-2',
    'UUIVKBHZENILKB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2-dibromo-2-cyanoacetamide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2-dibromo-2-cyanoacetamide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dibromo-2-cyanoacetamide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bronopol',
    'C<sub>3</sub>H<sub>6</sub>BrNO<sub>4</sub>',
    '',
    '52-51-7',
    'LVDKZNITIUWNER-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bronopol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6-dibromo-4-nitroaniline',
    'C<sub>6</sub>H<sub>4</sub>Br<sub>2</sub>N<sub>2</sub>O<sub>2</sub>',
    '',
    '827-94-1',
    'YMZIFDLWYUSZCC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dibromo-4-nitroaniline'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dibromo-4-nitroaniline'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dibromo-4-nitroaniline'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dibromo-4-nitroaniline'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-bromo-4,6-dinitroaniline',
    'C<sub>6</sub>H<sub>4</sub>BrN<sub>3</sub>O<sub>4</sub>',
    '',
    '1817-73-8',
    'KWMDHCLJYMVBNS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-bromo-4,6-dinitroaniline'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-bromo-4,6-dinitroaniline'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-bromo-4,6-dinitroaniline'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-bromo-4,6-dinitroaniline'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-bromonitrobenzene',
    'C<sub>6</sub>H<sub>4</sub>BrNO<sub>2</sub>',
    'm-bromonitrobenzene',
    '585-79-5',
    'FWIROFMBWVMWLB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-bromonitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-bromonitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='2165'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-bromonitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-bromonitrobenzene',
    'C<sub>6</sub>H<sub>4</sub>BrNO<sub>2</sub>',
    'p-bromonitrobenzene',
    '586-78-7',
    'ZDFBKZUDCQQKAC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-bromonitrobenzene'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,5-dibromo-4-hydroxy-benzonitrile',
    'C<sub>7</sub>H<sub>3</sub>Br<sub>2</sub>NO',
    'bromoxynil',
    '1689-84-5',
    'UPMXNNIRAGDFEH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,5-dibromo-4-hydroxy-benzonitrile'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,5-dibromo-4-hydroxy-benzonitrile'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH9'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,5-dibromo-4-hydroxy-benzonitrile'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH4'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3,5-dibromo-4-hydroxy-benzonitrile'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH7'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6-dibromo-3-methyl-4-nitroanisole',
    'C<sub>8</sub>H<sub>7</sub>Br<sub>2</sub>NO<sub>3</sub>',
    '',
    '62265-99-0',
    'RBAJFFLBHVZCDY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dibromo-3-methyl-4-nitroanisole'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dibromo-3-methyl-4-nitroanisole'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dibromo-3-methyl-4-nitroanisole'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dibromo-3-methyl-4-nitroanisole'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bromacil',
    'C<sub>9</sub>H<sub>13</sub>BrN<sub>2</sub>O<sub>2</sub>',
    '',
    '314-40-9',
    'CTSLUCNDVMMDHG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bromacil'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bromacil'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bromacil'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2',
    '',
    'X',
    (SELECT id from species WHERE iupac='bromacil'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromacil'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N''-(4-bromophenyl)-N-methoxy-N-methylurea',
    'C<sub>9</sub>H<sub>11</sub>BrN<sub>2</sub>O',
    'metobromuron',
    '3060-89-7',
    'WLFDQEVORAMCIM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='N''-(4-bromophenyl)-N-methoxy-N-methylurea'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='N''-(4-bromophenyl)-N-methoxy-N-methylurea'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='N''-(4-bromophenyl)-N-methoxy-N-methylurea'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N''-(4-bromophenyl)-N-methoxy-N-methylurea'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='N''-(4-bromophenyl)-N-methoxy-N-methylurea'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bromuron',
    'C<sub>9</sub>H<sub>11</sub>BrN<sub>2</sub>O',
    '',
    '3408-97-7',
    'GSNZNZUNAJCHDO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='bromuron'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bromoxynil butyrate',
    'C<sub>11</sub>H<sub>9</sub>Br<sub>2</sub>NO<sub>2</sub>',
    '',
    '3861-41-4',
    'PGMZYNZXIYOOHJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='bromoxynil butyrate'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tris(2,3-dibromopropyl)isocyanurate',
    'C<sub>12</sub>H<sub>15</sub>Br<sub>6</sub>N<sub>3</sub>O<sub>3</sub>',
    '',
    '52434-90-9',
    'NZUPFZNVGSWLQC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>12</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tris(2,3-dibromopropyl)isocyanurate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tris(2,3-dibromopropyl)isocyanurate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tris(2,3-dibromopropyl)isocyanurate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tris(2,3-dibromopropyl)isocyanurate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bromofenoxim',
    'C<sub>13</sub>H<sub>7</sub>Br<sub>2</sub>N<sub>3</sub>O<sub>6</sub>',
    '',
    '13181-17-4',
    'VTQWKUZUPOTXEH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='bromofenoxim'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromofenoxim'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='bromofenoxim'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tribromsalan',
    'C<sub>13</sub>H<sub>8</sub>Br<sub>3</sub>NO<sub>2</sub>',
    '',
    '87-10-5',
    'KVSKGMLNBAPGKH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tribromsalan'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tribromsalan'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tribromsalan'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tribromsalan'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bromoxynil heptanoate',
    'C<sub>14</sub>H<sub>15</sub>Br<sub>2</sub>NO<sub>2</sub>',
    '',
    '56634-95-8',
    'BHZWBQPHPLFZSV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3',
    '',
    '?',
    (SELECT id from species WHERE iupac='bromoxynil heptanoate'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-amino-2,4-dibromo-9,10-anthracenedione',
    'C<sub>14</sub>H<sub>7</sub>Br<sub>2</sub>NO<sub>2</sub>',
    '1-amino-2,4-dibromoanthraquinone',
    '81-49-2',
    'ZINRVIQBCHAZMM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-amino-2,4-dibromo-9,10-anthracenedione'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6-dibromo-4-cyanophenyl octanoate',
    'C<sub>15</sub>H<sub>17</sub>BrNO<sub>2</sub>',
    '',
    '1689-99-2',
    'DQKWXTIYGWPGOO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,6-dibromo-4-cyanophenyl octanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,6-dibromo-4-cyanophenyl octanoate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,6-dibromo-4-cyanophenyl octanoate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&lt; 5.3',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,6-dibromo-4-cyanophenyl octanoate'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bromobutide',
    'C<sub>15</sub>H<sub>22</sub>BrNO',
    '',
    '74712-19-9',
    'WZDDLAZXUYIVMU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='bromobutide'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(2E)-N,N''-bis(2,4,6-tribromophenyl)-2-butenediamide',
    'C<sub>16</sub>H<sub>8</sub>Br<sub>6</sub>N<sub>2</sub>O<sub>2</sub>',
    '',
    '92484-07-6',
    'IJUNKLAVMFKPCX-OWOJBTEDSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2E)-N,N''-bis(2,4,6-tribromophenyl)-2-butenediamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2E)-N,N''-bis(2,4,6-tribromophenyl)-2-butenediamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2E)-N,N''-bis(2,4,6-tribromophenyl)-2-butenediamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>13</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2E)-N,N''-bis(2,4,6-tribromophenyl)-2-butenediamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'SAYTEX BT 93',
    'C<sub>18</sub>H<sub>4</sub>Br<sub>8</sub>N<sub>2</sub>O<sub>4</sub>',
    '',
    '32588-76-4',
    'DYIZJUDNMOIZQO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>15</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='SAYTEX BT 93'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>15</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='SAYTEX BT 93'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='SAYTEX BT 93'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='SAYTEX BT 93'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>13</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='SAYTEX BT 93'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'SAYTEX BN 451',
    'C<sub>20</sub>H<sub>20</sub>Br<sub>4</sub>N<sub>2</sub>O<sub>4</sub>',
    '',
    '52907-07-0',
    'WOFYQUJNULCFLN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>15</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='SAYTEX BN 451'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='SAYTEX BN 451'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='SAYTEX BN 451'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>15</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='SAYTEX BN 451'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'deltamethrin',
    'C<sub>22</sub>H<sub>19</sub>Br<sub>2</sub>NO<sub>3</sub>',
    '',
    '52918-63-5',
    'OWZREIFADZCYQD-NSHGMRRFSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'V',
    (SELECT id from species WHERE iupac='deltamethrin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'V',
    (SELECT id from species WHERE iupac='deltamethrin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='deltamethrin'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'V',
    (SELECT id from species WHERE iupac='deltamethrin'),
    (SELECT id from literature WHERE bibtexkey='2973'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='deltamethrin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='deltamethrin'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2''-(methylenedi-4,1-phenylene)bis(4,5,6,7-tetrabromo-1H-isoindole-1,3(2H)-dione',
    'C<sub>29</sub>H<sub>10</sub>N<sub>2</sub>O<sub>4</sub>Br<sub>8</sub>',
    '',
    '32588-74-2',
    'RHFKNNBDKARGKL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Polybrominated diphenyl ethers (PBDEs)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>14</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2''-(methylenedi-4,1-phenylene)bis(4,5,6,7-tetrabromo-1H-isoindole-1,3(2H)-dione'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>14</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2''-(methylenedi-4,1-phenylene)bis(4,5,6,7-tetrabromo-1H-isoindole-1,3(2H)-dione'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2''-(methylenedi-4,1-phenylene)bis(4,5,6,7-tetrabromo-1H-isoindole-1,3(2H)-dione'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>15</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2''-(methylenedi-4,1-phenylene)bis(4,5,6,7-tetrabromo-1H-isoindole-1,3(2H)-dione'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)',
    (SELECT id from categories WHERE catname='Organic species with bromine (Br)'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bromotrifluoromethane',
    'CF<sub>3</sub>Br',
    '',
    '75-63-8',
    'RJCQBQGAPKAMLL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bromotrifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='bromotrifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='bromotrifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromotrifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromotrifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromotrifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromotrifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromotrifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromotrifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromotrifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromotrifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2550'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='bromotrifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='bromotrifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dibromodifluoromethane',
    'CBr<sub>2</sub>F<sub>2</sub>',
    '',
    '75-61-6',
    'AZSZCFSOHXEJQE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibromodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-bromo-1,2,2,2-tetrafluoroethane',
    'C<sub>2</sub>HBrF<sub>4</sub>',
    'teflurane',
    '124-72-1',
    'RZXZIZDRFQFCTA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;4</sup>',
    '2700',
    'L',
    (SELECT id from species WHERE iupac='1-bromo-1,2,2,2-tetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3696'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-bromo-1,2,2,2-tetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2442'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-1,2,2,2-tetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-1,2,2,2-tetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-1,2,2,2-tetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-1,2,2,2-tetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-bromo-1,2,2,2-tetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-bromo-1,2,2,2-tetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-bromo-1,2,2,2-tetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-dibromotetrafluoroethane',
    'C<sub>2</sub>Br<sub>2</sub>F<sub>4</sub>',
    '',
    '124-73-2',
    'KVBKAPANDHPRDG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;7</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dibromotetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;7</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dibromotetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dibromotetrafluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-bromo-2-fluorobenzene',
    'C<sub>6</sub>H<sub>4</sub>BrF',
    '',
    '1072-85-1',
    'IPWBFGUBXWMIPR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-bromo-2-fluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-bromo-3-fluorobenzene',
    'C<sub>6</sub>H<sub>4</sub>BrF',
    '',
    '1073-06-9',
    'QDFKKJYEIFBEFC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-bromo-3-fluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-bromo-4-fluorobenzene',
    'C<sub>6</sub>H<sub>4</sub>BrF',
    '',
    '460-00-4',
    'AITNMTXHTIIIBB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;3</sup>',
    '4400',
    'M',
    (SELECT id from species WHERE iupac='1-bromo-4-fluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bromopentafluorobenzene',
    'C<sub>6</sub>BrF<sub>5</sub>',
    '',
    '344-04-7',
    'XEKTVXADUPBFOA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromopentafluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromopentafluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromopentafluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromopentafluorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'halfenprox',
    'C<sub>24</sub>H<sub>23</sub>BrF<sub>2</sub>O<sub>3</sub>',
    '',
    '111872-58-3',
    'WIFXJBMOTMKRMM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='halfenprox'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bromethalin',
    'C<sub>14</sub>H<sub>7</sub>Br<sub>3</sub>F<sub>3</sub>N<sub>3</sub>O<sub>4</sub>',
    '',
    '63333-35-7',
    'USMZPYXTVKAYST-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromethalin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'brofluthrinate',
    'C<sub>26</sub>H<sub>22</sub>BrF<sub>2</sub>NO<sub>4</sub>',
    '',
    '160791-64-0',
    'BUHNCQOJJZAOMJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='brofluthrinate'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bromochloromethane',
    'CH<sub>2</sub>BrCl',
    '',
    '74-97-5',
    'JPOXNPPZZKNXOV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;3</sup>',
    '4700',
    'M',
    (SELECT id from species WHERE iupac='bromochloromethane'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;3</sup>',
    '4600',
    'M',
    (SELECT id from species WHERE iupac='bromochloromethane'),
    (SELECT id from literature WHERE bibtexkey='2904'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bromochloromethane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bromochloromethane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bromochloromethane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='bromochloromethane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromochloromethane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromochloromethane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromochloromethane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromochloromethane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='bromochloromethane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='bromochloromethane'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '1943-74-97-5-erratum',
    '1943', 'Erratum for page 285 of Fogg and Sangster (2003): data in their table look strange (9.70R) and are not used here.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1943-74-97-5-erratum'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bromodichloromethane',
    'CHCl<sub>2</sub>Br',
    '',
    '75-27-4',
    'FMWLUWPQPKEARP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;3</sup>',
    '5200',
    'L',
    (SELECT id from species WHERE iupac='bromodichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '4900',
    'L',
    (SELECT id from species WHERE iupac='bromodichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;3</sup>',
    '5200',
    'L',
    (SELECT id from species WHERE iupac='bromodichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '4900',
    'L',
    (SELECT id from species WHERE iupac='bromodichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;3</sup>',
    '5200',
    'L',
    (SELECT id from species WHERE iupac='bromodichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;3</sup>',
    '5200',
    'L',
    (SELECT id from species WHERE iupac='bromodichloromethane'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;3</sup>',
    '3700',
    'L',
    (SELECT id from species WHERE iupac='bromodichloromethane'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;3</sup>',
    '5200',
    'L',
    (SELECT id from species WHERE iupac='bromodichloromethane'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;3</sup>',
    '5200',
    'L',
    (SELECT id from species WHERE iupac='bromodichloromethane'),
    (SELECT id from literature WHERE bibtexkey='747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;3</sup>',
    '4700',
    'M',
    (SELECT id from species WHERE iupac='bromodichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='bromodichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3572'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='bromodichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2940'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;3</sup>',
    '4400',
    'M',
    (SELECT id from species WHERE iupac='bromodichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2904'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '4800',
    'M',
    (SELECT id from species WHERE iupac='bromodichloromethane'),
    (SELECT id from literature WHERE bibtexkey='583'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0583-75-27-4-ABC',
    '583', 'The data from Moore et&nbsp;al. (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;76.31131 +7250.73360/T +8.15388&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0583-75-27-4-ABC'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;3</sup>',
    '4200',
    'M',
    (SELECT id from species WHERE iupac='bromodichloromethane'),
    (SELECT id from literature WHERE bibtexkey='856'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;3</sup>',
    '5200',
    'M',
    (SELECT id from species WHERE iupac='bromodichloromethane'),
    (SELECT id from literature WHERE bibtexkey='531'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '5200',
    'M',
    (SELECT id from species WHERE iupac='bromodichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2271'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='bromodichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bromodichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bromodichloromethane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;3</sup>',
    '1200',
    'X',
    (SELECT id from species WHERE iupac='bromodichloromethane'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='bromodichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='bromodichloromethane'),
    (SELECT id from literature WHERE bibtexkey='531'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='bromodichloromethane'),
    (SELECT id from literature WHERE bibtexkey='531'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='bromodichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3083'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromodichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromodichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromodichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromodichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromodichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromodichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromodichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4100',
    'Q',
    (SELECT id from species WHERE iupac='bromodichloromethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromodichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromodichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='bromodichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='bromodichloromethane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3800',
    '?',
    (SELECT id from species WHERE iupac='bromodichloromethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='bromodichloromethane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bromotrichloromethane',
    'CBrCl<sub>3</sub>',
    '',
    '75-62-7',
    'XNNQFQFUQLJSQT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromotrichloromethane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dibromochloromethane',
    'CHClBr<sub>2</sub>',
    '',
    '124-48-1',
    'GATVIKZLVQHOMN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;3</sup>',
    '5500',
    'L',
    (SELECT id from species WHERE iupac='dibromochloromethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;3</sup>',
    '5200',
    'L',
    (SELECT id from species WHERE iupac='dibromochloromethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;3</sup>',
    '5500',
    'L',
    (SELECT id from species WHERE iupac='dibromochloromethane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;3</sup>',
    '5200',
    'L',
    (SELECT id from species WHERE iupac='dibromochloromethane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;3</sup>',
    '5500',
    'L',
    (SELECT id from species WHERE iupac='dibromochloromethane'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;3</sup>',
    '5500',
    'L',
    (SELECT id from species WHERE iupac='dibromochloromethane'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;3</sup>',
    '4400',
    'L',
    (SELECT id from species WHERE iupac='dibromochloromethane'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;3</sup>',
    '5500',
    'L',
    (SELECT id from species WHERE iupac='dibromochloromethane'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;3</sup>',
    '5500',
    'L',
    (SELECT id from species WHERE iupac='dibromochloromethane'),
    (SELECT id from literature WHERE bibtexkey='747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '5300',
    'M',
    (SELECT id from species WHERE iupac='dibromochloromethane'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dibromochloromethane'),
    (SELECT id from literature WHERE bibtexkey='3572'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dibromochloromethane'),
    (SELECT id from literature WHERE bibtexkey='2940'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;3</sup>',
    '5100',
    'M',
    (SELECT id from species WHERE iupac='dibromochloromethane'),
    (SELECT id from literature WHERE bibtexkey='2904'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;3</sup>',
    '4600',
    'M',
    (SELECT id from species WHERE iupac='dibromochloromethane'),
    (SELECT id from literature WHERE bibtexkey='583'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0583-124-48-1-ABC',
    '583', 'The data from Moore et&nbsp;al. (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;265.18008 +15516.80509/T +36.54803&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0583-124-48-1-ABC'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;3</sup>',
    '4600',
    'M',
    (SELECT id from species WHERE iupac='dibromochloromethane'),
    (SELECT id from literature WHERE bibtexkey='856'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;3</sup>',
    '6400',
    'M',
    (SELECT id from species WHERE iupac='dibromochloromethane'),
    (SELECT id from literature WHERE bibtexkey='1156'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1156'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;3</sup>',
    '5200',
    'M',
    (SELECT id from species WHERE iupac='dibromochloromethane'),
    (SELECT id from literature WHERE bibtexkey='531'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;3</sup>',
    '5000',
    'M',
    (SELECT id from species WHERE iupac='dibromochloromethane'),
    (SELECT id from literature WHERE bibtexkey='2271'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dibromochloromethane'),
    (SELECT id from literature WHERE bibtexkey='2900'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dibromochloromethane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dibromochloromethane'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '2500',
    'X',
    (SELECT id from species WHERE iupac='dibromochloromethane'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='dibromochloromethane'),
    (SELECT id from literature WHERE bibtexkey='531'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='dibromochloromethane'),
    (SELECT id from literature WHERE bibtexkey='531'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='dibromochloromethane'),
    (SELECT id from literature WHERE bibtexkey='3083'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibromochloromethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibromochloromethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4800',
    'Q',
    (SELECT id from species WHERE iupac='dibromochloromethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibromochloromethane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibromochloromethane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4600',
    '?',
    (SELECT id from species WHERE iupac='dibromochloromethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dibromochloromethane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-chloro-2-bromoethane',
    'C<sub>2</sub>H<sub>4</sub>BrCl',
    '',
    '107-04-0',
    'IBYHHJPAARCAIE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-chloro-2-bromoethane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='1-chloro-2-bromoethane'),
    (SELECT id from literature WHERE bibtexkey='3135'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-2-bromoethane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-2-bromoethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-2-bromoethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-2-bromoethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-2-bromoethane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-2-bromoethane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-chloro-2-bromoethane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-chloro-2-bromoethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-dibromo-1,1-dichloroethane',
    'C<sub>2</sub>H<sub>2</sub>Br<sub>2</sub>Cl<sub>2</sub>',
    '',
    '75-81-0',
    'FIYBYNHDEOSJPL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dibromo-1,1-dichloroethane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-bromo-3-chloropropane',
    'C<sub>3</sub>H<sub>6</sub>BrCl',
    '',
    '109-70-6',
    'MFESCIUQSIBMSM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-3-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-dibromo-3-chloropropane',
    'C<sub>3</sub>H<sub>5</sub>Br<sub>2</sub>Cl',
    '',
    '96-12-8',
    'WBEJYOJJBDISQU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;2</sup>',
    '7100',
    'M',
    (SELECT id from species WHERE iupac='1,2-dibromo-3-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;1</sup>',
    '10000',
    'M',
    (SELECT id from species WHERE iupac='1,2-dibromo-3-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='2904'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dibromo-3-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2-dibromo-3-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dibromo-3-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dibromo-3-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dibromo-3-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dibromo-3-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-dibromo-3-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-dibromo-3-chloropropane'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,4,5-pentabromo-6-chlorocyclohexane',
    'C<sub>6</sub>H<sub>6</sub>Br<sub>5</sub>Cl',
    '',
    '87-84-3',
    'UZOSVZSBPTTWIG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4,5-pentabromo-6-chlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4,5-pentabromo-6-chlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4,5-pentabromo-6-chlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4,5-pentabromo-6-chlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3,4-tetrabromo-5,6-dichlorocyclohexane',
    'C<sub>6</sub>H<sub>6</sub>Br<sub>4</sub>Cl<sub>2</sub>',
    '',
    '',
    'GABFTOZBVQIDBB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrabromo-5,6-dichlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrabromo-5,6-dichlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrabromo-5,6-dichlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3,4-tetrabromo-5,6-dichlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,3-tribromo-4,5,6-trichlorocyclohexane',
    'C<sub>6</sub>H<sub>6</sub>Br<sub>3</sub>Cl<sub>3</sub>',
    '',
    '',
    'ZDEQCIGFZLZXBZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-tribromo-4,5,6-trichlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-tribromo-4,5,6-trichlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-tribromo-4,5,6-trichlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,3-tribromo-4,5,6-trichlorocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-bromo-4-chlorobenzene',
    'C<sub>6</sub>H<sub>4</sub>BrCl',
    '',
    '106-39-8',
    'NHDODQWIKUYWMW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-bromo-4-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-bromo-4-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-4-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-4-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-4-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-4-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-4-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-4-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-4-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-4-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4-tribromo-3,5,6-trichlorobenzene',
    'C<sub>6</sub>Br<sub>3</sub>Cl<sub>3</sub>',
    '',
    '13075-01-9',
    'XAIKFWSNTFEXDC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-tribromo-3,5,6-trichlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-(bromomethyl)-2-chlorobenzene',
    'C<sub>7</sub>H<sub>6</sub>BrCl',
    '',
    '611-17-6',
    'PURSZYWBIQIANP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-(bromomethyl)-2-chlorobenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-bromo-4-chloro-1-methoxybenzene',
    'C<sub>7</sub>H<sub>6</sub>BrClO',
    '2-bromo-4-chloroanisole',
    '60633-25-2',
    'YJEMGEBDXDPBSP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-bromo-4-chloro-1-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1524'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1524'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-bromo-6-chloro-1-methoxybenzene',
    'C<sub>7</sub>H<sub>6</sub>BrClO',
    '2-bromo-6-chloroanisole',
    '174913-10-1',
    'NWOYYECMNBWCNK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-bromo-6-chloro-1-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1524'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1524'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-bromo-2-chloro-1-methoxybenzene',
    'C<sub>7</sub>H<sub>6</sub>BrClO',
    '4-bromo-2-chloroanisole',
    '50638-47-6',
    'FPIQNBOUYZLESW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='4-bromo-2-chloro-1-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1524'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1524'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-bromo-3,5-dichloro-1-methoxybenzene',
    'C<sub>7</sub>H<sub>5</sub>BrCl<sub>2</sub>O',
    '2-bromo-3,5-dichloroanisole',
    '73931-43-8',
    'LCHJNNXHVDDVAT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-bromo-3,5-dichloro-1-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1524'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1524'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-bromo-4,6-dichloro-1-methoxybenzene',
    'C<sub>7</sub>H<sub>5</sub>BrCl<sub>2</sub>O',
    '2-bromo-4,6-dichloroanisole',
    '60633-26-3',
    'OEYKUHBCPJRXGZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;3</sup>',
    '3100',
    'M',
    (SELECT id from species WHERE iupac='2-bromo-4,6-dichloro-1-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3118'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-bromo-4,6-dichloro-1-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1524'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1524'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-bromo-2,3-dichloro-1-methoxybenzene',
    'C<sub>7</sub>H<sub>5</sub>BrCl<sub>2</sub>O',
    '4-bromo-2,3-dichloroanisole',
    '109803-52-3',
    'BTRCDLZQISXWHZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='4-bromo-2,3-dichloro-1-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1524'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1524'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-bromo-2,6-dichloro-1-methoxybenzene',
    'C<sub>7</sub>H<sub>5</sub>BrCl<sub>2</sub>O',
    '4-bromo-2,6-dichloroanisole',
    '19240-91-6',
    'OAYSFAKCFYRCRU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '4900',
    'M',
    (SELECT id from species WHERE iupac='4-bromo-2,6-dichloro-1-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3118'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='4-bromo-2,6-dichloro-1-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1524'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1524'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-bromo-3,5-dichloro-1-methoxybenzene',
    'C<sub>7</sub>H<sub>5</sub>BrCl<sub>2</sub>O',
    '4-bromo-3,5-dichloroanisole',
    '174913-20-3',
    'SVEZPKVUIXAEOX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='4-bromo-3,5-dichloro-1-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1524'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1524'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-bromo-2,4-dichloro-1-methoxybenzene',
    'C<sub>7</sub>H<sub>5</sub>BrCl<sub>2</sub>O',
    '3-bromo-2,4-dichloroanisole',
    '174913-16-7',
    'OXINPOQPENRUHL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-bromo-2,4-dichloro-1-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_O4'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-bromo-2,6-dichloro-1-methoxybenzene',
    'C<sub>7</sub>H<sub>5</sub>BrCl<sub>2</sub>O',
    '3-bromo-2,6-dichloroanisole',
    '174913-18-9',
    'ANLVZYYGYBXMIX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '2700',
    'M',
    (SELECT id from species WHERE iupac='3-bromo-2,6-dichloro-1-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3118'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3118'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-bromo-2,4-dichloro-1-methoxybenzene',
    'C<sub>7</sub>H<sub>5</sub>BrCl<sub>2</sub>O',
    '5-bromo-2,4-dichloroanisole',
    '174913-22-5',
    'SJIIFORJBWPNPM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='5-bromo-2,4-dichloro-1-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1524'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1524'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '6-bromo-2,3-dichloro-1-methoxybenzene',
    'C<sub>7</sub>H<sub>5</sub>BrCl<sub>2</sub>O',
    '6-bromo-2,3-dichloroanisole',
    '174913-23-6',
    'PNLDDSLZYVNPQW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='6-bromo-2,3-dichloro-1-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1524'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1524'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '6-bromo-2,5-dichloro-1-methoxybenzene',
    'C<sub>7</sub>H<sub>5</sub>BrCl<sub>2</sub>O',
    '6-bromo-2,5-dichloroanisole',
    '174913-14-5',
    'BVSOVPUWHJWGEP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;3</sup>',
    '3000',
    'M',
    (SELECT id from species WHERE iupac='6-bromo-2,5-dichloro-1-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3118'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-bromo-3,4,5-trichloro-1-methoxybenzene',
    'C<sub>7</sub>H<sub>4</sub>BrCl<sub>3</sub>O',
    '2-bromo-3,4,5-trichloroanisole',
    '',
    'JIVCPRHFBFVZQL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2-bromo-3,4,5-trichloro-1-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1524'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1524'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-bromo-2,4,6-trichloro-1-methoxybenzene',
    'C<sub>7</sub>H<sub>4</sub>BrCl<sub>3</sub>O',
    '3-bromo-2,4,6-trichloroanisole',
    '174913-28-1',
    'OIHHRLYOSUNYTC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3-bromo-2,4,6-trichloro-1-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1524'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1524'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-bromo-2,5,6-trichloro-1-methoxybenzene',
    'C<sub>7</sub>H<sub>4</sub>BrCl<sub>3</sub>O',
    '3-bromo-2,5,6-trichloroanisole',
    '78647-93-5',
    'ZUXVGCIQOSXRJN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3-bromo-2,5,6-trichloro-1-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1524'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1524'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-bromo-2,3,6-trichloro-1-methoxybenzene',
    'C<sub>7</sub>H<sub>4</sub>BrCl<sub>3</sub>O',
    '4-bromo-2,3,6-trichloroanisole',
    '78647-87-7',
    'VZRSUQWPXPUWCS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='4-bromo-2,3,6-trichloro-1-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1524'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1524'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '6-bromo-2,3,4-trichloro-1-methoxybenzene',
    'C<sub>7</sub>H<sub>4</sub>BrCl<sub>3</sub>O',
    '6-bromo-2,3,4-trichloroanisole',
    '',
    'GVCDCZPXMGMNTR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='6-bromo-2,3,4-trichloro-1-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1524'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1524'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-bromo-2,3,5,6-tetrachloro-1-methoxybenzene',
    'C<sub>7</sub>H<sub>3</sub>BrCl<sub>4</sub>O',
    '4-bromo-2,3,5,6-tetrachloroanisole',
    '174913-33-8',
    'YSVAURKXNCNUNS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='4-bromo-2,3,5,6-tetrachloro-1-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1524'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1524'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dibromo-3-chloro-1-methoxybenzene',
    'C<sub>7</sub>H<sub>5</sub>Br<sub>2</sub>ClO',
    '2,4-dibromo-3-chloroanisole',
    '',
    'YXYRJAVLYYNRCE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,4-dibromo-3-chloro-1-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_O4'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dibromo-5-chloro-1-methoxybenzene',
    'C<sub>7</sub>H<sub>5</sub>Br<sub>2</sub>ClO',
    '2,4-dibromo-5-chloroanisole',
    '174913-38-3',
    'OTZRCEAVEJYZQS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,4-dibromo-5-chloro-1-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_O4'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6-dibromo-3-chloro-1-methoxybenzene',
    'C<sub>7</sub>H<sub>5</sub>Br<sub>2</sub>ClO',
    '2,6-dibromo-3-chloroanisole',
    '',
    'AHBGIHFKTBTQJP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;3</sup>',
    '770',
    'M',
    (SELECT id from species WHERE iupac='2,6-dibromo-3-chloro-1-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3118'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3118'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6-dibromo-4-chloro-1-methoxybenzene',
    'C<sub>7</sub>H<sub>5</sub>Br<sub>2</sub>ClO',
    '2,6-dibromo-4-chloroanisole',
    '174913-44-1',
    'WHRDPXDGAMJNGH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '6700',
    'M',
    (SELECT id from species WHERE iupac='2,6-dibromo-4-chloro-1-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='3118'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,6-dibromo-4-chloro-1-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1524'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1524'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dibromo-3,5-dichloro-1-methoxybenzene',
    'C<sub>7</sub>H<sub>4</sub>Br<sub>2</sub>Cl<sub>2</sub>O',
    '2,4-dibromo-3,5-dichloroanisole',
    '174913-52-1',
    'YZMXEWDTXSTFIJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,4-dibromo-3,5-dichloro-1-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1524'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1524'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dibromo-5,6-dichloro-1-methoxybenzene',
    'C<sub>7</sub>H<sub>4</sub>Br<sub>2</sub>Cl<sub>2</sub>O',
    '2,4-dibromo-5,6-dichloroanisole',
    '',
    'MUUDTVDSRYEMBU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,4-dibromo-5,6-dichloro-1-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1524'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1524'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dibromo-5,6-dichloro-1-methoxybenzene',
    'C<sub>7</sub>H<sub>4</sub>Br<sub>2</sub>Cl<sub>2</sub>O',
    '2,3-dibromo-5,6-dichloroanisole',
    '',
    'WDRCOFFEZVLCLX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3-dibromo-5,6-dichloro-1-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1524'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1524'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,6-dibromo-3,4,5-trichloro-1-methoxybenzene',
    'C<sub>7</sub>H<sub>3</sub>Br<sub>2</sub>Cl<sub>3</sub>O',
    '2,6-dibromo-3,4,5-trichloroanisole',
    '',
    'RFUGYJHXLQAXOX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,6-dibromo-3,4,5-trichloro-1-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1524'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1524'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,6-tribromo-3-chloro-1-methoxybenzene',
    'C<sub>7</sub>H<sub>4</sub>Br<sub>3</sub>ClO',
    '2,4,6-tribromo-3-chloroanisole',
    '174913-78-1',
    'FWKUBDOTUFVPBX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,4,6-tribromo-3-chloro-1-methoxybenzene'),
    (SELECT id from literature WHERE bibtexkey='1524'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1524'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dibromo-7,8-dichlorodibenzo-p-dioxin',
    'C<sub>12</sub>H<sub>4</sub>Br<sub>2</sub>Cl<sub>2</sub>O<sub>2</sub>',
    '',
    '50585-40-5',
    'SBSJXPIUKNBZND-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,3-dibromo-7,8-dichlorodibenzo-p-dioxin'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2'',4'',5'',7''-tetrabromo-3,4,5,6-tetrachlorofluorescein',
    'C<sub>20</sub>H<sub>4</sub>Br<sub>4</sub>Cl<sub>4</sub>O<sub>5</sub>',
    '',
    '13473-26-2',
    'ZYIBVBKZZZDFOY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>13</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2'',4'',5'',7''-tetrabromo-3,4,5,6-tetrachlorofluorescein'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2'',4'',5'',7''-tetrabromo-3,4,5,6-tetrachlorofluorescein'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2'',4'',5'',7''-tetrabromo-3,4,5,6-tetrachlorofluorescein'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2'',4'',5'',7''-tetrabromo-3,4,5,6-tetrachlorofluorescein'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bromochloroacetonitrile',
    'C<sub>2</sub>HBrClN',
    '',
    '83463-62-1',
    'BMWPPNAUMLRKML-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromochloroacetonitrile'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N,N''-dimethyl-3,3'',4-tribromo-4,5,5''-trichloro-2,2''-bipyrrole',
    'C<sub>10</sub>H<sub>6</sub>Br<sub>3</sub>Cl<sub>3</sub>N<sub>2</sub>',
    'DBP-Br3Cl3a',
    '400766-93-0',
    'JSQYFPHYSOZLPT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='N,N''-dimethyl-3,3'',4-tribromo-4,5,5''-trichloro-2,2''-bipyrrole'),
    (SELECT id from literature WHERE bibtexkey='2469'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N''-dimethyl-3,3'',4-tribromo-4,5,5''-trichloro-2,2''-bipyrrole'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N,N''-dimethyl- 3,4,4''-tribromo-3'',5,5''-trichloro-2,2''-bipyrrole',
    'C<sub>10</sub>H<sub>6</sub>Br<sub>3</sub>Cl<sub>3</sub>N<sub>2</sub>',
    'DBP-Br3Cl3b',
    '666856-68-4',
    'GUWAXPTVCYBOMV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='N,N''-dimethyl- 3,4,4''-tribromo-3'',5,5''-trichloro-2,2''-bipyrrole'),
    (SELECT id from literature WHERE bibtexkey='2469'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N''-dimethyl- 3,4,4''-tribromo-3'',5,5''-trichloro-2,2''-bipyrrole'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N,N''-dimethyl-3,3'',4,4''-tetrabromo-5,5''-dichloro-2,2''-bipyrrole',
    'C<sub>10</sub>H<sub>6</sub>Br<sub>4</sub>Cl<sub>2</sub>N<sub>2</sub>',
    'DBP-Br4Cl2',
    '253798-64-0',
    'FQGSQKFVAAJWFY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='N,N''-dimethyl-3,3'',4,4''-tetrabromo-5,5''-dichloro-2,2''-bipyrrole'),
    (SELECT id from literature WHERE bibtexkey='2469'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N''-dimethyl-3,3'',4,4''-tetrabromo-5,5''-dichloro-2,2''-bipyrrole'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N,N''-dimethyl-3,3'',4,4'',5-pentabromo-5''-chloro-2,2''-bipyrrole',
    'C<sub>10</sub>H<sub>6</sub>Br<sub>5</sub>ClN<sub>2</sub>',
    'DBP-Br5Cl',
    '400767-00-2',
    'LIYSVIAQQQEQBT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='N,N''-dimethyl-3,3'',4,4'',5-pentabromo-5''-chloro-2,2''-bipyrrole'),
    (SELECT id from literature WHERE bibtexkey='2469'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N''-dimethyl-3,3'',4,4'',5-pentabromo-5''-chloro-2,2''-bipyrrole'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-bromo-3-chloro-5,5-dimethylhydantoin',
    'C<sub>5</sub>H<sub>6</sub>BrClN<sub>2</sub>O<sub>2</sub>',
    '',
    '16079-88-2',
    'PIEXCQIOSMOEOU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-3-chloro-5,5-dimethylhydantoin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-(4-bromo-3-chlorophenyl)-1-methoxy-1-methylurea',
    'C<sub>9</sub>H<sub>10</sub>BrClN<sub>2</sub>O<sub>2</sub>',
    'chlorbromuron',
    '13360-45-7',
    'NLYNUTMZTCLNOO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-(4-bromo-3-chlorophenyl)-1-methoxy-1-methylurea'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-(4-bromo-3-chlorophenyl)-1-methoxy-1-methylurea'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-(4-bromo-3-chlorophenyl)-1-methoxy-1-methylurea'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-(4-bromo-2,6-dichloro-3-methylphenyl)acetamide',
    'C<sub>9</sub>H<sub>8</sub>BrCl<sub>2</sub>NO',
    '',
    '68399-95-1',
    'MRPNWLPYJSSISQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-(4-bromo-2,6-dichloro-3-methylphenyl)acetamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-(4-bromo-2,6-dichloro-3-methylphenyl)acetamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-(4-bromo-2,6-dichloro-3-methylphenyl)acetamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-(4-bromo-2,6-dichloro-3-methylphenyl)acetamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'halacrinate',
    'C<sub>12</sub>H<sub>7</sub>NO<sub>2</sub>BrCl',
    '',
    '34462-96-9',
    'YDNLKBDXQCHOTH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='halacrinate'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bromuconazole',
    'C<sub>13</sub>H<sub>12</sub>BrCl<sub>2</sub>N<sub>3</sub>O',
    '',
    '116255-48-2',
    'HJJVPARKXDDIQD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bromuconazole'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bromuconazole'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromuconazole'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='bromuconazole'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(&#177;)-(2R<sup>*</sup>,4S<sup>*</sup>)-bromuconazole',
    'C<sub>13</sub>H<sub>12</sub>BrCl<sub>2</sub>N<sub>3</sub>O',
    '',
    '114544-80-8',
    '',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(&#177;)-(2R<sup>*</sup>,4S<sup>*</sup>)-bromuconazole'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(&#177;)-(2R<sup>*</sup>,4R<sup>*</sup>)-bromuconazole',
    'C<sub>13</sub>H<sub>12</sub>BrCl<sub>2</sub>N<sub>3</sub>O',
    '',
    '114544-81-9',
    '',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(&#177;)-(2R<sup>*</sup>,4R<sup>*</sup>)-bromuconazole'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5,7-dibromo-2-(5-bromo-7-chloro-1,3-dihydro-3-oxo-2H-indol-2-ylidene)-1,2-dihydro-3H-indol-3-one',
    'C<sub>16</sub>H<sub>6</sub>Br<sub>3</sub>ClN<sub>2</sub>O<sub>2</sub>',
    '',
    '85702-64-3',
    'UOWUGDPSFZLTMZ-BUHFOSPRSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5,7-dibromo-2-(5-bromo-7-chloro-1,3-dihydro-3-oxo-2H-indol-2-ylidene)-1,2-dihydro-3H-indol-3-one'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>15</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5,7-dibromo-2-(5-bromo-7-chloro-1,3-dihydro-3-oxo-2H-indol-2-ylidene)-1,2-dihydro-3H-indol-3-one'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5,7-dibromo-2-(5-bromo-7-chloro-1,3-dihydro-3-oxo-2H-indol-2-ylidene)-1,2-dihydro-3H-indol-3-one'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5,7-dibromo-2-(5-bromo-7-chloro-1,3-dihydro-3-oxo-2H-indol-2-ylidene)-1,2-dihydro-3H-indol-3-one'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chlorantraniliprole',
    'C<sub>18</sub>H<sub>14</sub>BrCl<sub>2</sub>N<sub>5</sub>O<sub>2</sub>',
    '',
    '500008-45-7',
    'IZCBNTYXTMZSDP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>15</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorantraniliprole'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>8</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chlorantraniliprole'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cyantraniliprole',
    'C<sub>19</sub>H<sub>14</sub>BrClN<sub>6</sub>O<sub>2</sub>',
    '',
    '736994-63-1',
    'DVBUIBGJRQBEDP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>12</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cyantraniliprole'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tribromofluoromethane',
    'CBr<sub>3</sub>F',
    '',
    '353-54-8',
    'IHZAEIHJPNTART-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tribromofluoromethane'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bromochlorodifluoromethane',
    'CBrClF<sub>2</sub>',
    '',
    '353-59-3',
    'MEXUFEQDCXZEON-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='bromochlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at275K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromochlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromochlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromochlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromochlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='bromochlorodifluoromethane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at275K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-bromo-1-chloro-2,2,2-trifluoroethane',
    'C<sub>2</sub>HBrClF<sub>3</sub>',
    'halothane',
    '151-67-7',
    'BCQZXOMGPXTTIC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;4</sup>',
    '4700',
    'L',
    (SELECT id from species WHERE iupac='1-bromo-1-chloro-2,2,2-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-bromo-1-chloro-2,2,2-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2441'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;4</sup>',
    '4200',
    'L',
    (SELECT id from species WHERE iupac='1-bromo-1-chloro-2,2,2-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3696'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-bromo-1-chloro-2,2,2-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2924'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-bromo-1-chloro-2,2,2-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2444'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;4</sup>',
    '5000',
    'M',
    (SELECT id from species WHERE iupac='1-bromo-1-chloro-2,2,2-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2445'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-bromo-1-chloro-2,2,2-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2467'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-bromo-1-chloro-2,2,2-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3710'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-bromo-1-chloro-2,2,2-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at297K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-1-chloro-2,2,2-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-1-chloro-2,2,2-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-1-chloro-2,2,2-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-1-chloro-2,2,2-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-1-chloro-2,2,2-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4100',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-1-chloro-2,2,2-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-bromo-1-chloro-2,2,2-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-bromo-1-chloro-2,2,2-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-bromo-1-chloro-2,2,2-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-3072'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5000',
    '?',
    (SELECT id from species WHERE iupac='1-bromo-1-chloro-2,2,2-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-bromo-1-chloro-2,2,2-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at297K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-bromo-1-chloro-2,2,2-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-bromo-1-chloro-2,2,2-trifluoroethane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tralopyril',
    'C<sub>12</sub>H<sub>5</sub>BrClF<sub>3</sub>N<sub>2</sub>',
    '',
    '122454-29-9',
    'XNFIRYXKTXAHAC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tralopyril'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chlorfenapyr',
    'C<sub>15</sub>H<sub>11</sub>BrClF<sub>3</sub>N<sub>2</sub>O',
    '',
    '122453-73-0',
    'CWFOCCVIPCEQCK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorfenapyr'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fluazolate',
    'C<sub>15</sub>H<sub>12</sub>N<sub>2</sub>O<sub>2</sub>BrClF<sub>4</sub>',
    '',
    '174514-07-9',
    'FKLQIONHGSFYJY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Bromine, chlorine and fluorine (C, H, N, O, F, Cl, Br)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fluazolate'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO categories (catname) VALUES (
    'Organic species with iodine (I)');
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Iodocarbons (C, H, O, Cl, I)',
    (SELECT id from categories WHERE catname='Organic species with iodine (I)'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'iodomethane',
    'CH<sub>3</sub>I',
    'methyl iodide',
    '74-88-4',
    'INQOMBQAUSQDDS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Iodocarbons (C, H, O, Cl, I)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '3200',
    'L',
    (SELECT id from species WHERE iupac='iodomethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '3900',
    'L',
    (SELECT id from species WHERE iupac='iodomethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '3600',
    'L',
    (SELECT id from species WHERE iupac='iodomethane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '3900',
    'L',
    (SELECT id from species WHERE iupac='iodomethane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '3100',
    'L',
    (SELECT id from species WHERE iupac='iodomethane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '3600',
    'L',
    (SELECT id from species WHERE iupac='iodomethane'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '3600',
    'L',
    (SELECT id from species WHERE iupac='iodomethane'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '3600',
    'L',
    (SELECT id from species WHERE iupac='iodomethane'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '3200',
    'M',
    (SELECT id from species WHERE iupac='iodomethane'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '3900',
    'M',
    (SELECT id from species WHERE iupac='iodomethane'),
    (SELECT id from literature WHERE bibtexkey='3564'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='iodomethane'),
    (SELECT id from literature WHERE bibtexkey='892'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at294K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '4100',
    'M',
    (SELECT id from species WHERE iupac='iodomethane'),
    (SELECT id from literature WHERE bibtexkey='583'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0583-74-88-4-ABC',
    '583', 'The data from Moore et&nbsp;al. (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;229.06923 +13418.39257/T +31.15669&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0583-74-88-4-ABC'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '3700',
    'M',
    (SELECT id from species WHERE iupac='iodomethane'),
    (SELECT id from literature WHERE bibtexkey='1342'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '3800',
    'M',
    (SELECT id from species WHERE iupac='iodomethane'),
    (SELECT id from literature WHERE bibtexkey='608'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='608'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '3100',
    'M',
    (SELECT id from species WHERE iupac='iodomethane'),
    (SELECT id from literature WHERE bibtexkey='2952'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '3000',
    'M',
    (SELECT id from species WHERE iupac='iodomethane'),
    (SELECT id from literature WHERE bibtexkey='1340'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '3000',
    'M',
    (SELECT id from species WHERE iupac='iodomethane'),
    (SELECT id from literature WHERE bibtexkey='2222'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref2222-74-88-4-ABC',
    '2222', 'The data from Glew and Moelwyn-Hughes (1953) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;384.31677 +19391.25580/T +54.93602&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref2222-74-88-4-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '3700',
    'M',
    (SELECT id from species WHERE iupac='iodomethane'),
    (SELECT id from literature WHERE bibtexkey='863'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='iodomethane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '3600',
    'V',
    (SELECT id from species WHERE iupac='iodomethane'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='iodomethane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='iodomethane'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='iodomethane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='iodomethane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='iodomethane'),
    (SELECT id from literature WHERE bibtexkey='563'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='iodomethane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='iodomethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='iodomethane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='iodomethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='iodomethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='iodomethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='iodomethane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='iodomethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='iodomethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3800',
    'Q',
    (SELECT id from species WHERE iupac='iodomethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='iodomethane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='iodomethane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='iodomethane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='iodomethane'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='iodomethane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='iodomethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='iodomethane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3700',
    '?',
    (SELECT id from species WHERE iupac='iodomethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='iodomethane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='iodomethane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='iodomethane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diiodomethane',
    'CH<sub>2</sub>I<sub>2</sub>',
    '',
    '75-11-6',
    'NZZFYRREKKOMAT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Iodocarbons (C, H, O, Cl, I)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '5300',
    'L',
    (SELECT id from species WHERE iupac='diiodomethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '5300',
    'L',
    (SELECT id from species WHERE iupac='diiodomethane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '4700',
    'M',
    (SELECT id from species WHERE iupac='diiodomethane'),
    (SELECT id from literature WHERE bibtexkey='583'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0583-75-11-6-ABC',
    '583', 'The data from Moore et&nbsp;al. (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;247.93525 +14910.30572/T +34.08071&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0583-75-11-6-ABC'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diiodomethane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diiodomethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diiodomethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diiodomethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diiodomethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diiodomethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diiodomethane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diiodomethane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='diiodomethane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='diiodomethane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='diiodomethane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'triiodomethane',
    'CHI<sub>3</sub>',
    'iodoform',
    '75-47-8',
    'OKJPEAGHQZHRQV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Iodocarbons (C, H, O, Cl, I)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='triiodomethane'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='triiodomethane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triiodomethane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triiodomethane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triiodomethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='triiodomethane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'iodoethane',
    'C<sub>2</sub>H<sub>5</sub>I',
    '',
    '75-03-6',
    'HVTICUPFWKNHNG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Iodocarbons (C, H, O, Cl, I)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '4800',
    'L',
    (SELECT id from species WHERE iupac='iodoethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '4800',
    'L',
    (SELECT id from species WHERE iupac='iodoethane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '3600',
    'L',
    (SELECT id from species WHERE iupac='iodoethane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '4200',
    'L',
    (SELECT id from species WHERE iupac='iodoethane'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '1943-75-03-6',
    '1943', 'The regression given by Fogg and Sangster (2003) does not produce the data in their table. Thus the regression was recalculated.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1943-75-03-6'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '4800',
    'M',
    (SELECT id from species WHERE iupac='iodoethane'),
    (SELECT id from literature WHERE bibtexkey='3564'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='iodoethane'),
    (SELECT id from literature WHERE bibtexkey='2493'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '4000',
    'M',
    (SELECT id from species WHERE iupac='iodoethane'),
    (SELECT id from literature WHERE bibtexkey='863'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='iodoethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='iodoethane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='iodoethane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='iodoethane'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='iodoethane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='iodoethane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='iodoethane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='iodoethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='iodoethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='iodoethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='iodoethane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='iodoethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4200',
    'Q',
    (SELECT id from species WHERE iupac='iodoethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='iodoethane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='iodoethane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='iodoethane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='iodoethane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='iodoethane'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='iodoethane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4100',
    '?',
    (SELECT id from species WHERE iupac='iodoethane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='iodoethane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='iodoethane'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='iodoethane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='iodoethane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(E)-1,2-diiodoethene',
    'C<sub>2</sub>H<sub>2</sub>I<sub>2</sub>',
    '',
    '590-27-2',
    'CVOGMKGEVNGRSK-OWOJBTEDSA-N',
    (SELECT id from subcategories WHERE subcatname='Iodocarbons (C, H, O, Cl, I)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(E)-1,2-diiodoethene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(E)-1,2-diiodoethene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-iodopropane',
    'C<sub>3</sub>H<sub>7</sub>I',
    'propyl iodide',
    '107-08-4',
    'PVWOIHVRPOBWPI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Iodocarbons (C, H, O, Cl, I)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '4500',
    'L',
    (SELECT id from species WHERE iupac='1-iodopropane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-iodopropane'),
    (SELECT id from literature WHERE bibtexkey='2493'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '4600',
    'M',
    (SELECT id from species WHERE iupac='1-iodopropane'),
    (SELECT id from literature WHERE bibtexkey='863'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-iodopropane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-iodopropane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-iodopropane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-iodopropane'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-iodopropane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-iodopropane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at297K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-iodopropane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-iodopropane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-iodopropane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-iodopropane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-iodopropane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-iodopropane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-iodopropane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-iodopropane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4500',
    'Q',
    (SELECT id from species WHERE iupac='1-iodopropane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-iodopropane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-iodopropane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-iodopropane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-iodopropane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-iodopropane'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-iodopropane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4500',
    '?',
    (SELECT id from species WHERE iupac='1-iodopropane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-iodopropane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at297K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-iodopropane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at297K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-iodopropane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-iodopropane',
    'C<sub>3</sub>H<sub>7</sub>I',
    'isopropyl iodide',
    '75-30-9',
    'FMKOJHQHASLBPH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Iodocarbons (C, H, O, Cl, I)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;4</sup>',
    '4700',
    'L',
    (SELECT id from species WHERE iupac='2-iodopropane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;4</sup>',
    '4500',
    'M',
    (SELECT id from species WHERE iupac='2-iodopropane'),
    (SELECT id from literature WHERE bibtexkey='863'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-iodopropane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-iodopropane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-iodopropane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-iodopropane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-iodopropane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-iodopropane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-iodopropane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-iodopropane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-iodopropane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-iodopropane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-iodopropane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4500',
    'Q',
    (SELECT id from species WHERE iupac='2-iodopropane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-iodopropane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-iodopropane'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-iodopropane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-iodopropane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-iodopropane'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-iodopropane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4700',
    '?',
    (SELECT id from species WHERE iupac='2-iodopropane'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-iodopropane'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-iodopropane'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-iodobutane',
    'C<sub>4</sub>H<sub>9</sub>I',
    '',
    '542-69-8',
    'KMGBZBJJOKUPIA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Iodocarbons (C, H, O, Cl, I)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-iodobutane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-iodobutane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-iodobutane'),
    (SELECT id from literature WHERE bibtexkey='2612'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-iodobutane'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-iodobutane'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-iodobutane'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-iodobutane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-iodobutane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-iodobutane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-iodobutane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-iodobutane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-iodobutane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-iodobutane'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-iodobutane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-iodobutane'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-iodobutane'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-iodobutane'),
    (SELECT id from literature WHERE bibtexkey='2482'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-iodobutane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-iodobutane',
    'C<sub>4</sub>H<sub>9</sub>I',
    '',
    '513-48-4',
    'IQRUSQUYPCHEKN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Iodocarbons (C, H, O, Cl, I)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-iodobutane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-iodobutane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-iodobutane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-iodobutane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-iodobutane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-iodobutane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-iodopentane',
    'C<sub>5</sub>H<sub>11</sub>I',
    '',
    '628-17-1',
    'BLXSFCHWMBESKV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Iodocarbons (C, H, O, Cl, I)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-iodopentane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-iodopentane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-iodopentane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-iodopentane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-iodopentane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-iodopentane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-iodopentane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-iodopentane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-iodopentane'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-iodopentane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-iodopentane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-iodohexane',
    'C<sub>6</sub>H<sub>13</sub>I',
    '',
    '638-45-9',
    'ANOOTOPTCJRUPK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Iodocarbons (C, H, O, Cl, I)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-iodohexane'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-iodohexane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-iodohexane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-iodohexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-iodohexane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-iodohexane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-iodohexane'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-iodohexane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-iodohexane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-iodoheptane',
    'C<sub>7</sub>H<sub>15</sub>I',
    '',
    '4282-40-0',
    'LMHCYRULPLGEEZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Iodocarbons (C, H, O, Cl, I)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-iodoheptane'),
    (SELECT id from literature WHERE bibtexkey='1497'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-iodoheptane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-iodoheptane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-iodoheptane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-iodoheptane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-iodoheptane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-iodoheptane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-iodoheptane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-iodoheptane'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-iodoheptane'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-iodoheptane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-iodoheptane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'iodocyclohexane',
    'C<sub>6</sub>H<sub>11</sub>I',
    '',
    '626-62-0',
    'FUCOMWZKWIEKRK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Iodocarbons (C, H, O, Cl, I)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='iodocyclohexane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-iodo-1-propene',
    'C<sub>3</sub>H<sub>5</sub>I',
    '',
    '556-56-9',
    'HFEHLDPGIKPNKL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Iodocarbons (C, H, O, Cl, I)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-iodo-1-propene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-iodocyclohexene',
    'C<sub>6</sub>H<sub>9</sub>I',
    '',
    '17497-53-9',
    'CAROGICRCNKEOD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Iodocarbons (C, H, O, Cl, I)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-iodocyclohexene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'iodobenzene',
    'C<sub>6</sub>H<sub>5</sub>I',
    '',
    '591-50-4',
    'SNHMUERNLJLMHN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Iodocarbons (C, H, O, Cl, I)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='iodobenzene'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='iodobenzene'),
    (SELECT id from literature WHERE bibtexkey='2457'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='iodobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='iodobenzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='iodobenzene'),
    (SELECT id from literature WHERE bibtexkey='2165'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='iodobenzene'),
    (SELECT id from literature WHERE bibtexkey='635'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='iodobenzene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='iodobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='iodobenzene'),
    (SELECT id from literature WHERE bibtexkey='3689'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='iodobenzene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='iodobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-T'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='iodobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='iodobenzene'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='iodobenzene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='iodobenzene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='iodobenzene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='iodobenzene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='iodobenzene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='iodobenzene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='iodobenzene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='iodobenzene'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='iodobenzene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='iodobenzene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='iodobenzene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='iodobenzene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3518-591-50-4',
    '', 'The value listed as A for iodobenzene is probably not A but the Henry''s law volatility constant H<sub>v</sub><sup>px</sup> at 298&nbsp;K. For the value of B, a minus sign is probably missing.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3518-591-50-4'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'iodoacetic acid',
    'C<sub>2</sub>H<sub>3</sub>IO<sub>2</sub>',
    '',
    '64-69-7',
    'JDNTWHVOXJZDSN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Iodocarbons (C, H, O, Cl, I)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='iodoacetic acid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-iodophenol',
    'C<sub>6</sub>H<sub>5</sub>IO',
    '',
    '533-58-4',
    'KQDJTBPASNJQFQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Iodocarbons (C, H, O, Cl, I)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='2-iodophenol'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-iodophenol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-iodophenol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-iodophenol'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-iodophenol'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-iodophenol',
    'C<sub>6</sub>H<sub>5</sub>IO',
    '',
    '626-02-8',
    'FXTKWBZFNQHAAO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Iodocarbons (C, H, O, Cl, I)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-iodophenol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-iodophenol',
    'C<sub>6</sub>H<sub>5</sub>IO',
    '',
    '540-38-5',
    'VSMDINRNYYEDRN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Iodocarbons (C, H, O, Cl, I)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-iodophenol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'erythrosine',
    'C<sub>20</sub>H<sub>8</sub>I<sub>4</sub>O<sub>5</sub>',
    '',
    '16423-68-0',
    'OALHHIHQOFIMEF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Iodocarbons (C, H, O, Cl, I)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>13</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='erythrosine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='erythrosine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='erythrosine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='erythrosine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-hydroxy-3,5-diiodo-benzonitrile',
    'C<sub>7</sub>H<sub>3</sub>I<sub>2</sub>NO',
    'ioxynil',
    '1689-83-4',
    'NRXQIUSYPAHGNM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Iodocarbons (C, H, O, Cl, I)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-hydroxy-3,5-diiodo-benzonitrile'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-hydroxy-3,5-diiodo-benzonitrile'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-iodo-2-propynyl butylcarbamate',
    'C<sub>8</sub>H<sub>12</sub>INO<sub>2</sub>',
    '',
    '55406-53-6',
    'WYVVKGNFXHOCQV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Iodocarbons (C, H, O, Cl, I)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-iodo-2-propynyl butylcarbamate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diatrizoic acid',
    'C<sub>11</sub>H<sub>9</sub>I<sub>3</sub>N<sub>2</sub>O<sub>4</sub>',
    '',
    '117-96-4',
    'YVPYQUNUQOZFHG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Iodocarbons (C, H, O, Cl, I)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>12</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diatrizoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diatrizoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>17</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diatrizoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>16</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diatrizoic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'iothalamic acid',
    'C<sub>11</sub>H<sub>9</sub>I<sub>3</sub>N<sub>2</sub>O<sub>4</sub>',
    '',
    '2276-90-6',
    'UXIGWFXRQKWHHA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Iodocarbons (C, H, O, Cl, I)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>12</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='iothalamic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='iothalamic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>16</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='iothalamic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>16</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='iothalamic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benodanil',
    'C<sub>13</sub>H<sub>10</sub>INO',
    '',
    '15310-01-7',
    'LJOZMWRYMKECFF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Iodocarbons (C, H, O, Cl, I)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benodanil'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 2.3&times;10<sup>10</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='benodanil'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'proquinazid',
    'C<sub>14</sub>H<sub>17</sub>IN<sub>2</sub>O<sub>2</sub>',
    '',
    '189278-12-4',
    'FLVBXVXXXMLMOX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Iodocarbons (C, H, O, Cl, I)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='proquinazid'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'iopamidol',
    'C<sub>17</sub>H<sub>22</sub>I<sub>3</sub>N<sub>3</sub>O<sub>8</sub>',
    '',
    '60166-93-0',
    'XQZXYNRDCRIARQ-LURJTMIESA-N',
    (SELECT id from subcategories WHERE subcatname='Iodocarbons (C, H, O, Cl, I)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>19</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='iopamidol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ioxaglic acid',
    'C<sub>24</sub>H<sub>21</sub>I<sub>6</sub>N<sub>5</sub>O<sub>8</sub>',
    '',
    '59017-64-0',
    'TYYBFXNZMFNZJT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Iodocarbons (C, H, O, Cl, I)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>35</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ioxaglic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>27</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ioxaglic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>29</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ioxaglic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>38</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ioxaglic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'perfluorohexyl iodide',
    'C<sub>6</sub>F<sub>13</sub>I',
    '',
    '355-43-1',
    'BULLJMKUVKYZDJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Iodocarbons (C, H, O, Cl, I)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;4</sup>',
    '8200',
    'M',
    (SELECT id from species WHERE iupac='perfluorohexyl iodide'),
    (SELECT id from literature WHERE bibtexkey='3939'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,1,2,2,3,3-heptafluoro-5-iodopentane',
    'C<sub>5</sub>H<sub>4</sub>F<sub>7</sub>I',
    '',
    '68188-12-5',
    'TZNRRNKRZXHADL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Iodocarbons (C, H, O, Cl, I)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2,2,3,3-heptafluoro-5-iodopentane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2,2,3,3-heptafluoro-5-iodopentane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2,2,3,3-heptafluoro-5-iodopentane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2,2,3,3-heptafluoro-5-iodopentane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-fluoro-4-iodobenzene',
    'C<sub>6</sub>H<sub>4</sub>FI',
    '',
    '352-34-1',
    'KGNQDBQYEBMPFZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Iodocarbons (C, H, O, Cl, I)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-fluoro-4-iodobenzene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-diethylamiloride',
    'C<sub>6</sub>H<sub>4</sub>F<sub>9</sub>I',
    '',
    '2043-55-2',
    'CXHFIVFPHDGZIS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Iodocarbons (C, H, O, Cl, I)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-diethylamiloride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-diethylamiloride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-diethylamiloride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-diethylamiloride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,1,2,2,3,3,4,4,5,5,6,6-tridecafluoro-8-iodooctane',
    'C<sub>8</sub>H<sub>4</sub>F<sub>13</sub>I',
    '',
    '2043-57-4',
    'NVVZEKTVIXIUKW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Iodocarbons (C, H, O, Cl, I)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1,1,1,2,2,3,3,4,4,5,5,6,6-tridecafluoro-8-iodooctane'),
    (SELECT id from literature WHERE bibtexkey='3939'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2,2,3,3,4,4,5,5,6,6-tridecafluoro-8-iodooctane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2,2,3,3,4,4,5,5,6,6-tridecafluoro-8-iodooctane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2,2,3,3,4,4,5,5,6,6-tridecafluoro-8-iodooctane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2,2,3,3,4,4,5,5,6,6-tridecafluoro-8-iodooctane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1H,2H-perfluoro-1-iodooct-1-ene',
    'C<sub>8</sub>H<sub>2</sub>F<sub>13</sub>I',
    '',
    '150223-14-6',
    'WDWNMIBWWPZNJK-OWOJBTEDSA-N',
    (SELECT id from subcategories WHERE subcatname='Iodocarbons (C, H, O, Cl, I)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1H,2H-perfluoro-1-iodooct-1-ene'),
    (SELECT id from literature WHERE bibtexkey='3939'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,1,2,2,3,3,4,4,5,5,6,6,7,7,8,8-heptadecafluoro-10-iododecane',
    'C<sub>10</sub>H<sub>4</sub>F<sub>17</sub>I',
    '',
    '2043-53-0',
    'XVKJSLBVVRCOIT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Iodocarbons (C, H, O, Cl, I)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2,2,3,3,4,4,5,5,6,6,7,7,8,8-heptadecafluoro-10-iododecane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2,2,3,3,4,4,5,5,6,6,7,7,8,8-heptadecafluoro-10-iododecane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2,2,3,3,4,4,5,5,6,6,7,7,8,8-heptadecafluoro-10-iododecane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,1,2,2,3,3,4,4,5,5,6,6,7,7,8,8-heptadecafluoro-10-iododecane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chloroiodomethane',
    'CH<sub>2</sub>ClI',
    '',
    '593-71-5',
    'PJGJQVRXEUVAFT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Iodocarbons (C, H, O, Cl, I)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;3</sup>',
    '5100',
    'L',
    (SELECT id from species WHERE iupac='chloroiodomethane'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;3</sup>',
    '5100',
    'L',
    (SELECT id from species WHERE iupac='chloroiodomethane'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;3</sup>',
    '6200',
    'M',
    (SELECT id from species WHERE iupac='chloroiodomethane'),
    (SELECT id from literature WHERE bibtexkey='3564'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;3</sup>',
    '4100',
    'M',
    (SELECT id from species WHERE iupac='chloroiodomethane'),
    (SELECT id from literature WHERE bibtexkey='583'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref0583-593-71-5-ABC',
    '583', 'The data from Moore et&nbsp;al. (1995) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;242.58767 +14043.89458/T +33.48497&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref0583-593-71-5-ABC'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroiodomethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-V'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-GROMHE'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroiodomethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroiodomethane'),
    (SELECT id from literature WHERE bibtexkey='2546'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2546-HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroiodomethane'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chloroiodomethane'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-chloro-4-iodobenzene',
    'C<sub>6</sub>H<sub>4</sub>ClI',
    '',
    '637-87-6',
    'GWQSENYKCGJTRI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Iodocarbons (C, H, O, Cl, I)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-chloro-4-iodobenzene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bromoiodomethane',
    'CH<sub>2</sub>BrI',
    '',
    '557-68-6',
    'TUDWMIUPYRKEFN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Iodocarbons (C, H, O, Cl, I)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='bromoiodomethane'),
    (SELECT id from literature WHERE bibtexkey='3753'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3753',
    '3753', 'Karagodin-Doyennel et&nbsp;al. (2021) probably assume that CH<sub>2</sub>BrI has the same Henry''s law constant as CH<sub>2</sub>ClI.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3753'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-bromo-4-iodobenzene',
    'C<sub>6</sub>H<sub>4</sub>BrI',
    '',
    '589-87-7',
    'UCCUXODGPMAHRL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Iodocarbons (C, H, O, Cl, I)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-bromo-4-iodobenzene'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO categories (catname) VALUES (
    'Organic species with sulfur (S)');
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Sulfur (C, H, O, N, Cl, S)',
    (SELECT id from categories WHERE catname='Organic species with sulfur (S)'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methanethiol',
    'CH<sub>3</sub>SH',
    'methyl mercaptan',
    '74-93-1',
    'LSDPWZHWYPCBBB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '3400',
    'L',
    (SELECT id from species WHERE iupac='methanethiol'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '3400',
    'L',
    (SELECT id from species WHERE iupac='methanethiol'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '3400',
    'L',
    (SELECT id from species WHERE iupac='methanethiol'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '3400',
    'L',
    (SELECT id from species WHERE iupac='methanethiol'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '2900',
    'L',
    (SELECT id from species WHERE iupac='methanethiol'),
    (SELECT id from literature WHERE bibtexkey='3618'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '3100',
    'L',
    (SELECT id from species WHERE iupac='methanethiol'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '2800',
    'M',
    (SELECT id from species WHERE iupac='methanethiol'),
    (SELECT id from literature WHERE bibtexkey='586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '2700',
    'M',
    (SELECT id from species WHERE iupac='methanethiol'),
    (SELECT id from literature WHERE bibtexkey='3668'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3668'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '3400',
    'M',
    (SELECT id from species WHERE iupac='methanethiol'),
    (SELECT id from literature WHERE bibtexkey='522'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methanethiol'),
    (SELECT id from literature WHERE bibtexkey='714'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methanethiol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methanethiol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methanethiol'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methanethiol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '1600',
    'X',
    (SELECT id from species WHERE iupac='methanethiol'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanethiol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanethiol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanethiol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanethiol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3300',
    'Q',
    (SELECT id from species WHERE iupac='methanethiol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanethiol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanethiol'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanethiol'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanethiol'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanethiol'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanethiol'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3400',
    '?',
    (SELECT id from species WHERE iupac='methanethiol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methanethiol'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methanethiol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methanethiol'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethanethiol',
    'C<sub>2</sub>H<sub>5</sub>SH',
    'ethyl mercaptan',
    '75-08-1',
    'DNJIEGIFACGWOD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '3700',
    'L',
    (SELECT id from species WHERE iupac='ethanethiol'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '3700',
    'L',
    (SELECT id from species WHERE iupac='ethanethiol'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '3700',
    'L',
    (SELECT id from species WHERE iupac='ethanethiol'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '3700',
    'L',
    (SELECT id from species WHERE iupac='ethanethiol'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '3500',
    'L',
    (SELECT id from species WHERE iupac='ethanethiol'),
    (SELECT id from literature WHERE bibtexkey='3618'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '2800',
    'M',
    (SELECT id from species WHERE iupac='ethanethiol'),
    (SELECT id from literature WHERE bibtexkey='3556'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '3700',
    'M',
    (SELECT id from species WHERE iupac='ethanethiol'),
    (SELECT id from literature WHERE bibtexkey='522'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethanethiol'),
    (SELECT id from literature WHERE bibtexkey='728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethanethiol'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethanethiol'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethanethiol'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethanethiol'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethanethiol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanethiol'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanethiol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanethiol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanethiol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanethiol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3600',
    'Q',
    (SELECT id from species WHERE iupac='ethanethiol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanethiol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanethiol'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanethiol'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanethiol'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanethiol'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanethiol'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanethiol'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3700',
    '?',
    (SELECT id from species WHERE iupac='ethanethiol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethanethiol'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethanethiol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethanethiol'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethanethiol'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-ethanedithiol',
    'C<sub>2</sub>H<sub>6</sub>S<sub>2</sub>',
    '',
    '540-63-6',
    'VYMPLPIFKRHAAC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2-ethanedithiol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'thiirane',
    'C<sub>2</sub>H<sub>4</sub>S',
    'ethylene sulfide',
    '420-12-2',
    'VOVUARRWDCVURC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='thiirane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-propanethiol',
    'C<sub>3</sub>H<sub>7</sub>SH',
    'propyl mercaptan',
    '107-03-9',
    'SUVIGLJNEAMWEG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '3600',
    'L',
    (SELECT id from species WHERE iupac='1-propanethiol'),
    (SELECT id from literature WHERE bibtexkey='3618'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '4100',
    'M',
    (SELECT id from species WHERE iupac='1-propanethiol'),
    (SELECT id from literature WHERE bibtexkey='3304'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3304-107-03-9-ABC',
    '3304', 'The data from Haimi et&nbsp;al. (2006) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;266.45850 +15036.99733/T +36.80758&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3304-107-03-9-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '3100',
    'M',
    (SELECT id from species WHERE iupac='1-propanethiol'),
    (SELECT id from literature WHERE bibtexkey='1929'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '3900',
    'M',
    (SELECT id from species WHERE iupac='1-propanethiol'),
    (SELECT id from literature WHERE bibtexkey='522'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-propanethiol'),
    (SELECT id from literature WHERE bibtexkey='3669'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-propanethiol'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3812',
    '3812', 'Yaws et&nbsp;al. (2003) present Henry''s law constants based on water solubility and vapor pressure. The water solubility is calculated using a correlation to the boiling point. For the vapor pressures, no references are provided.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-propanethiol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-propanethiol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-propanethiol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-propanethiol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-propanethiol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-propanethiol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4000',
    'Q',
    (SELECT id from species WHERE iupac='1-propanethiol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-propanethiol'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-propanethiol'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-propanethiol'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-propanethiol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3800',
    '?',
    (SELECT id from species WHERE iupac='1-propanethiol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-propanethiol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-propanethiol'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-propanethiol',
    'C<sub>3</sub>H<sub>8</sub>S',
    'isopropyl mercaptan',
    '75-33-2',
    'KJRCEJOSASVSRA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '3700',
    'L',
    (SELECT id from species WHERE iupac='2-propanethiol'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '4300',
    'M',
    (SELECT id from species WHERE iupac='2-propanethiol'),
    (SELECT id from literature WHERE bibtexkey='3306'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3306-75-33-2-ABC',
    '3306', 'The data from Zin et&nbsp;al. (2016) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;419.66332 +22034.35758/T +59.55571&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3306-75-33-2-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '3800',
    'M',
    (SELECT id from species WHERE iupac='2-propanethiol'),
    (SELECT id from literature WHERE bibtexkey='3304'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3304-75-33-2-ABC',
    '3304', 'The data from Haimi et&nbsp;al. (2006) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;166.97891 +10357.07398/T +22.04420&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3304-75-33-2-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-propanethiol'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-propanethiol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propanethiol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propanethiol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propanethiol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propanethiol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propanethiol'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-propanethiol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-butanethiol',
    'C<sub>4</sub>H<sub>9</sub>SH',
    'butyl mercaptan',
    '109-79-5',
    'WQAQPCDUOCURKW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '4300',
    'L',
    (SELECT id from species WHERE iupac='1-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '4400',
    'L',
    (SELECT id from species WHERE iupac='1-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='3618'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '4300',
    'M',
    (SELECT id from species WHERE iupac='1-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='3304'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3304-109-79-5-ABC',
    '3304', 'The data from Haimi et&nbsp;al. (2006) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;406.56800 +21428.82541/T +57.60207&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3304-109-79-5-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '3600',
    'M',
    (SELECT id from species WHERE iupac='1-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='1929'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '4100',
    'M',
    (SELECT id from species WHERE iupac='1-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='522'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4300',
    'Q',
    (SELECT id from species WHERE iupac='1-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='3393'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4200',
    '?',
    (SELECT id from species WHERE iupac='1-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-butanethiol',
    'C<sub>4</sub>H<sub>10</sub>S',
    '<i>sec</i>-butyl mercaptan',
    '513-53-1',
    'LOCHFZBWPCLPAN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='3618'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-1-propanethiol',
    'C<sub>4</sub>H<sub>10</sub>S',
    'isobutyl mercaptan',
    '513-44-0',
    'BDFAOUQQXJIZDG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '3600',
    'M',
    (SELECT id from species WHERE iupac='2-methyl-1-propanethiol'),
    (SELECT id from literature WHERE bibtexkey='3306'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3306-513-44-0-ABC',
    '3306', 'The data from Zin et&nbsp;al. (2016) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( 10.26074 +2303.75755/T &#8722;4.36399&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3306-513-44-0-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-1-propanethiol'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-1-propanethiol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-propanethiol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-propanethiol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-propanethiol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-propanethiol'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methyl-1-propanethiol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-2-propanethiol',
    'C<sub>4</sub>H<sub>10</sub>S',
    '<i>tert</i>-butyl mercaptan',
    '75-66-1',
    'WMXCDAVJEZZYLT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2-methyl-2-propanethiol'),
    (SELECT id from literature WHERE bibtexkey='3618'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-2-propanethiol'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-2-propanethiol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propanethiol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propanethiol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propanethiol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propanethiol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-propanethiol'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methyl-2-propanethiol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,4-dithiane',
    'C<sub>4</sub>H<sub>8</sub>S<sub>2</sub>',
    '',
    '505-29-3',
    'LOZWAPSEEHRYPG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-dithiane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,4-dithiane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,4-dithiane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-pentanethiol',
    'C<sub>5</sub>H<sub>11</sub>SH',
    'pentyl mercaptan',
    '110-66-7',
    'ZRKMQKLGEQPLNS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-pentanethiol'),
    (SELECT id from literature WHERE bibtexkey='3618'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-pentanethiol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-pentanethiol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-pentanethiol'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-pentanethiol'),
    (SELECT id from literature WHERE bibtexkey='2388'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-pentanethiol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentanethiol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentanethiol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentanethiol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentanethiol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentanethiol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-pentanethiol'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-pentanethiol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dimethyl-1-propanethiol',
    'C<sub>5</sub>H<sub>12</sub>S',
    '',
    '1679-08-9',
    'LSUXMVNABVPWMF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2-dimethyl-1-propanethiol'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2-dimethyl-1-propanethiol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-1-propanethiol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-1-propanethiol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-1-butanethiol',
    'C<sub>5</sub>H<sub>12</sub>S',
    '',
    '1878-18-8',
    'WGQKBCSACFQGQY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-1-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-1-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-1-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-2-butanethiol',
    'C<sub>5</sub>H<sub>12</sub>S',
    '',
    '1679-09-0',
    'IQIBYAHJXQVQGB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-2-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-2-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-2-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3731_1679-09-0',
    '3731', 'Presumably, the species called "42-methyl-2-butanethiol" in Table&nbsp;1 of Yao et&nbsp;al. (2002) should be 2-methyl-2-butanethiol.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_1679-09-0'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methyl-2-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-pentanethiol',
    'C<sub>5</sub>H<sub>12</sub>S',
    '',
    '2084-19-7',
    'QUSTYFNPKBDELJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-pentanethiol'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-pentanethiol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-pentanethiol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentanethiol'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentanethiol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-pentanethiol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-pentanethiol',
    'C<sub>5</sub>H<sub>12</sub>S',
    '',
    '616-31-9',
    'WICKAMSPKJXSGN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-pentanethiol'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-pentanethiol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-pentanethiol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-pentanethiol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-1-butanethiol',
    'C<sub>5</sub>H<sub>12</sub>S',
    '',
    '541-31-1',
    'GIJGXNFNUUFEGH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='3-methyl-1-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='3618'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-methyl-1-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-1-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-1-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-2-butanethiol',
    'C<sub>5</sub>H<sub>12</sub>S',
    '',
    '2084-18-6',
    'BFLXFRNPNMTTAA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-methyl-2-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-2-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-butanethiol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-hexanethiol',
    'C<sub>6</sub>H<sub>14</sub>S',
    'hexyl mercaptan',
    '111-31-9',
    'PMBXCGGQNSVESQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-hexanethiol'),
    (SELECT id from literature WHERE bibtexkey='3618'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hexanethiol'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-hexanethiol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexanethiol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexanethiol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexanethiol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hexanethiol'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-hexanethiol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-hexanethiol',
    'C<sub>6</sub>H<sub>14</sub>S',
    '',
    '1679-06-7',
    'ABNPJVOPTXYSQW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-hexanethiol'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-hexanethiol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hexanethiol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-hexanethiol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-heptanethiol',
    'C<sub>7</sub>H<sub>16</sub>S',
    'heptyl mercaptan',
    '1639-09-4',
    'VPIAKHNXCOTPAY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;4</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='1-heptanethiol'),
    (SELECT id from literature WHERE bibtexkey='3618'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-heptanethiol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-heptanethiol'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-heptanethiol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-heptanethiol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-heptanethiol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-heptanethiol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-heptanethiol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-heptanethiol'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-heptanethiol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-heptanethiol',
    'C<sub>7</sub>H<sub>16</sub>S',
    '',
    '628-00-2',
    'DAZNOIJJVKASGS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-heptanethiol'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-heptanethiol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-heptanethiol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-heptanethiol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-octanethiol',
    'C<sub>8</sub>H<sub>18</sub>S',
    'octyl mercaptan',
    '111-88-6',
    'KZCOBXFFBQJQHH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-octanethiol'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-octanethiol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octanethiol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octanethiol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octanethiol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octanethiol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-octanethiol'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-octanethiol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '<i>tert</i>-octanethiol',
    'C<sub>8</sub>H<sub>18</sub>S',
    '<i>tert</i>-octyl mercaptan',
    '141-59-3',
    'QZLAEIZEPJAELS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='<i>tert</i>-octanethiol'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='<i>tert</i>-octanethiol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>tert</i>-octanethiol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>tert</i>-octanethiol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>tert</i>-octanethiol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='<i>tert</i>-octanethiol'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='<i>tert</i>-octanethiol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-octanethiol',
    'C<sub>8</sub>H<sub>18</sub>S',
    '',
    '3001-66-9',
    'BZXFEMZFRLXGCY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-octanethiol'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-octanethiol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-octanethiol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-octanethiol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-nonanethiol',
    'C<sub>9</sub>H<sub>20</sub>S',
    'nonyl mercaptan',
    '1455-21-6',
    'ZVEZMVFBMOOHAT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-nonanethiol'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-nonanethiol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nonanethiol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nonanethiol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nonanethiol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-nonanethiol'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-nonanethiol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-nonanethiol',
    'C<sub>9</sub>H<sub>20</sub>S',
    '',
    '13281-11-3',
    'UOMSUBPWUZCGQU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-nonanethiol'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-nonanethiol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nonanethiol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nonanethiol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-decanethiol',
    'C<sub>10</sub>H<sub>22</sub>S',
    'decyl mercaptan',
    '143-10-2',
    'VTXVGVNLYGSIAR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-decanethiol'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-decanethiol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-decanethiol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-decanethiol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-decanethiol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-decanethiol'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-decanethiol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-decanethiol',
    'C<sub>10</sub>H<sub>22</sub>S',
    '',
    '13402-60-3',
    'NWKXKAHGQAWFQP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-decanethiol'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-decanethiol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-decanethiol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-decanethiol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-undecanethiol',
    'C<sub>11</sub>H<sub>24</sub>S',
    'undecyl mercaptan',
    '5332-52-5',
    'CCIDWXHLGNEQSL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-undecanethiol'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-undecanethiol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-undecanethiol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-undecanethiol'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-undecanethiol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-undecanethiol',
    'C<sub>11</sub>H<sub>24</sub>S',
    '',
    '62155-02-6',
    'KRMLVHZORKTOLI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-undecanethiol'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-undecanethiol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-undecanethiol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-undecanethiol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-dodecanethiol',
    'C<sub>12</sub>H<sub>26</sub>S',
    'dodecyl mercaptan',
    '112-55-0',
    'WNAHIZMDSQCWRP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-dodecanethiol'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-dodecanethiol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-dodecanethiol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-dodecanethiol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-dodecanethiol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-dodecanethiol'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1-dodecanethiol'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-dodecanethiol',
    'C<sub>12</sub>H<sub>26</sub>S',
    '',
    '14402-50-7',
    'UROXMPKAGAWKPP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-dodecanethiol'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-dodecanethiol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-dodecanethiol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-dodecanethiol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-propyl-5-nonanethiol',
    'C<sub>12</sub>H<sub>26</sub>S',
    '',
    '',
    'BGQHJKADBZPYGJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-propyl-5-nonanethiol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-propyl-5-nonanethiol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-propyl-5-nonanethiol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-propyl-5-nonanethiol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-tridecanethiol',
    'C<sub>13</sub>H<sub>28</sub>S',
    '',
    '19484-26-5',
    'IPBROXKVGHZHJV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-tridecanethiol'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-tridecanethiol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-tridecanethiol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-tridecanethiol',
    'C<sub>13</sub>H<sub>28</sub>S',
    '',
    '62155-03-7',
    'ZAPRCDVCNIREGW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-tridecanethiol'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-tridecanethiol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-tridecanethiol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-tridecanethiol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-tetradecanethiol',
    'C<sub>14</sub>H<sub>30</sub>S',
    '',
    '2079-95-0',
    'GEKDEMKPCKTKEC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-tetradecanethiol'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-tetradecanethiol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-tetradecanethiol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-tetradecanethiol',
    'C<sub>14</sub>H<sub>30</sub>S',
    '',
    '62155-04-8',
    'YESAYZVWGLMPDY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-tetradecanethiol'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-tetradecanethiol'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-tetradecanethiol'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-tetradecanethiol'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimethyl sulfide',
    'CH<sub>3</sub>SCH<sub>3</sub>',
    'DMS',
    '75-18-3',
    'QMMFVYPAHWMCMS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;3</sup>',
    '3500',
    'L',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;3</sup>',
    '3500',
    'L',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;3</sup>',
    '3500',
    'L',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='moreTdep'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;3</sup>',
    '3500',
    'L',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='2828'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;3</sup>',
    '3500',
    'L',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;3</sup>',
    '3500',
    'L',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;3</sup>',
    '3800',
    'L',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3618'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;3</sup>',
    '3600',
    'L',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;3</sup>',
    '3500',
    'L',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='1525'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;3</sup>',
    '4700',
    'M',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3508'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='2823'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;3</sup>',
    '2800',
    'M',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3115'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='alsosalt'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;3</sup>',
    '3600',
    'M',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='1929'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;3</sup>',
    '3800',
    'M',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='1936'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='1937'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;3</sup>',
    '4100',
    'M',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='1773'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='1923'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3643'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3670'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3670'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;3</sup>',
    '3700',
    'M',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='2512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3611'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='2964'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '4300',
    'M',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='983'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;3</sup>',
    '3100',
    'M',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;3</sup>',
    '2700',
    'M',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3668'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3668'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;3</sup>',
    '3500',
    'M',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='512'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;3</sup>',
    '4000',
    'M',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='522'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='726'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2614_pc_problem'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='2964'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='714'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;3</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;3</sup>',
    '3700',
    'T',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='2016'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2016'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='gaffney84'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from715'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='730'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='2600'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at372K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3100',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='2964'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3500',
    '?',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dimethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyl methyl sulfide',
    'C<sub>2</sub>H<sub>5</sub>SCH<sub>3</sub>',
    '',
    '624-89-5',
    'WXEHBUMAEPOYKP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='ethyl methyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='ethyl methyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ethyl methyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='2823'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl methyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;3</sup>',
    '',
    'T',
    (SELECT id from species WHERE iupac='ethyl methyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='2016'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2016'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethyl methyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl methyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl methyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl methyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl methyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl methyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl methyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethyl methyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diethyl sulfide',
    'C<sub>2</sub>H<sub>5</sub>SC<sub>2</sub>H<sub>5</sub>',
    '',
    '352-93-2',
    'LJSQFQKUNVCTIA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='diethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='diethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;3</sup>',
    '4800',
    'L',
    (SELECT id from species WHERE iupac='diethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3618'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='diethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='2823'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;3</sup>',
    '4900',
    'M',
    (SELECT id from species WHERE iupac='diethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='522'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='diethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-Test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='731-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='diethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='diethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='diethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='diethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='diethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl isopropyl sulfide',
    'C<sub>4</sub>H<sub>10</sub>S',
    '',
    '1551-21-9',
    'ROSSIHMZZJOVOU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl isopropyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methyl isopropyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl isopropyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl isopropyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl isopropyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methyl isopropyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl propyl sulfide',
    'C<sub>4</sub>H<sub>10</sub>S',
    '',
    '3877-15-4',
    'ZOASGOXWEHUTKZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='methyl propyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3618'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methyl propyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3669'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl propyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methyl propyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl propyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl propyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl propyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methyl propyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tetrahydrothiophene',
    'C<sub>4</sub>H<sub>8</sub>S',
    '',
    '110-01-0',
    'RAOIDOHSFRTOEL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tetrahydrothiophene'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrahydrothiophene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-3-thiapentane',
    'C<sub>5</sub>H<sub>12</sub>S',
    '',
    '5145-99-3',
    'NZUQQADVSXWVNW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-3-thiapentane'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-3-thiapentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-thiapentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-thiapentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3-dimethyl-2-thiabutane',
    'C<sub>5</sub>H<sub>12</sub>S',
    '',
    '6163-64-0',
    'CJFVCTVYZFTORU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,3-dimethyl-2-thiabutane'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3-dimethyl-2-thiabutane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-2-thiabutane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-2-thiabutane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-2-thiapentane',
    'C<sub>5</sub>H<sub>12</sub>S',
    '',
    '10359-64-5',
    'IJRCRFQMYAJPPO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-methyl-2-thiapentane'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-2-thiapentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-thiapentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-thiapentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-2-thiapentane',
    'C<sub>5</sub>H<sub>12</sub>S',
    '',
    '5008-69-5',
    'UYVGFIKOUAFDOZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-methyl-2-thiapentane'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-2-thiapentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-thiapentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-thiapentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyl propyl sulfide',
    'C<sub>5</sub>H<sub>12</sub>S',
    '',
    '4110-50-3',
    'ZDDDFDQTSXYYSE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl propyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethyl propyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl propyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl propyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl propyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethyl propyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl butyl sulfide',
    'C<sub>5</sub>H<sub>12</sub>S',
    '',
    '628-29-5',
    'WCXXISMIJBRDQK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl butyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methyl butyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl butyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl butyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl butyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methyl butyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dipropyl sulfide',
    'C<sub>3</sub>H<sub>7</sub>SC<sub>3</sub>H<sub>7</sub>',
    '',
    '111-47-7',
    'ZERULLAPCVRMCO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;3</sup>',
    '5700',
    'L',
    (SELECT id from species WHERE iupac='dipropyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3618'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;3</sup>',
    '4500',
    'M',
    (SELECT id from species WHERE iupac='dipropyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='522'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dipropyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dipropyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dipropyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dipropyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dipropyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dipropyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dipropyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4500',
    'Q',
    (SELECT id from species WHERE iupac='dipropyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dipropyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Ts'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dipropyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dipropyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dipropyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dipropyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4500',
    '?',
    (SELECT id from species WHERE iupac='dipropyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dipropyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dipropyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'di-(2-propyl)-sulfide',
    '(C<sub>3</sub>H<sub>7</sub>)<sub>2</sub>S',
    'diisopropyl sulfide',
    '625-80-9',
    'XYWDPYKBIRQXQS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '4900',
    'L',
    (SELECT id from species WHERE iupac='di-(2-propyl)-sulfide'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='di-(2-propyl)-sulfide'),
    (SELECT id from literature WHERE bibtexkey='3618'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '5000',
    'M',
    (SELECT id from species WHERE iupac='di-(2-propyl)-sulfide'),
    (SELECT id from literature WHERE bibtexkey='522'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='di-(2-propyl)-sulfide'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='di-(2-propyl)-sulfide'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='di-(2-propyl)-sulfide'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='di-(2-propyl)-sulfide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='di-(2-propyl)-sulfide'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='di-(2-propyl)-sulfide'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='di-(2-propyl)-sulfide'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4500',
    'Q',
    (SELECT id from species WHERE iupac='di-(2-propyl)-sulfide'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='di-(2-propyl)-sulfide'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='di-(2-propyl)-sulfide'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='di-(2-propyl)-sulfide'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='di-(2-propyl)-sulfide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4200',
    '?',
    (SELECT id from species WHERE iupac='di-(2-propyl)-sulfide'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='di-(2-propyl)-sulfide'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='di-(2-propyl)-sulfide'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2-dimethyl-3-thiapentane',
    'C<sub>6</sub>H<sub>14</sub>S',
    '',
    '14290-92-7',
    'GZJUDUMQICJSFJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2-dimethyl-3-thiapentane'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,2-dimethyl-3-thiapentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-3-thiapentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2-dimethyl-3-thiapentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-3-thiahexane',
    'C<sub>6</sub>H<sub>14</sub>S',
    '',
    '5008-73-1',
    'BDFDQOJJDDORSR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-3-thiahexane'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-3-thiahexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-thiahexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-thiahexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3-dimethyl-2-thiapentane',
    'C<sub>6</sub>H<sub>14</sub>S',
    '',
    '13286-92-5',
    'SJOHDSPLOVBXOF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,3-dimethyl-2-thiapentane'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,3-dimethyl-2-thiapentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-2-thiapentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3-dimethyl-2-thiapentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4-dimethyl-2-thiapentane',
    'C<sub>6</sub>H<sub>14</sub>S',
    '',
    '53897-51-1',
    'AUNQXXJGFDKEMS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,4-dimethyl-2-thiapentane'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4-dimethyl-2-thiapentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyl-2-thiapentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethyl-2-thiapentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethyl-2-thiapentane',
    'C<sub>6</sub>H<sub>14</sub>S',
    '',
    '57093-84-2',
    'ZQOHJVSSVAWXQZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-ethyl-2-thiapentane'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethyl-2-thiapentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2-thiapentane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethyl-2-thiapentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-2-thiahexane',
    'C<sub>6</sub>H<sub>14</sub>S',
    '',
    '13286-91-4',
    'WGBHWWSSUGCSCP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-methyl-2-thiahexane'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-2-thiahexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-thiahexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-thiahexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,4-dimethyl-2-thiapentane',
    'C<sub>6</sub>H<sub>14</sub>S',
    '',
    '6079-57-8',
    'YUFAJXXIXSYTMS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4,4-dimethyl-2-thiapentane'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4,4-dimethyl-2-thiapentane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4-dimethyl-2-thiapentane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-2-thiahexane',
    'C<sub>6</sub>H<sub>14</sub>S',
    '',
    '15013-37-3',
    'XMOUDDXUCXXDTJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-methyl-2-thiahexane'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-2-thiahexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-thiahexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-2-thiahexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methyl-3-thiahexane',
    'C<sub>6</sub>H<sub>14</sub>S',
    '',
    '5008-72-0',
    'JFNGZXUPUVUYST-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='4-methyl-3-thiahexane'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='4-methyl-3-thiahexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-3-thiahexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methyl-3-thiahexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-methyl-2-thiahexane',
    'C<sub>6</sub>H<sub>14</sub>S',
    '',
    '13286-90-3',
    'ABIKQXWLJOURPN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='5-methyl-2-thiahexane'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='5-methyl-2-thiahexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-2-thiahexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-2-thiahexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-methyl-3-thiahexane',
    'C<sub>6</sub>H<sub>14</sub>S',
    '',
    '1613-45-2',
    'OIRKGXWQBSPXLQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='5-methyl-3-thiahexane'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='5-methyl-3-thiahexane'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-3-thiahexane'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-methyl-3-thiahexane'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyl butyl sulfide',
    'C<sub>6</sub>H<sub>14</sub>S',
    '',
    '638-46-0',
    'XJIRSLHMKBUGMR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl butyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethyl butyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl butyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl butyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl butyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethyl butyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl pentyl sulfide',
    'C<sub>6</sub>H<sub>14</sub>S',
    '',
    '1741-83-9',
    'FOJGPFUFFHWGFQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl pentyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methyl pentyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl pentyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyl pentyl sulfide',
    'C<sub>7</sub>H<sub>16</sub>S',
    '',
    '26158-99-6',
    'SOGIWVXLDPPMMF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl pentyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethyl pentyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl pentyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl pentyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl hexyl sulfide',
    'C<sub>7</sub>H<sub>16</sub>S',
    '',
    '20291-60-5',
    'LZRXQHHKXDXOIC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl hexyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methyl hexyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl hexyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl hexyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propyl butyl sulfide',
    'C<sub>7</sub>H<sub>16</sub>S',
    '',
    '1613-46-3',
    'ZBRWJPVULTZZCE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propyl butyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='propyl butyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl butyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl butyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dibutyl sulfide',
    'C<sub>8</sub>H<sub>18</sub>S',
    '',
    '544-40-1',
    'HTIRHQRTDBPHNZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dibutyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dibutyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibutyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibutyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyl hexyl sulfide',
    'C<sub>8</sub>H<sub>18</sub>S',
    '',
    '7309-44-6',
    'MGVUJBCOCITTRS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl hexyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethyl hexyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl hexyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl hexyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl heptyl sulfide',
    'C<sub>8</sub>H<sub>18</sub>S',
    '',
    '20291-61-6',
    'FJDWJOQOEZRIDJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl heptyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methyl heptyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl heptyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl heptyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propyl pentyl sulfide',
    'C<sub>8</sub>H<sub>18</sub>S',
    '',
    '42841-80-5',
    'MJRCCWJSYFOGBX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propyl pentyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='propyl pentyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl pentyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl pentyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'butyl pentyl sulfide',
    'C<sub>9</sub>H<sub>20</sub>S',
    '',
    '24768-42-1',
    'RNEUXBDXTNIASG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butyl pentyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='butyl pentyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl pentyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl pentyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyl heptyl sulfide',
    'C<sub>9</sub>H<sub>20</sub>S',
    '',
    '24768-44-3',
    'PYPULUCCVXMPFP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl heptyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethyl heptyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl heptyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl heptyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl octyl sulfide',
    'C<sub>9</sub>H<sub>20</sub>S',
    '',
    '3698-95-1',
    'AHCJTMBRROLNHV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl octyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methyl octyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl octyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl octyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propyl hexyl sulfide',
    'C<sub>9</sub>H<sub>20</sub>S',
    '',
    '24768-43-2',
    'ABZLKKGJOVPBBL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propyl hexyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='propyl hexyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl hexyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl hexyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'butyl hexyl sulfide',
    'C<sub>10</sub>H<sub>22</sub>S',
    '',
    '16967-04-7',
    'YZUHMAFUXBPUKH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butyl hexyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='butyl hexyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl hexyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl hexyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dipentyl sulfide',
    'C<sub>10</sub>H<sub>22</sub>S',
    '',
    '872-10-6',
    'JOZDADPMWLVEJK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dipentyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dipentyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dipentyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dipentyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyl octyl sulfide',
    'C<sub>10</sub>H<sub>22</sub>S',
    '',
    '3698-94-0',
    'WAITXWGCJQLPGH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl octyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethyl octyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl octyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl octyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl nonyl sulfide',
    'C<sub>10</sub>H<sub>22</sub>S',
    '',
    '59973-07-8',
    'FCRSULZJMFDBIK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl nonyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methyl nonyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl nonyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl nonyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propyl heptyl sulfide',
    'C<sub>10</sub>H<sub>22</sub>S',
    '',
    '24768-46-5',
    'PCPVCHFKVPNTBH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propyl heptyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='propyl heptyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl heptyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl heptyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'butyl heptyl sulfide',
    'C<sub>11</sub>H<sub>24</sub>S',
    '',
    '40813-84-1',
    'HYUPOCGXBZUYFY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butyl heptyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='butyl heptyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl heptyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl heptyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyl nonyl sulfide',
    'C<sub>11</sub>H<sub>24</sub>S',
    '',
    '59973-08-9',
    'LUAABLIRQSWMGZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl nonyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethyl nonyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl nonyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl nonyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl decyl sulfide',
    'C<sub>11</sub>H<sub>24</sub>S',
    '',
    '22438-39-7',
    'HKGUUZAACYBIID-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl decyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methyl decyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl decyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl decyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propyl octyl sulfide',
    'C<sub>11</sub>H<sub>24</sub>S',
    '',
    '3698-93-9',
    'GPJXDRJGQAKGLH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propyl octyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='propyl octyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl octyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl octyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'butyl octyl sulfide',
    'C<sub>12</sub>H<sub>26</sub>S',
    '',
    '16900-07-5',
    'UNIAPWPIAGJFDG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butyl octyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='butyl octyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl octyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl octyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dihexyl sulfide',
    'C<sub>12</sub>H<sub>26</sub>S',
    '',
    '6294-31-1',
    'LHNRHYOMDUJLLM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dihexyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dihexyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dihexyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dihexyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyl decyl sulfide',
    'C<sub>12</sub>H<sub>26</sub>S',
    '',
    '19313-61-2',
    'VSSRSPLEFYQIEK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl decyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethyl decyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl decyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl decyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl undecyl sulfide',
    'C<sub>12</sub>H<sub>26</sub>S',
    '',
    '7289-44-3',
    'HDOADYQJIBYVGE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl undecyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methyl undecyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl undecyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl undecyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propyl nonyl sulfide',
    'C<sub>12</sub>H<sub>26</sub>S',
    '',
    '62103-66-6',
    'AQAOPNMAEGBYHI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propyl nonyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='propyl nonyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl nonyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl nonyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'butyl nonyl sulfide',
    'C<sub>13</sub>H<sub>28</sub>S',
    '',
    '66577-32-0',
    'FWRIVMHSSSZAFD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butyl nonyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='butyl nonyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl nonyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl nonyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyl undecyl sulfide',
    'C<sub>13</sub>H<sub>28</sub>S',
    '',
    '66577-30-8',
    'OSWITQLVZPPUIR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl undecyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethyl undecyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl undecyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl undecyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl dodecyl sulfide',
    'C<sub>13</sub>H<sub>28</sub>S',
    '',
    '3698-89-3',
    'KJWHJDGMOQJLGF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl dodecyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methyl dodecyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl dodecyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl dodecyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propyl decyl sulfide',
    'C<sub>13</sub>H<sub>28</sub>S',
    '',
    '66577-31-9',
    'HPJCKXDELORROO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propyl decyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='propyl decyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl decyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl decyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'butyl decyl sulfide',
    'C<sub>14</sub>H<sub>30</sub>S',
    '',
    '19313-57-6',
    'CLBLVLKZMJDLOT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butyl decyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='butyl decyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl decyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butyl decyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diheptyl sulfide',
    'C<sub>14</sub>H<sub>30</sub>S',
    '',
    '629-65-2',
    'LEMIDOZYVQXGLI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diheptyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='diheptyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diheptyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diheptyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyl dodecyl sulfide',
    'C<sub>14</sub>H<sub>30</sub>S',
    '',
    '2851-83-4',
    'QECBTJWQRXCSCU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl dodecyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethyl dodecyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl dodecyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl dodecyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl tridecyl sulfide',
    'C<sub>14</sub>H<sub>30</sub>S',
    '',
    '62155-09-3',
    'QVXOOYOFFITGCV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl tridecyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methyl tridecyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl tridecyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl tridecyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propyl undecyl sulfide',
    'C<sub>14</sub>H<sub>30</sub>S',
    '',
    '66826-84-4',
    'ITNOZFAANYXVSG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propyl undecyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='propyl undecyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl undecyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl undecyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimethyl disulfide',
    'CH<sub>3</sub>SSCH<sub>3</sub>',
    '',
    '624-92-0',
    'WQOXQRCZOLPYPM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='dimethyl disulfide'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='dimethyl disulfide'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;3</sup>',
    '3700',
    'L',
    (SELECT id from species WHERE iupac='dimethyl disulfide'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;3</sup>',
    '4200',
    'L',
    (SELECT id from species WHERE iupac='dimethyl disulfide'),
    (SELECT id from literature WHERE bibtexkey='3618'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;3</sup>',
    '5200',
    'M',
    (SELECT id from species WHERE iupac='dimethyl disulfide'),
    (SELECT id from literature WHERE bibtexkey='3508'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dimethyl disulfide'),
    (SELECT id from literature WHERE bibtexkey='2823'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;3</sup>',
    '3200',
    'M',
    (SELECT id from species WHERE iupac='dimethyl disulfide'),
    (SELECT id from literature WHERE bibtexkey='3115'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='highTextrapol'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='alsosalt'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>&#8722;3</sup>',
    '4100',
    'M',
    (SELECT id from species WHERE iupac='dimethyl disulfide'),
    (SELECT id from literature WHERE bibtexkey='3610'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dimethyl disulfide'),
    (SELECT id from literature WHERE bibtexkey='3671'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dimethyl disulfide'),
    (SELECT id from literature WHERE bibtexkey='1923'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dimethyl disulfide'),
    (SELECT id from literature WHERE bibtexkey='3672'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at310K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;3</sup>',
    '4300',
    'M',
    (SELECT id from species WHERE iupac='dimethyl disulfide'),
    (SELECT id from literature WHERE bibtexkey='522'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dimethyl disulfide'),
    (SELECT id from literature WHERE bibtexkey='3669'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dimethyl disulfide'),
    (SELECT id from literature WHERE bibtexkey='728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dimethyl disulfide'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dimethyl disulfide'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;3</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='dimethyl disulfide'),
    (SELECT id from literature WHERE bibtexkey='728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl disulfide'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl disulfide'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '1700',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl disulfide'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl disulfide'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '1600',
    '?',
    (SELECT id from species WHERE iupac='dimethyl disulfide'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dimethyl disulfide'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diethyl disulfide',
    'C<sub>2</sub>H<sub>5</sub>SSC<sub>2</sub>H<sub>5</sub>',
    '',
    '110-81-6',
    'CETBSQOFQKLHHZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='diethyl disulfide'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='diethyl disulfide'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;3</sup>',
    '4900',
    'L',
    (SELECT id from species WHERE iupac='diethyl disulfide'),
    (SELECT id from literature WHERE bibtexkey='3618'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='diethyl disulfide'),
    (SELECT id from literature WHERE bibtexkey='2823'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;3</sup>',
    '4300',
    'M',
    (SELECT id from species WHERE iupac='diethyl disulfide'),
    (SELECT id from literature WHERE bibtexkey='522'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='diethyl disulfide'),
    (SELECT id from literature WHERE bibtexkey='728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl disulfide'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl disulfide'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl disulfide'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='diethyl disulfide'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dipropyl disulfide',
    'C<sub>3</sub>H<sub>7</sub>SSC<sub>3</sub>H<sub>7</sub>',
    '',
    '629-19-6',
    'ALVPFGSHPUPROW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '5400',
    'L',
    (SELECT id from species WHERE iupac='dipropyl disulfide'),
    (SELECT id from literature WHERE bibtexkey='3618'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dipropyl disulfide'),
    (SELECT id from literature WHERE bibtexkey='2823'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dipropyl disulfide'),
    (SELECT id from literature WHERE bibtexkey='3669'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'carbon disulfide',
    'CS<sub>2</sub>',
    '',
    '75-15-0',
    'QGJOPFRUJISHPQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;4</sup>',
    '4300',
    'L',
    (SELECT id from species WHERE iupac='carbon disulfide'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;4</sup>',
    '4300',
    'L',
    (SELECT id from species WHERE iupac='carbon disulfide'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;4</sup>',
    '3900',
    'L',
    (SELECT id from species WHERE iupac='carbon disulfide'),
    (SELECT id from literature WHERE bibtexkey='2828'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;4</sup>',
    '4300',
    'L',
    (SELECT id from species WHERE iupac='carbon disulfide'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;4</sup>',
    '4300',
    'L',
    (SELECT id from species WHERE iupac='carbon disulfide'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;4</sup>',
    '3700',
    'L',
    (SELECT id from species WHERE iupac='carbon disulfide'),
    (SELECT id from literature WHERE bibtexkey='3618'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;4</sup>',
    '3800',
    'M',
    (SELECT id from species WHERE iupac='carbon disulfide'),
    (SELECT id from literature WHERE bibtexkey='2891'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;4</sup>',
    '2800',
    'M',
    (SELECT id from species WHERE iupac='carbon disulfide'),
    (SELECT id from literature WHERE bibtexkey='586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;4</sup>',
    '3800',
    'M',
    (SELECT id from species WHERE iupac='carbon disulfide'),
    (SELECT id from literature WHERE bibtexkey='2631'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;4</sup>',
    '4300',
    'M',
    (SELECT id from species WHERE iupac='carbon disulfide'),
    (SELECT id from literature WHERE bibtexkey='863'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='carbon disulfide'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='carbon disulfide'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='carbon disulfide'),
    (SELECT id from literature WHERE bibtexkey='2439'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;4</sup>',
    '4100',
    'V',
    (SELECT id from species WHERE iupac='carbon disulfide'),
    (SELECT id from literature WHERE bibtexkey='862'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='carbon disulfide'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;4</sup>',
    '1200',
    'X',
    (SELECT id from species WHERE iupac='carbon disulfide'),
    (SELECT id from literature WHERE bibtexkey='usepa82'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from747'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='carbon disulfide'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='carbon disulfide'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='carbon disulfide'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='carbon disulfide'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='carbon disulfide'),
    (SELECT id from literature WHERE bibtexkey='3614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='carbon disulfide'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    '?',
    (SELECT id from species WHERE iupac='carbon disulfide'),
    (SELECT id from literature WHERE bibtexkey='735'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '735CS2a',
    '735,2835', 'Schäfer and Lax (1962) present data based on Booth and Jolley (1943). However, these data appear to be incorrect.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='735CS2a'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    '?',
    (SELECT id from species WHERE iupac='carbon disulfide'),
    (SELECT id from literature WHERE bibtexkey='2835'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2835rex',
    '2835,863', 'Booth and Jolley (1943) converted data from Rex (1906) to another unit. However, this was apparently not done correctly.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2835rex'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    '?',
    (SELECT id from species WHERE iupac='carbon disulfide'),
    (SELECT id from literature WHERE bibtexkey='2835'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2835chancel',
    '2835,2628', 'Booth and Jolley (1943) present data from Chancel and Parmentier (1885). However, in that paper only the solubility at an unknown partial pressure of CS<sub>2</sub> was measured.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2835chancel'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4-trithiapentane',
    'C<sub>2</sub>H<sub>6</sub>S<sub>3</sub>',
    'dimethyl trisulfide',
    '3658-80-8',
    'YWHLKYXPLRWGSE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='2,3,4-trithiapentane'),
    (SELECT id from literature WHERE bibtexkey='3618'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3,4-trithiapentane'),
    (SELECT id from literature WHERE bibtexkey='3671'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,3,4-trithiapentane'),
    (SELECT id from literature WHERE bibtexkey='2389'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dicyclohexyldisulfide',
    'C<sub>12</sub>H<sub>22</sub>S<sub>2</sub>',
    '',
    '2550-40-5',
    'ODHAQPXNQDBHSH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dicyclohexyldisulfide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'allyl mercaptan',
    'C<sub>3</sub>H<sub>6</sub>S',
    '',
    '870-23-5',
    'ULIKDJVNUXNQHS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='allyl mercaptan'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3''-thiobis-1-propene',
    '(C<sub>3</sub>H<sub>5</sub>)<sub>2</sub>S',
    'diallyl sulfide',
    '592-88-1',
    'UBJVUCKUDDKUJF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3,3''-thiobis-1-propene'),
    (SELECT id from literature WHERE bibtexkey='796'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '796',
    '', 'Value extracted from their Fig.&nbsp;46.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='796'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='3,3''-thiobis-1-propene'),
    (SELECT id from literature WHERE bibtexkey='3669'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3''-thiobis-1-propene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3''-thiobis-1-propene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'allyl methyl sulfide',
    'CH<sub>2</sub>CHCH<sub>2</sub>SCH<sub>3</sub>',
    '2-propenyl methyl sulfide',
    '10152-76-8',
    'NVLPQIPTCCLBEU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='allyl methyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='allyl methyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='allyl methyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='2823'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='allyl methyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3669'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'thiophene',
    'C<sub>4</sub>H<sub>4</sub>S',
    '',
    '110-02-1',
    'YTPLMLYBLZKORZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '4300',
    'M',
    (SELECT id from species WHERE iupac='thiophene'),
    (SELECT id from literature WHERE bibtexkey='3304'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    'ref3304-110-02-1-ABC',
    '3304', 'The data from Haimi et&nbsp;al. (2006) were fitted to the three-parameter equation: H<sub>s</sub><sup>cp</sup>= exp( &#8722;233.39763 +13839.16150/T +31.85189&nbsp;ln(T))&nbsp;mol&nbsp;m<sup>&#8722;3</sup>&nbsp;Pa<sup>&#8722;1</sup>, with T in K.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='ref3304-110-02-1-ABC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;3</sup>',
    '4000',
    'M',
    (SELECT id from species WHERE iupac='thiophene'),
    (SELECT id from literature WHERE bibtexkey='522'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='thiophene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='thiophene'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2614_pc_problem'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='thiophene'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='thiophene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='thiophene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='thiophene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='thiophene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='thiophene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2800',
    'Q',
    (SELECT id from species WHERE iupac='thiophene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='thiophene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='thiophene'),
    (SELECT id from literature WHERE bibtexkey='3731'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_RBFN'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3731_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='thiophene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='thiophene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='thiophene'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '1900',
    '?',
    (SELECT id from species WHERE iupac='thiophene'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='thiophene'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='thiophene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='thiophene'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='thiophene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methylthiophene',
    'CH<sub>3</sub>C<sub>4</sub>H<sub>3</sub>S',
    '',
    '554-14-3',
    'XQQBUAPQHNYYRS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '4300',
    'L',
    (SELECT id from species WHERE iupac='2-methylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '4300',
    'M',
    (SELECT id from species WHERE iupac='2-methylthiophene'),
    (SELECT id from literature WHERE bibtexkey='522'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methylthiophene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylthiophene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylthiophene'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-methylthiophene'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methylthiophene',
    'CH<sub>3</sub>C<sub>4</sub>H<sub>3</sub>S',
    '',
    '616-44-4',
    'QENGPZGAWFQWCZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-methylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methylthiophene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylthiophene'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylthiophene'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylthiophene'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-methylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propyl allyl disulfide',
    'C<sub>6</sub>H<sub>12</sub>S<sub>2</sub>',
    '',
    '2179-59-1',
    'FCSSPCOFDUKHPV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propyl allyl disulfide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,5-dithia-1,7-octadiene',
    'C<sub>6</sub>H<sub>10</sub>S<sub>2</sub>',
    'diallyl disulfide',
    '2179-57-9',
    'PFRGXCVKLLPLIP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='4,5-dithia-1,7-octadiene'),
    (SELECT id from literature WHERE bibtexkey='3669'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethylthiophene',
    'C<sub>6</sub>H<sub>8</sub>S',
    '',
    '632-16-6',
    'BZYUMXXOAYSFOW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3-dimethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3-dimethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dimethylthiophene',
    'C<sub>6</sub>H<sub>8</sub>S',
    '',
    '638-00-6',
    'CPULIKNSOUFMPL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,4-dimethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,4-dimethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dimethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5-dimethylthiophene',
    'C<sub>6</sub>H<sub>8</sub>S',
    '',
    '638-02-8',
    'GWQOOADXMVQEFT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='2,5-dimethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3669'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,5-dimethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,5-dimethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dimethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-ethylthiophene',
    'C<sub>6</sub>H<sub>8</sub>S',
    '',
    '872-55-9',
    'JCCCMAAJYSNBPR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-ethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-ethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-ethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,4-dimethylthiophene',
    'C<sub>6</sub>H<sub>8</sub>S',
    '',
    '632-15-5',
    'GPSFYJDZKSRMKZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3,4-dimethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3,4-dimethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,4-dimethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-ethylthiophene',
    'C<sub>6</sub>H<sub>8</sub>S',
    '',
    '1795-01-3',
    'SLDBAXYJAIRQMX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-ethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-ethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-ethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,4-trimethylthiophene',
    'C<sub>7</sub>H<sub>10</sub>S',
    '',
    '1795-04-6',
    'MAVVDCDMBKFUES-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,4-trimethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,4-trimethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,4-trimethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,5-trimethylthiophene',
    'C<sub>7</sub>H<sub>10</sub>S',
    '',
    '1795-05-7',
    'QKZJQIHBRCFDGQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3,5-trimethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2,3,5-trimethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5-trimethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,5-trimethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-isopropylthiophene',
    'C<sub>7</sub>H<sub>10</sub>S',
    '',
    '4095-22-1',
    'LOXBELRNKUFSRD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-isopropylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-isopropylthiophene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-isopropylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-isopropylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-3-ethylthiophene',
    'C<sub>7</sub>H<sub>10</sub>S',
    '',
    '53119-51-0',
    'RBRAJDCWXUJHIY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-3-ethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-3-ethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-ethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-3-ethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-4-ethylthiophene',
    'C<sub>7</sub>H<sub>10</sub>S',
    '',
    '13678-54-1',
    'KIWVMUQUYOKTKU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-4-ethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-4-ethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-4-ethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-4-ethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl-5-ethylthiophene',
    'C<sub>7</sub>H<sub>10</sub>S',
    '',
    '40323-88-4',
    'VOIVNYVBGCJFRW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-methyl-5-ethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-methyl-5-ethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-5-ethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl-5-ethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-propylthiophene',
    'C<sub>7</sub>H<sub>10</sub>S',
    '',
    '1551-27-5',
    'BTXIJTYYMLCUHI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-propylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='2-propylthiophene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-propylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-isopropylthiophene',
    'C<sub>7</sub>H<sub>10</sub>S',
    '',
    '29488-27-5',
    'LJPDBPCGTFTUDE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-isopropylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-isopropylthiophene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-isopropylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-isopropylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-2-ethylthiophene',
    'C<sub>7</sub>H<sub>10</sub>S',
    '',
    '31805-48-8',
    'VVSCPYCHXFEKLF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-methyl-2-ethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-2-ethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-ethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-2-ethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-4-ethylthiophene',
    'C<sub>7</sub>H<sub>10</sub>S',
    '',
    '66577-03-5',
    'QMHNYDJBWOPGHE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-methyl-4-ethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-4-ethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-4-ethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-4-ethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methyl-5-ethylthiophene',
    'C<sub>7</sub>H<sub>10</sub>S',
    '2-ethyl-4-methylthiophene',
    '66577-04-6',
    'NZOYEHPXDWJOCD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-methyl-5-ethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-methyl-5-ethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-5-ethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methyl-5-ethylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-propylthiophene',
    'C<sub>7</sub>H<sub>10</sub>S',
    '',
    '1518-75-8',
    'QZNFRMXKQCIPQY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='3-propylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3812'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3812'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='3-propylthiophene'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-propylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3406'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-propylthiophene'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benzenethiol',
    'C<sub>6</sub>H<sub>5</sub>SH',
    'thiophenol',
    '108-98-5',
    'RMVRSNDYEFQCLF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzenethiol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzenethiol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzenethiol'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzenethiol'),
    (SELECT id from literature WHERE bibtexkey='714'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='benzenethiol'),
    (SELECT id from literature WHERE bibtexkey='2165'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzenethiol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzenethiol'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzenethiol'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzenethiol'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzenethiol'),
    (SELECT id from literature WHERE bibtexkey='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2543-T'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzenethiol'),
    (SELECT id from literature WHERE bibtexkey='3764'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzenethiol'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzenethiol'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='benzenethiol'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl phenyl sulfide',
    'C<sub>6</sub>H<sub>5</sub>SCH<sub>3</sub>',
    'thioanisole',
    '100-68-5',
    'HNKJADCVZUBCPG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl phenyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl phenyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='714'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl phenyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl phenyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2535-Tr'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl phenyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='984'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl phenyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='1162'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1162PCR'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methylbenzenethiol',
    'C<sub>7</sub>H<sub>8</sub>S',
    '2-thiocresol',
    '137-06-4',
    'LXUNZSDDXMPKLP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbenzenethiol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-methylbenzenethiol',
    'C<sub>7</sub>H<sub>8</sub>S',
    '3-thiocresol',
    '108-40-7',
    'WRXOZRLZDJAYDR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3-methylbenzenethiol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methylbenzenethiol',
    'C<sub>7</sub>H<sub>8</sub>S',
    '4-thiocresol',
    '106-45-6',
    'WLHCBQAPPJAULW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylbenzenethiol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benzenemethanethiol',
    'C<sub>7</sub>H<sub>8</sub>S',
    '',
    '100-53-8',
    'UENWRTRMUIOCKN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzenemethanethiol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benzo[b]thiophene',
    'C<sub>8</sub>H<sub>6</sub>S',
    '',
    '95-15-8',
    'FCEHBMOGCRZNNI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzo[b]thiophene'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2614_pc_problem'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzo[b]thiophene'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benzo[b]thiophene'),
    (SELECT id from literature WHERE bibtexkey='3945'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='benzo[b]thiophene'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dibenzothiophene',
    'C<sub>12</sub>H<sub>8</sub>S',
    '',
    '132-65-0',
    'IYYZUPMFVPLQIF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dibenzothiophene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dibenzothiophene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dibenzothiophene'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dibenzothiophene'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dibenzothiophene'),
    (SELECT id from literature WHERE bibtexkey='3945'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibenzothiophene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibenzothiophene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'thianthrene',
    'C<sub>12</sub>H<sub>8</sub>S<sub>2</sub>',
    '',
    '92-85-3',
    'GVIJJXMXTUZIOD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='thianthrene'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyldibenzothiophene',
    'C<sub>13</sub>H<sub>10</sub>S',
    '',
    '20928-02-3',
    'VHUXLBLPAMBOJS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyldibenzothiophene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimethyldibenzothiophene',
    'C<sub>14</sub>H<sub>12</sub>S',
    '',
    '31317-17-6',
    'KEIKATUAMBEIQN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimethyldibenzothiophene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,8-dimethyldibenzothiophene',
    'C<sub>14</sub>H<sub>12</sub>S',
    '',
    '1207-15-4',
    'RRYWCJRYULRSJM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,8-dimethyldibenzothiophene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benzyl sulfide',
    'C<sub>14</sub>H<sub>14</sub>S',
    '',
    '538-74-9',
    'LUFPJJNWMYZRQE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,7-trimethyldibenzothiophene',
    'C<sub>15</sub>H<sub>14</sub>S',
    '',
    '',
    'HJSMFSZKADBZIO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,7-trimethyldibenzothiophene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3,8-trimethyldibenzothiophene',
    'C<sub>15</sub>H<sub>14</sub>S',
    '',
    '',
    'QSOGKFSFLARZIE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3,8-trimethyldibenzothiophene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4,7-trimethyldibenzothiophene',
    'C<sub>15</sub>H<sub>14</sub>S',
    '',
    '216983-03-8',
    'YDWNRDFOOADVGC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4,7-trimethyldibenzothiophene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,6-diethyldibenzothiophene',
    'C<sub>16</sub>H<sub>16</sub>S',
    '',
    '132034-91-4',
    'UMQGGSYHJPHWFV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,6-diethyldibenzothiophene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-butyldibenzothiophene',
    'C<sub>16</sub>H<sub>16</sub>S',
    '',
    '147792-31-2',
    'BEQMTJNPMZQPKZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-butyldibenzothiophene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'carbon oxide sulfide',
    'OCS',
    'carbonyl sulfide',
    '463-58-1',
    'JJWKPURADFRFRB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;4</sup>',
    '3500',
    'L',
    (SELECT id from species WHERE iupac='carbon oxide sulfide'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;4</sup>',
    '3500',
    'L',
    (SELECT id from species WHERE iupac='carbon oxide sulfide'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;4</sup>',
    '3300',
    'L',
    (SELECT id from species WHERE iupac='carbon oxide sulfide'),
    (SELECT id from literature WHERE bibtexkey='2828'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;4</sup>',
    '3500',
    'L',
    (SELECT id from species WHERE iupac='carbon oxide sulfide'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;4</sup>',
    '3500',
    'L',
    (SELECT id from species WHERE iupac='carbon oxide sulfide'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;4</sup>',
    '3000',
    'L',
    (SELECT id from species WHERE iupac='carbon oxide sulfide'),
    (SELECT id from literature WHERE bibtexkey='190'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;4</sup>',
    '2100',
    'M',
    (SELECT id from species WHERE iupac='carbon oxide sulfide'),
    (SELECT id from literature WHERE bibtexkey='586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;4</sup>',
    '3800',
    'M',
    (SELECT id from species WHERE iupac='carbon oxide sulfide'),
    (SELECT id from literature WHERE bibtexkey='524'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;4</sup>',
    '3500',
    'M',
    (SELECT id from species WHERE iupac='carbon oxide sulfide'),
    (SELECT id from literature WHERE bibtexkey='3119'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='seawater'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='carbon oxide sulfide'),
    (SELECT id from literature WHERE bibtexkey='2933'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;4</sup>',
    '3300',
    'M',
    (SELECT id from species WHERE iupac='carbon oxide sulfide'),
    (SELECT id from literature WHERE bibtexkey='3718'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;4</sup>',
    '3300',
    'M',
    (SELECT id from species WHERE iupac='carbon oxide sulfide'),
    (SELECT id from literature WHERE bibtexkey='862'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='carbon oxide sulfide'),
    (SELECT id from literature WHERE bibtexkey='869'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at287K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='carbon oxide sulfide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='carbon oxide sulfide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='carbon oxide sulfide'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='carbon oxide sulfide'),
    (SELECT id from literature WHERE bibtexkey='3728'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3728'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='carbon oxide sulfide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='carbon oxide sulfide'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2900',
    'Q',
    (SELECT id from species WHERE iupac='carbon oxide sulfide'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3300',
    '?',
    (SELECT id from species WHERE iupac='carbon oxide sulfide'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='carbon oxide sulfide'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;4</sup>',
    '3000',
    '?',
    (SELECT id from species WHERE iupac='carbon oxide sulfide'),
    (SELECT id from literature WHERE bibtexkey='3811'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='carbon oxide sulfide'),
    (SELECT id from literature WHERE bibtexkey='789'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methanesulfonic acid',
    'CH<sub>3</sub>SO<sub>3</sub>H',
    'MSA',
    '75-75-2',
    'AFVFQIVMOAPDHO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'T',
    (SELECT id from species WHERE iupac='methanesulfonic acid'),
    (SELECT id from literature WHERE bibtexkey='260'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '260MSA',
    '', 'H<sub>s</sub>&#8242;&nbsp;= 6.4&times;10<sup>14</sup>&nbsp;mol<sup>2</sup>/(m<sup>6</sup>&nbsp;Pa)');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='260MSA'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanesulfonic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanesulfonic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanesulfonic acid'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CH3SO2OOH',
    'CH<sub>4</sub>O<sub>4</sub>S',
    '',
    '',
    'BENVNICSYZXTGE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3SO2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3SO2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3SO2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CH3SOOOH',
    'CH<sub>4</sub>O<sub>3</sub>S',
    '',
    '',
    'IZTYBZWDPIUSAG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3SOOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3SOOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3SOOOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:MSIA',
    'CH<sub>4</sub>O<sub>2</sub>S',
    '',
    '',
    'XNEFVTBPCXGIRX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MSIA'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MSIA'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:MSIA'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'sulfuric acid, dimethyl ester',
    'C<sub>2</sub>H<sub>6</sub>O<sub>4</sub>S',
    'dimethyl sulfate',
    '77-78-1',
    'VAYGXNSJCAHWJZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='sulfuric acid, dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    '?',
    (SELECT id from species WHERE iupac='sulfuric acid, dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at291K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimethylsulfoxide',
    'CH<sub>3</sub>SOCH<sub>3</sub>',
    'DMSO',
    '67-68-5',
    'IAZDPXIOMUYVGZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='dimethylsulfoxide'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='dimethylsulfoxide'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>3</sup>',
    '7800',
    'L',
    (SELECT id from species WHERE iupac='dimethylsulfoxide'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='dimethylsulfoxide'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>2</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='dimethylsulfoxide'),
    (SELECT id from literature WHERE bibtexkey='1945'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 9.9&times;10<sup>3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dimethylsulfoxide'),
    (SELECT id from literature WHERE bibtexkey='1124'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>2</sup>',
    '1300',
    'M',
    (SELECT id from species WHERE iupac='dimethylsulfoxide'),
    (SELECT id from literature WHERE bibtexkey='824'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4',
    '',
    'V',
    (SELECT id from species WHERE iupac='dimethylsulfoxide'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4',
    '',
    'V',
    (SELECT id from species WHERE iupac='dimethylsulfoxide'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '8700',
    'T',
    (SELECT id from species WHERE iupac='dimethylsulfoxide'),
    (SELECT id from literature WHERE bibtexkey='2016'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2016'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='dimethylsulfoxide'),
    (SELECT id from literature WHERE bibtexkey='510'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylsulfoxide'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylsulfoxide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylsulfoxide'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylsulfoxide'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylsulfoxide'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylsulfoxide'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3100',
    'Q',
    (SELECT id from species WHERE iupac='dimethylsulfoxide'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylsulfoxide'),
    (SELECT id from literature WHERE bibtexkey='2531'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dimethylsulfoxide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4100',
    '?',
    (SELECT id from species WHERE iupac='dimethylsulfoxide'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    '?',
    (SELECT id from species WHERE iupac='dimethylsulfoxide'),
    (SELECT id from literature WHERE bibtexkey='1943'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '1943-67-68-5',
    '1943,2443', 'It is unclear how Fogg and Sangster (2003) obtained the data. Apparently, limiting activity coefficients &#947;<sup>&#8734;</sup> were taken from Trampe and Eckert (1993), but a source for vapor pressure data is not mentioned. Also, the &#947;<sup>&#8734;</sup> values listed in the table are different from those found in the original paper.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='1943-67-68-5'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimethylsulfone',
    'CH<sub>3</sub>SO<sub>2</sub>CH<sub>3</sub>',
    'DMSO2',
    '67-71-0',
    'HHVIBTZHLRERCL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dimethylsulfone'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dimethylsulfone'),
    (SELECT id from literature WHERE bibtexkey='636'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylsulfone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylsulfone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethylsulfone'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 4.9&times;10<sup>2</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='dimethylsulfone'),
    (SELECT id from literature WHERE bibtexkey='389'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'mercaptoacetic acid',
    'C<sub>2</sub>H<sub>4</sub>O<sub>2</sub>S',
    '',
    '68-11-1',
    'CWERGRDVMFNCDR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='mercaptoacetic acid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-mercaptoethanol',
    'C<sub>2</sub>H<sub>6</sub>OS',
    '',
    '60-24-2',
    'DGVVWUTYPXICAM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-mercaptoethanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-mercaptoethanol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-mercaptoethanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methanesulfonic acid, methyl ester',
    'C<sub>2</sub>H<sub>6</sub>O<sub>3</sub>S',
    '',
    '66-27-3',
    'MBABOKRGFJTBAE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanesulfonic acid, methyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CH3SCH2OOH',
    'C<sub>2</sub>H<sub>6</sub>O<sub>2</sub>S',
    '',
    '',
    'LDZPECMXMDESRV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3SCH2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3SCH2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3SCH2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DMSO2OOH',
    'C<sub>2</sub>H<sub>6</sub>O<sub>4</sub>S',
    '',
    '',
    'GCLQZLAJAMWHPS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMSO2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMSO2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMSO2OOH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CH3SCH2OH',
    'C<sub>2</sub>H<sub>6</sub>OS',
    '',
    '',
    'ZSSFPSNLAUYOFG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3SCH2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3SCH2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3SCH2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:DMSO2OH',
    'C<sub>2</sub>H<sub>6</sub>O<sub>3</sub>S',
    '',
    '',
    'ICHBUPLXTAHKLA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMSO2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMSO2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:DMSO2OH'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CH3SCHO',
    'C<sub>2</sub>H<sub>4</sub>OS',
    '',
    '',
    'LFJRGYNYRORDDM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3SCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3SCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3SCHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CH3SO2CHO',
    'C<sub>2</sub>H<sub>4</sub>O<sub>3</sub>S',
    '',
    '',
    'LUGQISNSRPQOGS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3SO2CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3SO2CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3SO2CHO'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'mercaptoacetic acid, methyl ester',
    'C<sub>3</sub>H<sub>6</sub>O<sub>2</sub>S',
    'methyl thioglycolate',
    '2365-48-2',
    'MKIJJIMOAABWGF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='mercaptoacetic acid, methyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3-propane sultone',
    'C<sub>3</sub>H<sub>6</sub>O<sub>3</sub>S',
    '',
    '1120-71-4',
    'FSSPGSAQUIYDCN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,3-propane sultone'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methanesulfonic acid, ethyl ester',
    'C<sub>3</sub>H<sub>8</sub>O<sub>3</sub>S',
    '',
    '62-50-0',
    'PLUBXMRUUVWRLT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methanesulfonic acid, ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanesulfonic acid, ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanesulfonic acid, ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,3-dimercapto-1-propanol',
    'C<sub>3</sub>H<sub>8</sub>OS<sub>2</sub>',
    '',
    '59-52-9',
    'WQABCVAJNWAXTE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,3-dimercapto-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,3-dimercapto-1-propanol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'divinyl sulfoxide',
    'C<sub>4</sub>H<sub>6</sub>OS',
    'vinyl sulfoxide',
    '1115-15-7',
    'HQSMEHLVLOGBCK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='divinyl sulfoxide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'divinyl sulphone',
    'C<sub>4</sub>H<sub>6</sub>O<sub>2</sub>S',
    '',
    '77-77-0',
    'AFOSIXZFDONLBT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='divinyl sulphone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,5-dihydrothiophene sulfone',
    'C<sub>4</sub>H<sub>6</sub>O<sub>2</sub>S',
    '2,5-dihydrothiophene 1,1-dioxide',
    '77-79-2',
    'MBDNRNMVTZADMQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,5-dihydrothiophene sulfone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'thiodiacetic acid',
    'C<sub>4</sub>H<sub>6</sub>O<sub>4</sub>S',
    '',
    '123-93-3',
    'UVZICZIVKIMRNE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='thiodiacetic acid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'thiophene, tetrahydro-, 1,1-dioxide',
    'C<sub>4</sub>H<sub>8</sub>O<sub>2</sub>S',
    'sulfolane',
    '126-33-0',
    'HXJUTPCZVOIRIF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='thiophene, tetrahydro-, 1,1-dioxide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-(ethylthio)ethanol',
    'C<sub>4</sub>H<sub>10</sub>OS',
    '',
    '110-77-0',
    'LNRIEBFNWGMXKP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(ethylthio)ethanol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'thiodiglycol',
    'C<sub>4</sub>H<sub>10</sub>O<sub>2</sub>S',
    '',
    '111-48-8',
    'YODZTKMDCQEPHD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='thiodiglycol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methanesulfonic acid, 1-methylethyl ester',
    'C<sub>4</sub>H<sub>10</sub>O<sub>3</sub>S',
    '',
    '926-06-7',
    'SWWHCQCMVCPLEQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanesulfonic acid, 1-methylethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diethyl sulfate',
    'C<sub>4</sub>H<sub>10</sub>O<sub>4</sub>S',
    '',
    '64-67-5',
    'DENRZWYUOJLTMF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6',
    '',
    '?',
    (SELECT id from species WHERE iupac='diethyl sulfate'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'S-methyl butanethioate',
    'C<sub>5</sub>H<sub>10</sub>OS',
    '',
    '2432-51-1',
    'GRLJIIJNZJVMGP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='S-methyl butanethioate'),
    (SELECT id from literature WHERE bibtexkey='3671'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-hydroxybenzenesulfonic acid',
    'C<sub>6</sub>H<sub>6</sub>O<sub>4</sub>S',
    '',
    '98-67-9',
    'FEPBITJSIHRMRT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-hydroxybenzenesulfonic acid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benzenesulfonic acid',
    'C<sub>6</sub>H<sub>6</sub>O<sub>3</sub>S',
    '',
    '98-11-3',
    'SRSXLGNVWSONIS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzenesulfonic acid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimethipin',
    'C<sub>6</sub>H<sub>10</sub>O<sub>4</sub>S<sub>2</sub>',
    '',
    '55290-64-7',
    'PHVNLLCAQHGNKU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dimethipin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethipin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dimethipin'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methylbenzenesulfonic acid',
    'C<sub>7</sub>H<sub>8</sub>O<sub>3</sub>S',
    '',
    '104-15-4',
    'JOXIMZWYDAKGHI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylbenzenesulfonic acid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phenylmethanesulfonic acid',
    'C<sub>7</sub>H<sub>8</sub>O<sub>3</sub>S',
    'benzylsulfonic acid',
    '100-87-8',
    'NIXKBAZVOQAHGC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenylmethanesulfonic acid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'isoprothiolane',
    'C<sub>12</sub>H<sub>18</sub>O<sub>4</sub>S<sub>2</sub>',
    '',
    '50512-35-1',
    'UFHLMYOGRXOCSL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='isoprothiolane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isoprothiolane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,4''-sulfonyldiphenol',
    'C<sub>12</sub>H<sub>10</sub>O<sub>4</sub>S',
    'bisphenol S',
    '80-09-1',
    'VPWNQTHUCYMVMZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4''-sulfonyldiphenol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benfuresate',
    'C<sub>12</sub>H<sub>16</sub>O<sub>4</sub>S',
    '',
    '68505-69-1',
    'QGQSRQPXXMTJCM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='benfuresate'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'lauryl sulfate',
    'C<sub>12</sub>H<sub>26</sub>O<sub>4</sub>S',
    'dodecyl sulfate',
    '151-41-7',
    'MOTZDAYCYVMXPC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='lauryl sulfate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethofumesate',
    'C<sub>13</sub>H<sub>18</sub>O<sub>5</sub>S',
    '',
    '26225-79-6',
    'IRCMYGHHKLLGHV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethofumesate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethofumesate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethofumesate'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethofumesate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethofumesate'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethofumesate'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1''-sulfonylbis(4-(1-methylethyl)-benzene',
    'C<sub>18</sub>H<sub>22</sub>O<sub>2</sub>S',
    '',
    '57913-35-6',
    'PKQWGBLKCJIMDP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1''-sulfonylbis(4-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1''-sulfonylbis(4-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1''-sulfonylbis(4-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1''-sulfonylbis(4-(1-methylethyl)-benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propargite',
    'C<sub>19</sub>H<sub>26</sub>O<sub>4</sub>S',
    '',
    '2312-35-8',
    'ZYHMJXZULPZUED-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propargite'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propargite'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propargite'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'kadethrin',
    'C<sub>23</sub>H<sub>24</sub>O<sub>4</sub>S',
    '',
    '58769-20-3',
    'UGWALRUNBSBTGI-QJLCOAGJSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='kadethrin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'spironolactone',
    'C<sub>24</sub>H<sub>32</sub>O<sub>4</sub>S',
    '',
    '52-01-7',
    'LXMSZDCAJNLERA-PJKOONHHSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='spironolactone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2''-thiobis(4-(1,1,3,3-tetramethylbutyl)phenol)',
    'C<sub>28</sub>H<sub>42</sub>O<sub>2</sub>S',
    '',
    '3294-03-9',
    'WQYFETFRIRDUPJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2''-thiobis(4-(1,1,3,3-tetramethylbutyl)phenol)'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2''-thiobis(4-(1,1,3,3-tetramethylbutyl)phenol)'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2''-thiobis(4-(1,1,3,3-tetramethylbutyl)phenol)'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2''-thiobis(4-(1,1,3,3-tetramethylbutyl)phenol)'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propanoic acid, 3,3''-thiobis-, didodecyl ester',
    'C<sub>30</sub>H<sub>58</sub>O<sub>4</sub>S',
    'dilauryl thiodipropionate',
    '123-28-4',
    'GHKOFFNLGXMVNJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propanoic acid, 3,3''-thiobis-, didodecyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dioctadecyl 3,3''-thiodipropionate',
    'C<sub>42</sub>H<sub>82</sub>O<sub>4</sub>S',
    '',
    '693-36-7',
    'PWWSSIYVTQUJQQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dioctadecyl 3,3''-thiodipropionate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl isothiocyanate',
    'CH<sub>3</sub>NCS',
    '',
    '556-61-6',
    'LGDSHSYDSCRFAB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='methyl isothiocyanate'),
    (SELECT id from literature WHERE bibtexkey='3500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='methyl isothiocyanate'),
    (SELECT id from literature WHERE bibtexkey='3245'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='methyl isothiocyanate'),
    (SELECT id from literature WHERE bibtexkey='2626'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methyl isothiocyanate'),
    (SELECT id from literature WHERE bibtexkey='2804'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl isothiocyanate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methyl isothiocyanate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl isothiocyanate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl isothiocyanate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'thiourea',
    'CH<sub>4</sub>N<sub>2</sub>S',
    '',
    '62-56-6',
    'UMGDCJDMYOKAJW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='thiourea'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='thiourea'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='thiourea'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hydrazinecarbothioamide',
    'CH<sub>5</sub>N<sub>3</sub>S',
    '1-amino-2-thiourea',
    '79-19-6',
    'BRWIZMBXBAOCCF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydrazinecarbothioamide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'thiocyanic acid, methyl ester',
    'C<sub>2</sub>H<sub>3</sub>NS',
    '',
    '556-64-9',
    'VYHVQEYOFIYNJP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='thiocyanic acid, methyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethanethioamide',
    'C<sub>2</sub>H<sub>5</sub>NS',
    'thioacetamide',
    '62-55-5',
    'YUKQRDCYNOVPGJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethanethioamide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'mercaptamine',
    'C<sub>2</sub>H<sub>7</sub>NS',
    'cysteamine',
    '60-23-1',
    'UFULAYFCSOUIOV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='mercaptamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'thiocyanic acid, ethyl ester',
    'C<sub>3</sub>H<sub>5</sub>NS',
    '',
    '542-90-5',
    'WFCLYEAZTHWNEH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='thiocyanic acid, ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-imidazolidinethione',
    'C<sub>3</sub>H<sub>6</sub>N<sub>2</sub>S',
    'ethylene thiourea',
    '96-45-7',
    'PDQAZBWRQCGBEV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-imidazolidinethione'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethylthiourea',
    'C<sub>3</sub>H<sub>8</sub>N<sub>2</sub>S',
    '',
    '625-53-6',
    'GMEHFXXZSWDEDB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethylthiourea'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'allyl isothiocyanate',
    'C<sub>4</sub>H<sub>5</sub>NS',
    '',
    '57-06-7',
    'ZOJBYZNEUISWFT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='allyl isothiocyanate'),
    (SELECT id from literature WHERE bibtexkey='3671'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='allyl isothiocyanate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='allyl isothiocyanate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='allyl isothiocyanate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='allyl isothiocyanate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dazomet',
    'C<sub>5</sub>H<sub>10</sub>N<sub>2</sub>S<sub>2</sub>',
    '',
    '533-74-4',
    'QAYICIQNSGETAS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dazomet'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dazomet'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dazomet'),
    (SELECT id from literature WHERE bibtexkey='macbean2012'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dazomet'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dazomet'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N,N''-diethylthiourea',
    'C<sub>5</sub>H<sub>12</sub>N<sub>2</sub>S',
    '',
    '105-55-5',
    'FLVIGYVXZHLUHP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N,N''-diethylthiourea'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tetramethylthiourea',
    'C<sub>5</sub>H<sub>12</sub>N<sub>2</sub>S',
    '',
    '2782-91-4',
    'MNOILHPDHOHILI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetramethylthiourea'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'thiram',
    'C<sub>6</sub>H<sub>12</sub>N<sub>2</sub>S<sub>4</sub>',
    '',
    '137-26-8',
    'KUAZQDVKQLNFPE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='thiram'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='thiram'),
    (SELECT id from literature WHERE bibtexkey='macbean2012'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bis(dimethylthiocarbamyl) sulfide',
    'C<sub>6</sub>H<sub>12</sub>N<sub>2</sub>S<sub>3</sub>',
    'bis(dimethylthiocarbamoyl) sulfide',
    '97-74-5',
    'REQPQFUJGGOFQL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis(dimethylthiocarbamyl) sulfide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benzothiazole',
    'C<sub>7</sub>H<sub>5</sub>NS',
    '',
    '95-16-9',
    'IOJUPLGTWVMSFF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzothiazole'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzothiazole'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzothiazole'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzothiazole'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzothiazole'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-mercaptobenzothiazole',
    'C<sub>7</sub>H<sub>5</sub>NS<sub>2</sub>',
    '',
    '149-30-4',
    'YXIWHUQXZSMYRE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-mercaptobenzothiazole'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-mercaptobenzothiazole'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-mercaptobenzothiazole'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-mercaptobenzothiazole'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-mercaptobenzothiazole'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-benzothiazolamine',
    'C<sub>7</sub>H<sub>6</sub>N<sub>2</sub>S',
    '',
    '136-95-8',
    'UHGULLIUJBCTEF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-benzothiazolamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phenylthiourea',
    'C<sub>7</sub>H<sub>8</sub>N<sub>2</sub>S',
    '',
    '103-85-5',
    'FULZLIGZKMKICU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenylthiourea'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'aziprotryn',
    'C<sub>7</sub>H<sub>11</sub>N<sub>7</sub>S',
    '',
    '4658-28-0',
    'AFIIBUOYKYSPKB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='aziprotryn'),
    (SELECT id from literature WHERE bibtexkey='2526'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='aziprotryn'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'isothiocyanatobenzene',
    'C<sub>7</sub>H<sub>5</sub>NS',
    '',
    '103-72-0',
    'QKFJKGMPGYROCL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='isothiocyanatobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isothiocyanatobenzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'simetryn',
    'C<sub>8</sub>H<sub>15</sub>N<sub>5</sub>S',
    '',
    '1014-70-6',
    'MGLWZSOBALDPEK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='simetryn'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='simetryn'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='simetryn'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='simetryn'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='simetryn'),
    (SELECT id from literature WHERE bibtexkey='2526'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'desmetryn',
    'C<sub>8</sub>H<sub>15</sub>N<sub>5</sub>S',
    '',
    '1014-69-3',
    'HCRWJJJUKUVORR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='desmetryn'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>7</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='desmetryn'),
    (SELECT id from literature WHERE bibtexkey='1931'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='desmetryn'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='desmetryn'),
    (SELECT id from literature WHERE bibtexkey='2526'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='desmetryn'),
    (SELECT id from literature WHERE bibtexkey='1931'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='desmetryn'),
    (SELECT id from literature WHERE bibtexkey='1931'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='desmetryn'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'thioquinox',
    'C<sub>9</sub>H<sub>4</sub>N<sub>2</sub>S<sub>3</sub>',
    '',
    '93-75-4',
    'ILERPRJWJPJZDN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='thioquinox'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'thiocyanic acid, (2-benzothiazolylthio)methyl ester',
    'C<sub>9</sub>H<sub>6</sub>N<sub>2</sub>S<sub>3</sub>',
    '',
    '21564-17-0',
    'TUBQDCKAWGHZPF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='thiocyanic acid, (2-benzothiazolylthio)methyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ametryn',
    'C<sub>9</sub>H<sub>17</sub>N<sub>5</sub>S',
    '',
    '834-12-8',
    'RQVYBGPQFYCBGX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='ametryn'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ametryn'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ametryn'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ametryn'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ametryn'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='ametryn'),
    (SELECT id from literature WHERE bibtexkey='1931'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ametryn'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ametryn'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ametryn'),
    (SELECT id from literature WHERE bibtexkey='2526'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ametryn'),
    (SELECT id from literature WHERE bibtexkey='1931'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ametryn'),
    (SELECT id from literature WHERE bibtexkey='1931'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cimetidine',
    'C<sub>10</sub>H<sub>16</sub>N<sub>6</sub>S',
    '',
    '51481-61-9',
    'AQIXAKUUQRKLND-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cimetidine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'prometryn',
    'C<sub>10</sub>H<sub>19</sub>N<sub>5</sub>S',
    '',
    '7287-19-6',
    'AAEVYOVXGOFMJO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='prometryn'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='prometryn'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='prometryn'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='prometryn'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>6</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='prometryn'),
    (SELECT id from literature WHERE bibtexkey='1931'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='prometryn'),
    (SELECT id from literature WHERE bibtexkey='1931'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='prometryn'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='prometryn'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='prometryn'),
    (SELECT id from literature WHERE bibtexkey='2526'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='prometryn'),
    (SELECT id from literature WHERE bibtexkey='1931'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='prometryn'),
    (SELECT id from literature WHERE bibtexkey='1931'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'terbutryn',
    'C<sub>10</sub>H<sub>19</sub>N<sub>5</sub>S',
    '',
    '886-50-0',
    'IROINLKCQGIITA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='terbutryn'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='terbutryn'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='terbutryn'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6',
    '',
    'X',
    (SELECT id from species WHERE iupac='terbutryn'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>6</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='terbutryn'),
    (SELECT id from literature WHERE bibtexkey='1931'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>2</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='terbutryn'),
    (SELECT id from literature WHERE bibtexkey='1931'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='terbutryn'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='terbutryn'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='terbutryn'),
    (SELECT id from literature WHERE bibtexkey='2526'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='terbutryn'),
    (SELECT id from literature WHERE bibtexkey='1931'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='terbutryn'),
    (SELECT id from literature WHERE bibtexkey='1931'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'disulfiram',
    'C<sub>10</sub>H<sub>20</sub>N<sub>2</sub>S<sub>4</sub>',
    '',
    '97-77-8',
    'AUZONCFQVSMFAP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='disulfiram'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-naphthalenylthiourea',
    'C<sub>11</sub>H<sub>10</sub>N<sub>2</sub>S',
    '',
    '86-88-4',
    'PIVQQUNOTICCSA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-naphthalenylthiourea'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,4''-thiobisbenzenamine',
    'C<sub>12</sub>H<sub>12</sub>N<sub>2</sub>S',
    'bis(4-aminophenyl) sulfide',
    '139-65-1',
    'ICNFHJVPAJKPHW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4''-thiobisbenzenamine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dipropetryn',
    'C<sub>11</sub>H<sub>19</sub>N<sub>5</sub>S',
    '',
    '4147-51-7',
    'NPWMZOGDXOFZIN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dipropetryn'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dipropetryn'),
    (SELECT id from literature WHERE bibtexkey='2526'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dipropetryn'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimethametryn',
    'C<sub>11</sub>H<sub>21</sub>N<sub>5</sub>S',
    '',
    '22936-75-0',
    'IKYICRRUVNIHPP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethametryn'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethametryn'),
    (SELECT id from literature WHERE bibtexkey='2526'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phenothiazine',
    'C<sub>12</sub>H<sub>9</sub>NS',
    '',
    '92-84-2',
    'WJFKNYWRSNBZNX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenothiazine'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenothiazine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenothiazine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenothiazine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenothiazine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenothiazine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cymiazole',
    'C<sub>12</sub>H<sub>14</sub>N<sub>2</sub>S',
    '',
    '61676-87-7',
    'YUAUPYJCVKNAEC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cymiazole'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2''-dithiobisbenzothiazole',
    'C<sub>14</sub>H<sub>8</sub>N<sub>2</sub>S<sub>4</sub>',
    '2,2''-dibenzothiazyl disulfide',
    '120-78-5',
    'AFZSMODLJJCVPP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2''-dithiobisbenzothiazole'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methapyrilene',
    'C<sub>14</sub>H<sub>19</sub>N<sub>3</sub>S',
    '',
    '91-80-5',
    'HNJJXZKZRAWDPF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methapyrilene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'olanzapine',
    'C<sub>17</sub>H<sub>20</sub>N<sub>4</sub>S',
    '',
    '132539-06-1',
    'KVWDHTXUZHCGIO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='olanzapine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-(1,1-dimethylethyl)bis(2-benzothiazolesulfen)amide',
    'C<sub>18</sub>H<sub>17</sub>N<sub>3</sub>S<sub>4</sub>',
    '',
    '3741-80-8',
    'VILGDADBAQFRJE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-(1,1-dimethylethyl)bis(2-benzothiazolesulfen)amide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-(1,1-dimethylethyl)bis(2-benzothiazolesulfen)amide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-(1,1-dimethylethyl)bis(2-benzothiazolesulfen)amide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-(1,1-dimethylethyl)bis(2-benzothiazolesulfen)amide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'buthiobate',
    'C<sub>21</sub>H<sub>28</sub>N<sub>2</sub>S<sub>2</sub>',
    '',
    '51308-54-4',
    'ZZVVDIVWGXTDRQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='buthiobate'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CH3SO4NO2',
    'CH<sub>3</sub>NO<sub>6</sub>S',
    '',
    '',
    'IMLJWBRSRKRPAQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3SO4NO2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3SO4NO2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3SO4NO2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'MCM:CH3SOO2NO2',
    'CH<sub>3</sub>NO<sub>5</sub>S',
    '',
    '',
    'PGTDFOBGUOOGGZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3SOO2NO2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3SOO2NO2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='MCM:CH3SOO2NO2'),
    (SELECT id from literature WHERE bibtexkey='3409'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3409-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'taurine',
    'C<sub>2</sub>H<sub>7</sub>NO<sub>3</sub>S',
    '',
    '107-35-7',
    'XOAAWQZATWQOTB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='taurine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-amino-5-nitrothiazole',
    'C<sub>3</sub>H<sub>3</sub>N<sub>3</sub>O<sub>2</sub>S',
    '',
    '121-66-4',
    'MIHADVKEHAFNPG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-amino-5-nitrothiazole'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-(aminothioxomethyl)acetamide',
    'C<sub>3</sub>H<sub>6</sub>N<sub>2</sub>OS',
    '1-acetyl-2-thiourea',
    '591-08-2',
    'IPCRBOOJBPETMF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-(aminothioxomethyl)acetamide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'acesulfame',
    'C<sub>4</sub>H<sub>5</sub>NO<sub>4</sub>S',
    '',
    '33665-90-6',
    'YGCFIWIQZPHFLU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='acesulfame'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methomyl',
    'C<sub>5</sub>H<sub>10</sub>N<sub>2</sub>O<sub>2</sub>S',
    '',
    '16752-77-5',
    'UHXUZOCRWCRNSJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methomyl'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methomyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methomyl'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methomyl'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methomyl'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methomyl'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methomyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methomyl'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_val'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-aminobenzenesulfonic acid',
    'C<sub>6</sub>H<sub>7</sub>NO<sub>3</sub>S',
    'sulfanilic acid',
    '121-57-3',
    'HVBSAKJJOYLTQU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-aminobenzenesulfonic acid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'sulfanilamide',
    'C<sub>6</sub>H<sub>8</sub>N<sub>2</sub>O<sub>2</sub>S',
    '',
    '63-74-1',
    'FDDDEECHVMSUSB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='sulfanilamide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nithiazide',
    'C<sub>6</sub>H<sub>8</sub>N<sub>4</sub>O<sub>3</sub>S',
    '',
    '139-94-6',
    'FQSUTLQHSDLLAN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nithiazide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methylbenzenesulfonamide',
    'C<sub>7</sub>H<sub>9</sub>NO<sub>2</sub>S',
    'o-toluenesulfonamide',
    '88-19-7',
    'YCMLQMDWSXFTIF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methylbenzenesulfonamide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methylbenzenesulfonamide',
    'C<sub>7</sub>H<sub>9</sub>NO<sub>2</sub>S',
    'p-toluenesulfonamide',
    '70-55-3',
    'LMYRWZFENFIFIT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylbenzenesulfonamide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethidimuron',
    'C<sub>7</sub>H<sub>12</sub>N<sub>4</sub>O<sub>3</sub>S<sub>2</sub>',
    '',
    '30043-49-3',
    'KCOCSOWTADCKOL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>8</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethidimuron'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'oxamyl',
    'C<sub>7</sub>H<sub>13</sub>N<sub>3</sub>O<sub>3</sub>S',
    '',
    '23135-22-0',
    'KZAUOCCYDRDERY-UITAMQMPSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='oxamyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='oxamyl'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='oxamyl'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='oxamyl'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='oxamyl'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='oxamyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='oxamyl'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='oxamyl'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'aldicarb',
    'C<sub>7</sub>H<sub>14</sub>N<sub>2</sub>O<sub>2</sub>S',
    '',
    '116-06-3',
    'QGLZXHRNAYXIBU-WEVVVXLNSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='aldicarb'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='aldicarb'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='aldicarb'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='aldicarb'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='aldicarb'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    'C',
    (SELECT id from species WHERE iupac='aldicarb'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='aldicarb'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='aldicarb'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_test'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'aldicarb sulfoxide',
    'C<sub>7</sub>H<sub>14</sub>N<sub>2</sub>O<sub>3</sub>S',
    '',
    '1646-87-3',
    'BXPMAGSOWXBZHS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='aldicarb sulfoxide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='aldicarb sulfoxide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'aldicarb sulfone',
    'C<sub>7</sub>H<sub>14</sub>N<sub>2</sub>O<sub>4</sub>S',
    '',
    '1646-88-4',
    'YRRKLBAKDXSTNC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='aldicarb sulfone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='aldicarb sulfone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='aldicarb sulfone'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'butocarboxim',
    'C<sub>7</sub>H<sub>14</sub>N<sub>2</sub>O<sub>2</sub>S',
    '',
    '34681-10-2',
    'SFNPDDSJBGRXLW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butocarboxim'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='butocarboxim'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'butoxycarboxim',
    'C<sub>7</sub>H<sub>14</sub>N<sub>2</sub>O<sub>4</sub>S',
    '',
    '34681-23-7',
    'CTJBHIROCMPUKL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butoxycarboxim'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'saccharin',
    'C<sub>7</sub>H<sub>5</sub>NO<sub>3</sub>S',
    '',
    '81-07-2',
    'CVHZOJJKTDOEJC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='saccharin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'acibenzolar-S-methyl',
    'C<sub>8</sub>H<sub>6</sub>N<sub>2</sub>OS<sub>2</sub>',
    '',
    '135158-54-2',
    'UELITFHSCLAHKR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='acibenzolar-S-methyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='acibenzolar-S-methyl'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='acibenzolar-S-methyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='acibenzolar-S-methyl'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'quinomethionate',
    'C<sub>8</sub>H<sub>6</sub>N<sub>2</sub>OS<sub>2</sub>',
    '',
    '2439-01-2',
    'FBQQHUGEACOBDN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='quinomethionate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='quinomethionate'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nifurthiazole',
    'C<sub>8</sub>H<sub>6</sub>N<sub>4</sub>O<sub>4</sub>S',
    '',
    '3570-75-0',
    'DUWYZHLZDVCZIO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>12</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nifurthiazole'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methylbenzenesulfonyl isocyanate',
    'C<sub>8</sub>H<sub>7</sub>NO<sub>3</sub>S',
    '',
    '4083-64-1',
    'VLJQDHDVZJXNQL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylbenzenesulfonyl isocyanate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylbenzenesulfonyl isocyanate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylbenzenesulfonyl isocyanate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylbenzenesulfonyl isocyanate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tinidazole',
    'C<sub>8</sub>H<sub>13</sub>N<sub>3</sub>O<sub>4</sub>S',
    '',
    '19387-91-8',
    'HJLSLZFTEKNLFI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tinidazole'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'metribuzin',
    'C<sub>8</sub>H<sub>14</sub>N<sub>4</sub>OS',
    '',
    '21087-64-9',
    'FOXFZRUHNHCZPX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='metribuzin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='metribuzin'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tricyclazole',
    'C<sub>9</sub>H<sub>7</sub>N<sub>3</sub>S',
    '',
    '41814-78-2',
    'DQJCHOQLCLEDLL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tricyclazole'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tricyclazole'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tricyclazole'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benzthiazuron',
    'C<sub>9</sub>H<sub>9</sub>N<sub>3</sub>OS',
    '',
    '1929-88-0',
    'DTCJYIIKPVRVDD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='benzthiazuron'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'thidiazuron',
    'C<sub>9</sub>H<sub>8</sub>N<sub>4</sub>OS',
    '',
    '51707-55-2',
    'HFCYZXMHUIHAQI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>7</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='thidiazuron'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'sulfathiazole',
    'C<sub>9</sub>H<sub>9</sub>N<sub>3</sub>O<sub>2</sub>S<sub>2</sub>',
    '',
    '72-14-0',
    'JNMRHUJNCSQMMB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='sulfathiazole'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'sulfamethizole',
    'C<sub>9</sub>H<sub>10</sub>N<sub>4</sub>O<sub>2</sub>S<sub>2</sub>',
    '',
    '144-82-1',
    'VACCAVUAMIDAGB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='sulfamethizole'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethiozin',
    'C<sub>9</sub>H<sub>16</sub>N<sub>4</sub>OS',
    '',
    '64529-56-2',
    'ADZSGNDOZREKJK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethiozin'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tebuthiuron',
    'C<sub>9</sub>H<sub>16</sub>N<sub>4</sub>OS',
    '',
    '34014-18-1',
    'HBPDKDSFLXWOAE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tebuthiuron'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tebuthiuron'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tebuthiuron'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'molinate',
    'C<sub>9</sub>H<sub>17</sub>NOS',
    '',
    '2212-67-1',
    'DEDOPGXGGQYYMW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7',
    '',
    'M',
    (SELECT id from species WHERE iupac='molinate'),
    (SELECT id from literature WHERE bibtexkey='2538'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'M',
    (SELECT id from species WHERE iupac='molinate'),
    (SELECT id from literature WHERE bibtexkey='1142'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '7300',
    'M',
    (SELECT id from species WHERE iupac='molinate'),
    (SELECT id from literature WHERE bibtexkey='1142'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9',
    '',
    'V',
    (SELECT id from species WHERE iupac='molinate'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='molinate'),
    (SELECT id from literature WHERE bibtexkey='1142'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='molinate'),
    (SELECT id from literature WHERE bibtexkey='3090'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6',
    '',
    'C',
    (SELECT id from species WHERE iupac='molinate'),
    (SELECT id from literature WHERE bibtexkey='3073'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='molinate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='molinate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'thiofanox',
    'C<sub>9</sub>H<sub>18</sub>N<sub>2</sub>O<sub>2</sub>S',
    '',
    '39196-18-4',
    'FZSVSABTBYGOQH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='thiofanox'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='thiofanox'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'amidosulfuron',
    'C<sub>9</sub>H<sub>15</sub>N<sub>5</sub>O<sub>7</sub>S<sub>2</sub>',
    '',
    '120923-37-7',
    'CTTHWASMBLQOFR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='amidosulfuron'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH7'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='amidosulfuron'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH4'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='amidosulfuron'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH9'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'S-ethyl dipropylthiocarbamate',
    'C<sub>9</sub>H<sub>19</sub>NOS',
    'eptam; EPTC',
    '759-94-4',
    'GUVLYNGULCJVDO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;1</sup>',
    '9100',
    'M',
    (SELECT id from species WHERE iupac='S-ethyl dipropylthiocarbamate'),
    (SELECT id from literature WHERE bibtexkey='2815'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '4800',
    'M',
    (SELECT id from species WHERE iupac='S-ethyl dipropylthiocarbamate'),
    (SELECT id from literature WHERE bibtexkey='2241'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='S-ethyl dipropylthiocarbamate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='S-ethyl dipropylthiocarbamate'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='S-ethyl dipropylthiocarbamate'),
    (SELECT id from literature WHERE bibtexkey='2241'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='S-ethyl dipropylthiocarbamate'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='S-ethyl dipropylthiocarbamate'),
    (SELECT id from literature WHERE bibtexkey='2968'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='S-ethyl dipropylthiocarbamate'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='S-ethyl dipropylthiocarbamate'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='S-ethyl dipropylthiocarbamate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='S-ethyl dipropylthiocarbamate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4800',
    'Q',
    (SELECT id from species WHERE iupac='S-ethyl dipropylthiocarbamate'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4800',
    '?',
    (SELECT id from species WHERE iupac='S-ethyl dipropylthiocarbamate'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'thiabendazole',
    'C<sub>10</sub>H<sub>7</sub>N<sub>3</sub>S',
    '',
    '148-79-8',
    'WJCNZQLZVWNLKY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='thiabendazole'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='thiabendazole'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='thiabendazole'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='thiabendazole'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='thiabendazole'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benzo[b]thiophene-4-ol, methylcarbamate',
    'C<sub>10</sub>H<sub>9</sub>NO<sub>2</sub>S',
    'mobam',
    '1079-33-0',
    'BOTUVXISJHKZKJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzo[b]thiophene-4-ol, methylcarbamate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'sulfamethoxazole',
    'C<sub>10</sub>H<sub>11</sub>N<sub>3</sub>O<sub>3</sub>S',
    '',
    '723-46-6',
    'JLKIGFTWXXRPMT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='sulfamethoxazole'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bentazone',
    'C<sub>10</sub>H<sub>12</sub>N<sub>2</sub>O<sub>3</sub>S',
    '',
    '25057-89-0',
    'ZOMSMJKLGFBRBS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bentazone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='bentazone'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bentazone'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='bentazone'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='bentazone'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'buthidazole',
    'C<sub>10</sub>H<sub>16</sub>N<sub>4</sub>O<sub>2</sub>S',
    '',
    '55511-98-3',
    'SWMGXKSQWDSBKV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='buthidazole'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'thiodicarb',
    'C<sub>10</sub>H<sub>18</sub>N<sub>4</sub>O<sub>4</sub>S<sub>3</sub>',
    '',
    '59669-26-0',
    'XDOTVMNBCQVZKG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='thiodicarb'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='thiodicarb'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pebulate',
    'C<sub>10</sub>H<sub>21</sub>NOS',
    '',
    '1114-71-2',
    'SGEJQUSYQTVSIU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pebulate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pebulate'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pebulate'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='pebulate'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pebulate'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pebulate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pebulate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 2.3&times;10<sup>10</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pebulate'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'vernolate',
    'C<sub>10</sub>H<sub>21</sub>NOS',
    '',
    '1929-77-7',
    'OKUGPJPKMAEJOE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='vernolate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='vernolate'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='vernolate'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='vernolate'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='vernolate'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='vernolate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='vernolate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'biotin',
    'C<sub>10</sub>H<sub>16</sub>N<sub>2</sub>O<sub>3</sub>S',
    '',
    '58-85-5',
    'YBJHBAHKTGYVGT-ZKWXMUAHSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='biotin'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methabenzthiazuron',
    'C<sub>10</sub>H<sub>11</sub>N<sub>3</sub>OS',
    '',
    '18691-97-9',
    'RRVIAQKBTUQODI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methabenzthiazuron'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methabenzthiazuron'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'sulfisoxazole',
    'C<sub>11</sub>H<sub>13</sub>N<sub>3</sub>O<sub>3</sub>S',
    '',
    '127-69-5',
    'NHUHCSRWZMLRLA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='sulfisoxazole'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethiofencarb',
    'C<sub>11</sub>H<sub>15</sub>NO<sub>2</sub>S',
    '',
    '29973-13-5',
    'HEZNVIYQEUHLNI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethiofencarb'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethiofencarb'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethiofencarb'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methiocarb',
    'C<sub>11</sub>H<sub>15</sub>NO<sub>2</sub>S',
    '',
    '2032-65-7',
    'YFBPRJGDJKVWAH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3',
    '',
    'V',
    (SELECT id from species WHERE iupac='methiocarb'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methiocarb'),
    (SELECT id from literature WHERE bibtexkey='macbean2012'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cycloate',
    'C<sub>11</sub>H<sub>21</sub>NOS',
    '',
    '1134-23-2',
    'DFCAFRGABIXSDS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    'V',
    (SELECT id from species WHERE iupac='cycloate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cycloate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cycloate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methoprotryn',
    'C<sub>11</sub>H<sub>21</sub>N<sub>5</sub>OS',
    '',
    '841-06-5',
    'DDUIUBPJPOKOMV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methoprotryn'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methoprotryn'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methoprotryn'),
    (SELECT id from literature WHERE bibtexkey='2526'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methoprotryn'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'butylate',
    'C<sub>11</sub>H<sub>23</sub>NOS',
    '',
    '2008-41-5',
    'BMTAFVWTTFSTOG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='butylate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='butylate'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2614_pc_problem'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'V',
    (SELECT id from species WHERE iupac='butylate'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='butylate'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butylate'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butylate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butylate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-octyl-3(2H)-isothiazolone',
    'C<sub>11</sub>H<sub>19</sub>NOS',
    '',
    '26530-20-1',
    'JPMIIZHYYWMHDT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-octyl-3(2H)-isothiazolone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-octyl-3(2H)-isothiazolone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'metsulfovax',
    'C<sub>12</sub>H<sub>12</sub>N<sub>2</sub>OS',
    '',
    '21452-18-6',
    'UDSJPFPDKCMYBD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='metsulfovax'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'carboxin',
    'C<sub>12</sub>H<sub>13</sub>NO<sub>2</sub>S',
    '',
    '5234-68-4',
    'GYSSRZJIHXQEHQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='carboxin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='carboxin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='carboxin'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='carboxin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='carboxin'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'oxycarboxin',
    'C<sub>12</sub>H<sub>13</sub>NO<sub>4</sub>S',
    '',
    '5259-88-1',
    'AMEKQAFGQBKLKX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='oxycarboxin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='oxycarboxin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='oxycarboxin'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='oxycarboxin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'thifensulfuron-methyl',
    'C<sub>12</sub>H<sub>13</sub>N<sub>5</sub>O<sub>6</sub>S<sub>2</sub>',
    '',
    '79277-27-3',
    'AHTPATJNIAFOLR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>8</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='thifensulfuron-methyl'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>14</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='thifensulfuron-methyl'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH7'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>12</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='thifensulfuron-methyl'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH5'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'sulfamethazine',
    'C<sub>12</sub>H<sub>14</sub>N<sub>4</sub>O<sub>2</sub>S',
    '',
    '57-68-1',
    'ASWVTGNCAZCNNR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='sulfamethazine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'thiophanate-methyl',
    'C<sub>12</sub>H<sub>14</sub>N<sub>4</sub>O<sub>4</sub>S<sub>2</sub>',
    '',
    '23564-05-8',
    'QGHREAKMXXNCOA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='thiophanate-methyl'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='thiophanate-methyl'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='thiophanate-methyl'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4,4''-oxydi(benzenesulphonohydrazide)',
    'C<sub>12</sub>H<sub>14</sub>N<sub>4</sub>O<sub>5</sub>S<sub>2</sub>',
    '',
    '80-51-3',
    'NBOCQTNZUPTTEI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4,4''-oxydi(benzenesulphonohydrazide)'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'albendazole',
    'C<sub>12</sub>H<sub>15</sub>N<sub>3</sub>O<sub>2</sub>S',
    '',
    '54965-21-8',
    'HXHWSAZORRCQMX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='albendazole'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'oryzalin',
    'C<sub>12</sub>H<sub>18</sub>N<sub>4</sub>O<sub>6</sub>S',
    '',
    '19044-88-3',
    'UNAHYJYOSSSJHH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='oryzalin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='oryzalin'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='oryzalin'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH5'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>8</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='oryzalin'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH10'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='oryzalin'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH7'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'STK366145',
    'C<sub>12</sub>H<sub>19</sub>N<sub>3</sub>O<sub>3</sub>S',
    'N-(2-ethyl(3-methyl-4-nitrosophenyl)amino)ethyl)-methanesulfonamide',
    '56046-62-9',
    'XWQURWIJAIIPQP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='STK366145'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'isomethiozin',
    'C<sub>12</sub>H<sub>20</sub>N<sub>4</sub>OS',
    '',
    '57052-04-7',
    'MZTLOILRKLUURT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='isomethiozin'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'thiencarbazone-methyl',
    'C<sub>12</sub>H<sub>14</sub>N<sub>4</sub>O<sub>7</sub>S<sub>2</sub>',
    '',
    '317815-83-1',
    'XSKZXGDFSCCXQX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>12</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='thiencarbazone-methyl'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3549-pH3.9',
    '', 'At pH = 3.9.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH3.9'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>12</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='thiencarbazone-methyl'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH4'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>13</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='thiencarbazone-methyl'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH7'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>13</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='thiencarbazone-methyl'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH9'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,8-dinitrodibenzothiophene',
    'C<sub>12</sub>H<sub>6</sub>N<sub>2</sub>O<sub>4</sub>S',
    '',
    '109041-38-5',
    'VMQHOWOVMXIROE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,8-dinitrodibenzothiophene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-nitrodibenzothiophene',
    'C<sub>12</sub>H<sub>7</sub>NO<sub>2</sub>S',
    '',
    '6639-36-7',
    'GXLYVLHWXVRVKI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-nitrodibenzothiophene'),
    (SELECT id from literature WHERE bibtexkey='3400'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3400-COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'azimsulfuron',
    'C<sub>13</sub>H<sub>16</sub>N<sub>10</sub>O<sub>5</sub>S',
    '',
    '120162-55-2',
    'MAHPNPYYQAIOJN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>9</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='azimsulfuron'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH7'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>8</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='azimsulfuron'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH5'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>10</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='azimsulfuron'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH9'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fenothiocarb',
    'C<sub>13</sub>H<sub>19</sub>NO<sub>2</sub>S',
    '',
    '62850-32-2',
    'HMIBKHHNXANVHR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fenothiocarb'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'isobornyl thiocyanoacetate',
    'C<sub>13</sub>H<sub>19</sub>NO<sub>2</sub>S',
    '',
    '115-31-1',
    'IXEVGHXRXDBAOB-RUETXSTFSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isobornyl thiocyanoacetate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nitralin',
    'C<sub>13</sub>H<sub>19</sub>N<sub>3</sub>O<sub>6</sub>S',
    '',
    '4726-14-1',
    'UMKANAFDOQQUKE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='nitralin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='nitralin'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='nitralin'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bupirimate',
    'C<sub>13</sub>H<sub>24</sub>N<sub>4</sub>O<sub>3</sub>S',
    '',
    '41483-43-6',
    'DSKJPMWIHSOYEA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bupirimate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bupirimate'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bupirimate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='bupirimate'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'timolol',
    'C<sub>13</sub>H<sub>24</sub>N<sub>4</sub>O<sub>3</sub>S',
    '',
    '26839-75-8',
    'BLJRIMJGRPQVNF-JTQLQIEISA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='timolol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'triazamate',
    'C<sub>13</sub>H<sub>22</sub>N<sub>4</sub>O<sub>3</sub>S',
    '',
    '112143-82-5',
    'NKNFWVNSBIXGLL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='triazamate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triazamate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dithianone',
    'C<sub>14</sub>H<sub>4</sub>N<sub>2</sub>O<sub>2</sub>S<sub>2</sub>',
    '',
    '3347-22-6',
    'PYZSVQVRHDXQSL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dithianone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='dithianone'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2614_pc_problem'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dithianone'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-(cyclohexylthio)phthalimide',
    'C<sub>14</sub>H<sub>15</sub>NO<sub>2</sub>S',
    '',
    '17796-82-6',
    'UEZWYKZHXASYJN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-(cyclohexylthio)phthalimide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'metsulfuron-methyl',
    'C<sub>14</sub>H<sub>15</sub>N<sub>5</sub>O<sub>6</sub>S',
    '',
    '74223-64-6',
    'RSMUVYRMZCOLBH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>10</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='metsulfuron-methyl'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>8</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='metsulfuron-methyl'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'rimsulfuron',
    'C<sub>14</sub>H<sub>17</sub>N<sub>5</sub>O<sub>7</sub>S<sub>2</sub>',
    '',
    '122931-48-0',
    'MEFOUWRMVYJCQC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='rimsulfuron'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='rimsulfuron'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH9'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='rimsulfuron'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH5'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='rimsulfuron'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH7'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'thiophanate',
    'C<sub>14</sub>H<sub>18</sub>N<sub>4</sub>O<sub>4</sub>S<sub>2</sub>',
    '',
    '23564-06-9',
    'YFNCATAIYKQPOO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='thiophanate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'sumatriptan',
    'C<sub>14</sub>H<sub>21</sub>N<sub>3</sub>O<sub>2</sub>S',
    '',
    '103628-46-2',
    'KQKPFRSPSRPDEB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='sumatriptan'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'mesotrione',
    'C<sub>14</sub>H<sub>13</sub>NO<sub>7</sub>S',
    '',
    '104206-82-8',
    'KPUREKXXPHOJQT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 2.0&times;10<sup>6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='mesotrione'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'prosulfocarb',
    'C<sub>14</sub>H<sub>21</sub>NOS',
    '',
    '52888-80-9',
    'NQLVQOSNDJXLKG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='prosulfocarb'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='prosulfocarb'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='prosulfocarb'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pyriftalid',
    'C<sub>15</sub>H<sub>14</sub>N<sub>2</sub>O<sub>4</sub>S',
    '',
    '135186-78-6',
    'RRKHIAYNPVQKEF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pyriftalid'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nicosulfuron',
    'C<sub>15</sub>H<sub>18</sub>N<sub>6</sub>O<sub>6</sub>S',
    '',
    '111991-09-4',
    'RTCOGUMHFFWOJV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>10</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='nicosulfuron'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'sulfometuron methyl',
    'C<sub>15</sub>H<sub>16</sub>N<sub>4</sub>O<sub>5</sub>S',
    '',
    '74222-97-2',
    'ZDXMLEQEMNLCQG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>12</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='sulfometuron methyl'),
    (SELECT id from literature WHERE bibtexkey='3073'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='sulfometuron methyl'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tribenuron-methyl',
    'C<sub>15</sub>H<sub>17</sub>N<sub>5</sub>O<sub>6</sub>S',
    '',
    '101200-48-0',
    'VLCQZHSMCYCDJL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>7</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='tribenuron-methyl'),
    (SELECT id from literature WHERE bibtexkey='macbean2012'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tribenuron-methyl'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tribenuron-methyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tribenuron-methyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>9</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tribenuron-methyl'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH5'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 7.5&times;10<sup>9</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tribenuron-methyl'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH9'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethametsulfuron-methyl',
    'C<sub>15</sub>H<sub>18</sub>N<sub>6</sub>O<sub>6</sub>S',
    '',
    '97780-06-8',
    'ZINJLDJMHCUBIP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>9</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethametsulfuron-methyl'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propoxycarbazone',
    'C<sub>15</sub>H<sub>18</sub>N<sub>4</sub>O<sub>7</sub>S',
    '',
    '145026-81-9',
    'JTHMVYBOQLDDIY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propoxycarbazone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimepiperate',
    'C<sub>15</sub>H<sub>21</sub>NOS',
    '',
    '61432-55-1',
    'BWUPSGJXXPATLU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dimepiperate'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'esprocarb',
    'C<sub>15</sub>H<sub>23</sub>NOS',
    '',
    '85785-20-2',
    'BXEHUCNTIZGSOJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='esprocarb'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='esprocarb'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'valdecoxib',
    'C<sub>16</sub>H<sub>14</sub>N<sub>2</sub>O<sub>3</sub>S',
    '',
    '181695-72-7',
    'LNPDTQAFDNKSHK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='valdecoxib'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'topramezone',
    'C<sub>16</sub>H<sub>17</sub>N<sub>3</sub>O<sub>5</sub>S',
    '',
    '210631-68-8',
    'BPPVUXSMLBXYGG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>12</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='topramezone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'sulfosulfuron',
    'C<sub>16</sub>H<sub>18</sub>N<sub>6</sub>O<sub>7</sub>S<sub>2</sub>',
    '',
    '141776-32-1',
    'RBSXHDIPCIWOMG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='sulfosulfuron'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='sulfosulfuron'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH9'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='sulfosulfuron'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH5'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>8</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='sulfosulfuron'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH7'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'orthosulfamuron',
    'C<sub>16</sub>H<sub>20</sub>N<sub>6</sub>O<sub>6</sub>S',
    '',
    '213464-77-8',
    'UCDPMNSCCRBWIC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='orthosulfamuron'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cafenstrole',
    'C<sub>16</sub>H<sub>22</sub>N<sub>4</sub>O<sub>3</sub>S',
    '',
    '125306-83-4',
    'HFEJHAAIJZXXRE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cafenstrole'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'buprofezin',
    'C<sub>16</sub>H<sub>23</sub>N<sub>3</sub>OS',
    '',
    '69327-76-0',
    'PRLVTUNWOQKEAI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '',
    'V',
    (SELECT id from species WHERE iupac='buprofezin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'V',
    (SELECT id from species WHERE iupac='buprofezin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='buprofezin'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bensulfuron methyl',
    'C<sub>16</sub>H<sub>18</sub>N<sub>4</sub>O<sub>7</sub>S',
    '',
    '83055-99-6',
    'XMQFTWRPUQYINF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>10</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='bensulfuron methyl'),
    (SELECT id from literature WHERE bibtexkey='3073'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>12</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='bensulfuron methyl'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH9'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>10</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='bensulfuron methyl'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH7'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>9</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='bensulfuron methyl'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH5'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'mefenacet',
    'C<sub>16</sub>H<sub>14</sub>N<sub>2</sub>O<sub>2</sub>S',
    '',
    '73250-68-7',
    'XIGAUIHYSDTJHW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='mefenacet'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='mefenacet'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'alanycarb',
    'C<sub>17</sub>H<sub>25</sub>N<sub>3</sub>O<sub>4</sub>S<sub>2</sub>',
    '',
    '83130-01-2',
    'GMAUQNJOSOMMHI-JXAWBTAJSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='alanycarb'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='alanycarb'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fenamidone',
    'C<sub>17</sub>H<sub>17</sub>N<sub>3</sub>OS',
    '',
    '161326-34-7',
    'LMVPQMGRYSRMIW-KRWDZBQOSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fenamidone'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'esomeprazole',
    'C<sub>17</sub>H<sub>19</sub>N<sub>3</sub>O<sub>3</sub>S',
    '',
    '119141-88-7',
    'SUBDBMMJDZJVOS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>13</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='esomeprazole'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'foramsulfuron',
    'C<sub>17</sub>H<sub>20</sub>N<sub>6</sub>O<sub>7</sub>S',
    '',
    '173159-57-4',
    'PXDNXJSDGQBLKS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>11</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='foramsulfuron'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>11</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='foramsulfuron'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'sethoxydim',
    'C<sub>17</sub>H<sub>29</sub>NO<sub>3</sub>S',
    '',
    '74051-80-2',
    'NMHGOXYVOKDNHF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='sethoxydim'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'mesosulfuron-methyl',
    'C<sub>17</sub>H<sub>21</sub>N<sub>5</sub>O<sub>9</sub>S<sub>2</sub>',
    '',
    '208465-21-8',
    'NIFKBBMCXCMCAO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>10</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='mesosulfuron-methyl'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>12</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='mesosulfuron-methyl'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH9'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>11</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='mesosulfuron-methyl'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH7'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>9</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='mesosulfuron-methyl'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH5'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cycloxydim',
    'C<sub>17</sub>H<sub>27</sub>NO<sub>3</sub>S',
    '',
    '101205-02-1',
    'HAHCNFVGRVWFIP-VKAVYKQESA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cycloxydim'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fenpyrazamine',
    'C<sub>17</sub>H<sub>21</sub>N<sub>3</sub>O<sub>2</sub>S',
    '',
    '473798-59-3',
    'UTOHZQYBSYOOGC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fenpyrazamine'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cyprosulfamide',
    'C<sub>18</sub>H<sub>18</sub>N<sub>2</sub>O<sub>5</sub>S',
    '',
    '221667-31-8',
    'OAWUUPVZMNKZRY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cyprosulfamide'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH9'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cyprosulfamide'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH4'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cyprosulfamide'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH7'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'rosiglitazone',
    'C<sub>18</sub>H<sub>19</sub>N<sub>3</sub>O<sub>3</sub>S',
    '',
    '122320-73-4',
    'YASAKCUCGLMORW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='rosiglitazone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'rabeprazole',
    'C<sub>18</sub>H<sub>21</sub>N<sub>3</sub>O<sub>3</sub>S',
    '',
    '117976-89-3',
    'YREYEVIYCVEVJK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='rabeprazole'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pyributicarb',
    'C<sub>18</sub>H<sub>22</sub>N<sub>2</sub>O<sub>2</sub>S',
    '',
    '88678-67-5',
    'VTRWMTJQBQJKQH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pyributicarb'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'furathiocarb',
    'C<sub>18</sub>H<sub>26</sub>N<sub>2</sub>O<sub>5</sub>S',
    '',
    '65907-30-4',
    'HAWJXYBZNNRMNO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='furathiocarb'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'lincomycin',
    'C<sub>18</sub>H<sub>34</sub>N<sub>2</sub>O<sub>6</sub>S',
    '',
    '154-21-2',
    'OJMMVQQUTAEWLP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>17</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='lincomycin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pioglitazone',
    'C<sub>19</sub>H<sub>20</sub>N<sub>2</sub>O<sub>3</sub>S',
    '',
    '111025-46-8',
    'HYAFETHFCAUJAY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pioglitazone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'isofetamid',
    'C<sub>20</sub>H<sub>25</sub>NO<sub>3</sub>S',
    '',
    '875915-78-9',
    'WMKZDPFZIZQROT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='isofetamid'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tamsulosin',
    'C<sub>20</sub>H<sub>28</sub>N<sub>2</sub>O<sub>5</sub>S',
    '',
    '106133-20-4',
    'DRHKJLXJIQTDTD-OAHLLOKOSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tamsulosin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'carbosulfan',
    'C<sub>20</sub>H<sub>32</sub>N<sub>2</sub>O<sub>3</sub>S',
    '',
    '55285-14-8',
    'JLQUFIHWVLZVTJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='carbosulfan'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='carbosulfan'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'sufentanil',
    'C<sub>22</sub>H<sub>30</sub>N<sub>2</sub>O<sub>2</sub>S',
    '',
    '56030-54-7',
    'GGCSSNBKKAUURC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='sufentanil'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'sildenafil',
    'C<sub>22</sub>H<sub>30</sub>N<sub>6</sub>O<sub>4</sub>S',
    '',
    '139755-83-2',
    'BNRNXUUZRGQAQC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>15</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='sildenafil'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benfuracarb',
    'C<sub>20</sub>H<sub>30</sub>N<sub>2</sub>O<sub>5</sub>S',
    '',
    '82560-54-1',
    'FYZBOYWSHKHDMT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='benfuracarb'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tirofiban',
    'C<sub>22</sub>H<sub>36</sub>N<sub>2</sub>O<sub>5</sub>S',
    '',
    '144494-65-5',
    'COKMIXFXJJXBQG-NRFANRHFSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tirofiban'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'vardenafil',
    'C<sub>23</sub>H<sub>32</sub>N<sub>6</sub>O<sub>4</sub>S',
    '',
    '224785-90-4',
    'SECKRCOLJRRGGV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>15</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='vardenafil'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'taurocholic acid',
    'C<sub>26</sub>H<sub>45</sub>NO<sub>7</sub>S',
    '',
    '81-24-3',
    'WBWWGRHZICKQGZ-HZAMXZRMSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>15</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='taurocholic acid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dalfopristin',
    'C<sub>34</sub>H<sub>50</sub>N<sub>4</sub>O<sub>9</sub>S',
    '',
    '112362-50-2',
    'SUYRLXYYZQTJHF-FUODUHIRSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>24</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dalfopristin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'C.I. acid green 3',
    'C<sub>37</sub>H<sub>37</sub>N<sub>2</sub>O<sub>6</sub>S<sub>2</sub>',
    '',
    '4680-78-8',
    'SRRJCDUOSQWHGS-UHFFFAOYSA-O',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>23</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='C.I. acid green 3'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tinopal',
    'C<sub>40</sub>H<sub>40</sub>N<sub>12</sub>O<sub>8</sub>S<sub>2</sub>',
    '',
    '24231-46-7',
    'YGUMVDWOQQJBGA-VAWYXSNFSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>38</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tinopal'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>40</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tinopal'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>26</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tinopal'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>37</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tinopal'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'quinupristin',
    'C<sub>53</sub>H<sub>67</sub>N<sub>9</sub>O<sub>10</sub>S',
    '',
    '120138-50-3',
    'WTHRRGMBUAHGNI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>22</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='quinupristin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3,4,4,4-pentafluorobutane-1-thiol',
    'C<sub>4</sub>H<sub>5</sub>F<sub>5</sub>S',
    '',
    '68140-18-1',
    'WEILNYJKAUGBAU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4,4-pentafluorobutane-1-thiol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4,4-pentafluorobutane-1-thiol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4,4-pentafluorobutane-1-thiol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4,4-pentafluorobutane-1-thiol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3,4,4,5,5,6,6,6-nonafluoro-1-hexanethiol',
    'C<sub>6</sub>H<sub>5</sub>F<sub>9</sub>S',
    '',
    '68140-20-5',
    'GQJXVHYUQPXZOL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4,5,5,6,6,6-nonafluoro-1-hexanethiol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4,5,5,6,6,6-nonafluoro-1-hexanethiol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4,5,5,6,6,6-nonafluoro-1-hexanethiol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4,5,5,6,6,6-nonafluoro-1-hexanethiol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3,4,4,5,5,7,7,8,8,9,9,10,10,10-pentadecafluoro-1-decanethiol',
    'C<sub>10</sub>H<sub>7</sub>F<sub>15</sub>S',
    '',
    '68140-21-6',
    'ROKKEEDUUQVHFZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4,5,5,7,7,8,8,9,9,10,10,10-pentadecafluoro-1-decanethiol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4,5,5,7,7,8,8,9,9,10,10,10-pentadecafluoro-1-decanethiol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4,5,5,7,7,8,8,9,9,10,10,10-pentadecafluoro-1-decanethiol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4,5,5,7,7,8,8,9,9,10,10,10-pentadecafluoro-1-decanethiol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3,3,4,4,5,5-hexafluoro-1-(3,3,4,4,5,5-hexafluorohexyldisulfanyl)hexane',
    'C<sub>12</sub>H<sub>14</sub>F<sub>12</sub>S<sub>2</sub>',
    '',
    '118400-71-8',
    'CIZUOSOWGOENRE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4,5,5-hexafluoro-1-(3,3,4,4,5,5-hexafluorohexyldisulfanyl)hexane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4,5,5-hexafluoro-1-(3,3,4,4,5,5-hexafluorohexyldisulfanyl)hexane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4,5,5-hexafluoro-1-(3,3,4,4,5,5-hexafluorohexyldisulfanyl)hexane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='3,3,4,4,5,5-hexafluoro-1-(3,3,4,4,5,5-hexafluorohexyldisulfanyl)hexane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methanesulfonyl fluoride',
    'CH<sub>3</sub>FO<sub>2</sub>S',
    '',
    '558-25-8',
    'KNWQLFOXPQZGPX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methanesulfonyl fluoride'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'perfluorobutane sulfonic acid',
    'C<sub>4</sub>HF<sub>9</sub>O<sub>3</sub>S',
    'PFBS',
    '375-73-5',
    'JGTNAGYHADQMCM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'E',
    (SELECT id from species WHERE iupac='perfluorobutane sulfonic acid'),
    (SELECT id from literature WHERE bibtexkey='2991'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-(pentafluorosulfanyl)phenol',
    'C<sub>6</sub>H<sub>5</sub>F<sub>5</sub>OS',
    '',
    '774-94-7',
    'XHJLGVIUMCBMHL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-(pentafluorosulfanyl)phenol'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_O2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1H,1H,2H,2H-perfluorohexane sulfonic acid',
    'C<sub>6</sub>H<sub>5</sub>F<sub>9</sub>O<sub>3</sub>S',
    '4:2 FTS',
    '757124-72-4',
    'TXGIGTRUEITPSC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1H,1H,2H,2H-perfluorohexane sulfonic acid'),
    (SELECT id from literature WHERE bibtexkey='3939'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'perfluorohexane sulfonic acid',
    'C<sub>6</sub>HF<sub>13</sub>O<sub>3</sub>S',
    'PFHxS',
    '355-46-4',
    'QZHDEAJFRJCDMF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;1</sup>',
    '',
    'E',
    (SELECT id from species WHERE iupac='perfluorohexane sulfonic acid'),
    (SELECT id from literature WHERE bibtexkey='2991'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1H,1H,2H,2H-perfluorooctane sulfonic acid',
    'C<sub>8</sub>H<sub>5</sub>F<sub>13</sub>O<sub>3</sub>S',
    '6:2 FTS',
    '27619-97-2',
    'VIONGDJUYAYOPU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '11000',
    'M',
    (SELECT id from species WHERE iupac='1H,1H,2H,2H-perfluorooctane sulfonic acid'),
    (SELECT id from literature WHERE bibtexkey='3939'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'perfluorooctane sulfonic acid',
    'C<sub>8</sub>HF<sub>17</sub>O<sub>3</sub>S',
    'PFOS',
    '1763-23-1',
    'YFSUTJLHUFNCNZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='perfluorooctane sulfonic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='perfluorooctane sulfonic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='perfluorooctane sulfonic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='perfluorooctane sulfonic acid'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='perfluorooctane sulfonic acid'),
    (SELECT id from literature WHERE bibtexkey='2992'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2992SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='perfluorooctane sulfonic acid'),
    (SELECT id from literature WHERE bibtexkey='2992'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2992COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'heptadecafluorooctanesulphonyl fluoride',
    'C<sub>8</sub>F<sub>18</sub>O<sub>2</sub>S',
    'perfluorooctylsulfonyl fluoride',
    '307-35-7',
    'BHFJBHMTEDLICO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptadecafluorooctanesulphonyl fluoride'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1H,1H,2H,2H-perfluorodecane sulfonic acid',
    'C<sub>10</sub>H<sub>5</sub>F<sub>17</sub>O<sub>3</sub>S',
    '8:2 FTS',
    '39108-34-4',
    'ALVYVCQIFHTIRD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1H,1H,2H,2H-perfluorodecane sulfonic acid'),
    (SELECT id from literature WHERE bibtexkey='3939'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fluticasone',
    'C<sub>22</sub>H<sub>27</sub>F<sub>3</sub>O<sub>4</sub>S',
    '',
    '90566-53-3',
    'MGNNYOODZCAHBA-GQKYHHCASA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fluticasone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '3-aminophenylsulfur pentafluoride',
    'C<sub>6</sub>H<sub>6</sub>F<sub>5</sub>NS',
    '',
    '2993-22-8',
    'NUFLICUHOXHWER-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4',
    '',
    '?',
    (SELECT id from species WHERE iupac='3-aminophenylsulfur pentafluoride'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_O2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-aminophenylsulfur pentafluoride',
    'C<sub>6</sub>H<sub>6</sub>F<sub>5</sub>NS',
    '',
    '2993-24-0',
    'MZGZUHNSMNNSRJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-aminophenylsulfur pentafluoride'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_O2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'flubenzimine',
    'C<sub>17</sub>H<sub>10</sub>F<sub>6</sub>N<sub>4</sub>S',
    '',
    '37893-02-0',
    'IZFZCMFMJKDHJZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 2.3&times;10<sup>10</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='flubenzimine'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'thiazafluron',
    'C<sub>6</sub>H<sub>7</sub>F<sub>3</sub>N<sub>4</sub>OS',
    '',
    '25366-23-8',
    'BBJPZPLAZVZTGR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='thiazafluron'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-nitrophenylsulfur pentafluoride',
    'C<sub>6</sub>H<sub>4</sub>F<sub>5</sub>NO<sub>2</sub>S',
    '',
    '2613-27-6',
    'AGNCKMHGYZKMLN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-nitrophenylsulfur pentafluoride'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_O2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'undecafluoro-N-methyl-1-pentanesulfonamide',
    'C<sub>6</sub>H<sub>4</sub>F<sub>11</sub>NO<sub>2</sub>S',
    '',
    '68298-13-5',
    'BKKNDZBSSSAGIB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='undecafluoro-N-methyl-1-pentanesulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='undecafluoro-N-methyl-1-pentanesulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='undecafluoro-N-methyl-1-pentanesulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='undecafluoro-N-methyl-1-pentanesulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,2,2,3,3,4,4,4-nonafluoro-N-(2-hydroxyethyl)-N-methylbutane-1-sulfonamide',
    'C<sub>7</sub>H<sub>8</sub>F<sub>9</sub>NO<sub>3</sub>S',
    '',
    '34454-97-2',
    'DSRUAYIFDCHEEV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2,3,3,4,4,4-nonafluoro-N-(2-hydroxyethyl)-N-methylbutane-1-sulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2,3,3,4,4,4-nonafluoro-N-(2-hydroxyethyl)-N-methylbutane-1-sulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2,3,3,4,4,4-nonafluoro-N-(2-hydroxyethyl)-N-methylbutane-1-sulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2,3,3,4,4,4-nonafluoro-N-(2-hydroxyethyl)-N-methylbutane-1-sulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tridecafluoro-N-methyl-1-hexanesulfonamide',
    'C<sub>7</sub>H<sub>4</sub>F<sub>13</sub>NO<sub>2</sub>S',
    '',
    '68259-15-4',
    'HPPDPHZGXWMRHN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tridecafluoro-N-methyl-1-hexanesulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tridecafluoro-N-methyl-1-hexanesulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tridecafluoro-N-methyl-1-hexanesulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tridecafluoro-N-methyl-1-hexanesulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'perfluorooctane sulfonamide',
    'C<sub>8</sub>H<sub>2</sub>F<sub>17</sub>NO<sub>2</sub>S',
    'PFOSA',
    '754-91-6',
    'RRRXPPIDPYTNJG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='perfluorooctane sulfonamide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='perfluorooctane sulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2992'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2992SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='perfluorooctane sulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2992'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2992COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'emtricitabine',
    'C<sub>8</sub>H<sub>10</sub>FN<sub>3</sub>O<sub>3</sub>S',
    '',
    '143491-57-0',
    'XQSPYNMVSIKCOC-NTSWFWBYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='emtricitabine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-ethyl-1,1,2,2,3,3,4,4,4-nonafluoro-N-(2-hydroxyethyl)butane-1-sulfonamide',
    'C<sub>8</sub>H<sub>10</sub>F<sub>9</sub>NO<sub>3</sub>S',
    '',
    '34449-89-3',
    'ZSBOIPHQFKYRMG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-ethyl-1,1,2,2,3,3,4,4,4-nonafluoro-N-(2-hydroxyethyl)butane-1-sulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-ethyl-1,1,2,2,3,3,4,4,4-nonafluoro-N-(2-hydroxyethyl)butane-1-sulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-ethyl-1,1,2,2,3,3,4,4,4-nonafluoro-N-(2-hydroxyethyl)butane-1-sulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-ethyl-1,1,2,2,3,3,4,4,4-nonafluoro-N-(2-hydroxyethyl)butane-1-sulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,2,2,3,3,4,4,5,5,6,6,7,7,7-pentadecafluoro-N-methylheptane-1-sulphonamide',
    'C<sub>8</sub>H<sub>4</sub>NO<sub>2</sub>F<sub>15</sub>S',
    '',
    '68259-14-3',
    'KDHCALLFPWZTPN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2,3,3,4,4,5,5,6,6,7,7,7-pentadecafluoro-N-methylheptane-1-sulphonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2,3,3,4,4,5,5,6,6,7,7,7-pentadecafluoro-N-methylheptane-1-sulphonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2,3,3,4,4,5,5,6,6,7,7,7-pentadecafluoro-N-methylheptane-1-sulphonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2,3,3,4,4,5,5,6,6,7,7,7-pentadecafluoro-N-methylheptane-1-sulphonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,2,2,3,3,4,4,5,5,5-undecafluoro-N-(2-hydroxyethyl)-N-methylpentane-1-sulphonamide',
    'C<sub>8</sub>H<sub>8</sub>NO<sub>3</sub>F<sub>11</sub>S',
    '',
    '68555-74-8',
    'BRBCKWCOTRPYGH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2,3,3,4,4,5,5,5-undecafluoro-N-(2-hydroxyethyl)-N-methylpentane-1-sulphonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2,3,3,4,4,5,5,5-undecafluoro-N-(2-hydroxyethyl)-N-methylpentane-1-sulphonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2,3,3,4,4,5,5,5-undecafluoro-N-(2-hydroxyethyl)-N-methylpentane-1-sulphonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2,3,3,4,4,5,5,5-undecafluoro-N-(2-hydroxyethyl)-N-methylpentane-1-sulphonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-(3-(dimethylamino)propyl)-nonafluoro-1-butanesulfonamide',
    'C<sub>9</sub>H<sub>13</sub>F<sub>9</sub>N<sub>2</sub>O<sub>2</sub>S',
    '',
    '68555-77-1',
    'XMRMVBVJGSKMEN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-(3-(dimethylamino)propyl)-nonafluoro-1-butanesulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-(3-(dimethylamino)propyl)-nonafluoro-1-butanesulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-(3-(dimethylamino)propyl)-nonafluoro-1-butanesulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-(3-(dimethylamino)propyl)-nonafluoro-1-butanesulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-methylperfluorooctanesulphonamide',
    'C<sub>9</sub>H<sub>4</sub>F<sub>17</sub>NO<sub>2</sub>S',
    'N-MeFOSA',
    '31506-32-8',
    'SRMWNTGHXHOWBT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='N-methylperfluorooctanesulphonamide'),
    (SELECT id from literature WHERE bibtexkey='3939'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-methylperfluorooctanesulphonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-methylperfluorooctanesulphonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-methylperfluorooctanesulphonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-methylperfluorooctanesulphonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-ethyl-1,1,2,2,3,3,4,4,5,5,5-undecafluoro-N-(2-hydroxyethyl)-1-pentanesulfonamide',
    'C<sub>9</sub>H<sub>10</sub>NO<sub>3</sub>F<sub>11</sub>S',
    '',
    '68555-72-6',
    'GBPAQIZWHVCENQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-ethyl-1,1,2,2,3,3,4,4,5,5,5-undecafluoro-N-(2-hydroxyethyl)-1-pentanesulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-ethyl-1,1,2,2,3,3,4,4,5,5,5-undecafluoro-N-(2-hydroxyethyl)-1-pentanesulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-ethyl-1,1,2,2,3,3,4,4,5,5,5-undecafluoro-N-(2-hydroxyethyl)-1-pentanesulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-ethyl-1,1,2,2,3,3,4,4,5,5,5-undecafluoro-N-(2-hydroxyethyl)-1-pentanesulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,2,2,3,3,4,4,5,5,6,6,6-tridecafluoro-N-(2-hydroxyethyl)-N-methyl-1-hexanesulfonamide',
    'C<sub>9</sub>H<sub>8</sub>NO<sub>3</sub>F<sub>13</sub>S',
    '',
    '68555-75-9',
    'UYIBZOUSVFOPJK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2,3,3,4,4,5,5,6,6,6-tridecafluoro-N-(2-hydroxyethyl)-N-methyl-1-hexanesulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2,3,3,4,4,5,5,6,6,6-tridecafluoro-N-(2-hydroxyethyl)-N-methyl-1-hexanesulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2,3,3,4,4,5,5,6,6,6-tridecafluoro-N-(2-hydroxyethyl)-N-methyl-1-hexanesulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2,3,3,4,4,5,5,6,6,6-tridecafluoro-N-(2-hydroxyethyl)-N-methyl-1-hexanesulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-ethyl-1,1,2,2,3,3,4,4,5,5,6,6,6-tridecafluoro-N-(2-hydroxyethyl)hexane-1-sulfonamide',
    'C<sub>10</sub>H<sub>10</sub>F<sub>13</sub>NO<sub>3</sub>S',
    '',
    '34455-03-3',
    'SSGYCIQAXNQIBC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-ethyl-1,1,2,2,3,3,4,4,5,5,6,6,6-tridecafluoro-N-(2-hydroxyethyl)hexane-1-sulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-ethyl-1,1,2,2,3,3,4,4,5,5,6,6,6-tridecafluoro-N-(2-hydroxyethyl)hexane-1-sulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-ethyl-1,1,2,2,3,3,4,4,5,5,6,6,6-tridecafluoro-N-(2-hydroxyethyl)hexane-1-sulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-ethyl-1,1,2,2,3,3,4,4,5,5,6,6,6-tridecafluoro-N-(2-hydroxyethyl)hexane-1-sulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methyl[(nonafluorobutyl)sulfonyl]aminoethyl acrylate',
    'C<sub>10</sub>H<sub>10</sub>F<sub>9</sub>NO<sub>4</sub>S',
    '',
    '67584-55-8',
    'KEMCLRGAIUJRAN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl[(nonafluorobutyl)sulfonyl]aminoethyl acrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl[(nonafluorobutyl)sulfonyl]aminoethyl acrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl[(nonafluorobutyl)sulfonyl]aminoethyl acrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-methyl[(nonafluorobutyl)sulfonyl]aminoethyl acrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-ethylperfluorooctanesulfonamide',
    'C<sub>10</sub>H<sub>6</sub>F<sub>17</sub>NO<sub>2</sub>S',
    'N-EtFOSA',
    '4151-50-2',
    'CCEKAJIANROZEO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='N-ethylperfluorooctanesulfonamide'),
    (SELECT id from literature WHERE bibtexkey='3939'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-ethylperfluorooctanesulfonamide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-ethylperfluorooctanesulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-ethylperfluorooctanesulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-ethylperfluorooctanesulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-ethylperfluorooctanesulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-ethylperfluorooctanesulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2992'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2992SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-ethylperfluorooctanesulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2992'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2992COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,2,2,3,3,4,4,5,5,6,6,7,7,7-pentadecafluoro-N-(2-hydroxyethyl)-N-methylheptane-1-sulphonamide',
    'C<sub>10</sub>H<sub>8</sub>NO<sub>3</sub>F<sub>15</sub>S',
    '',
    '68555-76-0',
    'UIZUTEDYGNRNSW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2,3,3,4,4,5,5,6,6,7,7,7-pentadecafluoro-N-(2-hydroxyethyl)-N-methylheptane-1-sulphonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2,3,3,4,4,5,5,6,6,7,7,7-pentadecafluoro-N-(2-hydroxyethyl)-N-methylheptane-1-sulphonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2,3,3,4,4,5,5,6,6,7,7,7-pentadecafluoro-N-(2-hydroxyethyl)-N-methylheptane-1-sulphonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2,3,3,4,4,5,5,6,6,7,7,7-pentadecafluoro-N-(2-hydroxyethyl)-N-methylheptane-1-sulphonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-methyl perfluorooctane sulfonamidoethanol',
    'C<sub>11</sub>H<sub>8</sub>F<sub>17</sub>NO<sub>3</sub>S',
    'MeFOSE',
    '24448-09-7',
    'PLGACQRCZCVKGK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-methyl perfluorooctane sulfonamidoethanol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-methyl perfluorooctane sulfonamidoethanol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-methyl perfluorooctane sulfonamidoethanol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-methyl perfluorooctane sulfonamidoethanol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-methyl perfluorooctane sulfonamidoethanol'),
    (SELECT id from literature WHERE bibtexkey='2992'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2992SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-methyl perfluorooctane sulfonamidoethanol'),
    (SELECT id from literature WHERE bibtexkey='2992'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2992COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-ethyl-1,1,2,2,3,3,4,4,5,5,6,6,7,7,7-pentadecafluoro-N-(2-hydroxyethyl)-1-heptanesulfonamide',
    'C<sub>11</sub>H<sub>10</sub>NO<sub>3</sub>F<sub>15</sub>S',
    '',
    '68555-73-7',
    'HINASMOVWHGCAK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-ethyl-1,1,2,2,3,3,4,4,5,5,6,6,7,7,7-pentadecafluoro-N-(2-hydroxyethyl)-1-heptanesulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-ethyl-1,1,2,2,3,3,4,4,5,5,6,6,7,7,7-pentadecafluoro-N-(2-hydroxyethyl)-1-heptanesulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-ethyl-1,1,2,2,3,3,4,4,5,5,6,6,7,7,7-pentadecafluoro-N-(2-hydroxyethyl)-1-heptanesulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-ethyl-1,1,2,2,3,3,4,4,5,5,6,6,7,7,7-pentadecafluoro-N-(2-hydroxyethyl)-1-heptanesulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'mefluidide',
    'C<sub>11</sub>H<sub>13</sub>F<sub>3</sub>N<sub>2</sub>O<sub>3</sub>S',
    '',
    '53780-34-0',
    'OKIBNKKYNPBDRS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='mefluidide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-(3-(dimethylamino)propyl)-1,1,2,2,3,3,4,4,5,5,6,6,6-tridecafluoro-1-hexanesulfonamide',
    'C<sub>11</sub>H<sub>13</sub>N<sub>2</sub>O<sub>2</sub>F<sub>13</sub>S',
    '',
    '50598-28-2',
    'INDOGKYZYLAGEM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-(3-(dimethylamino)propyl)-1,1,2,2,3,3,4,4,5,5,6,6,6-tridecafluoro-1-hexanesulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-(3-(dimethylamino)propyl)-1,1,2,2,3,3,4,4,5,5,6,6,6-tridecafluoro-1-hexanesulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-(3-(dimethylamino)propyl)-1,1,2,2,3,3,4,4,5,5,6,6,6-tridecafluoro-1-hexanesulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-(3-(dimethylamino)propyl)-1,1,2,2,3,3,4,4,5,5,6,6,6-tridecafluoro-1-hexanesulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-(methyl((undecafluoropentyl)sulfonyl)amino)ethyl prop-2-enoate',
    'C<sub>11</sub>H<sub>10</sub>F<sub>11</sub>NO<sub>4</sub>S',
    '',
    '67584-56-9',
    'FZWFDJBZTLTRGH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(methyl((undecafluoropentyl)sulfonyl)amino)ethyl prop-2-enoate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(methyl((undecafluoropentyl)sulfonyl)amino)ethyl prop-2-enoate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(methyl((undecafluoropentyl)sulfonyl)amino)ethyl prop-2-enoate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(methyl((undecafluoropentyl)sulfonyl)amino)ethyl prop-2-enoate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-(methyl((nonafluorobutyl)sulphonyl)amino)ethyl methacrylate',
    'C<sub>11</sub>H<sub>12</sub>F<sub>9</sub>NO<sub>4</sub>S',
    '',
    '67584-59-2',
    'BEIWUHUHJDEMQO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(methyl((nonafluorobutyl)sulphonyl)amino)ethyl methacrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(methyl((nonafluorobutyl)sulphonyl)amino)ethyl methacrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(methyl((nonafluorobutyl)sulphonyl)amino)ethyl methacrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(methyl((nonafluorobutyl)sulphonyl)amino)ethyl methacrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-(3-(dimethylamino)propyl)pentadecafluoro-1-heptanesulfonamide',
    'C<sub>12</sub>H<sub>13</sub>F<sub>15</sub>N<sub>2</sub>O<sub>2</sub>S',
    '',
    '67584-54-7',
    'RFJQYRXZGNILIY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-(3-(dimethylamino)propyl)pentadecafluoro-1-heptanesulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-(3-(dimethylamino)propyl)pentadecafluoro-1-heptanesulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-(3-(dimethylamino)propyl)pentadecafluoro-1-heptanesulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-(3-(dimethylamino)propyl)pentadecafluoro-1-heptanesulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'acrylic acid 2-[methyl[(tridecafluorohexyl)sulfonyl]amino]ethyl ester',
    'C<sub>12</sub>H<sub>10</sub>F<sub>13</sub>NO<sub>4</sub>S',
    '',
    '67584-57-0',
    'HLKZFXXWGVPYAY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='acrylic acid 2-[methyl[(tridecafluorohexyl)sulfonyl]amino]ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='acrylic acid 2-[methyl[(tridecafluorohexyl)sulfonyl]amino]ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='acrylic acid 2-[methyl[(tridecafluorohexyl)sulfonyl]amino]ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='acrylic acid 2-[methyl[(tridecafluorohexyl)sulfonyl]amino]ethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-ethyl perfluorooctane sulfonamidoethanol',
    'C<sub>12</sub>H<sub>10</sub>F<sub>17</sub>NO<sub>3</sub>S',
    'EtFOSE',
    '1691-99-2',
    'HUFHNYZNTFSKCT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-ethyl perfluorooctane sulfonamidoethanol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-ethyl perfluorooctane sulfonamidoethanol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-ethyl perfluorooctane sulfonamidoethanol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-ethyl perfluorooctane sulfonamidoethanol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-ethyl perfluorooctane sulfonamidoethanol'),
    (SELECT id from literature WHERE bibtexkey='2992'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2992SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-ethyl perfluorooctane sulfonamidoethanol'),
    (SELECT id from literature WHERE bibtexkey='2992'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2992COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'flumetsulam',
    'C<sub>12</sub>H<sub>9</sub>F<sub>2</sub>N<sub>5</sub>O<sub>2</sub>S',
    '',
    '98967-40-9',
    'RXCPQSJAVKGONC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>11</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='flumetsulam'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'florasulam',
    'C<sub>12</sub>H<sub>8</sub>F<sub>3</sub>N<sub>5</sub>O<sub>3</sub>S',
    '',
    '145701-23-1',
    'QZXATCCPQKOEIH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='florasulam'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='florasulam'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH7'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='florasulam'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH9'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='florasulam'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH5'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-(methyl((pentadecafluoroheptyl)sulphonyl)amino)ethyl acrylate',
    'C<sub>13</sub>H<sub>10</sub>F<sub>15</sub>NO<sub>4</sub>S',
    '',
    '68084-62-8',
    'BEYGZFVOTUDDJK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(methyl((pentadecafluoroheptyl)sulphonyl)amino)ethyl acrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(methyl((pentadecafluoroheptyl)sulphonyl)amino)ethyl acrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(methyl((pentadecafluoroheptyl)sulphonyl)amino)ethyl acrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(methyl((pentadecafluoroheptyl)sulphonyl)amino)ethyl acrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'flazasulfuron',
    'C<sub>13</sub>H<sub>12</sub>F<sub>3</sub>N<sub>5</sub>O<sub>5</sub>S',
    '',
    '104040-78-0',
    'HWATZEJQIXKWQS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='flazasulfuron'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 3.9&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='flazasulfuron'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tritosulfuron',
    'C<sub>13</sub>H<sub>9</sub>F<sub>6</sub>N<sub>5</sub>O<sub>4</sub>S',
    '',
    '142469-14-5',
    'KVEQCVKVIFQSGC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 1.0&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tritosulfuron'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pyroxsulam',
    'C<sub>14</sub>H<sub>13</sub>F<sub>3</sub>N<sub>6</sub>O<sub>5</sub>S',
    '',
    '422556-08-9',
    'GLBLPMUBLHYFCW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pyroxsulam'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-methyl perfluorooctane sulfonamidoethylacrylate',
    'C<sub>14</sub>H<sub>10</sub>F<sub>17</sub>NO<sub>4</sub>S',
    'MeFOSEA',
    '25268-77-3',
    'RTJZWOGSCLVJLD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-methyl perfluorooctane sulfonamidoethylacrylate'),
    (SELECT id from literature WHERE bibtexkey='2992'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2992SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-methyl perfluorooctane sulfonamidoethylacrylate'),
    (SELECT id from literature WHERE bibtexkey='2992'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2992COSMO'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pyrasulfotole',
    'C<sub>14</sub>H<sub>13</sub>F<sub>3</sub>N<sub>2</sub>O<sub>4</sub>S',
    '',
    '365400-11-9',
    'CZRVDACSCJKRFL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>8</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pyrasulfotole'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'triafamone',
    'C<sub>14</sub>H<sub>13</sub>F<sub>3</sub>N<sub>4</sub>O<sub>5</sub>S',
    '',
    '874195-61-6',
    'GBHVIWKSEHWFDD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='triafamone'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'flufenacet',
    'C<sub>14</sub>H<sub>13</sub>F<sub>4</sub>N<sub>3</sub>O<sub>2</sub>S',
    '',
    '142459-58-3',
    'IANUJLZYFUDJIH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='flufenacet'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='flufenacet'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'N-butyl-1,1,2,2,3,3,4,4,5,5,6,6,7,7,8,8,8-heptadecafluoro-N-(2-hydroxyethyl)-1-octanesulfonamide',
    'C<sub>14</sub>H<sub>14</sub>F<sub>17</sub>NO<sub>3</sub>S',
    '',
    '2263-09-4',
    'AQWROZBAYZBWIH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-butyl-1,1,2,2,3,3,4,4,5,5,6,6,7,7,8,8,8-heptadecafluoro-N-(2-hydroxyethyl)-1-octanesulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-butyl-1,1,2,2,3,3,4,4,5,5,6,6,7,7,8,8,8-heptadecafluoro-N-(2-hydroxyethyl)-1-octanesulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-butyl-1,1,2,2,3,3,4,4,5,5,6,6,7,7,8,8,8-heptadecafluoro-N-(2-hydroxyethyl)-1-octanesulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='N-butyl-1,1,2,2,3,3,4,4,5,5,6,6,7,7,8,8,8-heptadecafluoro-N-(2-hydroxyethyl)-1-octanesulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyl N-ethyl-N-[(heptadecafluorooctyl)sulphonyl]glycinate',
    'C<sub>14</sub>H<sub>12</sub>NO<sub>4</sub>F<sub>17</sub>S',
    '',
    '1869-77-8',
    'LMUUXHHNCDERBQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl N-ethyl-N-[(heptadecafluorooctyl)sulphonyl]glycinate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl N-ethyl-N-[(heptadecafluorooctyl)sulphonyl]glycinate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl N-ethyl-N-[(heptadecafluorooctyl)sulphonyl]glycinate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl N-ethyl-N-[(heptadecafluorooctyl)sulphonyl]glycinate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'perfluidone',
    'C<sub>14</sub>H<sub>12</sub>F<sub>3</sub>NO<sub>4</sub>S<sub>2</sub>',
    '',
    '37924-13-3',
    'WHTBVLXUSXVMEV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='perfluidone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='perfluidone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-(((heptadecafluorooctyl)sulfonyl)methylamino)ethyl methacrylate',
    'C<sub>15</sub>H<sub>12</sub>F<sub>17</sub>NO<sub>4</sub>S',
    '',
    '14650-24-9',
    'UZMOXNBUTMPDCX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(((heptadecafluorooctyl)sulfonyl)methylamino)ethyl methacrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(((heptadecafluorooctyl)sulfonyl)methylamino)ethyl methacrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(((heptadecafluorooctyl)sulfonyl)methylamino)ethyl methacrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(((heptadecafluorooctyl)sulfonyl)methylamino)ethyl methacrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-(N-ethylperfluorooctane-sulfonamido)ethyl acrylate',
    'C<sub>15</sub>H<sub>12</sub>F<sub>17</sub>NO<sub>4</sub>S',
    '',
    '423-82-5',
    'ZAZJGBCGMUKZEL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-(N-ethylperfluorooctane-sulfonamido)ethyl acrylate'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_O2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'isoxaflutole',
    'C<sub>15</sub>H<sub>12</sub>F<sub>3</sub>NO<sub>4</sub>S',
    '',
    '141112-29-0',
    'OYIKARCXOQLFHF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>4</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='isoxaflutole'),
    (SELECT id from literature WHERE bibtexkey='macbean2012'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='isoxaflutole'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'primisulfuron-methyl',
    'C<sub>15</sub>H<sub>12</sub>F<sub>4</sub>N<sub>4</sub>O<sub>7</sub>S',
    '',
    '86209-51-0',
    'ZTYVMAQSHCZXLF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='primisulfuron-methyl'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dithiopyr',
    'C<sub>15</sub>H<sub>16</sub>F<sub>5</sub>NO<sub>2</sub>S<sub>2</sub>',
    '',
    '97886-45-8',
    'YUBJPYNSGLJZPQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5',
    '',
    '?',
    (SELECT id from species WHERE iupac='dithiopyr'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'penoxsulam',
    'C<sub>16</sub>H<sub>14</sub>F<sub>5</sub>N<sub>5</sub>O<sub>5</sub>S',
    '',
    '219714-96-2',
    'SYJGKVOENHZYMQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>12</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='penoxsulam'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>14</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='penoxsulam'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH9'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>11</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='penoxsulam'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH5'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>13</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='penoxsulam'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH7'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pantoprazole',
    'C<sub>16</sub>H<sub>15</sub>F<sub>2</sub>N<sub>3</sub>O<sub>4</sub>S',
    '',
    '102625-70-7',
    'IQPSEEYGBUAQFF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>14</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pantoprazole'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-(N-ethylperfluorooctanesulfamido)ethyl methacrylate',
    'C<sub>16</sub>H<sub>14</sub>F<sub>17</sub>NO<sub>4</sub>S',
    '',
    '376-14-7',
    'DBCGADAHIXJHCE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(N-ethylperfluorooctanesulfamido)ethyl methacrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(N-ethylperfluorooctanesulfamido)ethyl methacrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(N-ethylperfluorooctanesulfamido)ethyl methacrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(N-ethylperfluorooctanesulfamido)ethyl methacrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'thiazopyr',
    'C<sub>16</sub>H<sub>17</sub>F<sub>5</sub>N<sub>2</sub>O<sub>2</sub>S',
    '',
    '117718-60-2',
    'YIJZJEYQBAAWRJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='thiazopyr'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='thiazopyr'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='thiazopyr'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'penthiopyrad',
    'C<sub>16</sub>H<sub>20</sub>F<sub>3</sub>N<sub>3</sub>OS',
    '',
    '183675-82-3',
    'PFFIDZXUXFLSSR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='penthiopyrad'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH5'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='penthiopyrad'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH7'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='penthiopyrad'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH4'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='penthiopyrad'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH10'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'triflusulfuron-methyl',
    'C<sub>17</sub>H<sub>19</sub>F<sub>3</sub>N<sub>6</sub>O<sub>6</sub>S',
    '',
    '126535-15-7',
    'IMEVJVISCHQJRM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 4.2&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='triflusulfuron-methyl'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH4'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'celecoxib',
    'C<sub>17</sub>H<sub>14</sub>F<sub>3</sub>N<sub>3</sub>O<sub>2</sub>S',
    '',
    '169590-42-5',
    'RZEKVGVHFLEQIL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='celecoxib'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-(butyl((heptadecafluorooctyl)sulfonyl)amino)ethyl acrylate',
    'C<sub>17</sub>H<sub>16</sub>F<sub>17</sub>NO<sub>4</sub>S',
    '',
    '383-07-3',
    'AQQNNAXBGPWALO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(butyl((heptadecafluorooctyl)sulfonyl)amino)ethyl acrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(butyl((heptadecafluorooctyl)sulfonyl)amino)ethyl acrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(butyl((heptadecafluorooctyl)sulfonyl)amino)ethyl acrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-(butyl((heptadecafluorooctyl)sulfonyl)amino)ethyl acrylate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'thidiazimin',
    'C<sub>18</sub>H<sub>17</sub>N<sub>4</sub>O<sub>2</sub>FS',
    '',
    '123249-43-4',
    'HZKBYBNLTLVSPX-JZJYNLBNSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>8</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='thidiazimin'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benthiavalicarb isopropyl',
    'C<sub>18</sub>H<sub>24</sub>FN<sub>3</sub>O<sub>3</sub>S',
    '',
    '177406-68-7',
    'USRKFGIXLGKMKU-IAQYHMDHSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='benthiavalicarb isopropyl'),
    (SELECT id from literature WHERE bibtexkey='macbean2012'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 1.1&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='benthiavalicarb isopropyl'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'flutianil',
    'C<sub>19</sub>H<sub>14</sub>F<sub>4</sub>N<sub>2</sub>OS<sub>2</sub>',
    '',
    '958647-10-4',
    'KGXUEPOHGFWQKF-ZCXUNETKSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='flutianil'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'rosuvastatin',
    'C<sub>22</sub>H<sub>28</sub>N<sub>3</sub>O<sub>6</sub>FS',
    '',
    '287714-41-4',
    'BPRHUIZQVSMCRT-YXWZHEERSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>14</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='rosuvastatin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'oxathiapiprolin',
    'C<sub>24</sub>H<sub>22</sub>F<sub>5</sub>N<sub>5</sub>O<sub>2</sub>S',
    '',
    '1003318-67-9',
    'IAQLCKZJGNTRDO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='oxathiapiprolin'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'trichloromethanesulfenyl chloride',
    'CCl<sub>4</sub>S',
    '',
    '594-42-3',
    'RYFZYYUIAZYQLC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloromethanesulfenyl chloride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloromethanesulfenyl chloride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloromethanesulfenyl chloride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloromethanesulfenyl chloride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,2,2-tetrachloroethanesulfenyl chloride',
    'C<sub>2</sub>HCl<sub>5</sub>S',
    '',
    '1185-09-7',
    'LCVOCDOSGJHZFH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachloroethanesulfenyl chloride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachloroethanesulfenyl chloride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachloroethanesulfenyl chloride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1,2,2-tetrachloroethanesulfenyl chloride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-chloroethyl methyl sulfide',
    'C<sub>3</sub>H<sub>7</sub>ClS',
    '',
    '542-81-4',
    'MYFKLQFBFSHBPA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-chloroethyl methyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3393'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-chloroethyl ethyl sulfide',
    'C<sub>4</sub>H<sub>9</sub>ClS',
    '',
    '693-07-2',
    'GBNVXYXIRHSYEG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloroethyl ethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-chloroethyl ethyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3393'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2''-dichlorodiethylsulfide',
    '(ClCH<sub>2</sub>CH<sub>2</sub>)<sub>2</sub>S',
    'mustard gas',
    '505-60-2',
    'QKSKPIVNLNLAAV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='2,2''-dichlorodiethylsulfide'),
    (SELECT id from literature WHERE bibtexkey='642'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2''-dichlorodiethylsulfide'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2''-dichlorodiethylsulfide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,2''-dichlorodiethylsulfide'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2''-dichlorodiethylsulfide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2''-dichlorodiethylsulfide'),
    (SELECT id from literature WHERE bibtexkey='3393'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2''-dichlorodiethylsulfide'),
    (SELECT id from literature WHERE bibtexkey='3121'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2-bis(2-chloroethylthio)ethane',
    'C<sub>6</sub>H<sub>12</sub>Cl<sub>2</sub>S<sub>2</sub>',
    'sesquimustard',
    '3563-36-8',
    'AMGNHZVUZWILSB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,2-bis(2-chloroethylthio)ethane'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pentachlorobenzenethiol',
    'C<sub>6</sub>HCl<sub>5</sub>S',
    '',
    '133-49-3',
    'LLMLGZUZTFMXSA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentachlorobenzenethiol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentachlorobenzenethiol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentachlorobenzenethiol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentachlorobenzenethiol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentachlorobenzenethiol'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chloroethyl phenyl sulfide',
    'C<sub>8</sub>H<sub>9</sub>ClS',
    '',
    '5535-49-9',
    'QDXIHHOPZFCEAP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chloroethyl phenyl sulfide'),
    (SELECT id from literature WHERE bibtexkey='3393'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tetrasul',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>S',
    '',
    '2227-13-6',
    'QUWSDLYBOVGOCW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tetrasul'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methanesulfonyl chloride',
    'CH<sub>3</sub>ClO<sub>2</sub>S',
    '',
    '124-63-0',
    'QARBMVPHQWIHKH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methanesulfonyl chloride'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bis(trichloromethyl)sulfone',
    'C<sub>2</sub>Cl<sub>6</sub>O<sub>2</sub>S',
    '',
    '3064-70-8',
    'YBNLWIZAWPBUKQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis(trichloromethyl)sulfone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis(trichloromethyl)sulfone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis(trichloromethyl)sulfone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis(trichloromethyl)sulfone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis(trichloromethyl)sulfone'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benzenesulfonyl chloride',
    'C<sub>6</sub>H<sub>5</sub>ClO<sub>2</sub>S',
    '',
    '98-09-9',
    'CSKNSYBAZOQPLR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzenesulfonyl chloride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzenesulfonyl chloride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzenesulfonyl chloride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benzenesulfonyl chloride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-methylbenzenesulfonyl chloride',
    'C<sub>7</sub>H<sub>7</sub>ClO<sub>2</sub>S',
    '',
    '98-59-9',
    'YYROPELSRYBVMQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylbenzenesulfonyl chloride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylbenzenesulfonyl chloride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylbenzenesulfonyl chloride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-methylbenzenesulfonyl chloride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'endosulfan',
    'C<sub>9</sub>H<sub>6</sub>Cl<sub>6</sub>O<sub>3</sub>S',
    '',
    '115-29-7',
    'RDYMFSUJUZBWLH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='endosulfan'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='endosulfan'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='endosulfan'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='endosulfan'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='endosulfan'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='endosulfan'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='endosulfan'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '&#945;-endosulfan',
    'C<sub>9</sub>H<sub>6</sub>Cl<sub>6</sub>O<sub>3</sub>S',
    'endosulfan I',
    '959-98-8',
    'RDYMFSUJUZBWLH-AMHWMVONSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'L',
    (SELECT id from species WHERE iupac='&#945;-endosulfan'),
    (SELECT id from literature WHERE bibtexkey='2948'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='LDV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'L',
    (SELECT id from species WHERE iupac='&#945;-endosulfan'),
    (SELECT id from literature WHERE bibtexkey='2948'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'L',
    (SELECT id from species WHERE iupac='&#945;-endosulfan'),
    (SELECT id from literature WHERE bibtexkey='2965'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'L',
    (SELECT id from species WHERE iupac='&#945;-endosulfan'),
    (SELECT id from literature WHERE bibtexkey='2965'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='LDV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'M',
    (SELECT id from species WHERE iupac='&#945;-endosulfan'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '4200',
    'M',
    (SELECT id from species WHERE iupac='&#945;-endosulfan'),
    (SELECT id from literature WHERE bibtexkey='2814'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'M',
    (SELECT id from species WHERE iupac='&#945;-endosulfan'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='&#945;-endosulfan'),
    (SELECT id from literature WHERE bibtexkey='893'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '2300',
    'M',
    (SELECT id from species WHERE iupac='&#945;-endosulfan'),
    (SELECT id from literature WHERE bibtexkey='3791'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='&#945;-endosulfan'),
    (SELECT id from literature WHERE bibtexkey='1995'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='&#945;-endosulfan'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='&#945;-endosulfan'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#945;-endosulfan'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#945;-endosulfan'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#945;-endosulfan'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '3200',
    'Q',
    (SELECT id from species WHERE iupac='&#945;-endosulfan'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    '?',
    (SELECT id from species WHERE iupac='&#945;-endosulfan'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '2300',
    '?',
    (SELECT id from species WHERE iupac='&#945;-endosulfan'),
    (SELECT id from literature WHERE bibtexkey='1917'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '&#946;-endosulfan',
    'C<sub>9</sub>H<sub>6</sub>Cl<sub>6</sub>O<sub>3</sub>S',
    'endosulfan II',
    '33213-65-9',
    'RDYMFSUJUZBWLH-MDBBVBRHSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='&#946;-endosulfan'),
    (SELECT id from literature WHERE bibtexkey='2948'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='LDV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='&#946;-endosulfan'),
    (SELECT id from literature WHERE bibtexkey='2948'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4',
    '',
    'M',
    (SELECT id from species WHERE iupac='&#946;-endosulfan'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '3700',
    'M',
    (SELECT id from species WHERE iupac='&#946;-endosulfan'),
    (SELECT id from literature WHERE bibtexkey='2814'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'M',
    (SELECT id from species WHERE iupac='&#946;-endosulfan'),
    (SELECT id from literature WHERE bibtexkey='1195'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'M',
    (SELECT id from species WHERE iupac='&#946;-endosulfan'),
    (SELECT id from literature WHERE bibtexkey='893'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    'M',
    (SELECT id from species WHERE iupac='&#946;-endosulfan'),
    (SELECT id from literature WHERE bibtexkey='3791'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='&#946;-endosulfan'),
    (SELECT id from literature WHERE bibtexkey='1995'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#946;-endosulfan'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#946;-endosulfan'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#946;-endosulfan'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='&#946;-endosulfan'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='&#946;-endosulfan'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'endosulfan sulfate',
    'C<sub>9</sub>H<sub>6</sub>Cl<sub>6</sub>O<sub>4</sub>S',
    '',
    '1031-07-8',
    'AAPVQEMYVNZIOO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='endosulfan sulfate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'mcpa-thioethyl',
    'C<sub>11</sub>H<sub>13</sub>ClO<sub>2</sub>S',
    '',
    '25319-90-8',
    'AZFKQCNGMSSWDS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='mcpa-thioethyl'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1''-sulfonylbis(4-chlorobenzene)',
    'C<sub>12</sub>H<sub>8</sub>Cl<sub>2</sub>O<sub>2</sub>S',
    '',
    '80-07-9',
    'GPAPPPVRLPGFEQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1''-sulfonylbis(4-chlorobenzene)'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1''-sulfonylbis(4-chlorobenzene)'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1''-sulfonylbis(4-chlorobenzene)'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1''-sulfonylbis(4-chlorobenzene)'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,1''-sulfonylbis(4-chlorobenzene)'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,2''-thiobis-4,6-dichlorophenol',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>O<sub>2</sub>S',
    'bithionol',
    '97-18-7',
    'JFIOVJDNOJYLKP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='2,2''-thiobis-4,6-dichlorophenol'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,2,4-trichloro-5-[(4-chlorophenyl)sulfonyl]benzene',
    'C<sub>12</sub>H<sub>6</sub>Cl<sub>4</sub>O<sub>2</sub>S',
    'tetradifon',
    '116-29-0',
    'MLGCXEBRWGEOQX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,4-trichloro-5-[(4-chlorophenyl)sulfonyl]benzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1,2,4-trichloro-5-[(4-chlorophenyl)sulfonyl]benzene'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,2,4-trichloro-5-[(4-chlorophenyl)sulfonyl]benzene'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ovex',
    'C<sub>12</sub>H<sub>8</sub>Cl<sub>2</sub>O<sub>3</sub>S',
    'chlorfenson',
    '80-33-1',
    'RZXLPPRPEOUENN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ovex'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'sulphenone',
    'C<sub>12</sub>H<sub>9</sub>ClO<sub>2</sub>S',
    '',
    '80-00-2',
    'OFCFYWOKHPOXKF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='sulphenone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'sulcotrione',
    'C<sub>14</sub>H<sub>13</sub>ClO<sub>5</sub>S',
    '',
    '99105-77-8',
    'PQTBTIFWAXVEPB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='sulcotrione'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3549-pH4.8',
    '', 'At pH = 4.8.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH4.8'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'aramite',
    'C<sub>15</sub>H<sub>23</sub>ClO<sub>4</sub>S',
    '',
    '140-57-8',
    'YKFRAOGHWKADFJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='aramite'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '6-chloro-2-(6-chloro-4-methyl-3-oxobenzo[b]thien-2(3H)-ylidene)-4-methylbenzo[b]thiophene-3(2H)-one',
    'C<sub>18</sub>H<sub>10</sub>Cl<sub>2</sub>O<sub>2</sub>S<sub>2</sub>',
    '',
    '2379-74-0',
    'NDDLLTAIKYHPOD-ISLYRVAYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-chloro-2-(6-chloro-4-methyl-3-oxobenzo[b]thien-2(3H)-ylidene)-4-methylbenzo[b]thiophene-3(2H)-one'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-chloro-2-(6-chloro-4-methyl-3-oxobenzo[b]thien-2(3H)-ylidene)-4-methylbenzo[b]thiophene-3(2H)-one'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-chloro-2-(6-chloro-4-methyl-3-oxobenzo[b]thien-2(3H)-ylidene)-4-methylbenzo[b]thiophene-3(2H)-one'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='6-chloro-2-(6-chloro-4-methyl-3-oxobenzo[b]thien-2(3H)-ylidene)-4-methylbenzo[b]thiophene-3(2H)-one'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '5-chloro-3-(trichloromethyl)-1,2,4-thiadiazole',
    'C<sub>3</sub>Cl<sub>4</sub>N<sub>2</sub>S',
    '',
    '5848-93-1',
    'MARKPJMFLDWCID-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-chloro-3-(trichloromethyl)-1,2,4-thiadiazole'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-chloro-3-(trichloromethyl)-1,2,4-thiadiazole'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-chloro-3-(trichloromethyl)-1,2,4-thiadiazole'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='5-chloro-3-(trichloromethyl)-1,2,4-thiadiazole'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2,4-dichloro-6-(methylthio)-1,3,5-triazine',
    'C<sub>4</sub>H<sub>3</sub>Cl<sub>2</sub>N<sub>3</sub>S',
    '',
    '13705-05-0',
    'MWPZLWRHHPWTFS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dichloro-6-(methylthio)-1,3,5-triazine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dichloro-6-(methylthio)-1,3,5-triazine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dichloro-6-(methylthio)-1,3,5-triazine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2,4-dichloro-6-(methylthio)-1,3,5-triazine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chlorthiamid',
    'C<sub>7</sub>H<sub>5</sub>Cl<sub>2</sub>NS',
    '',
    '1918-13-4',
    'KGKGSIUWJCAFPX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chlorthiamid'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(2-chlorophenyl)thiourea',
    'C<sub>7</sub>H<sub>7</sub>ClN<sub>2</sub>S',
    '',
    '5344-82-1',
    'YZUKKTCDYSIWKJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 9.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(2-chlorophenyl)thiourea'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-642'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-chloroallyl-N,N-diethyldithiocarbamate',
    'C<sub>8</sub>H<sub>14</sub>ClNS<sub>2</sub>',
    '',
    '95-06-7',
    'XJCLWVXTCRQIDI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-chloroallyl-N,N-diethyldithiocarbamate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='2-chloroallyl-N,N-diethyldithiocarbamate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloroallyl-N,N-diethyldithiocarbamate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloroallyl-N,N-diethyldithiocarbamate'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-chloroallyl-N,N-diethyldithiocarbamate'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'thiacloprid',
    'C<sub>10</sub>H<sub>9</sub>ClN<sub>4</sub>S',
    '',
    '111988-49-9',
    'HOKKPVIRMVDYPB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>8</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='thiacloprid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>9</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='thiacloprid'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chloromethiuron',
    'C<sub>10</sub>H<sub>13</sub>N<sub>2</sub>ClS',
    '',
    '28217-97-2',
    'IBZZDPVVVSNQOY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chloromethiuron'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'imibenconazole',
    'C<sub>17</sub>H<sub>13</sub>Cl<sub>3</sub>N<sub>4</sub>S',
    '',
    '86598-92-7',
    'AGKSTYPVMZODRV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='imibenconazole'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='imibenconazole'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'etridiazole',
    'C<sub>5</sub>H<sub>5</sub>Cl<sub>3</sub>N<sub>2</sub>OS',
    '',
    '2593-15-9',
    'KQTVWCSONPJJPE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='etridiazole'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='etridiazole'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='etridiazole'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='etridiazole'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-chloro-3-nitrobenzenesulfonamide',
    'C<sub>6</sub>H<sub>5</sub>ClN<sub>2</sub>O<sub>4</sub>S',
    '',
    '97-09-6',
    'SPZGXONNVLTQDE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-chloro-3-nitrobenzenesulfonamide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'clothianidin',
    'C<sub>6</sub>H<sub>8</sub>ClN<sub>5</sub>O<sub>2</sub>S',
    '',
    '210880-92-5',
    'PGOOBECODWQEAB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>10</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='clothianidin'),
    (SELECT id from literature WHERE bibtexkey='macbean2012'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>10</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='clothianidin'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chlobenthiazone',
    'C<sub>8</sub>H<sub>6</sub>NOClS',
    '',
    '63755-05-5',
    'QCPASDYEQAVIJF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    '?',
    (SELECT id from species WHERE iupac='chlobenthiazone'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'prothiocarb hydrochloride',
    'C<sub>8</sub>H<sub>19</sub>ClN<sub>2</sub>OS',
    '',
    '19622-19-6',
    'NMFAMPYSJHIYMR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>9</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='prothiocarb hydrochloride'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'thicyofen',
    'C<sub>8</sub>H<sub>5</sub>N<sub>2</sub>OClS<sub>2</sub>',
    '',
    '116170-30-0',
    'GNOOAFGERMHQJE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 2.3&times;10<sup>10</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='thicyofen'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'thiamethoxam',
    'C<sub>8</sub>H<sub>10</sub>ClN<sub>5</sub>O<sub>3</sub>S',
    '',
    '153719-23-4',
    'NWWZPOKUUAIXIW-DHZHZOJOSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>9</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='thiamethoxam'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>9</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='thiamethoxam'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-amino-3,5-dichloro-N-ethyl-2-methylbenzenesulfonamide',
    'C<sub>9</sub>H<sub>12</sub>Cl<sub>2</sub>N<sub>2</sub>O<sub>2</sub>S',
    '',
    '151574-12-8',
    'SBBHTEMLRJJIGK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-amino-3,5-dichloro-N-ethyl-2-methylbenzenesulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-amino-3,5-dichloro-N-ethyl-2-methylbenzenesulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-amino-3,5-dichloro-N-ethyl-2-methylbenzenesulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-amino-3,5-dichloro-N-ethyl-2-methylbenzenesulfonamide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dichlofluanid',
    'C<sub>9</sub>H<sub>11</sub>Cl<sub>2</sub>FN<sub>2</sub>O<sub>2</sub>S<sub>2</sub>',
    '',
    '1085-98-9',
    'WURGXGVFSMYFCG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dichlofluanid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dichlofluanid'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dichlofluanid'),
    (SELECT id from literature WHERE bibtexkey='2973'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichlofluanid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichlofluanid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'captan',
    'C<sub>9</sub>H<sub>8</sub>Cl<sub>3</sub>NO<sub>2</sub>S',
    '',
    '133-06-2',
    'LDVVMCZRFWMZSG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='captan'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='captan'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'V',
    (SELECT id from species WHERE iupac='captan'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='captan'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='captan'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_test'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='captan'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH5'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='captan'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549-pH7'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benazolin',
    'C<sub>9</sub>H<sub>6</sub>ClNO<sub>3</sub>S',
    '',
    '3813-05-6',
    'HYJSGOXICXYZGS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='benazolin'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'folpet',
    'C<sub>9</sub>H<sub>4</sub>Cl<sub>3</sub>NO<sub>2</sub>S',
    '',
    '133-07-3',
    'HKIOYBQGHSTUDB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='folpet'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='folpet'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6',
    '',
    'V',
    (SELECT id from species WHERE iupac='folpet'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='folpet'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='folpet'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='folpet'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='folpet'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'captafol',
    'C<sub>10</sub>H<sub>9</sub>Cl<sub>4</sub>NO<sub>2</sub>S',
    'difolatan',
    '2425-06-1',
    'JHRWWRDRBPCWTF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='captafol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='captafol'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='captafol'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diallate',
    'C<sub>10</sub>H<sub>17</sub>Cl<sub>2</sub>NOS',
    'avadex',
    '2303-16-4',
    'SPANOECCGNXGNR-UITAMQMPSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6',
    '',
    'V',
    (SELECT id from species WHERE iupac='diallate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.3',
    '',
    'V',
    (SELECT id from species WHERE iupac='diallate'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0',
    '',
    'V',
    (SELECT id from species WHERE iupac='diallate'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6',
    '',
    '?',
    (SELECT id from species WHERE iupac='diallate'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'triallate',
    'C<sub>10</sub>H<sub>16</sub>Cl<sub>3</sub>NOS',
    '',
    '2303-17-5',
    'MWBPRDONLNQCFV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='triallate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='triallate'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='triallate'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='triallate'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triallate'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    '?',
    (SELECT id from species WHERE iupac='triallate'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tolylfluanid',
    'C<sub>10</sub>H<sub>13</sub>Cl<sub>2</sub>FN<sub>2</sub>O<sub>2</sub>S<sub>2</sub>',
    '',
    '731-27-1',
    'HYVWIQDYBVKITD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tolylfluanid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tolylfluanid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tolylfluanid'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tolylfluanid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tiadinil',
    'C<sub>11</sub>H<sub>10</sub>ClN<sub>3</sub>OS',
    '',
    '223580-51-6',
    'VJQYLJSMBWXGDV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tiadinil'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'benazolin-ethyl',
    'C<sub>11</sub>H<sub>10</sub>NO<sub>3</sub>ClS',
    '',
    '25059-80-7',
    'WQRCEBAZAUAUQC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='benazolin-ethyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='benazolin-ethyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'orbencarb',
    'C<sub>12</sub>H<sub>16</sub>ClNOS',
    '',
    '34622-58-7',
    'LLLFASISUZUJEQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='orbencarb'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'S-(4-chlorobenzyl) diethylthiocarbamate',
    'C<sub>12</sub>H<sub>16</sub>ClNOS',
    'thiobencarb',
    '28249-77-6',
    'QHTQREMOGMZHJV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='S-(4-chlorobenzyl) diethylthiocarbamate'),
    (SELECT id from literature WHERE bibtexkey='2538'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    'M',
    (SELECT id from species WHERE iupac='S-(4-chlorobenzyl) diethylthiocarbamate'),
    (SELECT id from literature WHERE bibtexkey='2229'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='S-(4-chlorobenzyl) diethylthiocarbamate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='S-(4-chlorobenzyl) diethylthiocarbamate'),
    (SELECT id from literature WHERE bibtexkey='3090'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>1</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='S-(4-chlorobenzyl) diethylthiocarbamate'),
    (SELECT id from literature WHERE bibtexkey='3073'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'W',
    (SELECT id from species WHERE iupac='S-(4-chlorobenzyl) diethylthiocarbamate'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2614_28249-77-6',
    '2614', 'Mackay et&nbsp;al. (2006d) list two values for thiobencarb which differ by a large factor. It is unclear which number is correct (if any), and the data are not reproduced here.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2614_28249-77-6'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'furosemide',
    'C<sub>12</sub>H<sub>11</sub>ClN<sub>2</sub>O<sub>5</sub>S',
    '',
    '54-31-9',
    'ZZUFCTLCJUWOSV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='furosemide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chlorsulfuron',
    'C<sub>12</sub>H<sub>12</sub>ClN<sub>5</sub>O<sub>4</sub>S',
    '',
    '64902-72-3',
    'VJYIFXVZLXQVHO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chlorsulfuron'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>5</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='chlorsulfuron'),
    (SELECT id from literature WHERE bibtexkey='3073'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>10</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chlorsulfuron'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phosalone',
    'C<sub>12</sub>H<sub>15</sub>ClNO<sub>4</sub>S<sub>2</sub>',
    '',
    '2310-17-0',
    'IOUNQDKNJZEDEP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phosalone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimethenamid',
    'C<sub>12</sub>H<sub>18</sub>ClNO<sub>2</sub>S',
    '',
    '87674-68-8',
    'JLYFCTQDENRSOL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethenamid'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethenamid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethenamid'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethenamid'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dimethenamid'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimethenamid-p',
    'C<sub>12</sub>H<sub>18</sub>ClNO<sub>2</sub>S',
    '',
    '163515-14-8',
    'JLYFCTQDENRSOL-VIFPVBQESA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dimethenamid-p'),
    (SELECT id from literature WHERE bibtexkey='macbean2012'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dimethenamid-p'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cyazofamid',
    'C<sub>13</sub>H<sub>13</sub>ClN<sub>4</sub>O<sub>2</sub>S',
    '',
    '120116-88-3',
    'YXKMMRDKEKCERS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='cyazofamid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 2.5&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cyazofamid'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'metosulam',
    'C<sub>14</sub>H<sub>13</sub>Cl<sub>2</sub>N<sub>5</sub>O<sub>4</sub>S',
    '',
    '139528-85-1',
    'VGHPMIFEKOFHHQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>12</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='metosulam'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'prothioconazole',
    'C<sub>14</sub>H<sub>15</sub>Cl<sub>2</sub>N<sub>3</sub>OS',
    '',
    '178928-70-6',
    'MNHVNIJQQRJYDH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='prothioconazole'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 3.3&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='prothioconazole'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'triasulfuron',
    'C<sub>14</sub>H<sub>16</sub>ClN<sub>5</sub>O<sub>5</sub>S',
    '',
    '82097-50-5',
    'XOPFESVZMSQIKC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>8</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='triasulfuron'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chlorimuron-ethyl',
    'C<sub>15</sub>H<sub>15</sub>ClN<sub>4</sub>O<sub>6</sub>S',
    '',
    '90982-32-4',
    'NSWAMPCUPHPTTC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>9</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chlorimuron-ethyl'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'clopidogrel',
    'C<sub>16</sub>H<sub>16</sub>ClNO<sub>2</sub>S',
    '',
    '113665-84-2',
    'GKTWGGQPFAXNFI-HNNXBMFYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='clopidogrel'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'thenylchlor',
    'C<sub>16</sub>H<sub>18</sub>ClNO<sub>2</sub>S',
    '',
    '96491-05-3',
    'KDWQYMVPYJGPHS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='thenylchlor'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='thenylchlor'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chlorpromazine',
    'C<sub>17</sub>H<sub>19</sub>ClN<sub>2</sub>S',
    '',
    '50-53-3',
    'ZPEIMTDSQAKGNT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chlorpromazine'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hexythiazox',
    'C<sub>17</sub>H<sub>21</sub>N<sub>2</sub>O<sub>2</sub>ClS',
    '',
    '78587-05-0',
    'XGWIJUOSCAQSSV-XHDPSFHLSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexythiazox'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='hexythiazox'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'clethodim',
    'C<sub>17</sub>H<sub>26</sub>ClNO<sub>3</sub>S',
    '',
    '99129-21-2',
    'INNPZTGYZSAJFN-ZTVUPKSFSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='clethodim'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='clethodim'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'clindamycin',
    'C<sub>18</sub>H<sub>33</sub>N<sub>2</sub>O<sub>5</sub>ClS',
    '',
    '18323-44-9',
    'KDLRVYVGXIQJDK-AWPVFWJPSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>16</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='clindamycin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pyridate',
    'C<sub>19</sub>H<sub>23</sub>ClN<sub>2</sub>O<sub>2</sub>S',
    '',
    '55512-33-9',
    'JTZCTMAVMHRNTR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='pyridate'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pyridate'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pyridate'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'vismodegib',
    'C<sub>19</sub>H<sub>14</sub>Cl<sub>2</sub>N<sub>2</sub>O<sub>3</sub>S',
    '',
    '879085-55-9',
    'BPQMGSKTAYIVFO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='vismodegib'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pyridaben',
    'C<sub>19</sub>H<sub>25</sub>ClN<sub>2</sub>OS',
    '',
    '96489-71-3',
    'DWFZBUWUXWZWKD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pyridaben'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tembotrione',
    'C<sub>17</sub>H<sub>16</sub>ClF<sub>3</sub>O<sub>6</sub>S',
    '',
    '335104-84-2',
    'IUQAXCIUEPFPSF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>9</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tembotrione'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>9</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tembotrione'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fluensulfone',
    'C<sub>7</sub>H<sub>5</sub>ClF<sub>3</sub>NO<sub>2</sub>S<sub>2</sub>',
    '',
    '318290-98-1',
    'XSNMWAPKHUGZGQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fluensulfone'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fluothiuron',
    'C<sub>10</sub>H<sub>10</sub>Cl<sub>2</sub>F<sub>2</sub>N<sub>2</sub>OS',
    '',
    '33439-45-1',
    'YFEUKKUPOVGUIW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 2.3&times;10<sup>10</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fluothiuron'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'sulfentrazone',
    'C<sub>11</sub>H<sub>10</sub>Cl<sub>2</sub>F<sub>2</sub>N<sub>4</sub>O<sub>3</sub>S',
    '',
    '122836-35-5',
    'OORLZFUTLGXMEF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>7</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='sulfentrazone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>7</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='sulfentrazone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='sulfentrazone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'flurazole',
    'C<sub>12</sub>H<sub>7</sub>NO<sub>2</sub>ClF<sub>3</sub>S',
    '',
    '72850-64-7',
    'MKQSWTQPLLCSOB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='flurazole'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='flurazole'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='flurazole'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fipronil',
    'C<sub>12</sub>H<sub>4</sub>Cl<sub>2</sub>F<sub>6</sub>N<sub>4</sub>OS',
    '',
    '120068-37-3',
    'ZOCSXAVNDGMNBV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='fipronil'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='fipronil'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fipronil'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'flusulfamide',
    'C<sub>13</sub>H<sub>7</sub>Cl<sub>2</sub>F<sub>3</sub>N<sub>2</sub>O<sub>4</sub>S',
    '',
    '106917-52-6',
    'GNVDAZSPJWCIQZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='flusulfamide'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethiprole',
    'C<sub>13</sub>H<sub>9</sub>Cl<sub>2</sub>F<sub>3</sub>N<sub>4</sub>OS',
    '',
    '181587-01-9',
    'FNELVJVBIYMIMC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethiprole'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diclosulam',
    'C<sub>13</sub>H<sub>10</sub>Cl<sub>2</sub>FN<sub>5</sub>O<sub>3</sub>S',
    '',
    '145701-21-9',
    'QNXAVFXEJCPCJO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>10</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='diclosulam'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cloransulam-methyl',
    'C<sub>15</sub>H<sub>13</sub>ClFN<sub>5</sub>O<sub>5</sub>S',
    '',
    '147150-35-4',
    'BIKACRYIQSLICJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>11</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='cloransulam-methyl'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fluthiacet-methyl',
    'C<sub>15</sub>H<sub>15</sub>ClFN<sub>3</sub>O<sub>3</sub>S<sub>2</sub>',
    '',
    '117337-19-6',
    'ZCNQYNHDVRPZIH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='fluthiacet-methyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='fluthiacet-methyl'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fluthiacet-methyl'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fluthiacet-methyl'),
    (SELECT id from literature WHERE bibtexkey='2530'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2530'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'vemurafenib',
    'C<sub>23</sub>H<sub>18</sub>ClF<sub>2</sub>N<sub>3</sub>O<sub>3</sub>S',
    '',
    '918504-65-1',
    'GPXBXXGIAQBQNI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='vemurafenib'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tetrabromobisphenol S',
    'C<sub>12</sub>H<sub>6</sub>Br<sub>4</sub>O<sub>4</sub>S',
    '',
    '39635-79-5',
    'JHJUYGMZIWDHMO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrabromobisphenol S'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrabromobisphenol S'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrabromobisphenol S'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrabromobisphenol S'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,3-dibromo-5-[3,5-dibromo-4-(2,3-dibromopropoxy)benzenesulfonyl]-2-(2,3-dibromopropoxy)benzene',
    'C<sub>18</sub>H<sub>14</sub>Br<sub>8</sub>O<sub>4</sub>S',
    '',
    '42757-55-1',
    'CWZVMVIHYSYLSI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dibromo-5-[3,5-dibromo-4-(2,3-dibromopropoxy)benzenesulfonyl]-2-(2,3-dibromopropoxy)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dibromo-5-[3,5-dibromo-4-(2,3-dibromopropoxy)benzenesulfonyl]-2-(2,3-dibromopropoxy)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dibromo-5-[3,5-dibromo-4-(2,3-dibromopropoxy)benzenesulfonyl]-2-(2,3-dibromopropoxy)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1,3-dibromo-5-[3,5-dibromo-4-(2,3-dibromopropoxy)benzenesulfonyl]-2-(2,3-dibromopropoxy)benzene'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bromphenol blue',
    'C<sub>19</sub>H<sub>10</sub>Br<sub>4</sub>O<sub>5</sub>S',
    '',
    '115-39-9',
    'UDSAIICHUKSCKT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>13</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromphenol blue'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromphenol blue'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromphenol blue'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromphenol blue'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bromcresol green',
    'C<sub>21</sub>H<sub>14</sub>Br<sub>4</sub>O<sub>5</sub>S',
    '',
    '76-60-8',
    'FRPHFZCDPYBUAU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>13</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromcresol green'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromcresol green'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>9</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromcresol green'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromcresol green'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bromocresol purple',
    'C<sub>21</sub>H<sub>16</sub>Br<sub>2</sub>O<sub>5</sub>S',
    '',
    '115-40-2',
    'ABIUHPWEYMSGSR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>12</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromocresol purple'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'difethialone',
    'C<sub>31</sub>H<sub>23</sub>BrO<sub>2</sub>S',
    '',
    '104653-34-1',
    'VSVAQRUUFVBBFS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9',
    '',
    'V',
    (SELECT id from species WHERE iupac='difethialone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9',
    '',
    'V',
    (SELECT id from species WHERE iupac='difethialone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='difethialone'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'amisulbrom',
    'C<sub>13</sub>H<sub>13</sub>BrFN<sub>5</sub>O<sub>4</sub>S<sub>2</sub>',
    '',
    '348635-87-0',
    'BREATYVWRHIPIY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='amisulbrom'),
    (SELECT id from literature WHERE bibtexkey='macbean2012'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='amisulbrom'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'thifluzamide',
    'C<sub>13</sub>H<sub>6</sub>Br<sub>2</sub>F<sub>6</sub>N<sub>2</sub>O<sub>2</sub>S',
    '',
    '130000-40-7',
    'WOSNCVAPUOFXEH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='thifluzamide'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'amical 48',
    'C<sub>8</sub>H<sub>8</sub>I<sub>2</sub>O<sub>2</sub>S',
    'diiodomethyl p-tolyl sulfone',
    '20018-09-1',
    'XOILGBPDXMVFIP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='amical 48'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'flubendiamide',
    'C<sub>23</sub>H<sub>22</sub>F<sub>7</sub>IN<sub>2</sub>O<sub>4</sub>S',
    '',
    '272451-65-7',
    'ZGNITFSDLCMLGI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Sulfur (C, H, O, N, Cl, S)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='flubendiamide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO categories (catname) VALUES (
    'Organic species with phosphorus (P)');
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Phosphorus (C, H, O, N, Cl, Br, S, P)',
    (SELECT id from categories WHERE catname='Organic species with phosphorus (P)'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '9-icosyl-9-phosphabicyclo[4.2.1]nonane',
    'C<sub>28</sub>H<sub>55</sub>P',
    '',
    '13886-99-2',
    'UNOOEFGBOLKBFW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='9-icosyl-9-phosphabicyclo[4.2.1]nonane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='9-icosyl-9-phosphabicyclo[4.2.1]nonane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='9-icosyl-9-phosphabicyclo[4.2.1]nonane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='9-icosyl-9-phosphabicyclo[4.2.1]nonane'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'triphenylphosphine',
    'C<sub>18</sub>H<sub>15</sub>P',
    '',
    '603-35-0',
    'RIOQSEWOXXDEQQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triphenylphosphine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triphenylphosphine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triphenylphosphine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triphenylphosphine'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phosphoric acid, trimethyl ester',
    'C<sub>3</sub>H<sub>9</sub>O<sub>4</sub>P',
    'trimethyl phosphate',
    '512-56-1',
    'WVLBCYQITXONBZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='phosphoric acid, trimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3084'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='phosphoric acid, trimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phosphoric acid, trimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='phosphoric acid, trimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3393'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='phosphoric acid, trimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'trimethyl phosphite',
    'C<sub>3</sub>H<sub>9</sub>O<sub>3</sub>P',
    '',
    '121-45-9',
    'CYTQBVOFDCPGCX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trimethyl phosphite'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimethyl methylphosphonate',
    'C<sub>3</sub>H<sub>9</sub>O<sub>3</sub>P',
    '',
    '756-79-6',
    'VONWDASPFIQPDY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl methylphosphonate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6',
    '',
    '?',
    (SELECT id from species WHERE iupac='dimethyl methylphosphonate'),
    (SELECT id from literature WHERE bibtexkey='3393'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diethyl hydrogen phosphite',
    'C<sub>4</sub>H<sub>11</sub>O<sub>3</sub>P',
    '',
    '762-04-9',
    'MJUJXFBTEFXVKU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl hydrogen phosphite'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='diethyl hydrogen phosphite'),
    (SELECT id from literature WHERE bibtexkey='3393'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'triethylphosphate',
    'C<sub>6</sub>H<sub>15</sub>O<sub>4</sub>P',
    '',
    '78-40-0',
    'DQWPFSLDHJDLRL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='triethylphosphate'),
    (SELECT id from literature WHERE bibtexkey='3084'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'R',
    (SELECT id from species WHERE iupac='triethylphosphate'),
    (SELECT id from literature WHERE bibtexkey='1501'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='triethylphosphate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3682'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='triethylphosphate'),
    (SELECT id from literature WHERE bibtexkey='yaws2003handbook'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3579'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triethylphosphate'),
    (SELECT id from literature WHERE bibtexkey='3682'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3682-COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triethylphosphate'),
    (SELECT id from literature WHERE bibtexkey='3579'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3579-NN-GC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6',
    '',
    '?',
    (SELECT id from species WHERE iupac='triethylphosphate'),
    (SELECT id from literature WHERE bibtexkey='3393'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.6&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='triethylphosphate'),
    (SELECT id from literature WHERE bibtexkey='2440'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diethyl ethyl phosphonate',
    'C<sub>6</sub>H<sub>15</sub>O<sub>3</sub>P',
    '',
    '78-38-6',
    'AATNZNJRDOVKDD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4',
    '',
    '?',
    (SELECT id from species WHERE iupac='diethyl ethyl phosphonate'),
    (SELECT id from literature WHERE bibtexkey='3393'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'mevinphos',
    'C<sub>7</sub>H<sub>13</sub>O<sub>6</sub>P',
    '',
    '7786-34-7',
    'GEPDYQSQVLXLEU-AATRIKPKSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='mevinphos'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2614_pc_problem'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='mevinphos'),
    (SELECT id from literature WHERE bibtexkey='2455'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='mevinphos'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diisopropyl methanephosphonate',
    'C<sub>7</sub>H<sub>17</sub>O<sub>3</sub>P',
    '',
    '1445-75-6',
    'WOAFDHWYKSOANX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diisopropyl methanephosphonate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='diisopropyl methanephosphonate'),
    (SELECT id from literature WHERE bibtexkey='3393'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dibutyl hydrogen phosphite',
    'C<sub>8</sub>H<sub>19</sub>O<sub>3</sub>P',
    '',
    '1809-19-4',
    'NFJPGAKRJKLOJK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibutyl hydrogen phosphite'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dibutyl phosphate',
    'C<sub>8</sub>H<sub>19</sub>O<sub>4</sub>P',
    '',
    '107-66-4',
    'JYFHYPJRHGVZDY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dibutyl phosphate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tetraethyl pyrophosphate',
    'C<sub>8</sub>H<sub>20</sub>O<sub>7</sub>P<sub>2</sub>',
    '',
    '107-49-3',
    'IDCBOTIENDVCBQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tetraethyl pyrophosphate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tripropyl phosphate',
    'C<sub>9</sub>H<sub>21</sub>O<sub>4</sub>P',
    '',
    '513-08-6',
    'RXPQRKFMDQNODS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='tripropyl phosphate'),
    (SELECT id from literature WHERE bibtexkey='3084'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'triallyl phosphate',
    'C<sub>9</sub>H<sub>15</sub>O<sub>4</sub>P',
    '',
    '1623-19-4',
    'XHGIFBQQEGRTPB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triallyl phosphate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tributylphosphate',
    'C<sub>12</sub>H<sub>27</sub>O<sub>4</sub>P',
    '',
    '126-73-8',
    'STCOOQWBFONSKY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0',
    '',
    'V',
    (SELECT id from species WHERE iupac='tributylphosphate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tributylphosphate'),
    (SELECT id from literature WHERE bibtexkey='2452'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8',
    '',
    'V',
    (SELECT id from species WHERE iupac='tributylphosphate'),
    (SELECT id from literature WHERE bibtexkey='2971'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hexaethyl tetraphosphate',
    'C<sub>12</sub>H<sub>30</sub>O<sub>13</sub>P<sub>4</sub>',
    '',
    '757-58-4',
    'DAJYZXUXDOSMCG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexaethyl tetraphosphate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'crotoxyphos',
    'C<sub>14</sub>H<sub>19</sub>O<sub>6</sub>P',
    '',
    '7700-17-6',
    'XXXSILNSXNPGKG-ZHACJKMWSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='crotoxyphos'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='crotoxyphos'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='crotoxyphos'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phosphoric acid, dibutyl phenyl ester',
    'C<sub>14</sub>H<sub>23</sub>O<sub>4</sub>P',
    '',
    '2528-36-1',
    'YICSVBJRVMLQNS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phosphoric acid, dibutyl phenyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bis(2-ethylhexyl) hydrogen phosphite',
    'C<sub>16</sub>H<sub>35</sub>O<sub>3</sub>P',
    '',
    '3658-48-8',
    'HZIUHEQKVCPTAJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis(2-ethylhexyl) hydrogen phosphite'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='bis(2-ethylhexyl) hydrogen phosphite'),
    (SELECT id from literature WHERE bibtexkey='3393'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bis(2-ethylhexyl)hydrogen phosphate',
    'C<sub>16</sub>H<sub>35</sub>O<sub>4</sub>P',
    'bis(2-ethylhexyl) phosphate',
    '298-07-7',
    'SEGLCEQVOFDUPX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis(2-ethylhexyl)hydrogen phosphate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'triphenyl phosphate',
    'C<sub>18</sub>H<sub>15</sub>O<sub>4</sub>P',
    '',
    '115-86-6',
    'XZZNDPSIHUTMOC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '',
    'V',
    (SELECT id from species WHERE iupac='triphenyl phosphate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tris(2-butoxyethyl) phosphate',
    'C<sub>18</sub>H<sub>39</sub>O<sub>7</sub>P',
    '',
    '78-51-3',
    'WTLBZVNBAKMVDP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tris(2-butoxyethyl) phosphate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'p-cresyl diphenyl phosphate',
    'C<sub>19</sub>H<sub>17</sub>O<sub>4</sub>P',
    '',
    '78-31-9',
    'OJUZRFGUKHQNJX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='p-cresyl diphenyl phosphate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'triphenylphosphine oxide',
    'C<sub>18</sub>H<sub>15</sub>OP',
    '',
    '791-28-6',
    'FIQMHBFVRAXMOP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triphenylphosphine oxide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triphenylphosphine oxide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triphenylphosphine oxide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triphenylphosphine oxide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phosphorous acid, triphenyl ester',
    'C<sub>18</sub>H<sub>15</sub>O<sub>3</sub>P',
    '',
    '101-02-0',
    'HVLLSGMXQDNUAL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phosphorous acid, triphenyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phosphorous acid, triphenyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phosphorous acid, triphenyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phosphorous acid, triphenyl ester'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'trihexylphosphine oxide',
    'C<sub>18</sub>H<sub>39</sub>OP',
    '',
    '3084-48-8',
    'PPDZLUVUQQGIOJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trihexylphosphine oxide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trihexylphosphine oxide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trihexylphosphine oxide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trihexylphosphine oxide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phosphoric acid, octyl diphenyl ester',
    'C<sub>20</sub>H<sub>27</sub>O<sub>4</sub>P',
    '',
    '115-88-8',
    'YAFOVCNAQTZDQB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phosphoric acid, octyl diphenyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'octyldihexylphosphine oxide',
    'C<sub>20</sub>H<sub>43</sub>OP',
    '',
    '31160-64-2',
    'XHRRUIJGMKIISX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octyldihexylphosphine oxide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octyldihexylphosphine oxide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octyldihexylphosphine oxide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octyldihexylphosphine oxide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'octicizer',
    'C<sub>20</sub>H<sub>27</sub>O<sub>4</sub>P',
    '',
    '1241-94-7',
    'CGSLYBDCEGBZCG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octicizer'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octicizer'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='octicizer'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tris(methylphenyl) phosphate',
    'C<sub>21</sub>H<sub>21</sub>O<sub>4</sub>P',
    'tricresyl phosphate',
    '1330-78-5',
    'IUJIYUAKFBGBCG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tris(methylphenyl) phosphate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phosphoric acid, (1-methylethyl)phenyl diphenyl ester',
    'C<sub>21</sub>H<sub>21</sub>O<sub>4</sub>P',
    '',
    '28108-99-8',
    'JJXNVYMIYBNZQX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phosphoric acid, (1-methylethyl)phenyl diphenyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phosphoric acid, tris(2-methylphenyl) ester',
    'C<sub>21</sub>H<sub>21</sub>O<sub>4</sub>P',
    'tri-o-cresyl phosphate',
    '78-30-8',
    'YSMRWXYRXBRSND-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phosphoric acid, tris(2-methylphenyl) ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phosphoric acid, tris(3-methylphenyl) ester',
    'C<sub>21</sub>H<sub>21</sub>O<sub>4</sub>P',
    'tri-m-cresyl phosphate',
    '563-04-2',
    'RMLPZKRPSQVRAB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phosphoric acid, tris(3-methylphenyl) ester'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phosphoric acid, tris(3-methylphenyl) ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phosphoric acid, tris(3-methylphenyl) ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='phosphoric acid, tris(3-methylphenyl) ester'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phosphoric acid, tris(4-methylphenyl) ester',
    'C<sub>21</sub>H<sub>21</sub>O<sub>4</sub>P',
    'tri-p-cresyl phosphate',
    '78-32-0',
    'BOSMZFBHAYFUBJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phosphoric acid, tris(4-methylphenyl) ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(3-<i>tert</i>-butylphenyl) diphenyl phosphate',
    'C<sub>22</sub>H<sub>23</sub>O<sub>4</sub>P',
    '',
    '',
    'NIAVXHWAURFNOW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(3-<i>tert</i>-butylphenyl) diphenyl phosphate'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(4-<i>tert</i>-butylphenyl) diphenyl phosphate',
    'C<sub>22</sub>H<sub>23</sub>O<sub>4</sub>P',
    '',
    '981-40-8',
    'ULGAVXUJJBOWOD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(4-<i>tert</i>-butylphenyl) diphenyl phosphate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(4-<i>tert</i>-butylphenyl) diphenyl phosphate'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(4-<i>tert</i>-butylphenyl) diphenyl phosphate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(4-<i>tert</i>-butylphenyl) diphenyl phosphate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'isodecyl diphenyl phosphate',
    'C<sub>22</sub>H<sub>31</sub>O<sub>4</sub>P',
    '',
    '29761-21-5',
    'RYUJRXVZSJCHDZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isodecyl diphenyl phosphate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dioctylhexylphosphine oxide',
    'C<sub>22</sub>H<sub>47</sub>OP',
    '',
    '31160-66-4',
    'MKEFGIKZZDCMQC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dioctylhexylphosphine oxide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dioctylhexylphosphine oxide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dioctylhexylphosphine oxide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dioctylhexylphosphine oxide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tris(2,4-dimethylphenyl)phosphate',
    'C<sub>24</sub>H<sub>27</sub>O<sub>4</sub>P',
    '',
    '3862-12-2',
    'KOWVWXQNQNCRRS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tris(2,4-dimethylphenyl)phosphate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tris(2,5-dimethylphenyl)phosphate',
    'C<sub>24</sub>H<sub>27</sub>O<sub>4</sub>P',
    '',
    '19074-59-0',
    'MDHAARLWBHZGIP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tris(2,5-dimethylphenyl)phosphate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tris(2,6-dimethylphenyl)phosphate',
    'C<sub>24</sub>H<sub>27</sub>O<sub>4</sub>P',
    '',
    '121-06-2',
    'QLORRTLBSJTMSN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tris(2,6-dimethylphenyl)phosphate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tris(3,4-dimethylphenyl)phosphate',
    'C<sub>24</sub>H<sub>27</sub>O<sub>4</sub>P',
    '',
    '3862-11-1',
    'BCTKCHOESSAGCN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tris(3,4-dimethylphenyl)phosphate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tris(3,5-dimethylphenyl)phosphate',
    'C<sub>24</sub>H<sub>27</sub>O<sub>4</sub>P',
    '',
    '25653-16-1',
    'LLPMAOBOEQFPRE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tris(3,5-dimethylphenyl)phosphate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tris(4-isopropylphenyl) phosphate',
    'C<sub>27</sub>H<sub>33</sub>O<sub>4</sub>P',
    '',
    '26967-76-0',
    'ANVREEJNGJMLOV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tris(4-isopropylphenyl) phosphate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'trioctylphosphine oxide',
    'C<sub>24</sub>H<sub>51</sub>OP',
    '',
    '78-50-2',
    'ZMBHCYHQLYEYDV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trioctylphosphine oxide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trioctylphosphine oxide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trioctylphosphine oxide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trioctylphosphine oxide'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bis(2-ethylhexyl)-2-ethylhexyl phosphonate',
    'C<sub>24</sub>H<sub>51</sub>O<sub>3</sub>P',
    '',
    '126-63-6',
    'GOCVCBDBQYEFQD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis(2-ethylhexyl)-2-ethylhexyl phosphonate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis(2-ethylhexyl)-2-ethylhexyl phosphonate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis(2-ethylhexyl)-2-ethylhexyl phosphonate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis(2-ethylhexyl)-2-ethylhexyl phosphonate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='bis(2-ethylhexyl)-2-ethylhexyl phosphonate'),
    (SELECT id from literature WHERE bibtexkey='3393'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'didodecyl hydrogen phosphate',
    'C<sub>24</sub>H<sub>51</sub>O<sub>4</sub>P',
    '',
    '7057-92-3',
    'JTXUVYOABGUBMX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='didodecyl hydrogen phosphate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phosphoric acid, tris(2-ethylhexyl) ester',
    'C<sub>24</sub>H<sub>51</sub>O<sub>4</sub>P',
    'trioctyl phosphate',
    '78-42-2',
    'GTVWRXDRKAHEAD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='phosphoric acid, tris(2-ethylhexyl) ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diisodecylphenyl phosphite',
    'C<sub>26</sub>H<sub>47</sub>O<sub>3</sub>P',
    '',
    '25550-98-5',
    'SXXILWLQSQDLDL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diisodecylphenyl phosphite'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diisodecylphenyl phosphite'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diisodecylphenyl phosphite'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diisodecylphenyl phosphite'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '4-nonylphenyl diphenyl phosphate',
    'C<sub>27</sub>H<sub>33</sub>O<sub>4</sub>P',
    '',
    '64532-97-4',
    'LMCLPMXCYFSRNG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nonylphenyl diphenyl phosphate'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='4-nonylphenyl diphenyl phosphate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='4-nonylphenyl diphenyl phosphate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'resorcinol bis(diphenyl phosphate)',
    'C<sub>30</sub>H<sub>24</sub>O<sub>8</sub>P<sub>2</sub>',
    '',
    '57583-54-7',
    'OWICEWMBIBPFAH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='resorcinol bis(diphenyl phosphate)'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='resorcinol bis(diphenyl phosphate)'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='resorcinol bis(diphenyl phosphate)'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>16</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='resorcinol bis(diphenyl phosphate)'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hydroquinone bis(diphenyl phosphate)',
    'C<sub>30</sub>H<sub>24</sub>O<sub>8</sub>P<sub>2</sub>',
    '',
    '51732-57-1',
    'RECLNCPBBUHRDY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>12</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hydroquinone bis(diphenyl phosphate)'),
    (SELECT id from literature WHERE bibtexkey='3627'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tris(4-<i>tert</i>-butylphenyl) phosphate',
    'C<sub>30</sub>H<sub>39</sub>O<sub>4</sub>P',
    '',
    '78-33-1',
    'LORSVOJSXMHDHF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tris(4-<i>tert</i>-butylphenyl) phosphate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tris(4-<i>tert</i>-butylphenyl) phosphate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tris(4-<i>tert</i>-butylphenyl) phosphate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tris(4-<i>tert</i>-butylphenyl) phosphate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tris-(2,4-di-<i>tert</i>-butylphenyl) phosphite',
    'C<sub>42</sub>H<sub>63</sub>O<sub>3</sub>P',
    '',
    '31570-04-4',
    'JKIJEFPNVSHHEI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tris-(2,4-di-<i>tert</i>-butylphenyl) phosphite'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tris-(2,4-di-<i>tert</i>-butylphenyl) phosphite'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tris-(2,4-di-<i>tert</i>-butylphenyl) phosphite'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tris-(2,4-di-<i>tert</i>-butylphenyl) phosphite'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'glyphosate',
    'C<sub>3</sub>H<sub>8</sub>NO<sub>5</sub>P',
    '',
    '1071-83-6',
    'XDDAORKBJWWYJS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='glyphosate'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='glyphosate'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'krenite',
    'C<sub>3</sub>H<sub>11</sub>N<sub>2</sub>O<sub>4</sub>P',
    'fosamine-ammonium',
    '25954-13-6',
    'OTSAMNSACVKIOJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>7</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='krenite'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tabun',
    'C<sub>5</sub>H<sub>11</sub>N<sub>2</sub>O<sub>2</sub>P',
    '',
    '77-81-6',
    'PJVJTCIRVMBVIA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tabun'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tabun'),
    (SELECT id from literature WHERE bibtexkey='3393'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tabun'),
    (SELECT id from literature WHERE bibtexkey='3121'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'glufosinate-ammonium',
    'C<sub>5</sub>H<sub>15</sub>N<sub>2</sub>O<sub>4</sub>P',
    '',
    '77182-82-2',
    'ZBMRKNMTMPPMMK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>8</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='glufosinate-ammonium'),
    (SELECT id from literature WHERE bibtexkey='macbean2012'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hexamethylphosphoramide',
    'C<sub>6</sub>H<sub>18</sub>N<sub>3</sub>OP',
    '',
    '680-31-9',
    'GNOIPBMMFNIUFM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexamethylphosphoramide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexamethylphosphoramide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'monocrotophos',
    'C<sub>7</sub>H<sub>14</sub>NO<sub>5</sub>P',
    '',
    '6923-22-4',
    'KRTSDMXIXPKRQR-AATRIKPKSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>7</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='monocrotophos'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '',
    'V',
    (SELECT id from species WHERE iupac='monocrotophos'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2614_pc_problem'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dicrotophos',
    'C<sub>8</sub>H<sub>16</sub>NO<sub>5</sub>P',
    '',
    '141-66-2',
    'VEENJGZXVHKXNB-VOTSOKGWSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dicrotophos'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dicrotophos'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dicrotophos'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dicrotophos'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'octamethyldiphosphoramide',
    'C<sub>8</sub>H<sub>24</sub>N<sub>4</sub>O<sub>3</sub>P<sub>2</sub>',
    'schradan',
    '152-16-9',
    'SZKKRCSOSQAJDE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>11</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octamethyldiphosphoramide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fyrol 6',
    'C<sub>9</sub>H<sub>22</sub>NO<sub>5</sub>P',
    'diethyl ((diethanolamino)methyl) phosphonate',
    '2781-11-5',
    'CCJKFLLIJCGHMO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='fyrol 6'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diethyl 4-nitrophenyl phosphate',
    'C<sub>10</sub>H<sub>14</sub>NO<sub>6</sub>P',
    'paraoxon',
    '311-45-5',
    'WYMSBXTXOHUIGT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diethyl 4-nitrophenyl phosphate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diethyl 4-nitrophenyl phosphate'),
    (SELECT id from literature WHERE bibtexkey='2452'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl 4-nitrophenyl phosphate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl 4-nitrophenyl phosphate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='diethyl 4-nitrophenyl phosphate'),
    (SELECT id from literature WHERE bibtexkey='3393'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimethyl 4-nitrophenyl phosphate',
    'C<sub>8</sub>H<sub>10</sub>NO<sub>6</sub>P',
    'methyl paraoxon',
    '950-35-6',
    'BAFQDKPJKOLXFZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 1.1&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dimethyl 4-nitrophenyl phosphate'),
    (SELECT id from literature WHERE bibtexkey='3090'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'buminafos',
    'C<sub>18</sub>H<sub>38</sub>NO<sub>3</sub>P',
    '',
    '51249-05-9',
    'NMBXMBCZBXUXAM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0',
    '',
    '?',
    (SELECT id from species WHERE iupac='buminafos'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methylphosphonyldifluoride',
    'CH<sub>3</sub>F<sub>2</sub>OP',
    '',
    '676-99-3',
    'PQIOSYKVBBWRRI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylphosphonyldifluoride'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'sarin',
    'C<sub>4</sub>H<sub>10</sub>FO<sub>2</sub>P',
    '',
    '107-44-8',
    'DYAHQFWOVKZOOW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='sarin'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1',
    '',
    '?',
    (SELECT id from species WHERE iupac='sarin'),
    (SELECT id from literature WHERE bibtexkey='3393'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='sarin'),
    (SELECT id from literature WHERE bibtexkey='3121'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimefox',
    'C<sub>4</sub>H<sub>12</sub>FN<sub>2</sub>OP',
    '',
    '115-26-4',
    'PGJBQBDNXAZHBP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dimefox'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'isoflurophate',
    'C<sub>6</sub>H<sub>14</sub>FO<sub>3</sub>P',
    'diisopropyl fluorophosphate',
    '55-91-4',
    'MUCZHBLJLSDCSD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isoflurophate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='isoflurophate'),
    (SELECT id from literature WHERE bibtexkey='3393'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cyclohexyl methylphosphonofluoridate',
    'C<sub>7</sub>H<sub>14</sub>FO<sub>2</sub>P',
    'cyclosarin',
    '329-99-7',
    'SNTRKUOVAPUGAY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='cyclohexyl methylphosphonofluoridate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='cyclohexyl methylphosphonofluoridate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclohexyl methylphosphonofluoridate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'soman',
    'C<sub>7</sub>H<sub>16</sub>FO<sub>2</sub>P',
    '',
    '96-64-0',
    'GRXKLBBBQUKJJZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='soman'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    '?',
    (SELECT id from species WHERE iupac='soman'),
    (SELECT id from literature WHERE bibtexkey='3393'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    '?',
    (SELECT id from species WHERE iupac='soman'),
    (SELECT id from literature WHERE bibtexkey='3121'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'mipafox',
    'C<sub>6</sub>H<sub>16</sub>FN<sub>2</sub>OP',
    '',
    '371-86-8',
    'UOSHUBFBCPGQAY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='mipafox'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phenylphosphonous dichloride',
    'C<sub>6</sub>H<sub>5</sub>Cl<sub>2</sub>P',
    '',
    '644-97-3',
    'IMDXZWRLUZPMDH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenylphosphonous dichloride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenylphosphonous dichloride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenylphosphonous dichloride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenylphosphonous dichloride'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chlorphonium chloride',
    'C<sub>19</sub>H<sub>32</sub>Cl<sub>3</sub>P',
    '',
    '115-78-6',
    'IVHVNMLJNASKHW-UHFFFAOYSA-M',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chlorphonium chloride'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'triclofos',
    'C<sub>2</sub>H<sub>4</sub>Cl<sub>3</sub>O<sub>4</sub>P',
    '',
    '306-52-5',
    'YYQRGCZGSFRBAM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triclofos'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(2-chloroethyl)-phosphonic acid',
    'C<sub>2</sub>H<sub>6</sub>ClO<sub>3</sub>P',
    'ethephon',
    '16672-87-0',
    'UDPGUMQDCGORJQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>7</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='(2-chloroethyl)-phosphonic acid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 6.9&times;10<sup>6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(2-chloroethyl)-phosphonic acid'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-hydroxy-2,2,2-trichloroethylphosphonic acid, dimethyl ester',
    'C<sub>4</sub>H<sub>8</sub>Cl<sub>3</sub>O<sub>4</sub>P',
    'trichlorfon',
    '52-68-6',
    'NFACJZMKEDPNKN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-hydroxy-2,2,2-trichloroethylphosphonic acid, dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 8.1&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='1-hydroxy-2,2,2-trichloroethylphosphonic acid, dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2229'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-2,2,2-trichloroethylphosphonic acid, dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-2,2,2-trichloroethylphosphonic acid, dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-hydroxy-2,2,2-trichloroethylphosphonic acid, dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='1-hydroxy-2,2,2-trichloroethylphosphonic acid, dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-hydroxy-2,2,2-trichloroethylphosphonic acid, dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimethyl-2,2-dichlorovinyl phosphate',
    'C<sub>4</sub>H<sub>7</sub>Cl<sub>2</sub>O<sub>4</sub>P',
    'dichlorvos',
    '62-73-7',
    'OEBRKCOSUFCWJD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>1</sup>',
    '11000',
    'M',
    (SELECT id from species WHERE iupac='dimethyl-2,2-dichlorovinyl phosphate'),
    (SELECT id from literature WHERE bibtexkey='2438'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dimethyl-2,2-dichlorovinyl phosphate'),
    (SELECT id from literature WHERE bibtexkey='2229'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dimethyl-2,2-dichlorovinyl phosphate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2',
    '',
    'V',
    (SELECT id from species WHERE iupac='dimethyl-2,2-dichlorovinyl phosphate'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3',
    '',
    'V',
    (SELECT id from species WHERE iupac='dimethyl-2,2-dichlorovinyl phosphate'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dimethyl-2,2-dichlorovinyl phosphate'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl-2,2-dichlorovinyl phosphate'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_test'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tris(2-chloroethyl) phosphate',
    'C<sub>6</sub>H<sub>12</sub>Cl<sub>3</sub>O<sub>4</sub>P',
    '',
    '115-96-8',
    'HQUQLFOMPYWACS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '',
    'V',
    (SELECT id from species WHERE iupac='tris(2-chloroethyl) phosphate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cyclophosphamide',
    'C<sub>7</sub>H<sub>15</sub>Cl<sub>2</sub>N<sub>2</sub>O<sub>2</sub>P',
    '',
    '50-18-0',
    'CMSMOCZEIVJLDB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='cyclophosphamide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ifosfamide',
    'C<sub>7</sub>H<sub>15</sub>Cl<sub>2</sub>N<sub>2</sub>O<sub>2</sub>P',
    '',
    '3778-73-2',
    'HOMGKSMUEGBAAB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ifosfamide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'butonate',
    'C<sub>8</sub>H<sub>14</sub>Cl<sub>3</sub>O<sub>5</sub>P',
    '',
    '126-22-7',
    'BKAQXYNWONVOAX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='butonate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phosphoric acid, 7-chlorobicyclo[3.2.0]hepta-2,6-dien-6-yl dimethyl ester',
    'C<sub>9</sub>H<sub>12</sub>ClO<sub>4</sub>P',
    'heptenophos',
    '23560-59-0',
    'GBAWQJNHVWMTLU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='phosphoric acid, 7-chlorobicyclo[3.2.0]hepta-2,6-dien-6-yl dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='phosphoric acid, 7-chlorobicyclo[3.2.0]hepta-2,6-dien-6-yl dimethyl ester'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tris(2,3-dichloropropyl) phosphate',
    'C<sub>9</sub>H<sub>15</sub>Cl<sub>6</sub>O<sub>4</sub>P',
    '',
    '78-43-3',
    'JZZBTMVTLBHJHL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tris(2,3-dichloropropyl) phosphate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tris(1,3-dichloroisopropyl)phosphate',
    'C<sub>9</sub>H<sub>15</sub>Cl<sub>6</sub>O<sub>4</sub>P',
    '',
    '13674-87-8',
    'ASLWPAWFJZFCKF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tris(1,3-dichloroisopropyl)phosphate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tris(1,3-dichloroisopropyl)phosphate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tris(1,3-dichloroisopropyl)phosphate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tris(1,3-dichloroisopropyl)phosphate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tris(1,3-dichloroisopropyl)phosphate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tris(2-chloropropyl) phosphate',
    'C<sub>9</sub>H<sub>18</sub>Cl<sub>3</sub>O<sub>4</sub>P',
    '',
    '6145-73-9',
    'GTRSAMFYSUBAGN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tris(2-chloropropyl) phosphate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tris(2-chloropropyl) phosphate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tris(2-chloropropyl) phosphate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tris(2-chloropropyl) phosphate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tri-(2-chloroisopropyl)phosphate',
    'C<sub>9</sub>H<sub>18</sub>Cl<sub>3</sub>O<sub>4</sub>P',
    '',
    '13674-84-5',
    'KVMPUXDNESXNOH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tri-(2-chloroisopropyl)phosphate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tri-(2-chloroisopropyl)phosphate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tri-(2-chloroisopropyl)phosphate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tri-(2-chloroisopropyl)phosphate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tri-(2-chloroisopropyl)phosphate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bis(2-chloropropyl) 2-chloro-1-methylethyl phosphate',
    'C<sub>9</sub>H<sub>18</sub>Cl<sub>3</sub>O<sub>4</sub>P',
    '',
    '76649-15-5',
    'WDLBXPUJJVVRGX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis(2-chloropropyl) 2-chloro-1-methylethyl phosphate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis(2-chloropropyl) 2-chloro-1-methylethyl phosphate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis(2-chloropropyl) 2-chloro-1-methylethyl phosphate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis(2-chloropropyl) 2-chloro-1-methylethyl phosphate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tetrachlorvinphos',
    'C<sub>10</sub>H<sub>9</sub>Cl<sub>4</sub>O<sub>4</sub>P',
    '',
    '22248-79-9',
    'UBCKGWBNUIFUST-YHYXMXQVSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tetrachlorvinphos'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tetrachlorvinphos'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tetrachlorvinphos'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimethylvinphos',
    'C<sub>10</sub>H<sub>10</sub>Cl<sub>3</sub>O<sub>4</sub>P',
    '',
    '2274-67-1',
    'QSGNQELHULIMSJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dimethylvinphos'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diphenyl chlorophosphate',
    'C<sub>12</sub>H<sub>10</sub>ClO<sub>3</sub>P',
    '',
    '2524-64-3',
    'BHIIGRBMZRSDRI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='diphenyl chlorophosphate'),
    (SELECT id from literature WHERE bibtexkey='3393'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chlorfenvinphos',
    'C<sub>12</sub>H<sub>14</sub>Cl<sub>3</sub>O<sub>4</sub>P',
    'clofenvinfos',
    '470-90-6',
    'FSAVDKDHPDSCTO-XYOKQWHBSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chlorfenvinphos'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chlorfenvinphos'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chlorfenvinphos'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='chlorfenvinphos'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorfenvinphos'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'crufomate',
    'C<sub>12</sub>H<sub>19</sub>ClNO<sub>3</sub>P',
    'ruelene',
    '299-86-5',
    'BOFHKBLZOYVHSI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='crufomate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phosdiphen',
    'C<sub>14</sub>H<sub>11</sub>O<sub>4</sub>Cl<sub>4</sub>P',
    '',
    '36519-00-3',
    'HEMINMLPKZELPP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='phosdiphen'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phosphamidon',
    'C<sub>10</sub>H<sub>19</sub>ClNO<sub>5</sub>P',
    '',
    '13171-21-6',
    'RGCLLPNLLBQHPF-HJWRWDBZSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '',
    'V',
    (SELECT id from species WHERE iupac='phosphamidon'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8',
    '',
    'V',
    (SELECT id from species WHERE iupac='phosphamidon'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phosphamidon'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tris(2,3-dibromo-1-propyl) phosphate',
    'C<sub>9</sub>H<sub>15</sub>Br<sub>6</sub>O<sub>4</sub>P',
    '',
    '126-72-7',
    'PQYJRMFWJJONBO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tris(2,3-dibromo-1-propyl) phosphate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'naled',
    'C<sub>4</sub>H<sub>7</sub>Br<sub>2</sub>Cl<sub>2</sub>O<sub>4</sub>P',
    '',
    '300-76-5',
    'BUYMVQAILCEWRR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='naled'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-bromo-1,1-dimethylethyl 2-bromoethyl 2-chloroethyl phosphate',
    'C<sub>9</sub>H<sub>18</sub>Br<sub>2</sub>ClO<sub>4</sub>P',
    '',
    '125997-20-8',
    'GZSKSYDWLZIPOX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-bromo-1,1-dimethylethyl 2-bromoethyl 2-chloroethyl phosphate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-bromo-1,1-dimethylethyl 2-bromoethyl 2-chloroethyl phosphate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-bromo-1,1-dimethylethyl 2-bromoethyl 2-chloroethyl phosphate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-bromo-1,1-dimethylethyl 2-bromoethyl 2-chloroethyl phosphate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'leptophos',
    'C<sub>13</sub>H<sub>10</sub>O<sub>3</sub>BrCl<sub>2</sub>P',
    '',
    '21609-90-5',
    'CVRALZAYCYJELZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7',
    '',
    'L',
    (SELECT id from species WHERE iupac='leptophos'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7',
    '',
    'V',
    (SELECT id from species WHERE iupac='leptophos'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0',
    '',
    'V',
    (SELECT id from species WHERE iupac='leptophos'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0',
    '',
    'V',
    (SELECT id from species WHERE iupac='leptophos'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='leptophos'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tributyl phosphorotrithioite',
    'C<sub>12</sub>H<sub>27</sub>PS<sub>3</sub>',
    '',
    '150-50-5',
    'KLAPGAOQRZTCBI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tributyl phosphorotrithioite'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tributyl phosphorotrithioite'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tributyl phosphorotrithioite'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tributyl phosphorotrithioite'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tributyl phosphorotrithioite'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bis(2,6,6-trimethylbicyclo[3.1.1]hept-2-enyl) bis(2,6,6-trimethylbicyclo[3.1.1]hept-2-enyl)thiodiphosphonate',
    'C<sub>40</sub>H<sub>60</sub>P<sub>2</sub>S<sub>5</sub>',
    '',
    '68400-79-3',
    'ZZMOHCWFHCHISQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis(2,6,6-trimethylbicyclo[3.1.1]hept-2-enyl) bis(2,6,6-trimethylbicyclo[3.1.1]hept-2-enyl)thiodiphosphonate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995EPI'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis(2,6,6-trimethylbicyclo[3.1.1]hept-2-enyl) bis(2,6,6-trimethylbicyclo[3.1.1]hept-2-enyl)thiodiphosphonate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995SPARC'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis(2,6,6-trimethylbicyclo[3.1.1]hept-2-enyl) bis(2,6,6-trimethylbicyclo[3.1.1]hept-2-enyl)thiodiphosphonate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995COSMO'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bis(2,6,6-trimethylbicyclo[3.1.1]hept-2-enyl) bis(2,6,6-trimethylbicyclo[3.1.1]hept-2-enyl)thiodiphosphonate'),
    (SELECT id from literature WHERE bibtexkey='2995'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='supplement'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2995ABSOLV'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'thiometon',
    'C<sub>6</sub>H<sub>15</sub>O<sub>2</sub>PS<sub>3</sub>',
    '',
    '640-15-3',
    'OPASCBHCTNRLRM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='thiometon'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'demeton-S-methyl sulfone',
    'C<sub>6</sub>H<sub>15</sub>O<sub>5</sub>PS<sub>2</sub>',
    '',
    '17040-19-6',
    'PZIRJMYRYORVIT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&lt; 2.3&times;10<sup>10</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='demeton-S-methyl sulfone'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'oxydemeton-methyl',
    'C<sub>6</sub>H<sub>15</sub>O<sub>4</sub>PS<sub>2</sub>',
    '',
    '301-12-2',
    'PMCVMORKVPSKHZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='oxydemeton-methyl'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'demeton-O-methyl',
    'C<sub>6</sub>H<sub>15</sub>O<sub>3</sub>PS<sub>2</sub>',
    '',
    '867-27-6',
    'ZVZQKNVMDKSGGF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2',
    '',
    '?',
    (SELECT id from species WHERE iupac='demeton-O-methyl'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'demeton-S-methyl',
    'C<sub>6</sub>H<sub>15</sub>O<sub>3</sub>PS<sub>2</sub>',
    '',
    '919-86-8',
    'WEBQKRLKWNIYKK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='demeton-S-methyl'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='demeton-S-methyl'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methacrifos',
    'C<sub>7</sub>H<sub>13</sub>O<sub>5</sub>PS',
    '',
    '62610-77-9',
    'NTAHCMPOMKHKEU-AATRIKPKSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methacrifos'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phorate',
    'C<sub>7</sub>H<sub>17</sub>O<sub>2</sub>PS<sub>3</sub>',
    '',
    '298-02-2',
    'BULVZWIRKLYCBC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='phorate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='phorate'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='phorate'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='phorate'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phorate'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'salithion',
    'C<sub>8</sub>H<sub>9</sub>O<sub>3</sub>PS',
    '',
    '3811-49-2',
    'OUNSASXJZHBGAI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='salithion'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'acetoxon',
    'C<sub>8</sub>H<sub>17</sub>O<sub>5</sub>PS',
    '',
    '2425-25-4',
    'ZRCQYAQOWIQUBA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='acetoxon'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'demeton-O',
    'C<sub>8</sub>H<sub>19</sub>O<sub>3</sub>PS<sub>2</sub>',
    '',
    '298-03-3',
    'DGLIBALSRMUQDD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1',
    '',
    '?',
    (SELECT id from species WHERE iupac='demeton-O'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'demeton-S',
    'C<sub>8</sub>H<sub>19</sub>O<sub>3</sub>PS<sub>2</sub>',
    'isosystox',
    '126-75-0',
    'GRPRVIYRYGLIJU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='demeton-S'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'sulfotep',
    'C<sub>8</sub>H<sub>20</sub>O<sub>5</sub>P<sub>2</sub>S<sub>2</sub>',
    '',
    '3689-24-5',
    'XIUROWKZWPIAIB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'V',
    (SELECT id from species WHERE iupac='sulfotep'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4',
    '',
    'V',
    (SELECT id from species WHERE iupac='sulfotep'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='sulfotep'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='sulfotep'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_test'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tetrakis(hydroxymethyl) phosphonium sulfate',
    'C<sub>8</sub>H<sub>24</sub>O<sub>12</sub>P<sub>2</sub>S',
    '',
    '55566-30-8',
    'YIEDHPBKGZGLIK-UHFFFAOYSA-L',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>17</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrakis(hydroxymethyl) phosphonium sulfate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethoprophos',
    'C<sub>8</sub>H<sub>19</sub>O<sub>2</sub>PS<sub>2</sub>',
    '',
    '13194-48-4',
    'VJYFKVYYMZPMAB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethoprophos'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethoprophos'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'disulfoton',
    'C<sub>8</sub>H<sub>19</sub>O<sub>2</sub>PS<sub>3</sub>',
    '',
    '298-04-4',
    'DOFZAZXDOSGAJZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='disulfoton'),
    (SELECT id from literature WHERE bibtexkey='2965'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='disulfoton'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='disulfoton'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='disulfoton'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='disulfoton'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='disulfoton'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_test'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'endothion',
    'C<sub>9</sub>H<sub>13</sub>O<sub>6</sub>PS',
    '',
    '2778-04-3',
    'YCAGGFXSFQFVQL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='endothion'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'terbufos',
    'C<sub>9</sub>H<sub>21</sub>O<sub>2</sub>PS<sub>3</sub>',
    '',
    '13071-79-9',
    'XLNZEKHULJKQBA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='terbufos'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='terbufos'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='terbufos'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='terbufos'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethion',
    'C<sub>9</sub>H<sub>22</sub>O<sub>4</sub>P<sub>2</sub>S<sub>4</sub>',
    '',
    '563-12-2',
    'RIZMRRKBZQXFOY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethion'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethion'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethion'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='ethion'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethion'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fonofos',
    'C<sub>10</sub>H<sub>15</sub>OPS<sub>2</sub>',
    '',
    '944-22-9',
    'KVGLBTYUCJYMND-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'V',
    (SELECT id from species WHERE iupac='fonofos'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'V',
    (SELECT id from species WHERE iupac='fonofos'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'V',
    (SELECT id from species WHERE iupac='fonofos'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fonofos'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fenthion',
    'C<sub>10</sub>H<sub>15</sub>O<sub>3</sub>PS<sub>2</sub>',
    '',
    '55-38-9',
    'PNVJTZOFSHSLTO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8',
    '',
    'V',
    (SELECT id from species WHERE iupac='fenthion'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='fenthion'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='fenthion'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='fenthion'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fenthion'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'malathion',
    'C<sub>10</sub>H<sub>19</sub>O<sub>6</sub>PS<sub>2</sub>',
    '',
    '121-75-5',
    'JXSJBGJIGXNWCI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '8300',
    'L',
    (SELECT id from species WHERE iupac='malathion'),
    (SELECT id from literature WHERE bibtexkey='3518'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='malathion'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='malathion'),
    (SELECT id from literature WHERE bibtexkey='2538'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='malathion'),
    (SELECT id from literature WHERE bibtexkey='1144'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='malathion'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='malathion'),
    (SELECT id from literature WHERE bibtexkey='1995'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='malathion'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='malathion'),
    (SELECT id from literature WHERE bibtexkey='2452'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='malathion'),
    (SELECT id from literature WHERE bibtexkey='2455'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='malathion'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3',
    '',
    'X',
    (SELECT id from species WHERE iupac='malathion'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='malathion'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='malathion'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='malathion'),
    (SELECT id from literature WHERE bibtexkey='3393'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'malaoxon',
    'C<sub>10</sub>H<sub>19</sub>O<sub>7</sub>PS',
    '',
    '1634-78-2',
    'WSORODGWGUUOBO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='malaoxon'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cadusafos',
    'C<sub>10</sub>H<sub>23</sub>O<sub>2</sub>PS<sub>2</sub>',
    '',
    '95465-99-9',
    'KXRPCFINVWWFHQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6',
    '',
    'V',
    (SELECT id from species WHERE iupac='cadusafos'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fensulfothion',
    'C<sub>11</sub>H<sub>17</sub>O<sub>4</sub>PS<sub>2</sub>',
    '',
    '115-90-2',
    'XDNBJTQLKCIJBV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fensulfothion'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phenthoate',
    'C<sub>12</sub>H<sub>17</sub>O<sub>4</sub>PS<sub>2</sub>',
    '',
    '2597-03-7',
    'XAMUDJHXFNRLCY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='phenthoate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='phenthoate'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'sulprofos',
    'C<sub>12</sub>H<sub>19</sub>O<sub>2</sub>PS<sub>3</sub>',
    '',
    '35400-43-2',
    'JXHJNEJVUNHLKO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='sulprofos'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='sulprofos'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'S,S,S-tributyl phosphorotrithioate',
    'C<sub>12</sub>H<sub>27</sub>OPS<sub>3</sub>',
    'DEF',
    '78-48-8',
    'ZOKXUAHZSKEQSS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='S,S,S-tributyl phosphorotrithioate'),
    (SELECT id from literature WHERE bibtexkey='1144'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3',
    '',
    'V',
    (SELECT id from species WHERE iupac='S,S,S-tributyl phosphorotrithioate'),
    (SELECT id from literature WHERE bibtexkey='2452'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'aspon',
    'C<sub>12</sub>H<sub>28</sub>O<sub>5</sub>P<sub>2</sub>S<sub>2</sub>',
    'tetrapropyl dithiopyrophosphate',
    '3244-90-4',
    'IIDFEIDMIKSJSV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1',
    '',
    '?',
    (SELECT id from species WHERE iupac='aspon'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'iprobenphos',
    'C<sub>13</sub>H<sub>21</sub>O<sub>3</sub>PS',
    '',
    '26087-47-8',
    'FCOAHACKGGIURQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='iprobenphos'),
    (SELECT id from literature WHERE bibtexkey='2538'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propaphos',
    'C<sub>13</sub>H<sub>21</sub>O<sub>4</sub>PS',
    '',
    '7292-16-2',
    'PWYIUEFFPNVCMW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propaphos'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propaphos'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='propaphos'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propaphos'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'edifenphos',
    'C<sub>14</sub>H<sub>15</sub>O<sub>2</sub>PS<sub>2</sub>',
    '',
    '17109-49-8',
    'AWZOLILCOUMRDG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='edifenphos'),
    (SELECT id from literature WHERE bibtexkey='2538'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='edifenphos'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='edifenphos'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'systox',
    'C<sub>16</sub>H<sub>38</sub>O<sub>6</sub>P<sub>2</sub>S<sub>4</sub>',
    '',
    '8065-48-3',
    'FAXIJTUDSBIMHY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='systox'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'temefos',
    'C<sub>16</sub>H<sub>20</sub>O<sub>6</sub>P<sub>2</sub>S<sub>3</sub>',
    'temephos',
    '3383-96-8',
    'WWJZWCUNLNYYAU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'X',
    (SELECT id from species WHERE iupac='temefos'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='temefos'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='temefos'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methamidophos',
    'C<sub>2</sub>H<sub>8</sub>NOPS<sub>2</sub>',
    '',
    '10265-92-6',
    'NNKVPIKMPCQWCG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methamidophos'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'acephate',
    'C<sub>4</sub>H<sub>10</sub>NO<sub>3</sub>PS',
    '',
    '30560-19-1',
    'YASYVMFAVPKPKE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>7</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='acephate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>7</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='acephate'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>5</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='acephate'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='acephate'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimethoate',
    'C<sub>5</sub>H<sub>12</sub>NO<sub>3</sub>PS<sub>2</sub>',
    '',
    '60-51-5',
    'MCWXGJITAZMZEV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dimethoate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dimethoate'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dimethoate'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='dimethoate'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethoate'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_val'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'omethoate',
    'C<sub>5</sub>H<sub>12</sub>NO<sub>4</sub>PS',
    '',
    '1113-02-6',
    'PZXOQEXFMJCDPG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>8</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='omethoate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methidathion',
    'C<sub>6</sub>H<sub>11</sub>N<sub>2</sub>O<sub>4</sub>PS<sub>3</sub>',
    '',
    '950-37-8',
    'MEBQXILRKZHVCX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methidathion'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methidathion'),
    (SELECT id from literature WHERE bibtexkey='2452'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methidathion'),
    (SELECT id from literature WHERE bibtexkey='2968'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fosthietan',
    'C<sub>6</sub>H<sub>12</sub>NO<sub>3</sub>PS<sub>2</sub>',
    '',
    '21548-32-3',
    'RHJOIOVESMTJEK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='fosthietan'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fosthietan'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'formothion',
    'C<sub>6</sub>H<sub>12</sub>NO<sub>4</sub>PS<sub>2</sub>',
    '',
    '2540-82-1',
    'AIKKULXCBHRFOS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='formothion'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'menazon',
    'C<sub>6</sub>H<sub>12</sub>N<sub>5</sub>O<sub>2</sub>PS<sub>2</sub>',
    '',
    '78-57-9',
    'SUYHYHLFUHHVJQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.6&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='menazon'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethoate-methyl',
    'C<sub>6</sub>H<sub>14</sub>NO<sub>3</sub>PS<sub>2</sub>',
    '',
    '116-01-8',
    'DICRHEJCQXFJBY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethoate-methyl'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'glyphosate-trimesium',
    'C<sub>6</sub>H<sub>16</sub>NO<sub>5</sub>PS',
    '',
    '81591-81-3',
    'RUCAXVJJQQJZGU-UHFFFAOYSA-M',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 2.3&times;10<sup>10</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='glyphosate-trimesium'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phosfolan',
    'C<sub>7</sub>H<sub>14</sub>NO<sub>3</sub>PS<sub>2</sub>',
    'cyolane',
    '947-02-4',
    'ILBONRFSLATCRE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='phosfolan'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methylparathion',
    'C<sub>8</sub>H<sub>10</sub>NO<sub>5</sub>PS',
    'parathion-methyl',
    '298-00-0',
    'RLBIQVVOMOPOHC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='methylparathion'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methylparathion'),
    (SELECT id from literature WHERE bibtexkey='3404'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methylparathion'),
    (SELECT id from literature WHERE bibtexkey='893'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methylparathion'),
    (SELECT id from literature WHERE bibtexkey='1144'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='methylparathion'),
    (SELECT id from literature WHERE bibtexkey='2454'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methylparathion'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methylparathion'),
    (SELECT id from literature WHERE bibtexkey='3090'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methylparathion'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methylparathion'),
    (SELECT id from literature WHERE bibtexkey='2452'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methylparathion'),
    (SELECT id from literature WHERE bibtexkey='2455'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methylparathion'),
    (SELECT id from literature WHERE bibtexkey='2454'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='methylparathion'),
    (SELECT id from literature WHERE bibtexkey='3945'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='atroomT'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='methylparathion'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylparathion'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylparathion'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'zinophos',
    'C<sub>8</sub>H<sub>13</sub>N<sub>2</sub>O<sub>3</sub>PS',
    'thionazin',
    '297-97-2',
    'IRVDMKJLOCGUBJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='zinophos'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='zinophos'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='zinophos'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'vamidothion',
    'C<sub>8</sub>H<sub>18</sub>NO<sub>4</sub>PS<sub>2</sub>',
    '',
    '2275-23-2',
    'LESVOLZBIFDZGS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='vamidothion'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'cyanophos',
    'C<sub>9</sub>H<sub>10</sub>NO<sub>3</sub>PS',
    '',
    '2636-26-2',
    'SCKHCCSZFPSHGR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'V',
    (SELECT id from species WHERE iupac='cyanophos'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fenitrothion',
    'C<sub>9</sub>H<sub>12</sub>NO<sub>5</sub>PS',
    '',
    '122-14-5',
    'ZNOLGFHPUIJIMJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='fenitrothion'),
    (SELECT id from literature WHERE bibtexkey='2538'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='fenitrothion'),
    (SELECT id from literature WHERE bibtexkey='2454'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='fenitrothion'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='fenitrothion'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='fenitrothion'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='fenitrothion'),
    (SELECT id from literature WHERE bibtexkey='2454'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    'X',
    (SELECT id from species WHERE iupac='fenitrothion'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fenitrothion'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fenitrothion'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fosthiazate-1',
    'C<sub>9</sub>H<sub>18</sub>NO<sub>3</sub>PS<sub>2</sub>',
    '',
    '98886-44-3',
    'DUFVKSUJRWYZQP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='fosthiazate-1'),
    (SELECT id from literature WHERE bibtexkey='macbean2012'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fosthiazate-1'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='fosthiazate-1'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fosthiazate-1'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fosthiazate-1'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'prothoate',
    'C<sub>9</sub>H<sub>20</sub>NO<sub>3</sub>PS<sub>2</sub>',
    'trimethoate',
    '2275-18-5',
    'QTXHFDHVLBDJIO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='prothoate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'amiton',
    'C<sub>10</sub>H<sub>24</sub>NO<sub>3</sub>PS',
    '',
    '78-53-5',
    'PJISLFCKHOHLLP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='amiton'),
    (SELECT id from literature WHERE bibtexkey='3393'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'azinphos-methyl',
    'C<sub>10</sub>H<sub>12</sub>N<sub>3</sub>O<sub>3</sub>PS<sub>2</sub>',
    '',
    '86-50-0',
    'CJJOSEISRRTUQB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='azinphos-methyl'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='azinphos-methyl'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='azinphos-methyl'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '',
    'X',
    (SELECT id from species WHERE iupac='azinphos-methyl'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='azinphos-methyl'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'parathion',
    'C<sub>10</sub>H<sub>14</sub>NO<sub>5</sub>PS',
    'E 605',
    '56-38-2',
    'LCCNCVORNKJIRZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='parathion'),
    (SELECT id from literature WHERE bibtexkey='1144'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='parathion'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='parathion'),
    (SELECT id from literature WHERE bibtexkey='2973'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='parathion'),
    (SELECT id from literature WHERE bibtexkey='2967'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='parathion'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='parathion'),
    (SELECT id from literature WHERE bibtexkey='2452'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='parathion'),
    (SELECT id from literature WHERE bibtexkey='2455'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='parathion'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='parathion'),
    (SELECT id from literature WHERE bibtexkey='2968'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='parathion'),
    (SELECT id from literature WHERE bibtexkey='2979'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='parathion'),
    (SELECT id from literature WHERE bibtexkey='macbean2012'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.0&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='parathion'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='parathion'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='parathion'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='parathion'),
    (SELECT id from literature WHERE bibtexkey='3393'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'isoparathion',
    'C<sub>10</sub>H<sub>14</sub>NO<sub>5</sub>PS',
    '',
    '597-88-6',
    'BGWJTLLALYACOG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='isoparathion'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'etrimfos',
    'C<sub>10</sub>H<sub>17</sub>N<sub>2</sub>O<sub>4</sub>PS',
    '',
    '38260-54-7',
    'FGIWFCGDPUIBEZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='etrimfos'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propetamphos',
    'C<sub>10</sub>H<sub>20</sub>NO<sub>4</sub>PS',
    '',
    '31218-83-4',
    'BZNDWPRGXNILMS-VQHVLOKHSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='propetamphos'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'mecarbam',
    'C<sub>10</sub>H<sub>20</sub>NO<sub>5</sub>PS<sub>2</sub>',
    '',
    '2595-54-2',
    'KLGMSAOQDHLCOS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='mecarbam'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phosmet',
    'C<sub>11</sub>H<sub>12</sub>NO<sub>4</sub>PS<sub>2</sub>',
    '',
    '732-11-6',
    'LMNZTLDVJIUSHT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='phosmet'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='phosmet'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='phosmet'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='phosmet'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phosmet'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='phosmet'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pirimiphos methyl',
    'C<sub>11</sub>H<sub>20</sub>N<sub>3</sub>O<sub>3</sub>PS',
    '',
    '29232-93-7',
    'QHOQHJPRIBSPCY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pirimiphos methyl'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pirimiphos methyl'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'imicyafos',
    'C<sub>11</sub>H<sub>21</sub>N<sub>4</sub>O<sub>2</sub>PS',
    '',
    '140163-89-9',
    'PPCUNNLZTNMXFO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>9</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='imicyafos'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'Agent VX',
    'C<sub>11</sub>H<sub>26</sub>NO<sub>2</sub>PS',
    '',
    '50782-69-9',
    'JJIUCEJQJXNMHV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.1&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='Agent VX'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='Agent VX'),
    (SELECT id from literature WHERE bibtexkey='3393'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='Agent VX'),
    (SELECT id from literature WHERE bibtexkey='3121'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ditalimfos',
    'C<sub>12</sub>H<sub>14</sub>NO<sub>4</sub>PS',
    '',
    '5131-24-8',
    'MTBZIGHNGSTDJV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ditalimfos'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'quinalphos',
    'C<sub>12</sub>H<sub>15</sub>N<sub>2</sub>O<sub>3</sub>PS',
    '',
    '13593-03-8',
    'JYQUHIFYBATCCY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='quinalphos'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phoxim',
    'C<sub>12</sub>H<sub>15</sub>N<sub>2</sub>O<sub>3</sub>PS',
    '',
    '14816-18-3',
    'ATROHALUCMTWTB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.0&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='phoxim'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'triazophos',
    'C<sub>12</sub>H<sub>16</sub>N<sub>3</sub>O<sub>3</sub>PS',
    '',
    '24017-47-8',
    'AMFGTOFWMRQMEM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='triazophos'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'azinphos-ethyl',
    'C<sub>12</sub>H<sub>16</sub>N<sub>3</sub>O<sub>3</sub>PS<sub>2</sub>',
    '',
    '2642-71-9',
    'RQVGAIADHNPSME-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='azinphos-ethyl'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diazinon',
    'C<sub>12</sub>H<sub>21</sub>N<sub>2</sub>O<sub>3</sub>PS',
    'dimpylate',
    '333-41-5',
    'FHIVAFMUCKRCQO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='diazinon'),
    (SELECT id from literature WHERE bibtexkey='2965'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='diazinon'),
    (SELECT id from literature WHERE bibtexkey='2965'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='LDV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '12000',
    'M',
    (SELECT id from species WHERE iupac='diazinon'),
    (SELECT id from literature WHERE bibtexkey='2818'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='diazinon'),
    (SELECT id from literature WHERE bibtexkey='2538'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='diazinon'),
    (SELECT id from literature WHERE bibtexkey='901'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at296K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='diazinon'),
    (SELECT id from literature WHERE bibtexkey='900'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at296K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diazinon'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diazinon'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.7',
    '',
    'V',
    (SELECT id from species WHERE iupac='diazinon'),
    (SELECT id from literature WHERE bibtexkey='2452'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diazinon'),
    (SELECT id from literature WHERE bibtexkey='2455'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='diazinon'),
    (SELECT id from literature WHERE bibtexkey='2968'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='diazinon'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diazinon'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diazinon'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'isoxathion',
    'C<sub>13</sub>H<sub>16</sub>NO<sub>4</sub>PS',
    '',
    '18854-01-8',
    'SDMSCIWHRZJSRN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isoxathion'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'butamifos',
    'C<sub>13</sub>H<sub>21</sub>N<sub>2</sub>O<sub>4</sub>PS',
    '',
    '36335-67-8',
    'OEYOMNZEMCPTKN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='butamifos'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fenamiphos',
    'C<sub>13</sub>H<sub>22</sub>NO<sub>3</sub>PS',
    '',
    '22224-92-6',
    'ZCJPOPBZHLUFHF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='fenamiphos'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tebupirimfos',
    'C<sub>13</sub>H<sub>23</sub>N<sub>2</sub>O<sub>3</sub>PS',
    '',
    '96182-53-5',
    'AWYOMXWDGWUJHS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='tebupirimfos'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pirimiphos ethyl',
    'C<sub>13</sub>H<sub>24</sub>N<sub>3</sub>O<sub>3</sub>PS',
    '',
    '23505-41-1',
    'TZBPRYIIJAJUOY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pirimiphos ethyl'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bensulide',
    'C<sub>14</sub>H<sub>24</sub>NO<sub>4</sub>PS<sub>3</sub>',
    '',
    '741-58-2',
    'RRNIZKPFKNDSRS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bensulide'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyl p-nitrophenyl benzenethiophosphonate',
    'C<sub>14</sub>H<sub>14</sub>NO<sub>4</sub>PS',
    '',
    '2104-64-5',
    'AIGRXSNSLVJMEA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl p-nitrophenyl benzenethiophosphonate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ethyl p-nitrophenyl benzenethiophosphonate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyl p-nitrophenyl benzenethiophosphonate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pyridaphenthion',
    'C<sub>14</sub>H<sub>17</sub>N<sub>2</sub>O<sub>4</sub>PS',
    '',
    '119-12-0',
    'CXJSOEPQXUCJSA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pyridaphenthion'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'piperophos',
    'C<sub>14</sub>H<sub>28</sub>NO<sub>3</sub>PS<sub>2</sub>',
    '',
    '24151-93-7',
    'UNLYSVIDNRIVFJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='piperophos'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'isofenphos',
    'C<sub>15</sub>H<sub>24</sub>NO<sub>4</sub>PS',
    '',
    '25311-71-1',
    'HOQADATXFBOEGG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='isofenphos'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>2</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='isofenphos'),
    (SELECT id from literature WHERE bibtexkey='macbean2012'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='isofenphos'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='isofenphos'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='isofenphos'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chlormephos',
    'C<sub>5</sub>H<sub>12</sub>ClO<sub>2</sub>PS<sub>2</sub>',
    '',
    '24934-91-6',
    'QGTYWWGEWOBMAK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chlormephos'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chlormephos'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlormephos'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chlorethoxyfos',
    'C<sub>6</sub>H<sub>11</sub>Cl<sub>4</sub>O<sub>3</sub>PS',
    '',
    '54593-83-8',
    'XFDJMIHUAHSGKG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorethoxyfos'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ronnel',
    'C<sub>8</sub>H<sub>8</sub>O<sub>3</sub>Cl<sub>3</sub>PS',
    '',
    '299-84-3',
    'JHJOOSLFWRRSGU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.8&times;10<sup>&#8722;1</sup>',
    '',
    'L',
    (SELECT id from species WHERE iupac='ronnel'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ronnel'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ronnel'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ronnel'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tolclofos-methyl',
    'C<sub>9</sub>H<sub>11</sub>Cl<sub>2</sub>O<sub>3</sub>PS',
    '',
    '57018-04-9',
    'OBZIQQJJIKNWNO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tolclofos-methyl'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7',
    '',
    '?',
    (SELECT id from species WHERE iupac='tolclofos-methyl'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyl trithion',
    'C<sub>9</sub>H<sub>12</sub>ClO<sub>2</sub>PS<sub>3</sub>',
    '',
    '953-17-3',
    'OUCCVXVYGFBXSV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methyl trithion'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'trichloronate',
    'C<sub>10</sub>H<sub>12</sub>Cl<sub>3</sub>O<sub>2</sub>PS',
    '',
    '327-98-0',
    'ANIAQSUBRGXWLS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='trichloronate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='trichloronate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trichloronate'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='trichloronate'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dichlofenthion',
    'C<sub>10</sub>H<sub>13</sub>Cl<sub>2</sub>O<sub>3</sub>PS',
    '',
    '97-17-6',
    'WGOWCPGHOCIHBW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dichlofenthion'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dichlofenthion'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dichlofenthion'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dichlofenthion'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichlofenthion'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'prothiofos',
    'C<sub>11</sub>H<sub>15</sub>Cl<sub>2</sub>O<sub>2</sub>PS<sub>2</sub>',
    '',
    '34643-46-4',
    'FITIWKDOCAUBQD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='prothiofos'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chlorthiophos',
    'C<sub>11</sub>H<sub>15</sub>Cl<sub>2</sub>O<sub>3</sub>PS<sub>2</sub>',
    '',
    '21923-23-9',
    'JAZJVWLGNLCNDD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorthiophos'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'carbophenothion',
    'C<sub>11</sub>H<sub>16</sub>ClO<sub>2</sub>PS<sub>3</sub>',
    '',
    '786-19-6',
    'VEDTXTNSFWUXGQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='carbophenothion'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='carbophenothion'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'coumaphos',
    'C<sub>14</sub>H<sub>16</sub>ClO<sub>5</sub>PS',
    '',
    '56-72-4',
    'BXNANOICGRISHX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='coumaphos'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methylchlorpyrifos',
    'C<sub>7</sub>H<sub>7</sub>NO<sub>3</sub>Cl<sub>3</sub>PS',
    '',
    '5598-13-0',
    'HRBKVYFZANMGRE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='methylchlorpyrifos'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'V',
    (SELECT id from species WHERE iupac='methylchlorpyrifos'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9',
    '',
    'V',
    (SELECT id from species WHERE iupac='methylchlorpyrifos'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3',
    '',
    'V',
    (SELECT id from species WHERE iupac='methylchlorpyrifos'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='methylchlorpyrifos'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3',
    '',
    '?',
    (SELECT id from species WHERE iupac='methylchlorpyrifos'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dicapthon',
    'C<sub>8</sub>H<sub>9</sub>NO<sub>5</sub>ClPS',
    '',
    '2463-84-5',
    'OTKXWJHPGBRXCR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dicapthon'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dicapthon'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dicapthon'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dicapthon'),
    (SELECT id from literature WHERE bibtexkey='479'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dicapthon'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chlorthion',
    'C<sub>8</sub>H<sub>9</sub>ClNO<sub>5</sub>PS',
    '',
    '500-28-7',
    'NZNRRXXETLSZRO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chlorthion'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chlorthion'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'azamethiphos',
    'C<sub>9</sub>H<sub>10</sub>ClN<sub>2</sub>O<sub>5</sub>PS',
    '',
    '35575-96-3',
    'VNKBTWQZTQIWDV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='azamethiphos'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'isazophos',
    'C<sub>9</sub>H<sub>17</sub>ClN<sub>3</sub>O<sub>3</sub>PS',
    '',
    '42509-80-8',
    'XRHGWAGWAHHFLF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='isazophos'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='isazophos'),
    (SELECT id from literature WHERE bibtexkey='2968'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.2&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='isazophos'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chlorpyrifos',
    'C<sub>9</sub>H<sub>11</sub>Cl<sub>3</sub>NO<sub>3</sub>PS',
    '',
    '2921-88-2',
    'SBPBAQFWLVIOKP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8',
    '',
    'L',
    (SELECT id from species WHERE iupac='chlorpyrifos'),
    (SELECT id from literature WHERE bibtexkey='2965'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='FAV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    'L',
    (SELECT id from species WHERE iupac='chlorpyrifos'),
    (SELECT id from literature WHERE bibtexkey='2965'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='LDV'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '7800',
    'M',
    (SELECT id from species WHERE iupac='chlorpyrifos'),
    (SELECT id from literature WHERE bibtexkey='2814'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '',
    'M',
    (SELECT id from species WHERE iupac='chlorpyrifos'),
    (SELECT id from literature WHERE bibtexkey='893'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4',
    '',
    'M',
    (SELECT id from species WHERE iupac='chlorpyrifos'),
    (SELECT id from literature WHERE bibtexkey='1144'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chlorpyrifos'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7',
    '',
    'V',
    (SELECT id from species WHERE iupac='chlorpyrifos'),
    (SELECT id from literature WHERE bibtexkey='2967'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chlorpyrifos'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chlorpyrifos'),
    (SELECT id from literature WHERE bibtexkey='2452'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='chlorpyrifos'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4',
    '',
    'C',
    (SELECT id from species WHERE iupac='chlorpyrifos'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4',
    '',
    'C',
    (SELECT id from species WHERE iupac='chlorpyrifos'),
    (SELECT id from literature WHERE bibtexkey='3073'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorpyrifos'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorpyrifos'),
    (SELECT id from literature WHERE bibtexkey='2521'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='chlorpyrifos'),
    (SELECT id from literature WHERE bibtexkey='1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1',
    '',
    '?',
    (SELECT id from species WHERE iupac='chlorpyrifos'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chlorphoxim',
    'C<sub>12</sub>H<sub>14</sub>ClN<sub>2</sub>O<sub>3</sub>PS',
    '',
    '14816-20-7',
    'GQKRUMZWUHSLJF-NTCAYCPXSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 2.3&times;10<sup>10</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chlorphoxim'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phosazetim',
    'C<sub>14</sub>H<sub>11</sub>Cl<sub>2</sub>N<sub>2</sub>O<sub>4</sub>PS',
    '',
    '4104-14-7',
    'XIBXUAZIZXDFTG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phosazetim'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dialifor',
    'C<sub>14</sub>H<sub>17</sub>ClNO<sub>4</sub>PS<sub>2</sub>',
    '',
    '10311-84-9',
    'MUMQYXACQUZOFP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dialifor'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='dialifor'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1',
    '',
    'V',
    (SELECT id from species WHERE iupac='dialifor'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pyraclofos',
    'C<sub>14</sub>H<sub>18</sub>ClN<sub>2</sub>O<sub>3</sub>PS',
    '',
    '77458-01-6',
    'QHGVXILFMXYDRS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='pyraclofos'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bromophos',
    'C<sub>8</sub>H<sub>8</sub>BrCl<sub>2</sub>O<sub>3</sub>PS',
    '',
    '2104-96-3',
    'NYQDCVLCJXRDSK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='bromophos'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='bromophos'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bromophos-ethyl',
    'C<sub>10</sub>H<sub>12</sub>BrCl<sub>2</sub>O<sub>3</sub>PS',
    '',
    '4824-78-6',
    'KWGUFOITWDSNQY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='bromophos-ethyl'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'profenofos',
    'C<sub>11</sub>H<sub>15</sub>BrClO<sub>3</sub>PS',
    '',
    '41198-08-7',
    'QYMMJNLHFKGANY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='profenofos'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.2&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='profenofos'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'iodofenphos',
    'C<sub>8</sub>H<sub>8</sub>Cl<sub>2</sub>IO<sub>3</sub>PS',
    '',
    '18181-70-9',
    'LFVLUOAHQIVABZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Phosphorus (C, H, O, N, Cl, Br, S, P)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2',
    '',
    'V',
    (SELECT id from species WHERE iupac='iodofenphos'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 2.3&times;10<sup>10</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='iodofenphos'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO categories (catname) VALUES (
    'Organic species with other elements');
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Sodium (Na)',
    (SELECT id from categories WHERE catname='Organic species with other elements'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'sesone',
    'C<sub>8</sub>H<sub>7</sub>Cl<sub>2</sub>NaO<sub>5</sub>S',
    '2,4-dichlorophenoxyethyl sulfate',
    '136-78-7',
    'KISFEBPWFCGRGN-UHFFFAOYSA-M',
    (SELECT id from subcategories WHERE subcatname='Sodium (Na)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='sesone'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'iodosulfuron-methyl-sodium',
    'C<sub>14</sub>H<sub>14</sub>IN<sub>5</sub>O<sub>6</sub>SNa',
    '',
    '144550-36-7',
    'JUJFQMPKBJPSFZ-UHFFFAOYSA-M',
    (SELECT id from subcategories WHERE subcatname='Sodium (Na)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>10</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='iodosulfuron-methyl-sodium'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'propoxycarbazone-sodium',
    'C<sub>15</sub>H<sub>17</sub>N<sub>4</sub>O<sub>7</sub>NaS',
    '',
    '181274-15-7',
    'JRQGDDUXDKCWRF-UHFFFAOYSA-M',
    (SELECT id from subcategories WHERE subcatname='Sodium (Na)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 1.0&times;10<sup>10</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='propoxycarbazone-sodium'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dioctyl sulfosuccinatesodium salt',
    'C<sub>20</sub>H<sub>37</sub>NaO<sub>7</sub>S',
    'bis(2-ethylhexyl) sodium sulfosuccinate',
    '577-11-7',
    'APSBXTVYXVQYAB-UHFFFAOYSA-M',
    (SELECT id from subcategories WHERE subcatname='Sodium (Na)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dioctyl sulfosuccinatesodium salt'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dodecylbenzenesulfonic acid sodium salt',
    'C<sub>18</sub>H<sub>29</sub>NaO<sub>3</sub>S',
    'sodium dodecylbenzenesulfonate',
    '25155-30-0',
    'BWUAQXVVJWAXHR-UHFFFAOYSA-M',
    (SELECT id from subcategories WHERE subcatname='Sodium (Na)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dodecylbenzenesulfonic acid sodium salt'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'D&amp;C yellow 10',
    'C<sub>20</sub>H<sub>17</sub>NO<sub>8</sub>Na<sub>2</sub>S<sub>2</sub>',
    '',
    '8004-92-0',
    'NYMFWSWVZMTZQO-UHFFFAOYSA-L',
    (SELECT id from subcategories WHERE subcatname='Sodium (Na)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>14</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D&amp;C yellow 10'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'D&amp;C yellow 8',
    'C<sub>20</sub>H<sub>10</sub>Na<sub>2</sub>O<sub>5</sub>',
    'fluorescein sodium',
    '518-47-8',
    'NJDNXYGOVLYJHP-UHFFFAOYSA-L',
    (SELECT id from subcategories WHERE subcatname='Sodium (Na)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.5&times;10<sup>10</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D&amp;C yellow 8'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'D&amp;C black 1',
    'C<sub>22</sub>H<sub>14</sub>N<sub>6</sub>Na<sub>2</sub>O<sub>9</sub>S<sub>2</sub>',
    'amido black 10B',
    '1064-48-8',
    'HKBVRFLHNUEVRO-DWTBGCDMSA-L',
    (SELECT id from subcategories WHERE subcatname='Sodium (Na)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.2&times;10<sup>25</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D&amp;C black 1'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'D&amp;C green 5',
    'C<sub>28</sub>H<sub>20</sub>N<sub>2</sub>Na<sub>2</sub>O<sub>8</sub>S<sub>2</sub>',
    '',
    '4403-90-1',
    'FPAYXBWMYIMERV-UHFFFAOYSA-L',
    (SELECT id from subcategories WHERE subcatname='Sodium (Na)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>23</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D&amp;C green 5'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'FD&amp;C green 2',
    'C<sub>37</sub>H<sub>34</sub>N<sub>2</sub>Na<sub>2</sub>O<sub>9</sub>S3',
    '',
    '5141-20-8',
    'DGOBMKYRQHEFGQ-UHFFFAOYSA-L',
    (SELECT id from subcategories WHERE subcatname='Sodium (Na)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>30</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='FD&amp;C green 2'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-EPI-Suite'));
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Aluminum (Al)',
    (SELECT id from categories WHERE catname='Organic species with other elements'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fosetyl-aluminum',
    'C<sub>6</sub>H<sub>18</sub>AlO<sub>9</sub>P<sub>3</sub>',
    '',
    '39148-24-8',
    'ZKZMJOFIHHZSRW-UHFFFAOYSA-K',
    (SELECT id from subcategories WHERE subcatname='Aluminum (Al)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>9</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='fosetyl-aluminum'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 3.1&times;10<sup>9</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fosetyl-aluminum'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Silicon (Si)',
    (SELECT id from categories WHERE catname='Organic species with other elements'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tetramethylsilane',
    'C<sub>4</sub>H<sub>12</sub>Si',
    '',
    '75-76-3',
    'CZDYPVPMEAXLPK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tetramethylsilane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tetramethylsilane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetramethylsilane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tetramethylsilane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tetraethylsilane',
    'C<sub>8</sub>H<sub>20</sub>Si',
    '',
    '631-36-7',
    'VCZQFJFZMMALHB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tetraethylsilane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'trimethylsilanol',
    '(CH<sub>3</sub>)<sub>3</sub>SiOH',
    'TMS',
    '1066-40-6',
    'AAPLIUHOKVUFCC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;2</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='trimethylsilanol'),
    (SELECT id from literature WHERE bibtexkey='3094'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='trimethylsilanol'),
    (SELECT id from literature WHERE bibtexkey='3095'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'silicic acid',
    'Si(OH)<sub>4</sub>',
    '',
    '10193-36-9',
    'RMAQACBXLXPBSY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>10</sup>',
    '14000',
    'M',
    (SELECT id from species WHERE iupac='silicic acid'),
    (SELECT id from literature WHERE bibtexkey='3015'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3015',
    '', 'Extrapolated from data at elevated temperatures.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3015'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimethylsilanediol',
    'C<sub>2</sub>H<sub>8</sub>O<sub>2</sub>Si',
    '',
    '1066-42-8',
    'XCLIHDJZGPCUBT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>3</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dimethylsilanediol'),
    (SELECT id from literature WHERE bibtexkey='3096'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dimethylsilanediol'),
    (SELECT id from literature WHERE bibtexkey='3095'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tetramethyl silicate',
    'C<sub>4</sub>H<sub>12</sub>O<sub>4</sub>Si',
    '',
    '681-84-5',
    'LFQCEHFDDXELDD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetramethyl silicate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pentamethyldisiloxanol',
    'C<sub>5</sub>H<sub>16</sub>O<sub>2</sub>Si<sub>2</sub>',
    '',
    '56428-93-4',
    'FGOLZCPMTWJPOU-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pentamethyldisiloxanol'),
    (SELECT id from literature WHERE bibtexkey='3095'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tetraethyl silicate',
    'C<sub>8</sub>H<sub>20</sub>O<sub>4</sub>Si',
    '',
    '78-10-4',
    'BOTDANWDWHJENH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetraethyl silicate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'trimethoxysilylpropyl methacrylate',
    'C<sub>10</sub>H<sub>20</sub>O<sub>5</sub>Si',
    '',
    '2530-85-0',
    'XDLMVUHYZWKMMD-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='trimethoxysilylpropyl methacrylate'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hexamethyldisiloxane',
    'C<sub>6</sub>H<sub>18</sub>OSi<sub>2</sub>',
    'L2',
    '107-46-0',
    'UQEAIHBTYFGYIE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='hexamethyldisiloxane'),
    (SELECT id from literature WHERE bibtexkey='3094'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='hexamethyldisiloxane'),
    (SELECT id from literature WHERE bibtexkey='3081'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at300K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3081VEL'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='hexamethyldisiloxane'),
    (SELECT id from literature WHERE bibtexkey='3081'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at300K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3081HS'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.7&times;10<sup>&#8722;7</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='hexamethyldisiloxane'),
    (SELECT id from literature WHERE bibtexkey='1573'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at296K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexamethyldisiloxane'),
    (SELECT id from literature WHERE bibtexkey='3094'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexamethyldisiloxane'),
    (SELECT id from literature WHERE bibtexkey='3081'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexamethyldisiloxane'),
    (SELECT id from literature WHERE bibtexkey='3095'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexamethyldisiloxane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexamethyldisiloxane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='hexamethyldisiloxane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'octamethyltrisiloxane',
    'C<sub>8</sub>H<sub>24</sub>O<sub>2</sub>Si<sub>3</sub>',
    'L3',
    '107-51-7',
    'CXQXSVUQTKDNFP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;7</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='octamethyltrisiloxane'),
    (SELECT id from literature WHERE bibtexkey='3094'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;6</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='octamethyltrisiloxane'),
    (SELECT id from literature WHERE bibtexkey='3081'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at300K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3081VEL'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;6</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='octamethyltrisiloxane'),
    (SELECT id from literature WHERE bibtexkey='3081'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at300K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3081HS'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;7</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='octamethyltrisiloxane'),
    (SELECT id from literature WHERE bibtexkey='3094'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;7</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='octamethyltrisiloxane'),
    (SELECT id from literature WHERE bibtexkey='3081'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='octamethyltrisiloxane'),
    (SELECT id from literature WHERE bibtexkey='3095'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octamethyltrisiloxane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octamethyltrisiloxane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='octamethyltrisiloxane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'decamethyltetrasiloxane',
    'C<sub>10</sub>H<sub>30</sub>O<sub>3</sub>Si<sub>4</sub>',
    'L4',
    '141-62-8',
    'YFCGDEUVHLPRCZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;7</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='decamethyltetrasiloxane'),
    (SELECT id from literature WHERE bibtexkey='3094'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;7</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='decamethyltetrasiloxane'),
    (SELECT id from literature WHERE bibtexkey='3081'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at300K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3081VEL'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;7</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='decamethyltetrasiloxane'),
    (SELECT id from literature WHERE bibtexkey='3094'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;7</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='decamethyltetrasiloxane'),
    (SELECT id from literature WHERE bibtexkey='3081'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;7</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='decamethyltetrasiloxane'),
    (SELECT id from literature WHERE bibtexkey='3095'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.1&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decamethyltetrasiloxane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decamethyltetrasiloxane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_val'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='decamethyltetrasiloxane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dodecamethylpentasiloxane',
    'C<sub>12</sub>H<sub>36</sub>O<sub>4</sub>Si<sub>5</sub>',
    'L5',
    '141-63-9',
    'FBZANXDWQAVSTQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;8</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dodecamethylpentasiloxane'),
    (SELECT id from literature WHERE bibtexkey='3095'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'silthiofam',
    'C<sub>13</sub>H<sub>21</sub>NOSSi',
    '',
    '175217-20-6',
    'MXMXHPPIGKYTAR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9',
    '',
    '?',
    (SELECT id from species WHERE iupac='silthiofam'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tetradecamethylhexasiloxane',
    'C<sub>14</sub>H<sub>42</sub>O<sub>5</sub>Si<sub>6</sub>',
    'L6',
    '107-52-8',
    'ADANNTOYRVPQLJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;8</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tetradecamethylhexasiloxane'),
    (SELECT id from literature WHERE bibtexkey='3095'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hexadecamethylheptasiloxane',
    'C<sub>16</sub>H<sub>48</sub>O<sub>6</sub>Si<sub>7</sub>',
    'L7',
    '541-01-5',
    'NFVSFLUJRHRSJG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;9</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexadecamethylheptasiloxane'),
    (SELECT id from literature WHERE bibtexkey='3095'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'octadecamethyloctasiloxane',
    'C<sub>18</sub>H<sub>54</sub>O<sub>7</sub>Si<sub>8</sub>',
    'L8',
    '556-69-4',
    'VWGDPBQTSZDFMX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;9</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='octadecamethyloctasiloxane'),
    (SELECT id from literature WHERE bibtexkey='3095'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hexamethylcyclotrisiloxane',
    'C<sub>6</sub>H<sub>18</sub>O<sub>3</sub>Si<sub>3</sub>',
    'D3',
    '541-05-9',
    'HTDJPCNNEPUOOQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexamethylcyclotrisiloxane'),
    (SELECT id from literature WHERE bibtexkey='3095'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexamethylcyclotrisiloxane'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3676HENRYWIN',
    '', 'Calculated using HENRYWIN 3.21.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexamethylcyclotrisiloxane'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3676HENRYWIN_V',
    '', 'Calculated using vapor pressures and water solubilities from HENRYWIN 3.21.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexamethylcyclotrisiloxane'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '3676TEST',
    '', 'Calculated using vapor pressures and water solubilities from the EPA Toxicity Estimation Software Tool (TEST).');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676TEST'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'octamethylcyclotetrasiloxane',
    'C<sub>8</sub>H<sub>24</sub>O<sub>4</sub>Si<sub>4</sub>',
    'D4',
    '556-67-2',
    'HMMGMWAXVFQUOA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.3&times;10<sup>&#8722;7</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='octamethylcyclotetrasiloxane'),
    (SELECT id from literature WHERE bibtexkey='3094'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;7</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='octamethylcyclotetrasiloxane'),
    (SELECT id from literature WHERE bibtexkey='3096'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;5</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='octamethylcyclotetrasiloxane'),
    (SELECT id from literature WHERE bibtexkey='3081'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at301K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3081VEL'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;5</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='octamethylcyclotetrasiloxane'),
    (SELECT id from literature WHERE bibtexkey='3081'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at301K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3081HS'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='octamethylcyclotetrasiloxane'),
    (SELECT id from literature WHERE bibtexkey='2456'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='octamethylcyclotetrasiloxane'),
    (SELECT id from literature WHERE bibtexkey='3094'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='octamethylcyclotetrasiloxane'),
    (SELECT id from literature WHERE bibtexkey='3081'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;7</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='octamethylcyclotetrasiloxane'),
    (SELECT id from literature WHERE bibtexkey='3095'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='octamethylcyclotetrasiloxane'),
    (SELECT id from literature WHERE bibtexkey='2456'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octamethylcyclotetrasiloxane'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octamethylcyclotetrasiloxane'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octamethylcyclotetrasiloxane'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676TEST'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octamethylcyclotetrasiloxane'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='octamethylcyclotetrasiloxane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='octamethylcyclotetrasiloxane'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'decamethylcyclopentasiloxane',
    'C<sub>10</sub>H<sub>30</sub>O<sub>5</sub>Si<sub>5</sub>',
    'D5',
    '541-02-6',
    'XMSXQFUHVRWGNA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;7</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='decamethylcyclopentasiloxane'),
    (SELECT id from literature WHERE bibtexkey='3094'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>&#8722;7</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='decamethylcyclopentasiloxane'),
    (SELECT id from literature WHERE bibtexkey='3096'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;5</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='decamethylcyclopentasiloxane'),
    (SELECT id from literature WHERE bibtexkey='3081'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at299K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3081VEL'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;5</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='decamethylcyclopentasiloxane'),
    (SELECT id from literature WHERE bibtexkey='3081'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at299K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3081HS'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.4&times;10<sup>&#8722;5</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='decamethylcyclopentasiloxane'),
    (SELECT id from literature WHERE bibtexkey='1573'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at296K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='decamethylcyclopentasiloxane'),
    (SELECT id from literature WHERE bibtexkey='3094'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='decamethylcyclopentasiloxane'),
    (SELECT id from literature WHERE bibtexkey='3081'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='decamethylcyclopentasiloxane'),
    (SELECT id from literature WHERE bibtexkey='3095'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;7</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decamethylcyclopentasiloxane'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decamethylcyclopentasiloxane'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='decamethylcyclopentasiloxane'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676TEST'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dodecamethylcyclohexasiloxane',
    'C<sub>12</sub>H<sub>36</sub>O<sub>6</sub>Si<sub>6</sub>',
    'D6',
    '540-97-6',
    'IUMSDRXLFWAGNT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;7</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dodecamethylcyclohexasiloxane'),
    (SELECT id from literature WHERE bibtexkey='3096'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at297K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;5</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dodecamethylcyclohexasiloxane'),
    (SELECT id from literature WHERE bibtexkey='3081'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at299K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3081VEL'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;4</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='dodecamethylcyclohexasiloxane'),
    (SELECT id from literature WHERE bibtexkey='3081'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at299K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3081HS'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='dodecamethylcyclohexasiloxane'),
    (SELECT id from literature WHERE bibtexkey='3081'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tetramethyldisiloxane-1,3-diol',
    'C<sub>4</sub>H<sub>14</sub>O<sub>3</sub>Si<sub>2</sub>',
    '',
    '1118-15-6',
    'PFEAZKFNWPIFCV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tetramethyldisiloxane-1,3-diol'),
    (SELECT id from literature WHERE bibtexkey='3095'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hexamethyltrisiloxane-1,5-diol',
    'C<sub>6</sub>H<sub>20</sub>O<sub>4</sub>Si<sub>3</sub>',
    '',
    '3663-50-1',
    'XYBQTTAROZGWOZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.4&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexamethyltrisiloxane-1,5-diol'),
    (SELECT id from literature WHERE bibtexkey='3095'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'octamethyltetrasiloxane-1,7-diol',
    'C<sub>8</sub>H<sub>26</sub>O<sub>5</sub>Si<sub>4</sub>',
    '',
    '3081-07-0',
    'VERNMKKMBJGSQB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='octamethyltetrasiloxane-1,7-diol'),
    (SELECT id from literature WHERE bibtexkey='3095'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'pentamethylcyclotrisiloxanol',
    'C<sub>5</sub>H<sub>16</sub>O<sub>4</sub>Si<sub>3</sub>',
    'D3OH',
    '106916-50-1',
    'OGNYSZJXUXVWRE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='pentamethylcyclotrisiloxanol'),
    (SELECT id from literature WHERE bibtexkey='3095'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentamethylcyclotrisiloxanol'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentamethylcyclotrisiloxanol'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='pentamethylcyclotrisiloxanol'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676TEST'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'heptamethylcyclotetrasiloxanol',
    'C<sub>7</sub>H<sub>22</sub>O<sub>5</sub>Si<sub>4</sub>',
    'D4OH',
    '5290-02-8',
    'MLGUQSFCJNMKPT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>&#8722;4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='heptamethylcyclotetrasiloxanol'),
    (SELECT id from literature WHERE bibtexkey='3095'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptamethylcyclotetrasiloxanol'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptamethylcyclotetrasiloxanol'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='heptamethylcyclotetrasiloxanol'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676TEST'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'nonamethylcyclopentasiloxanol',
    'C<sub>9</sub>H<sub>28</sub>O<sub>6</sub>Si<sub>5</sub>',
    'D5OH',
    '5290-04-0',
    'DKTKKERLEMHMHS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='nonamethylcyclopentasiloxanol'),
    (SELECT id from literature WHERE bibtexkey='3095'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonamethylcyclopentasiloxanol'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonamethylcyclopentasiloxanol'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='nonamethylcyclopentasiloxanol'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676TEST'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'D3FormEst',
    'C<sub>6</sub>H<sub>16</sub>O<sub>5</sub>Si<sub>3</sub>',
    '',
    '',
    'TZIXLALHTGGYNZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D3FormEst'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D3FormEst'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D3FormEst'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676TEST'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'D3OHFormEst',
    'C<sub>5</sub>H<sub>14</sub>O<sub>6</sub>Si<sub>3</sub>',
    '',
    '',
    'RMJPVGNUQFKGPC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.4',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D3OHFormEst'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D3OHFormEst'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D3OHFormEst'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676TEST'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'D3Hydroperoxide',
    'C<sub>6</sub>H<sub>18</sub>O<sub>5</sub>Si<sub>3</sub>',
    '',
    '',
    'JKDUHABXPCJOJB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D3Hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D3Hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D3Hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676TEST'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'D3EtherHydroperoxide',
    'C<sub>6</sub>H<sub>18</sub>O<sub>6</sub>Si<sub>3</sub>',
    '',
    '',
    'LHGAYMWHCKTFJV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.4&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D3EtherHydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D3EtherHydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D3EtherHydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676TEST'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'D3FormEst2',
    'C<sub>6</sub>H<sub>14</sub>O<sub>7</sub>Si<sub>3</sub>',
    '',
    '',
    'WKTLUKWDJJZJCN-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D3FormEst2'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D3FormEst2'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D3FormEst2'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676TEST'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'D3OH2O1',
    'C<sub>4</sub>H<sub>14</sub>O<sub>5</sub>Si<sub>3</sub>',
    '',
    '',
    'UGEQNRIYBONGCP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D3OH2O1'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D3OH2O1'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D3OH2O1'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676TEST'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'D4FormEst',
    'C<sub>8</sub>H<sub>22</sub>O<sub>6</sub>Si<sub>4</sub>',
    '',
    '',
    'PWVQOGDRWKITJQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D4FormEst'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D4FormEst'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D4FormEst'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676TEST'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'D4OHFormEst',
    'C<sub>7</sub>H<sub>20</sub>O<sub>7</sub>Si<sub>4</sub>',
    '',
    '',
    'AXBVNNKTZSENOJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D4OHFormEst'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D4OHFormEst'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D4OHFormEst'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676TEST'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1,1,1,3,5,5,5-heptamethyltrisiloxane',
    'C<sub>7</sub>H<sub>22</sub>O<sub>2</sub>Si<sub>3</sub>',
    '',
    '1873-88-7',
    'QNWOFLWXQGHSRH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;7</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='1,1,1,3,5,5,5-heptamethyltrisiloxane'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'D4Hydroperoxide',
    'C<sub>8</sub>H<sub>24</sub>O<sub>6</sub>Si<sub>4</sub>',
    '',
    '',
    'IEOAKTNTPADFJB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D4Hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D4Hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D4Hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676TEST'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'D4EtherHydroperoxide',
    'C<sub>8</sub>H<sub>24</sub>O<sub>7</sub>Si<sub>4</sub>',
    '',
    '',
    'BKBHFCQPJIYNBR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D4EtherHydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D4EtherHydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D4EtherHydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676TEST'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'D4FormEst2',
    'C<sub>8</sub>H<sub>20</sub>O<sub>8</sub>Si<sub>4</sub>',
    '',
    '',
    'WJOJQLFAIHHNFX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D4FormEst2'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D4FormEst2'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D4FormEst2'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676TEST'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'D4OH2',
    'C<sub>6</sub>H<sub>20</sub>O<sub>6</sub>Si<sub>4</sub>',
    '',
    '',
    'ONAQLRRZBYFKLA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D4OH2'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D4OH2'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.3&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D4OH2'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676TEST'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'D5FormEst',
    'C<sub>10</sub>H<sub>28</sub>O<sub>7</sub>Si<sub>5</sub>',
    '',
    '',
    'IGERVNZEGVJPED-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D5FormEst'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D5FormEst'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.4&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D5FormEst'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676TEST'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'glycidoxypropyltrimethoxysilane',
    'C<sub>9</sub>H<sub>20</sub>O<sub>5</sub>Si',
    '',
    '2530-83-8',
    'BPSIOYPQMFLKFR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='glycidoxypropyltrimethoxysilane'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'D5OHFormEst',
    'C<sub>9</sub>H<sub>26</sub>O<sub>8</sub>Si<sub>5</sub>',
    '',
    '',
    'KNIXZSAQQHGMJX-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D5OHFormEst'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D5OHFormEst'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D5OHFormEst'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676TEST'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'D5Hydroperoxide',
    'C<sub>10</sub>H<sub>30</sub>O<sub>7</sub>Si<sub>5</sub>',
    '',
    '',
    'VGMLSGIAATVHBV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D5Hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D5Hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D5Hydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676TEST'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'D5EtherHydroperoxide',
    'C<sub>10</sub>H<sub>30</sub>O<sub>8</sub>Si<sub>5</sub>',
    '',
    '',
    'GSAPDUDDTPAQSH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D5EtherHydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.8&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D5EtherHydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D5EtherHydroperoxide'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676TEST'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'D5FormEst2',
    'C<sub>10</sub>H<sub>26</sub>O<sub>9</sub>Si<sub>5</sub>',
    '',
    '',
    'QFORSIVEJZTNKQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D5FormEst2'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D5FormEst2'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D5FormEst2'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676TEST'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'isobutyltriethoxysilane',
    'C<sub>10</sub>H<sub>24</sub>O<sub>3</sub>Si',
    '',
    '17980-47-1',
    'ALVYUZIFSCKIFP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.5&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='isobutyltriethoxysilane'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methyltris(trimethylsiloxy)silane',
    'C<sub>10</sub>H<sub>30</sub>O<sub>3</sub>Si<sub>4</sub>',
    '',
    '17928-28-8',
    'RGMZNZABJYWAEC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;8</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methyltris(trimethylsiloxy)silane'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'vinyltris(2-methoxyethoxy)silane',
    'C<sub>11</sub>H<sub>24</sub>O<sub>6</sub>Si',
    '',
    '1067-53-4',
    'WOXXJEVNDJOOLV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.9&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='vinyltris(2-methoxyethoxy)silane'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tetrakis(trimethylsiloxy)silane',
    'C<sub>12</sub>H<sub>36</sub>O<sub>4</sub>Si<sub>5</sub>',
    '',
    '3555-47-3',
    'VNRWTCZXQWOWIG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>&#8722;8</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tetrakis(trimethylsiloxy)silane'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-(3,4-epoxycyclohexyl)ethyltriethoxysilane',
    'C<sub>14</sub>H<sub>28</sub>O<sub>4</sub>Si',
    '',
    '10217-34-2',
    'UDUKMRHNZZLJRB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9',
    '',
    '?',
    (SELECT id from species WHERE iupac='2-(3,4-epoxycyclohexyl)ethyltriethoxysilane'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'D5OH2',
    'C<sub>8</sub>H<sub>26</sub>O<sub>7</sub>Si<sub>5</sub>',
    '',
    '',
    'AGIASGIZCMBNMT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.9&times;10<sup>1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D5OH2'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D5OH2'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D5OH2'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676TEST'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hexamethyldisilazane',
    'C<sub>6</sub>H<sub>19</sub>NSi<sub>2</sub>',
    '',
    '999-97-3',
    'FFUAGWLWBBFQJT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='hexamethyldisilazane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'D3Organonitrate',
    'C<sub>6</sub>H<sub>17</sub>NO<sub>6</sub>Si<sub>3</sub>',
    '',
    '',
    'WGZJMUDCTAXYSF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D3Organonitrate'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D3Organonitrate'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D3Organonitrate'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676TEST'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'D3EtherOrganonitrate',
    'C<sub>6</sub>H<sub>17</sub>NO<sub>7</sub>Si<sub>3</sub>',
    '',
    '',
    'CJWFNCZCCFYEKP-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D3EtherOrganonitrate'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.7&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D3EtherOrganonitrate'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D3EtherOrganonitrate'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676TEST'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'D4Organonitrate',
    'C<sub>8</sub>H<sub>23</sub>NO<sub>7</sub>Si<sub>4</sub>',
    '',
    '',
    'CYMCLGYPZZKOOI-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D4Organonitrate'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D4Organonitrate'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.5&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D4Organonitrate'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676TEST'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'D4EtherOrganonitrate',
    'C<sub>8</sub>H<sub>23</sub>NO<sub>8</sub>Si<sub>4</sub>',
    '',
    '',
    'XHFUWVKWVPBCDO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.4&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D4EtherOrganonitrate'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D4EtherOrganonitrate'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D4EtherOrganonitrate'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676TEST'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(3-aminopropyl)triethoxysilane',
    'C<sub>9</sub>H<sub>23</sub>NO<sub>3</sub>Si',
    '',
    '919-30-2',
    'WYTZZXDRDKSJID-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='(3-aminopropyl)triethoxysilane'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'D5Organonitrate',
    'C<sub>10</sub>H<sub>29</sub>NO<sub>8</sub>Si<sub>5</sub>',
    '',
    '',
    'KWHVDACCYNMOAR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.7&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D5Organonitrate'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D5Organonitrate'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D5Organonitrate'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676TEST'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'D5EtherOrganonitrate',
    'C<sub>10</sub>H<sub>29</sub>NO<sub>9</sub>Si<sub>5</sub>',
    '',
    '',
    'BQINUVFPZWRRBW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D5EtherOrganonitrate'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D5EtherOrganonitrate'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676HENRYWIN_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='D5EtherOrganonitrate'),
    (SELECT id from literature WHERE bibtexkey='3676'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3676TEST'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'silafluofen',
    'C<sub>25</sub>H<sub>29</sub>FO<sub>2</sub>Si',
    '',
    '105024-66-6',
    'HPYNBECUCCGGPA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='silafluofen'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'flusilazole',
    'C<sub>16</sub>H<sub>15</sub>F<sub>2</sub>N<sub>3</sub>Si',
    '',
    '85509-19-9',
    'FQKUGOMFVDPBIZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>1</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='flusilazole'),
    (SELECT id from literature WHERE bibtexkey='barcelo97'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3729'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.4&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='flusilazole'),
    (SELECT id from literature WHERE bibtexkey='3729'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_BR'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3729_test'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'simeconazole',
    'C<sub>14</sub>H<sub>20</sub>FN<sub>3</sub>OSi',
    '',
    '149508-90-7',
    'YABFPHSQTSFWQB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.0&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='simeconazole'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dichloromethylsilane',
    'CH<sub>4</sub>Cl<sub>2</sub>Si',
    'methyldichlorosilane',
    '75-54-7',
    'NWKBSEBOBPHMKL-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>&#8722;4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dichloromethylsilane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'etacelasil',
    'C<sub>11</sub>H<sub>25</sub>O<sub>6</sub>ClSi',
    '',
    '37894-46-5',
    'SLZWEMYSYKOWCG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Silicon (Si)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='etacelasil'),
    (SELECT id from literature WHERE bibtexkey='3087'));
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Calcium (Ca)',
    (SELECT id from categories WHERE catname='Organic species with other elements'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'prohexadione-calcium',
    'C<sub>20</sub>H<sub>22</sub>O<sub>10</sub>Ca',
    '',
    '127277-53-6',
    'VQIYODJWCVPJRC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Calcium (Ca)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>4</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='prohexadione-calcium'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='unknownT'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Zinc (Zn)',
    (SELECT id from categories WHERE catname='Organic species with other elements'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'zineb',
    'C<sub>4</sub>H<sub>6</sub>N<sub>2</sub>S<sub>4</sub>Zn',
    '',
    '12122-67-7',
    'AMHNZOICSMBGDH-UHFFFAOYSA-L',
    (SELECT id from subcategories WHERE subcatname='Zinc (Zn)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.7&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='zineb'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 3.7&times;10<sup>3</sup>',
    '',
    'X',
    (SELECT id from species WHERE iupac='zineb'),
    (SELECT id from literature WHERE bibtexkey='macbean2012'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='from3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '&gt; 1.9&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='zineb'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ziram',
    'C<sub>6</sub>H<sub>12</sub>N<sub>2</sub>S<sub>4</sub>Zn',
    '',
    '137-30-4',
    'DUBNHZYBDBBJHD-UHFFFAOYSA-L',
    (SELECT id from subcategories WHERE subcatname='Zinc (Zn)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ziram'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='ziram'),
    (SELECT id from literature WHERE bibtexkey='2614'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ziram'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'mancozeb',
    'C<sub>8</sub>H<sub>12</sub>MnN<sub>4</sub>S<sub>8</sub>Zn',
    '',
    '8018-01-7',
    'CHNQZRKUZPNOOH-UHFFFAOYSA-J',
    (SELECT id from subcategories WHERE subcatname='Zinc (Zn)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='mancozeb'),
    (SELECT id from literature WHERE bibtexkey='3549'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3549'));
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Arsenic (Sn)',
    (SELECT id from categories WHERE catname='Organic species with other elements'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'methylarsine',
    'CH<sub>5</sub>As',
    '',
    '593-52-2',
    'IDDBICIFODFKQO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Arsenic (Sn)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='methylarsine'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethylarsine',
    'C<sub>2</sub>H<sub>7</sub>As',
    '',
    '593-59-9',
    'OSAGMAAQMRQLLW-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Arsenic (Sn)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='ethylarsine'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diethyl arsine',
    'C<sub>4</sub>H<sub>11</sub>As',
    '',
    '692-42-2',
    'JZCIYTSNUPIOMK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Arsenic (Sn)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyl arsine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phenylarsine oxide',
    'C<sub>6</sub>H<sub>5</sub>AsO',
    '',
    '637-03-6',
    'BQVCCPGCDUSGOE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Arsenic (Sn)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='phenylarsine oxide'),
    (SELECT id from literature WHERE bibtexkey='3393'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diphenylarsanylformonitrile',
    'C<sub>13</sub>H<sub>10</sub>AsN',
    '',
    '23525-22-6',
    'BDHNJKLLVSRGDK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Arsenic (Sn)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='diphenylarsanylformonitrile'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dichloro(methyl)arsane',
    'CH<sub>3</sub>AsCl<sub>2</sub>',
    '',
    '593-89-5',
    'VXRMBBLRHSRVDK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Arsenic (Sn)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.1&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dichloro(methyl)arsane'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'lewisite',
    'C<sub>2</sub>H<sub>2</sub>AsCl<sub>3</sub>',
    '',
    '541-25-3',
    'GIKLTQKNOXNBNY-OWOJBTEDSA-N',
    (SELECT id from subcategories WHERE subcatname='Arsenic (Sn)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.5&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='lewisite'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='lewisite'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='lewisite'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7&times;10<sup>&#8722;2</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='lewisite'),
    (SELECT id from literature WHERE bibtexkey='3393'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diphenylchloroarsine',
    'C<sub>12</sub>H<sub>10</sub>AsCl',
    '',
    '712-48-1',
    'YHHKGKCOLGRKKB-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Arsenic (Sn)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='diphenylchloroarsine'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'lewisite oxide',
    'C<sub>2</sub>H<sub>2</sub>AsClO',
    '',
    '3088-37-7',
    'MVCVAGFCWDFQQX-OWOJBTEDSA-N',
    (SELECT id from subcategories WHERE subcatname='Arsenic (Sn)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.2&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='lewisite oxide'),
    (SELECT id from literature WHERE bibtexkey='3393'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phenyldichloroarsine',
    'C<sub>6</sub>H<sub>5</sub>AsCl<sub>2</sub>',
    '',
    '696-28-6',
    'UDHDFEGCOJAVRE-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Arsenic (Sn)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.3&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='phenyldichloroarsine'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'adamsite',
    'C<sub>12</sub>H<sub>9</sub>AsClN',
    '',
    '578-94-9',
    'PBNSPNYJYOYWTA-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Arsenic (Sn)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0&times;10<sup>2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='adamsite'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Selenium (Se)',
    (SELECT id from categories WHERE catname='Organic species with other elements'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimethyl selenide',
    'C<sub>2</sub>H<sub>6</sub>Se',
    '',
    '593-79-3',
    'RVIXKDRPFPUUOO-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Selenium (Se)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;2</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl selenide'),
    (SELECT id from literature WHERE bibtexkey='3730'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.3&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='dimethyl selenide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dimethyl selenide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_exp'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimethyl diselenide',
    'C<sub>2</sub>H<sub>6</sub>Se<sub>2</sub>',
    '',
    '7101-31-7',
    'VLXBWPOEOIIREY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Selenium (Se)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.4&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dimethyl diselenide'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-amino-4-(methylselenyl)butyric acid',
    'C<sub>5</sub>H<sub>11</sub>NO<sub>2</sub>Se',
    'selenium methionine',
    '1464-42-2',
    'RJFAYQIBOAGBLC-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Selenium (Se)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='2-amino-4-(methylselenyl)butyric acid'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Tin (Sn)',
    (SELECT id from categories WHERE catname='Organic species with other elements'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tetramethylstannane',
    'C<sub>4</sub>H<sub>12</sub>Sn',
    'tetramethyltin',
    '594-27-4',
    'VXKWYPOMXBVZSJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Tin (Sn)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.4&times;10<sup>&#8722;6</sup>',
    '3800',
    'M',
    (SELECT id from species WHERE iupac='tetramethylstannane'),
    (SELECT id from literature WHERE bibtexkey='2225'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.7&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tetramethylstannane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tetramethylstannane'),
    (SELECT id from literature WHERE bibtexkey='2226'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tetraethylstannane',
    'C<sub>8</sub>H<sub>20</sub>Sn',
    'tetraethyltin',
    '597-64-8',
    'RWWNQEOPUOCKGR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Tin (Sn)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetraethylstannane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '6.1&times;10<sup>&#8722;6</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tetraethylstannane'),
    (SELECT id from literature WHERE bibtexkey='1500'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.7&times;10<sup>&#8722;6</sup>',
    '6100',
    '?',
    (SELECT id from species WHERE iupac='tetraethylstannane'),
    (SELECT id from literature WHERE bibtexkey='2225'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2225',
    '190,2226', 'Wilhelm et&nbsp;al. (1977) and Abraham (1979) are quoted as the source. However, the data cannot be found there.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2225'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tetraethylstannane'),
    (SELECT id from literature WHERE bibtexkey='2226'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tetrabutylstannane',
    'C<sub>16</sub>H<sub>36</sub>Sn',
    'tetra-butyl tin',
    '1461-25-2',
    'AFCAKJKUYFLYFK-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Tin (Sn)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;6</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='tetrabutylstannane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'triphenyltin hydroxide',
    'C<sub>18</sub>H<sub>16</sub>OSn',
    '',
    '76-87-9',
    'BFWMWWXRWVJXSE-UHFFFAOYSA-M',
    (SELECT id from subcategories WHERE subcatname='Tin (Sn)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.3&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='triphenyltin hydroxide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>&#8722;1</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triphenyltin hydroxide'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hexabutyldistannoxane',
    'C<sub>24</sub>H<sub>54</sub>OSn<sub>2</sub>',
    'bis(tributyltin)oxide',
    '56-35-9',
    'APQHKWPGGHMYKJ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Tin (Sn)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.6&times;10<sup>1</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexabutyldistannoxane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hexakis(2-methyl-2-phenylpropyl)distannoxane',
    'C<sub>60</sub>H<sub>78</sub>OSn<sub>2</sub>',
    'fenbutatin oxide',
    '13356-08-6',
    'HOXINJBQVZWYGZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Tin (Sn)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.9&times;10<sup>3</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='hexakis(2-methyl-2-phenylpropyl)distannoxane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'fentin acetate',
    'C<sub>20</sub>H<sub>18</sub>O<sub>2</sub>Sn',
    '',
    '900-95-8',
    'WDQNIWFZKXZFAY-UHFFFAOYSA-M',
    (SELECT id from subcategories WHERE subcatname='Tin (Sn)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='fentin acetate'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_D1'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '1-(tricyclohexylstannyl)1H-1,2,4-triazole',
    'C<sub>20</sub>H<sub>35</sub>N<sub>3</sub>Sn',
    'azocyclotin',
    '41083-11-8',
    'ONHBDDJJTDTLIR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Tin (Sn)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-(tricyclohexylstannyl)1H-1,2,4-triazole'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '4.6&times;10<sup>6</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='1-(tricyclohexylstannyl)1H-1,2,4-triazole'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2',
    '',
    'Q',
    (SELECT id from species WHERE iupac='1-(tricyclohexylstannyl)1H-1,2,4-triazole'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Mercury (Hg)',
    (SELECT id from categories WHERE catname='Organic species with other elements'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dimethylmercury',
    'C<sub>2</sub>H<sub>6</sub>Hg',
    '',
    '593-74-8',
    'ATZBPOVXVPIOMR-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mercury (Hg)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '2700',
    'M',
    (SELECT id from species WHERE iupac='dimethylmercury'),
    (SELECT id from literature WHERE bibtexkey='2289'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;3</sup>',
    '',
    'C',
    (SELECT id from species WHERE iupac='dimethylmercury'),
    (SELECT id from literature WHERE bibtexkey='2577'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '2700',
    'C',
    (SELECT id from species WHERE iupac='dimethylmercury'),
    (SELECT id from literature WHERE bibtexkey='3070'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '3000',
    'Q',
    (SELECT id from species WHERE iupac='dimethylmercury'),
    (SELECT id from literature WHERE bibtexkey='2577'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2577'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dimethylmercury'),
    (SELECT id from literature WHERE bibtexkey='2171'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;3</sup>',
    '2700',
    '?',
    (SELECT id from species WHERE iupac='dimethylmercury'),
    (SELECT id from literature WHERE bibtexkey='2171'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.1&times;10<sup>&#8722;3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='dimethylmercury'),
    (SELECT id from literature WHERE bibtexkey='2576'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='morethanoneref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diethylmercury',
    'C<sub>4</sub>H<sub>10</sub>Hg',
    '',
    '627-44-1',
    'SPIUPAOJDZNUJH-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mercury (Hg)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.0&times;10<sup>&#8722;3</sup>',
    '3800',
    'Q',
    (SELECT id from species WHERE iupac='diethylmercury'),
    (SELECT id from literature WHERE bibtexkey='2577'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2577'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dipropylmercury',
    'C<sub>6</sub>H<sub>14</sub>Hg',
    '',
    '628-85-3',
    'UZTYYBPPVOXULF-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mercury (Hg)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.6&times;10<sup>&#8722;4</sup>',
    '4600',
    'Q',
    (SELECT id from species WHERE iupac='dipropylmercury'),
    (SELECT id from literature WHERE bibtexkey='2577'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2577'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diisopropylmercury',
    'C<sub>6</sub>H<sub>14</sub>Hg',
    '',
    '1071-39-2',
    'UVUGOJQWNVFTRT-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mercury (Hg)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>&#8722;4</sup>',
    '4600',
    'Q',
    (SELECT id from species WHERE iupac='diisopropylmercury'),
    (SELECT id from literature WHERE bibtexkey='2577'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2577'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'dibutylmercury',
    'C<sub>8</sub>H<sub>18</sub>Hg',
    '',
    '629-35-6',
    'CCYKQVBIPYDCKS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mercury (Hg)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.9&times;10<sup>&#8722;4</sup>',
    '5400',
    'Q',
    (SELECT id from species WHERE iupac='dibutylmercury'),
    (SELECT id from literature WHERE bibtexkey='2577'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2577'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diphenylmercury',
    'C<sub>12</sub>H<sub>10</sub>Hg',
    '',
    '587-85-9',
    'HWMTUNCVVYPZHZ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mercury (Hg)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>2</sup>',
    '8800',
    'Q',
    (SELECT id from species WHERE iupac='diphenylmercury'),
    (SELECT id from literature WHERE bibtexkey='2577'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2577'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'hydroxymethylmercury',
    'CH<sub>3</sub>HgOH',
    '',
    '1184-57-2',
    'KRZWEBVPFGCYMY-UHFFFAOYSA-M',
    (SELECT id from subcategories WHERE subcatname='Mercury (Hg)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.8&times;10<sup>2</sup>',
    '7700',
    'M',
    (SELECT id from species WHERE iupac='hydroxymethylmercury'),
    (SELECT id from literature WHERE bibtexkey='2576'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>3</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='hydroxymethylmercury'),
    (SELECT id from literature WHERE bibtexkey='2285'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2285wrongrefHgCH3OH',
    '2285,2286', 'Shon et&nbsp;al. (2005) refer to Petersen et&nbsp;al. (1998) as the source, but this value cannot be found there.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2285wrongrefHgCH3OH'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'phenyl mercuric ethanoate',
    'C<sub>8</sub>H<sub>8</sub>HgO<sub>2</sub>',
    '',
    '62-38-4',
    'XEBWQGVWTUSTLN-UHFFFAOYSA-M',
    (SELECT id from subcategories WHERE subcatname='Mercury (Hg)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>4</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='phenyl mercuric ethanoate'),
    (SELECT id from literature WHERE bibtexkey='1157'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at293K'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '(3-cyanoguanidino)methylmercury',
    'C<sub>3</sub>H<sub>6</sub>N<sub>4</sub>Hg',
    'methylmercuric dicyanamide',
    '502-39-6',
    'JVJUWCMBRUMDDQ-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Mercury (Hg)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0&times;10<sup>4</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='(3-cyanoguanidino)methylmercury'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chloromethylmercury',
    'CH<sub>3</sub>HgCl',
    '',
    '115-09-3',
    'BABMCXWQNSQAOC-UHFFFAOYSA-M',
    (SELECT id from subcategories WHERE subcatname='Mercury (Hg)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.2&times;10<sup>1</sup>',
    '1800',
    'M',
    (SELECT id from species WHERE iupac='chloromethylmercury'),
    (SELECT id from literature WHERE bibtexkey='2288'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HTdep_r2_lessthan_0.9'));
INSERT INTO notes (notelabel, noterefs, notetext) VALUES (
    '2288',
    '', 'The value from their experiment 7 at 10&nbsp;<sup>&#176;</sup>C is not used in the determination of the temperature dependence because of very different ionic strengths and concentrations for that experiment.');
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2288'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    'M',
    (SELECT id from species WHERE iupac='chloromethylmercury'),
    (SELECT id from literature WHERE bibtexkey='2289'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at295K'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0&times;10<sup>1</sup>',
    '4100',
    'C',
    (SELECT id from species WHERE iupac='chloromethylmercury'),
    (SELECT id from literature WHERE bibtexkey='3070'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='HTdep_r2_lessthan_0.9'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '5300',
    'Q',
    (SELECT id from species WHERE iupac='chloromethylmercury'),
    (SELECT id from literature WHERE bibtexkey='2577'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2577-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.6&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chloromethylmercury'),
    (SELECT id from literature WHERE bibtexkey='2171'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='at288K'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='whichref'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='chloromethylmercury'),
    (SELECT id from literature WHERE bibtexkey='2576'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='morethanoneref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chloroethylmercury',
    'C<sub>2</sub>H<sub>5</sub>HgCl',
    '',
    '107-27-7',
    'QWUGXIXRFGEYBD-UHFFFAOYSA-M',
    (SELECT id from subcategories WHERE subcatname='Mercury (Hg)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.5&times;10<sup>1</sup>',
    '5600',
    'Q',
    (SELECT id from species WHERE iupac='chloroethylmercury'),
    (SELECT id from literature WHERE bibtexkey='2577'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2577'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chloropropylmercury',
    'C<sub>3</sub>H<sub>7</sub>HgCl',
    '',
    '2440-40-6',
    'ZLAYJSKLDWSALK-UHFFFAOYSA-M',
    (SELECT id from subcategories WHERE subcatname='Mercury (Hg)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.2&times;10<sup>1</sup>',
    '5900',
    'Q',
    (SELECT id from species WHERE iupac='chloropropylmercury'),
    (SELECT id from literature WHERE bibtexkey='2577'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2577'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chloroisopropylmercury',
    'C<sub>3</sub>H<sub>7</sub>HgCl',
    '',
    '30615-19-1',
    'YOKZNQICWABELX-UHFFFAOYSA-M',
    (SELECT id from subcategories WHERE subcatname='Mercury (Hg)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.9',
    '6000',
    'Q',
    (SELECT id from species WHERE iupac='chloroisopropylmercury'),
    (SELECT id from literature WHERE bibtexkey='2577'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2577'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chlorobutylmercury',
    'C<sub>4</sub>H<sub>9</sub>HgCl',
    '',
    '543-63-5',
    'OKPMTXZRMGMMOO-UHFFFAOYSA-M',
    (SELECT id from subcategories WHERE subcatname='Mercury (Hg)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '8.8',
    '6300',
    'Q',
    (SELECT id from species WHERE iupac='chlorobutylmercury'),
    (SELECT id from literature WHERE bibtexkey='2577'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2577'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chloropentylmercury',
    'C<sub>5</sub>H<sub>11</sub>HgCl',
    '',
    '544-15-0',
    'UHFZINPMKCNPQL-UHFFFAOYSA-M',
    (SELECT id from subcategories WHERE subcatname='Mercury (Hg)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '7.0',
    '6700',
    'Q',
    (SELECT id from species WHERE iupac='chloropentylmercury'),
    (SELECT id from literature WHERE bibtexkey='2577'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2577'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'chlorophenylmercury',
    'C<sub>6</sub>H<sub>5</sub>HgCl',
    '',
    '100-56-1',
    'AWGTVRDHKJQFAX-UHFFFAOYSA-M',
    (SELECT id from subcategories WHERE subcatname='Mercury (Hg)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.8&times;10<sup>2</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='chlorophenylmercury'),
    (SELECT id from literature WHERE bibtexkey='2577'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.2&times;10<sup>2</sup>',
    '7400',
    'Q',
    (SELECT id from species WHERE iupac='chlorophenylmercury'),
    (SELECT id from literature WHERE bibtexkey='2577'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2577'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    '2-methoxyethylmercury chloride',
    'CH<sub>3</sub>OC<sub>2</sub>H<sub>4</sub>HgCl',
    'aretan',
    '123-88-6',
    'VJTAZCKMHINUKO-UHFFFAOYSA-M',
    (SELECT id from subcategories WHERE subcatname='Mercury (Hg)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.9&times;10<sup>3</sup>',
    '8600',
    'Q',
    (SELECT id from species WHERE iupac='2-methoxyethylmercury chloride'),
    (SELECT id from literature WHERE bibtexkey='2577'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2577'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bromomethylmercury',
    'CH<sub>3</sub>HgBr',
    '',
    '506-83-2',
    'ZDHHIJSLJCLMPX-UHFFFAOYSA-M',
    (SELECT id from subcategories WHERE subcatname='Mercury (Hg)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '',
    '4800',
    'Q',
    (SELECT id from species WHERE iupac='bromomethylmercury'),
    (SELECT id from literature WHERE bibtexkey='2577'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2577-LFER'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.7',
    '',
    '?',
    (SELECT id from species WHERE iupac='bromomethylmercury'),
    (SELECT id from literature WHERE bibtexkey='2576'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='morethanoneref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bromoethylmercury',
    'C<sub>2</sub>H<sub>5</sub>HgBr',
    '',
    '107-26-6',
    'UREACWLAXSOUKG-UHFFFAOYSA-M',
    (SELECT id from subcategories WHERE subcatname='Mercury (Hg)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '3.0',
    '5200',
    'Q',
    (SELECT id from species WHERE iupac='bromoethylmercury'),
    (SELECT id from literature WHERE bibtexkey='2577'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2577'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'bromophenylmercury',
    'C<sub>6</sub>H<sub>5</sub>HgBr',
    '',
    '1192-89-8',
    'PUPHNPSAIJQNEE-UHFFFAOYSA-M',
    (SELECT id from subcategories WHERE subcatname='Mercury (Hg)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.8&times;10<sup>2</sup>',
    '6900',
    'Q',
    (SELECT id from species WHERE iupac='bromophenylmercury'),
    (SELECT id from literature WHERE bibtexkey='2577'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2577'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'iodomethylmercury',
    'CH<sub>3</sub>HgI',
    '',
    '143-36-2',
    'JVDIOYBHEYUIBM-UHFFFAOYSA-M',
    (SELECT id from subcategories WHERE subcatname='Mercury (Hg)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.0',
    '4800',
    'Q',
    (SELECT id from species WHERE iupac='iodomethylmercury'),
    (SELECT id from literature WHERE bibtexkey='2577'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2577'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '5.8&times;10<sup>&#8722;1</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='iodomethylmercury'),
    (SELECT id from literature WHERE bibtexkey='2576'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='morethanoneref'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'iodoethylmercury',
    'C<sub>2</sub>H<sub>5</sub>HgI',
    '',
    '2440-42-8',
    'BYIGJUQTUPMNMF-UHFFFAOYSA-M',
    (SELECT id from subcategories WHERE subcatname='Mercury (Hg)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '5200',
    'Q',
    (SELECT id from species WHERE iupac='iodoethylmercury'),
    (SELECT id from literature WHERE bibtexkey='2577'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2577'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'iodophenylmercury',
    'C<sub>6</sub>H<sub>5</sub>HgI',
    '',
    '823-04-1',
    'BISBXZWWFIOZSX-UHFFFAOYSA-M',
    (SELECT id from subcategories WHERE subcatname='Mercury (Hg)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '9.0&times;10<sup>1</sup>',
    '6700',
    'Q',
    (SELECT id from species WHERE iupac='iodophenylmercury'),
    (SELECT id from literature WHERE bibtexkey='2577'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='2577'));
INSERT INTO subcategories (subcatname, cat_id) VALUES (
    'Lead (Pb)',
    (SELECT id from categories WHERE catname='Organic species with other elements'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tetramethyl lead',
    'C<sub>4</sub>H<sub>12</sub>Pb',
    '',
    '75-74-1',
    'XOOGZRUBTYCLHG-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Lead (Pb)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='tetramethyl lead'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'ethyltrimethylplumbane',
    'C<sub>5</sub>H<sub>14</sub>Pb',
    '',
    '1762-26-1',
    'KHQJREYATBQBHY-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Lead (Pb)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.8&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='ethyltrimethylplumbane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'diethyldimethylplumbane',
    'C<sub>6</sub>H<sub>16</sub>Pb',
    'diethyldimethyl lead',
    '1762-27-2',
    'OLOAJSHVLXNSQV-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Lead (Pb)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='diethyldimethylplumbane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'triethylmethylplumbane',
    'C<sub>7</sub>H<sub>18</sub>Pb',
    'methyltriethyl lead',
    '1762-28-3',
    'KGFRUGHBHNUHOS-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Lead (Pb)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.6&times;10<sup>&#8722;5</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triethylmethylplumbane'),
    (SELECT id from literature WHERE bibtexkey='3088'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3088-1145'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'tetraethyl lead',
    'C<sub>8</sub>H<sub>20</sub>Pb',
    '',
    '78-00-2',
    'MRMOZBOQVYRSEM-UHFFFAOYSA-N',
    (SELECT id from subcategories WHERE subcatname='Lead (Pb)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '6400',
    'M',
    (SELECT id from species WHERE iupac='tetraethyl lead'),
    (SELECT id from literature WHERE bibtexkey='3077'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.3&times;10<sup>&#8722;5</sup>',
    '',
    '?',
    (SELECT id from species WHERE iupac='tetraethyl lead'),
    (SELECT id from literature WHERE bibtexkey='2226'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'trimethyl lead chloride',
    'C<sub>3</sub>H<sub>9</sub>ClPb',
    '',
    '1520-78-1',
    'HPQRSQFZILKRDH-UHFFFAOYSA-M',
    (SELECT id from subcategories WHERE subcatname='Lead (Pb)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.5',
    '',
    '?',
    (SELECT id from species WHERE iupac='trimethyl lead chloride'),
    (SELECT id from literature WHERE bibtexkey='3766'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3766_M2'));
INSERT INTO species (iupac, formula, trivial, casrn, inchikey, subcat_id) VALUES (
    'triethyl lead chloride',
    'C<sub>6</sub>H<sub>15</sub>ClPb',
    '',
    '1067-14-7',
    'UQWYUMLFPUILRT-UHFFFAOYSA-M',
    (SELECT id from subcategories WHERE subcatname='Lead (Pb)'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '2.1&times;10<sup>5</sup>',
    '',
    'V',
    (SELECT id from species WHERE iupac='triethyl lead chloride'),
    (SELECT id from literature WHERE bibtexkey='3586'));
INSERT INTO henry_notes (henry_id, notes_id) VALUES (
    (SELECT CURRVAL('henry_id_seq')),
    (SELECT id from notes WHERE notelabel='3586_V'));
INSERT INTO henry(Hominus, mindHR, htype, species_id, literature_id) VALUES (
    '1.1&times;10<sup>&#8722;3</sup>',
    '',
    'Q',
    (SELECT id from species WHERE iupac='triethyl lead chloride'),
    (SELECT id from literature WHERE bibtexkey='3586'));
